(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)



(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Analyzing the \[Micro]A741 Operational Amplifier", "Subtitle"],

Cell[TextData[{
  "To execute this notebook you need the add-on package ",
  StyleBox["Analog Insydes 2",
    FontWeight->"Bold"],
  " by ITWM (see copyright message at end of document)."
}], "Box"],

Cell[CellGroupData[{

Cell["OP \[Micro]A741", "ExampleSection"],

Cell[TextData[{
  "In this notebook an operational amplifier is analyzed step by step \
according to the symbolic analysis flow as presented in R. Sommer, M. Thole, \
E. Hennig, \[OpenCurlyDoubleQuote]A Generic Circuit Modeling Strategy \
Combining Symbolic and Numeric Analysis\[CloseCurlyDoubleQuote], in ",
  StyleBox[
  "Proc. 5th International Workshop on Symbolic Methods and Applications to \
Circuit Design (SMACD'98)",
    FontSlant->"Italic"],
  ", Kaiserslautern, Oct. 1998. Symbolic analysis is applied to extract a \
symbolic formula which describes the dominant pole of the approximated \
transfer function. ",
  "This executable notebook contains all Analog Insydes commands which were \
used for the derivation of the presented results."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000930001[a000`40O003
h00Oof<HXV<H00Aoof<HHaQ2499S6004OomS66<H@Q08HaP00?l00?l004@0
005S600000=S648@@Q00od8@od8@@48@0@000F<H0000ofLiOomS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS6000ofLiOomS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS6000A6LiOomS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT1HaP00003HaQoofLi0?mS6?mS
63mS605240400052400000EW>GooHaQS67oo0?mS6?mS63eS60524040005S
600000ES67ooHaQS67oo009S6005IcUS66LiHaQW>@20000026<HIcUS66Li
HaQW>F<HIcWo0009000026<HIcUS66LiHaQW>F<HIcVB00001V<HIcUS66Li
HaQW>@AS60524040005S600000IW>GooHaQS67ooIcT6HaP00`00HaQS601l
HaP00`00HaQS6006HaP00`00HaQS603oHaP5HaP00`00HaQS6006HaP00`00
HaQS602>HaP00`00HaQS6004HaP01VLiHaQW>F<H@Q00005oo`0000ES67oo
IcUS67oo009S6003IcUS66<H009S6003001S66<H07aS6006001S66<HIcUS
66Li0f<H00<006<HHaP0of<H1F<H00H006<HHaQW>F<HIcT3HaP00`00HaQS
602>HaP01000HaQS66Li1f<H0D8@0@000F<H00001F<HOomS66<HOol016<H
00AW>F<HHaP0009S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<H
HaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S
6004IcUS66<HIcT2HaP200001F<HIcUS66<HIcT00V<H00AW>F<HHaQW>@9S
6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS
66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2
HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016Li
HaQS66Li0f<H00<006<HHaP01V<H00D006<HHaQS66Li009S6004IcUS66<H
IcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP0
16LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS
66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H
00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<H
HaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S
6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS
66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2
HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016Li
HaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li
0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW
>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW
>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6005
IcUS66<HHaP00008HaP01000HaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS
66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2
HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016Li
HaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li
0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW
>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW
>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004
IcUS66<HIcT3HaP00`00HaQS6002HaP026LiHaQW>F<HIcUS648@0001Ool0
0005HaQoof<HHaQoo`02HaP00fLiHaQS6002HaP00`00HaQS6002HaP016Li
HaQS66Li0V<H10000V<H00AW>F<H0000009S6003IcUS66<H008000=S60@0
00=S6003IcT00000008000=S608000ES6005IcUS66<HIcUS60020002HaP0
0fLi000000020003HaP20002HaP00fLi000000020004HaP40002HaP016Li
HaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li
0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP02FLiHaP006<HIcUS66Li
HaQW>@02HaP01000HaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2
HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016Li
HaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li
0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW
>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW
>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004
IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<H
IcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP0
16LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS
66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H
00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<H
HaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S
6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00aW>F<HHaQW>F<H001S66Li
HaQW>F<HIcT2HaP00`00HaQS6002HaP00fLiHaQS60040002HaP00fLi0000
0002HaP20002HaP20003HaP50002HaP20004HaP016LiHaQS66Li0V<H00AW
>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW
>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004
IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<H
IcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP0
16LiHaQS66Li0V<H00AW>F<HHaQW>@9S6005IcUS6000HaQW>@08HaP1@Q01
0001Ool00006IcUoof<HHaQoofLi16<H00=W>F<H00000V<H00=W>F<HHaP0
16<H0P0000AW>F<H000000=S608000ES6080009S60800004IcUS60000002
HaP2000016LiHaP000000V<H0P0000AS66LiHaQW>@IS6080009S60800004
IcUS60000002HaP20002HaP2000016LiHaP000000V<H0P0000AW>F<H0000
02MS6003001S66<H00IS6003001S66<H0?mS60ES6003001S66<H00IS6004
001S66<HIcT3HaP2000016LiHaP000000V<H0P000V<H0P000V<H0P000V<H
0P0000AW>F<H0000009S6080009S6003IcUS66<H06MS600=001S66<HIcUS
66LiHaQW>F<HIcUS648@00000Goo00001F<HOomS66<HOol00V<H00=W>F<H
IcT00V<H00L006<HHaQS66LiHaQW>@03HaP20002HaP20003HaP20002HaP0
0fLiHaQS6008HaP20002HaP20002HaP20008HaP00fLiHaP000050002HaP2
0002HaP2000:HaP20002HaP20002HaP20002HaP08fLiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT00V<H00H006<HHaQW>F<HIcT3HaP0o`00HaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>@001P00HaQW>F<HIcUS609S6006001S66<HIcUS66Li0f<H00<006<H
HaP00V<H00=W>@00000016<H00<006<HHaP00P000V<H0P000V<H0P000V<H
0P000V<H0P001F<H06QW>F<HHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li0f<H
00<006<HHaP026<H0D8@0@000Goo00001FLiOomS66<HOol01f<H00@006<H
HaQW>@=S6003IcUS66<H00800004IcUS60000004HaP20003HaP01FLiHaQS
66<HIcT016<H0P000V<H0P0000AW>F<H000000IS6004IcUS66<HHaP20000
16LiHaP000000V<H0P0000AW>F<H000000YS6080009S60800006IcUS6000
001S66Li9F<H00<006<HIcT016<H00=W>F<H0000of<H1f<H00<006<HIcT0
16<H00=W>F<H00000V<H00=W>F<HHaP00P001f<H0P000V<H0P000V<H0P00
0V<H0P0000AW>F<H000000MS6003IcUS66<H06=S6006IcUS66<H001S66Li
0V<H00QW>F<HIcUS66LiHaQ240000Goo00003F<HOomS66<HOomS66LiHaQW
>F<HIcUS600000=S6003IcUS66Li00=S6080009S608000AS608000ES6003
IcUS66<H0080009S60800004HaQW>@000002HaP20003HaP00fLiHaQS6002
HaP00fLiHaQS600200000f<H00000002HaP20002HaP20002HaP016LiHaQW
>F<H0P000V<H0P000V<H0P000V<H0P000f<H02EW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaP00003HaP00fLiHaQS6002HaP0o`00HaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>@001P00HaQW>F<HIcUS609S6005001S66<HHaQW>@04HaP00`00HaQS6003
HaP20003HaP016LiHaQS66<H0P0000IS66Li000006<HIcT20002HaP20002
HaP20002HaP00fLiHaQW>@04HaP0HfLiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@04HaP0
1@00HaQS66<HIcT01V<H0D8@0@000Goo00001FLiOomS66<HOol01f<H00@0
06<HHaQW>@IS60D0009S6003IcUS66<H00800004HaQW>F<HIcT4HaP50003
HaP200001VLiHaP00000HaQW>@9S6003IcUS66Li00AS60800005HaP00000
IcUS6002000016LiHaP000001V<H1@0000=S66LiHaP00P0000AW>F<H0000
009S6003IcUS66<H029S6004001S66<HIcT2HaP016LiHaQS6000of<H1f<H
00@006<HHaQW>@9S6007IcUS66<H001W>F<HIcT00V<H0P0000=S66LiHaP0
16<H0P000V<H0P000V<H0P0000IW>F<H000006LiHaP20006HaP0JfLiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H00000V<H00YW>F<HIcUS66Li
HaQW>F<H@Q00005oo`0000ES67ooHaQS67oo009S6003IcUS66Li009S600:
001S66<HHaQW>F<HIcUS66LiHaP20009HaP20004HaP00fLiHaQS60020003
HaP00fLiHaQS60020002HaP20007HaP00fLiHaQS6002HaP40002HaP20002
HaP20002HaP016LiHaQS66<H0P000f<H00=W>F<HHaP00P000V<H0P0016<H
025W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00V<H00<006<HHaP00V<H0?mW>F<H
IcUS6000HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT000eW>F<HIcUS6000HaQW>F<HIcUS66LiHaQW>@04HaP0
1FLiHaQW>F<H00001F<H0P000f<H00AW>F<HIcUS60T0009S6003IcUS6000
00@0009S608000ES601SIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00AS6003001S66<H
00QS60524040005oo`0000MW>GooHaQS67ooHaQW>@05HaP01000IcUS66Li
1V<H0P001V<H00=W>F<HHaP00P000V<H00=W>F<HHaP00V<H0P001V<H0P00
00AW>F<H000000=S6003IcUS66Li00=S6003IcUS66<H00@00006IcUS6000
001W>F<H0P000f<H00=W>F<HHaP00P001V<H0P0000AW>F<H000000=S6003
IcUS66<H025S6005001S66LiHaQW>@04HaP00`00HaQS603oHaP5HaP01@00
HaQW>F<HIcT016<H00<006<HHaP00f<H0P0016<H00<006<HHaP036<H00AW
>F<HHaQS6080009S6080001WIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT0
0V<H00AW>F<HHaP0009S600:IcUS66LiHaQW>F<HIcUS648@0001Ool00005
HaQoof<HHaQoo`03HaP01FLiHaQW>F<H000016<H00=W>F<HIcT00V<H0P00
0V<H0P001V<H0P000f<H00=W>F<HHaP00P001V<H0P000V<H0P000V<H00EW
>F<HHaQS66Li00IS60<0009S6080009S608000IS608000IS6080009S6080
009S600SIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@02HaP00`00HaQS6003
HaP016LiHaQS60000V<H0?mW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00FLi0F<H0f<H00<0
06<HHaP00f<H00AW>F<HHaP0009S6004IcUS66<HHaP20002HaP20005HaP0
0fLiHaQW>@0:HaP20009HaP0HfLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@03HaP00fLi
001S6009HaP1@Q010001Ool00005IcUoof<HHaQoo`02HaP00fLiHaQS6002
HaP01@00HaQS66<HIcT01V<H10000f<H1P0000=S66LiHaP00f<H1P000f<H
10001F<H00MW>F<HHaQS66LiHaQW>@03HaP200000f<HIcUS60040002HaP0
0fLiHaQW>@02HaP60003HaP40004HaP00fLiHaQS600QHaP01P00HaQS66Li
HaQW>@=S6003001S66Li0?mS609S6004IcUS66<H0003HaP00fLiHaQS6002
HaP00`00HaQW>@05HaP4000=HaP00fLiHaQS6003HaP200000f<HIcUS6003
HaP0HfLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>@04HaP016LiHaQS60000V<H00YW>F<H
IcUS66LiHaQW>F<H@Q00005oo`0000ES67ooHaQS67oo00AS6004IcUS66<H
0002HaP01FLiHaQW>F<HIcT026<H00=W>F<HHaP026<H00=W>F<HHaP03f<H
00EW>F<HIcUS66Li01mS6003IcUS66<H00ES600WIcUS66<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@0000ES6004IcUS66<H0003HaP0ofLiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>@04HaP02P00HaQS66LiHaQW>F<HIcUS60000f<H00=W>F<HHaP0
1f<H00=W>F<HHaP016<H00=W>F<HHaP00f<H00=W>F<HHaP01V<H00=W>F<H
HaP00f<H06=W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT016<H00<006<HHaP026<H0D8@
0@000Goo00001FLiOomS66<HOol00V<H00=W>F<HHaP00V<H00<006<HHaP0
1V<H00=W>F<HHaP01F<H00=W>F<HHaP01F<H00AW>F<HHaQW>@QS6003IcUS
66<H00QS6009IcUS66LiHaQW>F<HIcUS66Li00eS6003IcUS66Li00IS6003
IcUS66<H00US6003IcUS66<H025S6006001S66<HIcUS66Li0f<H0?l006<H
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaP000/006<HHaQW>F<HIcUS66LiHaQW>F<H00IS6003001S
66Li00=S6003IcUS66<H00IS6005IcUS66LiHaQW>@03HaP00fLiHaQW>@03
HaP00fLiHaQS6005HaP0IFLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT016<H00AW
>F<HHaP0009S600:IcUS66LiHaQW>F<HIcUS648@0001Ool00005HaQoof<H
HaQoo`03HaP02fLiHaQW>F<H001S66LiHaQW>F<HIcT016<H00AW>F<HHaQW
>@AS6004IcUS66<HIcT7HaP01VLiHaQS66LiHaQW>@=S6008IcUS66<HIcUS
66LiHaQW>@9S6003IcUS66<H00IS6003IcUS66Li009S6005IcUS66<HHaQW
>@05HaP00fLiHaQW>@05HaP026LiHaQS66LiHaQW>F<HIcT4HaP07fLiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66Li00=S6003001S66<H00=S6004IcUS66Li0005HaP0oFLi
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66Li00AS6007001S66<HHaQW>F<HIcT00V<H00D006<HHaQS66Li
00=S6004IcUS66<HIcT8HaP00fLiHaQS6003HaP01FLiHaQS66<HIcT00V<H
00=W>F<HIcT01V<H06=W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00f<H00=W>@00HaP0
2F<H0D8@0@000Goo00001fLiOomS66<HOomS66Li00ES68000004HaQW>F<H
IcT4HaSo00090002HaP00fLiHaQS6003HaRB0002HaP02VLiHaQW>F<HIcUS
66LiHaQ240000Goo00001F<HOomS66<HOol00f<H00=W>F<HHaP0QF<H00=W
>F<HIcT0of<H3V<H00=W>F<HHaP0WF<H0D8@0@000Goo00001fLiOomS66<H
OomS66Li00=S6003IcUS66<H081S6003IcUS66Li0?mS60iS6003IcUS66Li
009S6003IcUS66<H09=S600:IcUS66LiHaQW>F<HIcUS648@0001Ool00004
HaQoof<HHaSoOoooOollOol2HaP1@Q010001Ool00004IcUoof<HHaSo003o
000l0002HaP1@Q010001Ool00004HaQoofLiHaP@0000?F<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<H0100003oOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo002n
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaP@000?HaP01FLiHaQS648@00000Goo0000
0fLiOomS6002HaP>@Q00?`00OomW>GooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS600>@Q00o`00HaQoof<HOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoo`00_P00HaQoof<HOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<H0V<H3T8@00`006LiHaQW>F<HIcUS66LiHaQW>F<HIcT7HaP1@Q01
0001Ool00003HaQoof<H009S601;OomW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQ24000HaQoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo009S603oOomW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQ24000OomW>GooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLi003MOomW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQ24000
OomW>GooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS600@HaP016LiHaQ240000Goo00000fLiOomS6002HaP00gooHaQS
6009HaP0@VLi@Q0007ooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
IcUoo`]S603oIcU24000HaQoof<HOomW>GooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67oo0030IcU24000HaQoof<HOomW>Goo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<H0V<H00=oof<HHaP02F<H00=W>D8@000036<H00=W>F<HIcT00f<H
0D8@0@000Goo00000f<HOomS6002HaP00gooHaQS600:HaP0?T8@001S67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOol2HaP00gooHaQS600:HaP0od8@
001oofLiOomS67ooHaQoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoo`00`T8@001oofLiOomS67ooHaQoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaP<
HaP00d8@001S6002HaP01fLiHaQW>F<HIcUS66Li00ES6005IcUS66<H@Q00
0001Ool00003IcUoof<H009S6003OomS66<H009S6006IcUS6000IcUS66Li
0V<H04524000OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
00=S6007IcUS66LiHaQW>F<HIcT00V<H0?m24000HaQoofLiOomS67ooIcUo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaP00<92
4000HaQoofLiOomS67ooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67oo16<H00H006LiHaQW>F<HIcT2
HaP0148@001S66Li26<H00YW>F<HIcUS66LiHaQW>F<H@Q00005oo`0000=S
67ooIcT00V<H00Ioof<HIcUS66LiHaP20004HaP0@VLi@Q0006<HOomW>Goo
HaQoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiHaQoo`9S6003IcUS66<H00IS603o
IcU24000OomW>GooHaQoof<HOomS67ooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLi0035IcU24000OomW>GooHaQoof<HOomS67ooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS6002HaP20005HaP00fLi@Q000003HaP00fLiHaQW>@02HaP00fLi
HaQS6004HaP01FLiHaQW>D8@00000Goo00000fLiOomS6002HaP00gooHaQS
6002HaP30002HaP0AFLiHaQS648@001oof<HOomS67ooIcUoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomW>@03HaP01VLiHaQS66LiHaQW>@9S603o@Q0006<H
OomS67ooIcUoof<HOomW>GooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<H002o@Q0006<HOomS67ooIcUoof<HOomW>GooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS6002HaP00gooHaQS
6002HaP30002HaP01FLiHaQS648@00001V<H00=W>F<HHaP00f<H00=W>F<H
IcT00f<H0D8@0@000Goo00000f<HOomS6002HaP017ooHaQS66<H10001F<H
03i24000HaQoofLiOomS67ooHaQoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo0V<H00=oof<H
HaP016<H00=W>F<HHaP00f<H0?m24000OomS67ooHaQoof<HOomS67ooHaQo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOol00<924000OomS
67ooHaQoof<HOomS67ooHaQoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<H0V<H00=W>F<H00000`0016<H00M24000
HaQS66LiHaQW>@03HaP00fLiHaQW>@04HaP01FLiHaQS648@00000Goo0000
0fLiOomS6002HaP00gooHaQW>@02HaP30003HaP0@fLiHaQ24000OomS67oo
HaQoof<HOomW>GooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo009S6003IcUS66Li00=S
603oIcUS66LiHaQ24000HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<H0033IcUS66LiHaQ24000HaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<H009S6003OomS66<H009S60<000=S6006IcUS648@001S66Li0f<H
00=W>F<HIcT01F<H00=W>F<HHaP00V<H0D8@0@000Goo00001V<HOomS66Li
HaQoo`ES6080009S6011IcUS66<H@Q0006<HOomW>GooHaQoof<HOomS67oo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoo`02HaP00gooHaQS6003HaP00fLiHaQW>@03HaP0ofLi@Q00
07ooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>@00`fLi@Q0007ooIcUoof<HOomS67ooHaQoof<HOomS67oo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>@02
HaP016LiHaP000001V<H00=24000HaP00V<H00=W>F<HHaP00V<H00aW>F<H
IcUS66LiHaQW>F<HIcUS648@0001Ool00003HaQoof<H009S6003OomS66<H
00AS6003001S66<H00=S6011@Q0007ooHaQoof<HOomW>GooHaQoofLiOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomW>GooHaQoo`02HaP00fLiHaQW>@04HaP0ofLiHaQS648@001S67oo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
o`00`VLiHaQS648@001S67ooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaP2HaP00gooHaQS6002
HaP03000HaQS66<HIcUS66LiHaQ24000HaQW>@=S6003IcUS66Li00ES6003
IcUS66<H009S60524040005oo`0000=S67ooHaP00V<H00Eoof<HIcUS66Li
00ES6011IcUS66<H@Q0006<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooHaQo
o`02HaP00gooHaQS6003HaP00fLiHaQW>@03HaP0ofLi@Q0007ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
6000`fLi@Q0007ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS6002HaP00fLiHaQS
6007HaP00d8@001S6002HaP00fLiHaQS6002HaP036LiHaQW>F<HIcUS66Li
HaQW>F<H@Q00005oo`0000=W>GooHaP00V<H00=oof<HHaP026<H04=W>F<H
@Q0007ooIcUoofLiOomS67ooIcUoof<HOomW>GooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoofLiOomS67ooHaQoo`02HaP0
0fLiHaQW>@04HaP0ofLiHaQS648@001S67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoo`00`VLiHaQS648@001S67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaP2HaP00gooIcUS6006HaP026LiHaQW>F<H@Q0006<H
IcT3HaP00fLiHaQW>@05HaP00fLiHaQS6002HaP1@Q010001Ool00005HaQo
of<HIcUS600=Ool0?T8@001S67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooHaQoof<H
Ool2HaP=Ool0od8@001oofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoo`00`D8@001oofLiOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67oo00eoo`03@Q0006<H009S6003IcUS66<H009S600<IcUS66Li
HaQW>F<HIcUS66LiHaQ240000Goo00000fLiOomS600@HaP0?P00OomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomW>GooHaQoof<HOol?HaP0o`00HaQoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
o`00_P00HaQoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<H46<H00<006<HHaP00f<H00=W>F<H
IcT01F<H00=W>F<HHaP00V<H0D8@0@000Goo000016<HOomS66<Hogooogoo
;7oo40000V<H0D8@0@000Goo000016LiOomS66<Hogooogoo;7oo00=S648@
@Q00348@00D006<HHaQ24000005oo`0000AS67ooHaQS6?mooomoobaoo`03
IcUoof<H009S6003IcUS66<H00IS6006@Q0006<HHaQ240000Goo000016Li
OomS66Liogooogoo;7oo00=S67ooHaP01V<H00=W>F<HHaP00V<H00I24000
HaQS648@0001Ool00004HaQoof<HHaSoOoooOol/Ool01FLiOomS66<HIcT0
0V<H00EW>F<HHaQS66Li009S6006@Q0006<HHaQ240000Goo000016LiOomS
66Liogooogoo;7oo00=S67ooHaP00V<H00EW>F<HHaQS66Li009S6004IcUS
648@0002HaP1@Q010001Ool00004HaQoof<HHaSoOoooOol/Ool00fLiOomS
6004HaP01@00HaQS66<HIcT00V<H00I24000HaQS648@0001Ool00004IcUo
of<HIcWoOoooOol/Ool01V<HOomS66<HIcUS60<00003IcUS66<H009S6006
@Q0006<HHaQ240000Goo000016<HOomS66<Hogooogoo;7oo00=W>GooHaP0
0V<H1@000V<H00AW>F<H@Q00009S60524040005oo`0000AW>GooHaQW>Omo
oomoobaoo`04HaQoof<HHaP70003HaP01T8@001S66<H@Q00005oo`0000AS
67ooHaQS6?mooomoobaoo`03IcUoof<H00]S6006@Q0006<HHaQ240000Goo
000016LiOomS66Liogooogoo;7oo00=S67ooHaP02F<H00AW>F<H@Q00009S
60524040005oo`0000AS67ooHaQS6?mooomoobaoo`04IcUoof<HIcT6HaP0
1VLiHaQS66<H@Q00009S60524040005oo`0000AW>GooHaQW>Omooomoobao
o`09HaQoof<HHaQW>F<HIcUS66Li00=S6004IcUS648@0002HaP1@Q010001
Ool00004HaQoof<HHaSoOoooOol/Ool00fLiOomoo`0;Ool01T8@001S66<H
@Q00005oo`0000AW>GooHaQW>Omooomoobaoo`mS6005001S66<H@Q000001
Ool00004HaQoof<HHaSoOoooOol/Ool046LiOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67oo0V<H0D8@0@000Goo000016LiOomS66Liogooogoo;Goo
00iS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo0f<H0D8@0@000Goo0000
16<HOomS66<Hogooogoo;7oo01AW>GooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HIcU240000Goo000016LiOomS66Liogooogoo;Goo00iS67oo
HaQoof<HOomS67ooHaQoof<HOomS67oo0f<H0D8@0@000Goo000016<HOomS
66<Hogooogoo;7oo011W>GooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
o`9S60524040005oo`0000AW>GooHaQW>Omooomoobeoo`0>IcUoof<HOomW
>GooHaQoof<HOomS67ooHaQoo`=S60524040005oo`0000AS67ooHaQS6?mo
oomoobaoo`0DIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomS66Li
@Q00005oo`0000AW>GooHaQW>Omooomoobeoo`0>IcUoof<HOomS67ooHaQo
ofLiOomS67ooHaQoo`=S60524040005oo`0000AS67ooHaQS6?mooomoobao
o`0@IcUoof<HOomS67ooHaQoof<HOomS67ooIcUoof<HOol2HaP1@Q010001
Ool00004IcUoof<HIcWoOoooOol]Ool03V<HOomW>GooHaQoofLiOomS67oo
HaQoof<HOol3HaP1@Q010001Ool00004HaQoof<HHaSoOolkOol301o]Ool0
56LiOomS67ooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQW>D8@0001Ool0
0004IcUoof<HIcWoOolhOol00`0OOomoo`03Ool00`0OOomoo`3[Ool03V<H
OomW>GooHaQoof<HOomS67ooHaQoof<HOol3HaP1@Q010001Ool00004HaQo
of<HHaSoOolhOol00`0OOomoo`03Ool00`0OOomoo`3ZOol046LiOomS67oo
HaQoof<HOomW>GooHaQoofLiOomS67oo0V<H0D8@0@000Goo000016LiOomS
66Liogoo>7oo00<07gooOol00Woo00<07gooOol0k7oo00iS67ooHaQoofLi
OomS67ooHaQoof<HOomS67oo0f<H0D8@0@000Goo000016<HOomS66<Hogoo
=goo0P0O17oo00<07gooOol0jgoo01AW>GooIcUoof<HOomS67ooHaQoofLi
OomS67ooHaQoof<HIcU240000Goo000016LiOomS66Liogoo?7oo0P0OkWoo
00iS67ooHaQoof<HOomW>GooHaQoof<HOomW>Goo0f<H0D8@0@000Goo0000
16<HOomS66<Hogooogoo;7oo011W>GooHaQoofLiOomS67ooHaQoof<HOomS
67ooHaQoo`9S60524040005oo`0000AW>GooHaQW>Omooomoobeoo`0>HaQo
of<HOomS67ooHaQoof<HOomW>GooHaQoo`=S60524040005oo`0000AS67oo
HaQS62moo`0301l200800302000301l200800102000301l2008003L20003
01l2008002@2000301l200800342000301l2008001L2000301l200800142
000301l2008002<2000301l200800342000301l2008002/2000301l20080
0102000301l20080040201Aoo`0DIcUoofLiOomS67ooIcUoof<HOomW>Goo
HaQoof<HOomS66Li@Q00005oo`0000AW>GooHaQW>Bmoo`0301moogoo031o
o`807a5oo`807cQoo`807bEoo`0301l207oo035oo`0301l207oo01Moo`80
7a9oo`807bAoo`807c9oo`0301l207oo02]oo`807a5oo`0301l207oo03mo
o`030P1oogoo01=oo`0>HaQoof<HOomS67ooHaQoof<HOomS67ooIcUoo`=S
60524040005oo`0000AS67ooHaQS62moo`0301moogoo035oo`0301moogoo
011oo`0301moogoo03Moo`0301moogoo02Aoo`030P1oogoo035oo`030P1o
ogoo01Moo`0301moogoo015oo`0301moogoo02=oo`0301moogoo035oo`03
0P1oogoo02]oo`0301moogoo011oo`030P1oogoo03ioo`030P1oogoo019o
o`0@IcUoof<HOomW>GooHaQoofLiOomS67ooHaQoof<HOol2HaP1@Q010001
Ool00004IcUoof<HIcT_Ool00`0OOomoo`0aOol00`0OOomoo`0@Ool00`0O
Oomoo`0gOol00`0OOomoo`0TOol00`80Oomoo`0aOol00`80Oomoo`0GOol0
0`0OOomoo`0AOol00`0OOomoo`0SOol00`0OOomoo`0aOol00`80Oomoo`0[
Ool00`0OOomoo`0@Ool00`80Oomoo`0nOol00`80Oomoo`0COol03V<HOomS
67ooHaQoof<HOomS67ooIcUoof<HOol3HaP1@Q010001Ool00004HaQoof<H
HaP_Ool00`0OOomoo`0aOol00`0OOomoo`0@Ool00`0OOomoo`0gOol00`0O
Oomoo`0TOol00`80Oomoo`0aOol00`80Oomoo`0GOol00`0OOomoo`0AOol0
0`0OOomoo`0SOol00`0OOomoo`0aOol00`80Oomoo`0[Ool00`0OOomoo`0@
Ool00`80Oomoo`0nOol00`80Oomoo`0BOol056LiOomW>GooHaQoofLiOomS
67ooHaQoof<HOomS67ooHaQW>D8@0001Ool00004IcUoof<HIcT_Ool00`0O
Oomoo`0aOol00`0OOomoo`0@Ool00`0OOomoo`0gOol00`0OOomoo`0TOol0
0`80Oomoo`0aOol00`80Oomoo`0GOol00`0OOomoo`0AOol00`0OOomoo`0S
Ool00`0OOomoo`0aOol00`80Oomoo`0[Ool00`0OOomoo`0@Ool00`80Oomo
o`0nOol00`80Oomoo`0COol03V<HOomS67ooHaQoof<HOomW>GooHaQoofLi
Ool3HaP1@Q010001Ool00004HaQoof<HHaP_Ool00`80Oomoo`0aOol00`80
Oomoo`0@Ool00`80Oomoo`0gOol00`80Oomoo`0TOol00`80Oomoo`0aOol0
0`80Oomoo`0GOol00`80Oomoo`0AOol00`80Oomoo`1GOol00`80Oomoo`0[
Ool00`80Oomoo`0@Ool00`80Oomoo`0nOol00`80Oomoo`0BOol046LiOomS
67ooIcUoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@0@000Goo000016Li
OomS66Li;Woo0P80<Woo0P804Goo0P80>Goo00<207ooOol097oo00<207oo
Ool0<Goo00<207ooOol05Woo0P804Woo0P809Woo10800Woo00<207ooOol0
:Woo00<207ooOol067oo0`0O0goo0P0O2Woo0P804Woo00<207ooOol0?Woo
00<207ooOol04goo00iS67ooHaQoof<HOomW>GooHaQoofLiOomS67oo0f<H
0D8@0@000Goo000016<HOomS66<H;7oo0P80<Woo0P804Goo0P80>Goo0P80
9goo00<207ooOol0<Goo00<207ooOol01Goo0`0O0goo0P0O1goo0P804Woo
0P80:Goo00<207ooOol00Woo00<207ooOol0:Woo00<207ooOol06goo00<0
7goo01l00Woo00@07goo01l07`Aoo`8201Aoo`030P1oogoo03ioo`030P1o
ogoo019oo`0DIcUoofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS66Li
@Q00005oo`0000AW>GooHaQW>B=oo`0301moogoo00807`Ioo`8201moo`<0
7`=oo`807`]oo`82015oo`<202aoo`<07`Uoo`8202Eoo`030P1oogoo035o
o`030P1oogoo00Qoo`0301moo`0O009oo`0401moo`0O01l5Ool30P04Ool2
01l3Ool201l6Ool20P0WOol20P03Ool00`80Oomoo`0ZOol00`80Oomoo`0K
Ool00`0OOol07`02Ool0100OOol07`0O1Woo0P804Woo00<207ooOol0?Woo
00<207ooOol04goo00iS67ooHaQoofLiOomS67ooIcUoof<HOomW>Goo0f<H
0D8@0@000Goo000016<HOomS66<H8goo00<07gooOol00P0O27oo0P8087oo
00<07goo01l00Woo00@07goo01l07`Uoo`8200Eoo`0301moogoo00807`Qo
o`8202eoo`0401moo`0O01l7Ool20P0SOol00`80Oomoo`0aOol00`80Oomo
o`08Ool00`0OOol07`02Ool0100OOol07`0O27oo0P8000Moo`0OOomoo`0O
Ool07`02Ool00`0OOomoo`05Ool20P02Ool201lQOol00`80Ool20002Ool0
0`80Oomoo`0ZOol00`80Oomoo`0HOol301l2Ool0200OOomoo`0OOol07goo
01l7Ool20P0@Ool00`80Oomoo`0nOol00`80Oomoo`0BOol046LiOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@0@000Goo000016LiOomS
66Li8goo00H07gooOol07goo01l5Ool20P0ROol00`0OOol07`02Ool0100O
Ool07`0O1goo0P801goo00<07gooOol00P0O1Goo0`80;goo00@07goo01l0
7`Eoo`8202Eoo`030P1oogoo035oo`030P1oogoo00Eoo`<07`9oo`0801mo
ogoo01moo`0OOol07`Aoo`<2000401moogoo01l2Ool00`0OOol07`02Ool0
0`0OOomoo`03Ool20P03Ool01`0OOol07`0OOol07goo00807`03Ool07goo
00=oo`0401moo`0O01l2Ool00`0OOomoo`03Ool00`0OOomoo`02Ool01@0O
Oomoogoo0P000Woo00<207oo0P00;7oo00<207ooOol067oo00<07gooOol0
0Woo00H07goo01l07goo01l7Ool20P0BOol00`80Oomoo`0nOol00`80Oomo
o`0COol03V<HOomW>GooHaQoofLiOomS67ooIcUoof<HOol3HaP1@Q010001
Ool00004HaQoof<HHaPROol201l2Ool00`0OOomoo`03Ool20P0QOol301l2
Ool0200OOomoo`0OOol07goo01l4Ool20P09Ool01P0OOomoo`0OOol07`9o
o`8202moo`<07`9oo`0301moo`0O009oo`8202Moo`030P1oogoo035oo`03
0P1oogoo00Eoo`0301moogoo009oo`0601moo`0O01moo`0O17oo0P800goo
00@07gooOol07`9oo`0301moo`0O009oo`0401moogooOol20P05Ool01`0O
Oomoo`0OOol07goo00807`04Ool07`0O01l2Ool0100OOol07`0O0goo00<0
7gooOol00`0O17oo00<07gooOol01Goo0P80;7oo00<207ooOol06Goo0P0O
0goo00<07gooOol01goo0P8057oo00<207ooOol0?Woo00<207ooOol04Woo
01AW>GooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HIcU240000Goo
000016LiOomS66Li;Woo0P807goo00<07gooOol00Woo00H07goo01l07goo
01l8Ool20P06Ool201l2Ool00`0OOomoo`04Ool30P0/Ool00`0OOomoo`02
Ool00`0OOomoo`04Ool20P0UOol00`80Oomoo`0aOol00`80Oomoo`06Ool2
01l3Ool00`0OOomoo`08Ool30P001@0OOomoo`0OOol00P0O00=oo`0OOol0
0P0O1Goo0P800goo00D07gooOol07goo00807`04Ool07goo01l2Ool01P0O
Ool07`0OOol07`=oo`0401moogooOol201l4Ool00`0OOomoo`06Ool00`80
01l07`0301l>0P0IOol00`80Oomoo`0ZOol20P0BOol00`80Oomoo`0nOol0
0`80Oomoo`0COol03V<HOomS67ooIcUoof<HOomW>GooHaQoofLiOol3HaP1
@Q010001Ool00004HaQoof<HHaP`Ool20P0NOol201l3Ool00`0OOomoo`0<
Ool20P0BOol20P0[Ool201l;Ool20P0SOol00`80Oomoo`0aOol00`80Oomo
o`0?Ool301l7Ool20P02Ool00`0OOomoo`02Ool00`0OOomoo`07Ool20P00
1goo01moogoo01moo`0O009oo`0301moo`0O009oo`0301moo`0O009oo`03
01moogoo009oo`0501moogooOol07`03Ool201l7Ool20P0201l2Ool301l;
Ool00`80Oomoo`0GOol00`80Oomoo`0IOol00`0OOol07`04Ool00`0OOomo
o`02Ool00`0OOomoo`04Ool20P0@Ool00`80Oomoo`0nOol00`80Oomoo`0B
Ool046LiOomW>GooHaQoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@0@00
0Goo000016LiOomS66Li8Goo00<07goo01l017oo00<07gooOol00goo0P80
<Woo0P804Goo0`80>7oo0P809Goo00<207ooOol0<Goo00<207ooOol02Woo
00<07goo01l01Goo00@07gooOomoo`<2015oo`8200Aoo`807`Eoo`0301mo
o`0O00807`Eoo`0301moo`0O00<07`moo`040P1oo`0OOol201l2Ool00`0O
Oomoo`03Ool00`0OOomoo`04Ool00`80Oomoo`0GOol00`80Oomoo`0IOol3
01l4Ool00`0OOomoo`02Ool00`0OOomoo`02Ool20P0BOol00`80Oomoo`0n
Ool00`80Oomoo`0COol03V<HOomS67ooHaQoofLiOomS67ooIcUoof<HOol3
HaP1@Q01000101l00004HaQoof<HHaPQOol301l4Ool0100OOomoogoo0P80
;7oo0`0O0goo0P8037oo0`0O0Woo0P80>Goo0P809goo00<207ooOol0<Goo
00<207ooOol02Woo0`0O0Woo100O00=oo`800P0037oo0`0O0goo0P80:Woo
0P800Woo00@07gooOol07`=oo`0301moogoo00<07`Ioo`030P1oogoo01Mo
o`030P1oogoo01Uoo`0401moogoo01l3Ool00`0OOomoo`02Ool00`0OOomo
o`020P0DOol00`80Oomoo`0nOol00`80Oomoo`0BOol056LiOomS67ooIcUo
of<HOomS67ooHaQoof<HOomS67ooHaQW>D8@0001Ool00004IcUoof<HIcTQ
Ool0100OOomoo`0O0goo00<07gooOol00goo0P809Goo00<07goo01l01Goo
00<07gooOol00Woo0P801Goo00<07goo01l00goo00<07gooOol00goo0`80
;7oo00<07goo01l017oo00<07gooOol00Woo0P809Goo00<207ooOol0<Goo
00<207ooOol02Woo00H07gooOol07goo01l2Ool0100OOomoogoo0`8017oo
00<07goo01l00Woo00@07gooOol07`Aoo`8202Moo`030P1oogoo009oo`04
01moogoo01l4Ool00`0OOomoo`0201l6Ool00`80Oomoo`0GOol00`80Oomo
o`0IOol0100OOomoo`0O0Woo0P0O0goo0P0O17oo0P804Woo00<207ooOol0
?Woo00<207ooOol04goo00iS67ooHaQoof<HOomS67ooIcUoof<HOomW>Goo
0f<H0D8@0@000Goo000016<HOomS66<H8Goo00@07gooOol07`9oo`807`Mo
o`8202=oo`<07`Eoo`0301moogoo00Aoo`8200=oo`<07`Aoo`0301moogoo
00Eoo`8202Yoo`<07`9oo`<07`Ioo`8202=oo`030P1oogoo035oo`030P1o
ogoo00Yoo`0801moogoo01moo`0OOol07`Moo`82009oo`<07`9oo`0401mo
o`0O01l6Ool20P0TOol00`80Oomoo`03Ool01`0OOomoo`0OOol07goo0080
7`=oo`0301moogoo00Aoo`030P1oogoo01Moo`030P1oogoo01Uoo`<07a1o
o`82011oo`030P1oogoo03ioo`030P1oogoo019oo`0@IcUoofLiOomS67oo
IcUoof<HOomS67ooHaQoof<HOol2HaP1@Q010001Ool00004IcUoof<HIcTQ
Ool301l<Ool00`80Oomoo`0ROol0100OOomoo`0O0goo00<07gooOol01Goo
00<207ooOol00Woo00@07gooOol07`Aoo`0301moogoo00=oo`030P1oogoo
02Yoo`0401moogoo01l2Ool201l5Ool00`80Oomoo`0SOol00`80Oomoo`0a
Ool00`80Oomoo`0:Ool301l3Ool00`0OOomoo`05Ool00`80Oomoo`02Ool0
1@0OOomoo`0OOol00`0O1goo00<207ooOol08Woo00<207ooOol017oo00<2
000O01l00goo00<07gooOol02Woo00<207ooOol05goo00<207ooOol0;7oo
00<207ooOol03goo00<207ooOol0?Woo00<207ooOol04goo00iS67ooHaQo
of<HOomS67ooHaQoofLiOomS67oo0f<H0D8@0@000Goo000016<HOomS66<H
;goo00<07gooOol08goo00@07gooOol07`=oo`0301moogoo00Aoo`0301mo
ogoo00=oo`0701moogoo01moo`0OOol00P0O17oo00<07gooOol0:goo00@0
7gooOol07`=oo`0301moogoo009oo`0301moogoo02Aoo`030P1oogoo035o
o`0301moogoo01Moo`0301moogoo00=oo`0601moogoo01moo`0O0Woo00<0
7gooOol00goo00<07gooOol08goo00<07gooOol05goo00<207ooOol05goo
00<207ooOol0:goo00<07gooOol047oo00<207ooOol0?Woo00<07gooOol0
4Woo01AW>GooHaQoofLiOomS67ooIcUoof<HOomS67ooHaQoof<HIcU24000
0Goo000016LiOomS66Li;goo00<07gooOol08goo0`0O0goo0P0O1Woo00<0
7gooOol00goo0`0O0goo00<07gooOol017oo00<07gooOol0:goo0`0O2Goo
00<07gooOol097oo00<207ooOol0<Goo00<07gooOol05goo00<07gooOol0
0goo0`0O0goo0P0O1Woo00<07gooOol08goo00<07gooOol05goo00<207oo
Ool05goo00<207ooOol0:goo00<07gooOol047oo00<207ooOol0?Woo00<0
7gooOol04goo00iS67ooHaQoof<HOomS67ooHaQoof<HOomW>Goo0f<H0D8@
0@000Goo000016<HOomS66<H;goo00<07gooOol0<Goo00<07gooOol047oo
00<07gooOol0=goo00<07gooOol097oo00<207ooOol0<Goo00<07gooOol0
5goo00<07gooOol04Goo00<07gooOol08goo00<07gooOol05goo00<207oo
Ool05goo00<207ooOol0:goo00<07gooOol047oo00<207ooOol0?Woo00<0
7gooOol04Woo011W>GooIcUoof<HOomW>GooHaQoofLiOomS67ooHaQoo`9S
60524040005oo`0000AW>GooHaQW>Bmoo`0301moogoo035oo`0301moogoo
011oo`0301moogoo03Moo`0301moogoo02Aoo`030P1oogoo035oo`0301mo
ogoo01Moo`0301moogoo015oo`0301moogoo02=oo`0301moogoo01Moo`03
0P1oogoo01Moo`030P1oogoo02]oo`0301moogoo011oo`030P1oogoo03io
o`0301moogoo01=oo`0>HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoo`=S
60524040005oo`0000AS67ooHaQS62moo`0301moogoo035oo`0301moogoo
011oo`0301moogoo03Moo`0301moogoo02Aoo`030P1oogoo035oo`0301mo
ogoo01Moo`0301moogoo015oo`0301moogoo02=oo`0301moogoo01Moo`03
0P1oogoo01Moo`030P1oogoo02]oo`0301moogoo011oo`030P1oogoo03io
o`0301moogoo019oo`0DIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomS66Li@Q00005oo`0000AW>GooHaQW>Bmoo`0301moogoo035oo`0301mo
ogoo011oo`0301moogoo03Moo`0301moogoo02Aoo`030P1oogoo035oo`03
01moogoo01Moo`0301moogoo015oo`0301moogoo02=oo`0301moogoo01Mo
o`030P1oogoo01Moo`030P1oogoo02]oo`0301moogoo011oo`030P1oogoo
03ioo`0301moogoo01=oo`0>HaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
o`=S60524040005oo`0000AS67ooHaQS62moo`030P1oogoo035oo`030P1o
ogoo011oo`030P1oogoo03Moo`030P1oogoo02Aoo`030P1oogoo04]oo`03
0P1oogoo015oo`030P1oogoo02=oo`030P1oogoo01Moo`030P1oogoo01Mo
o`030P1oogoo02]oo`030P1oogoo011oo`030P1oogoo05=oo`0@IcUoofLi
OomS67ooIcUoof<HOomW>GooHaQoof<HOol2HaP1@Q010001Ool00004IcUo
of<HIcT_Ool00`80Oomoo`0aOol00`80Oomoo`0@Ool00`80Oomoo`0gOol0
0`80Oomoo`0TOol00`80Oomoo`0bOol40P02Ool00`80Oomoo`0@Ool00`80
Oomoo`0AOol00`80Oomoo`0SOol00`80Oomoo`0GOol00`80Oomoo`0GOol0
0`80Oomoo`0[Ool00`80Oomoo`0@Ool00`80Oomoo`0lOol30P0EOol03V<H
OomS67ooHaQoof<HOomS67ooHaQoofLiOol3HaP1@Q010001Ool00004HaQo
of<HHaP_Ool00`80Oomoo`0aOol00`80Oomoo`0@Ool00`80Oomoo`0gOol0
0`80Oomoo`0TOol00`80Oomoo`0bOol20P04Ool00`80Oomoo`0@Ool00`80
Oomoo`0AOol00`80Oomoo`0SOol00`80Oomoo`0GOol00`80Oomoo`0GOol0
0`80Oomoo`0[Ool00`80Oomoo`0@Ool00`80Oomoo`0jOol20P000goo0P02
00020P0BOol056LiOomS67ooIcUoof<HOomW>GooHaQoof<HOomS67ooHaQW
>D8@0001Ool00004IcUoof<HIcT_Ool00`80Oomoo`0aOol00`80Oomoo`0@
Ool00`80Oomoo`0gOol00`80Oomoo`0TOol00`80Oomoo`0bOol01080Ool2
00800Woo00<207ooOol047oo00<207ooOol04Goo00<207ooOol08goo00<2
07ooOol05goo00<207ooOol05goo00<207ooOol0:goo00<207ooOol047oo
00<207ooOol0>Goo00<207ooOol01Goo00<207ooOol047oo00iS67ooHaQo
of<HOomS67ooHaQoofLiOomS67oo0f<H0D8@0@000Goo000016<HOomS66<H
;goo00<207ooOol0<Goo00<207ooOol047oo00<207ooOol0;goo00<07goo
Ool00Woo00@07gooOol202Ioo`030P1oogoo039oo`070P1oogooOol207oo
0P004Woo00<207ooOol04Goo00<207ooOol08goo00<207ooOol05goo00<2
07ooOol05goo00<207ooOol0:goo00<207ooOol047oo00<207ooOol0>7oo
00<207ooOol01goo00<207ooOol03Woo011W>GooIcUoof<HOomW>GooHaQo
of<HOomS67ooHaQoo`9S60524040005oo`0000AW>GooHaQW>Bmoo`030P1o
ogoo035oo`030P1oogoo011oo`030P1oogoo02moo`0301moogoo00<07`9o
o`030P1oogoo02Aoo`030P1oogoo00moo`807bIoo`82019oo`030P1oogoo
015oo`030P1oogoo02=oo`030P1oogoo01Moo`030P1oogoo01Moo`030P1o
ogoo02]oo`030P1oogoo011oo`030P1oogoo03Qoo`030P1oogoo00Moo`03
0P1oogoo00moo`0>HaQoof<HOomS67ooHaQoofLiOomS67ooIcUoo`=S6052
4040005oo`0000AS67ooHaQS62moo`030P1oogoo035oo`030P1oogoo011o
o`030P1oogoo00Aoo`<07bQoo`0401moogooOol201l2Ool00`80Oomoo`0T
Ool00`80Oomoo`0>Ool01`0OOol07`0OOol07goo00807`03Ool07goo00=o
o`0401moo`0O01l2Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomo
o`07Ool00`8001l07`0301m60P000`0O0P02000G0P000`0O0P0200150P00
0`0OOomoo`0AOol00`80Oomoo`0gOol00`80Oomoo`09Ool00`80Oomoo`0=
Ool056LiOomS67ooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQW>D8@0001
Ool00004IcUoof<HIcT_Ool01@80Oomoogoo01l017oo00<07gooOol0:7oo
00<207ooOol047oo00D207ooOomoo`0O00=oo`0301moogoo02Ioo`807`Ao
o`0401moogoo0P0VOol00`80Oomoo`0>Ool01`0OOomoo`0OOol07goo0080
7`04Ool07`0O01l2Ool0100OOol07`0O0goo00<07gooOol00`0O17oo00<0
7gooOol01Woo0P804Woo00<207ooOol04Goo00<207ooOol08Woo00<07goo
Ool05goo00<07gooOol067oo00<207ooOol0:Woo00<07`80Ool04Goo00<2
07ooOol0=goo00<207ooOol02Goo00<207ooOol03Woo00iS67ooHaQoof<H
OomW>GooHaQoofLiOomS67oo0f<H0D8@0@000Goo000016<HOomS66<H;goo
00D207ooOomoo`0O00Aoo`0301moogoo02Qoo`030P1oogoo011oo`050P1o
ogooOol07`04Ool00`0OOomoo`0^Ool00`80Oomoo`0TOol00`80Oomoo`0>
Ool01@0OOomoo`0OOol00P0O00Aoo`0OOol07`9oo`0601moo`0O01moo`0O
0goo00@07gooOomoo`807`Aoo`0301moogoo00Eoo`040P1oo`80Ool201l2
Ool301l2Ool301l5Ool00`80Oomoo`0AOol00`80Oomoo`1GOol00`80Oomo
o`0[Ool00`80Oomoo`0@Ool00`80Oomoo`0hOol00`80Oomoo`07Ool00`80
Oomoo`0>Ool046LiOomW>GooHaQoof<HOomS67ooHaQoof<HOomS67oo0V<H
0D8@0@000Goo000016LiOomS66Li;goo00D207ooOomoo`0O00Aoo`0301mo
ogoo02Qoo`030P1oogoo011oo`050P1oogooOol07`05Ool00`0OOomoo`0]
Ool00`80Oomoo`0TOol00`80Oomoo`0>Ool01P0OOomoo`0OOol07`9oo`03
01moo`0O009oo`0301moo`0O009oo`0301moogoo009oo`0501moogooOol0
7`03Ool201l5Ool20P02Ool00`8001moo`0201l2Ool00`0OOomoo`04Ool0
0`0OOomoo`02Ool00`80Oomoo`0AOol00`80Oomoo`1GOol00`80Oomoo`0[
Ool00`80Oomoo`0@Ool00`80Oomoo`0hOol00`80Oomoo`07Ool00`80Oomo
o`0?Ool03V<HOomS67ooIcUoof<HOomW>GooHaQoofLiOol3HaP1@Q010001
Ool00004HaQoof<HHaP_Ool00`80Oomoo`0201l3Ool201lZOol00`80Oomo
o`0@Ool00`80Oomoo`0201l2Ool0100OOol07`0O;goo00<207ooOol097oo
00<207ooOol03goo0P0O1Goo00<07goo01l00P0O1Goo00<07goo01l00`0O
3Goo00<207ooOol00Woo00D2000OOomoo`0O00=oo`0301moogoo00=oo`03
01moogoo009oo`030P1oogoo015oo`030P1oogoo01moo`<07cEoo`030P1o
ogoo02]oo`030P1oogoo011oo`030P1oogoo03Uoo`040P1oogooOol30P00
0goo0P1oo`0@Ool056LiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQW>D8@0001Ool00004IcUoof<HIcT_Ool00`80Oomoo`0aOol00`80Oomo
o`0@Ool00`80Oomoo`05Ool00`0OOomoo`0_Ool00`80Oomoo`0TOol00`80
Oomoo`0bOol00`80Oomoo`03Ool01@8001moogoo01l017oo00D07gooOomo
o`0O00Eoo`030P1oogoo015oo`030P1oo`0O00807`=oo`807aUoo`0301mo
ogoo00=oo`0301moogoo02ioo`030P1oogoo02]oo`030P1oogoo011oo`03
0P1oogoo03Yoo`82009oo`<201=oo`0>HaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoo`=S60524040005oo`0000AS67ooHaQS62moo`0301moogoo035o
o`030P1oogoo011oo`0301moogoo03Moo`0301moogoo02Aoo`030P1oogoo
035oo`030P1oogoo00Aoo`080P007gooOol07goo01moo`807`=oo`0301mo
ogoo00=oo`030P1oogoo015oo`0401moogoo01l3Ool0100OOomoo`0O6Goo
00<07gooOol00Woo00<07gooOol0;Woo00<207ooOol0:goo00<207ooOol0
47oo00<207ooOol0?7oo0`801Woo0`0O2goo011W>GooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoo`9S60524040005oo`0000AW>GooHaQW>Bmoo`03
01moogoo035oo`030P1oogoo011oo`0301moogoo03Moo`0301moogoo02Ao
o`0301moogoo035oo`0301moogoo00Ioo`807`=oo`0301moogoo009oo`80
7`Eoo`030P1oogoo015oo`0501moogooOol07`02Ool0100OOomoo`0O6Woo
00D07gooOomoo`0O031oo`030P1oogoo02]oo`030P1oogoo011oo`030P1o
ogoo03ioo`0501moogooOol07`03Ool00`0OOomoo`0;Ool03V<HOomS67oo
IcUoof<HOomW>GooHaQoofLiOol3HaP1@Q010001Ool00004HaQoof<HHaP_
Ool00`0OOomoo`0aOol00`80Oomoo`0@Ool00`0OOomoo`0gOol00`0OOomo
o`0TOol00`0OOomoo`0aOol00`0OOomoo`0GOol00`80Oomoo`0AOol00`0O
Oomoo`02Ool00`0OOol07`02Ool00`0OOomoo`0EOol0100OOol07`0O0Woo
0P0O<7oo00<207ooOol0:goo00<207ooOol047oo00<207ooOol0?Woo00H0
7gooOol07goo01l3Ool00`0OOomoo`09Ool056LiOomW>GooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQW>D8@0001Ool00004IcUoof<HIcT_Ool00`0O
Oomoo`0aOol00`80Oomoo`0@Ool00`0OOomoo`0gOol00`0OOomoo`0TOol0
0`0OOomoo`0aOol00`0OOomoo`0GOol00`80Oomoo`0AOol0100OOol07goo
0P0O00=oo`0OOol00P0O67oo00<07gooOol0=7oo00<207ooOol0:goo00<2
07ooOol047oo00<207ooOol0?Woo00H07gooOol07goo01l4Ool00`0OOomo
o`09Ool03V<HOomS67ooHaQoofLiOomS67ooIcUoof<HOol3HaP1@Q010001
Ool00004HaQoof<HHaP_Ool00`0OOomoo`0aOol00`80Oomoo`0@Ool00`0O
Oomoo`0gOol00`0OOomoo`0TOol00`0OOomoo`0aOol00`0OOomoo`0GOol0
0`80Oomoo`0AOol0100OOomoo`0O17oo00<07gooOol0Cgoo00<207ooOol0
:goo00<207ooOol047oo00<207ooOol0?Woo00<07goo01l00Woo00@07goo
01moo`807`Yoo`0@IcUoof<HOomW>GooHaQoof<HOomS67ooHaQoof<HOol2
HaP1@Q010001Ool00004IcUoof<HIcT_Ool00`0OOomoo`0aOol00`80Oomo
o`0@Ool00`0OOomoo`0gOol00`0OOomoo`0TOol00`0OOomoo`0aOol00`0O
Oomoo`0GOol00`80Oomoo`0AOol00`0OOomoo`1GOol00`80Oomoo`0[Ool0
0`80Oomoo`0@Ool00`80Oomoo`0nOol00`0OOomoo`02Ool0100OOomoo`0O
3Goo00iS67ooHaQoof<HOomS67ooIcUoof<HOomW>Goo0f<H0D8@0@000Goo
000016<HOomS66<H;goo00<07gooOol04goo0P0O77oo00<207ooOol047oo
00<07gooOol0=goo00<07gooOol097oo00<07gooOol0<Goo00<07gooOol0
5goo00<207ooOol04Goo00<07gooOol0Egoo00<207ooOol0:goo00<207oo
Ool047oo00<207ooOol0?Woo00<07gooOol04Woo01AW>GooIcUoof<HOomW
>GooHaQoof<HOomS67ooHaQoof<HIcU240000Goo000016LiOomS66Li@Goo
00@07gooOol07`9oo`0301moogoo01Uoo`030P1oogoo0:Eoo`030P1oogoo
01Moo`030P1oogoo06]oo`030P1oogoo02]oo`030P1oogoo011oo`030P1o
ogoo03ioo`0301moogoo01=oo`0>HaQoof<HOomS67ooHaQoof<HOomW>Goo
HaQoo`=S60524040005oo`0000AS67ooHaQS631oo`<2009oo`030P1oogoo
00Uoo`0401moogoo01l2Ool00`0OOomoo`0IOol00`80Oomoo`0:Ool00`80
Ool200030P0kOol40P02Ool00`80Oomoo`0GOol00`80Oomoo`030P0dOol0
0`80Oomoo`0GOol00`80Oomoo`0:Ool00`80Oomoo`040P1JOol00`80Oomo
o`0[Ool00`80Oomoo`0@Ool00`80Oomoo`0nOol00`80Oomoo`0BOol046Li
OomS67ooIcUoof<HOomW>GooHaQoof<HOomS67oo0V<H0D8@0@000Goo0000
16LiOomS66Li<7oo0P800goo00<207ooOol02Goo00@07gooOol07`9oo`03
01moogoo01Uoo`030P1oogoo00Yoo`040P1oogooOol20P0lOol00`80Oomo
o`02Ool00`80Oomoo`0GOol01080Oomoogoo0P80=7oo00<207ooOol05goo
00<207ooOol02Woo00<207ooOol00Woo00<207ooOol0FGoo00<207ooOol0
:goo00<207ooOol047oo00<207ooOol0?Woo00<207ooOol04goo00iS67oo
HaQoof<HOomS67ooHaQoof<HOomW>Goo0f<H0D8@0@000Goo000016<HOomS
66<H<7oo00<207oo0P000Woo00<207ooOol027oo0P0O0Woo00@07goo01l0
7a]oo`030P1oogoo00Yoo`060P1oogoo0P1oo`806Goo0P0O8Goo0`800Woo
00<207ooOol05goo00H207ooOol207oo0P0dOol00`80Oomoo`0GOol00`80
Oomoo`0:Ool00`80Oomoo`030P1KOol00`80Oomoo`0[Ool00`80Oomoo`0@
Ool00`80Oomoo`0nOol00`80Oomoo`0BOol056LiOomW>GooHaQoofLiOomS
67ooIcUoof<HOomS67ooHaQW>D8@0001Ool00004IcUoof<HIcT<Ool201lR
Ool01P80Oomoo`80Ool200moo`0301moogoo01]oo`030P1oogoo00Yoo`03
0P1oo`80009oo`030P1oogoo01Ioo`0701moo`0O01moo`0OOol00P0O00=o
o`0OOol00goo00@07goo01l07`9oo`0301moogoo00=oo`0301moogoo009o
o`0501moogooOol20002Ool00`80Ool2000IOol00`80Ool20002Ool00`80
Oomoo`0bOol00`80Oomoo`0@Ool301l4Ool00`80Oomoo`0:Ool00`80Ool2
0002Ool00`80Oomoo`1IOol00`80Oomoo`0[Ool00`80Oomoo`0@Ool00`80
Oomoo`0nOol00`80Oomoo`0COol03V<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOol3HaP1@Q010001Ool00004HaQoof<HHaP;Ool01`0OOol07`0OOol0
7goo00807`03Ool07goo00=oo`0401moo`0O01l2Ool00`0OOomoo`03Ool0
0`0OOomoo`02Ool00`0OOomoo`06Ool20P0]Ool00`80Oomoo`0:Ool20P0L
Ool01`0OOomoo`0OOol07goo00807`04Ool07`0O01l2Ool0100OOol07`0O
0goo00<07gooOol00`0O17oo00<07gooOol01Goo0P806Goo0P801goo0P0O
;goo00<207ooOol03Goo00<07gooOol00goo00D07gooOomoo`8000aoo`82
00Moo`807eIoo`030P1oogoo02]oo`030P1oogoo011oo`030P1oogoo03io
o`030P1oogoo019oo`0@IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
Ool2HaP1@Q010001Ool00004IcUoof<HIcT;Ool01`0OOomoo`0OOol07goo
00807`04Ool07`0O01l2Ool0100OOol07`0O0goo00<07gooOol00`0O17oo
00<07gooOol01goo00<2000O01l01@0O108000<07`800P007P8000<07`80
0P001@801P0O00<207ooOol06goo00D07gooOol07goo00807`04Ool07goo
01l2Ool01P0OOol07`0OOol07`=oo`0401moogooOol201l4Ool00`0OOomo
o`06Ool00`8001l07`0301l60P000`0O0P0200040P0701l00`80Oomoo`05
Ool01`0OOol07`0OOol07goo00807`03Ool07goo00=oo`0401moo`0O01l2
Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`0?Ool00`80Oomo
o`0=Ool00`0OOomoo`0401l2Ool00`0O0P0200050P0601l00`80Oomoo`05
Ool01`0OOol07`0OOol07goo00807`03Ool07goo00=oo`0401moo`0O01l2
Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`0fOol00`80Oomo
o`0[Ool00`80Oomoo`0@Ool00`80Oomoo`0nOol00`80Oomoo`0COol03V<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOol3HaP1@Q010001Ool00004HaQo
of<HHaP;Ool01@0OOomoo`0OOol00P0O00Aoo`0OOol07`9oo`0601moo`0O
01moo`0O0goo00@07gooOomoo`807`Aoo`0301moogoo00Ioo`8200]oo`03
01l207oo01ioo`0301moogoo00]oo`8201aoo`0601moogoo01moo`0O0Woo
00<07goo01l00Woo00<07goo01l00Woo00<07gooOol00Woo00D07gooOomo
o`0O00=oo`807`Moo`8200]oo`0301l207oo00]oo`8200Ioo`0701moogoo
01moo`0OOol00P0O00Aoo`0O01l07`9oo`0401moo`0O01l3Ool00`0OOomo
o`0301l4Ool00`0OOomoo`0?Ool00`80Oomoo`0=Ool0100OOomoo`0O0Woo
00D07gooOol07`8000aoo`8200Ioo`0701moogoo01moo`0OOol00P0O00Ao
o`0O01l07`9oo`0401moo`0O01l3Ool00`0OOomoo`0301l4Ool00`0OOomo
o`0fOol00`80Oomoo`0[Ool00`80Oomoo`0@Ool00`80Oomoo`0nOol00`80
Oomoo`0BOol056LiOomW>GooHaQoofLiOomS67ooIcUoof<HOomS67ooHaQW
>D8@0001Ool00004IcUoof<HIcT;Ool01P0OOomoo`0OOol07`9oo`0301mo
o`0O009oo`0301moo`0O009oo`0301moogoo009oo`0501moogooOol07`03
Ool201l7Ool01080Ool207oo0P0O0Woo0`0O17oo00<207ooOol08goo0P0O
0goo0P0O00Aoo`80Ool201aoo`807`Eoo`0301moo`0O00807`Eoo`0301mo
o`0O00<07`moo`030P1oo`8000aoo`030P1oogoo00Yoo`030P1oo`8000Eo
o`0501moogoo01moo`0201l017oo01moo`0O0Woo00H07goo01l07goo01l3
Ool0100OOomoogoo0P0O17oo00<07gooOol03goo00<207ooOol037oo0P0O
0Woo00<07goo01l017oo00<207ooOol02Woo00<207oo0P001Goo00D07goo
Ool07goo00807`04Ool07goo01l2Ool01P0OOol07`0OOol07`=oo`0401mo
ogooOol201l4Ool00`0OOomoo`0fOol00`80Oomoo`0[Ool00`80Oomoo`0@
Ool00`80Oomoo`0nOol00`80Oomoo`0COol03V<HOomS67ooHaQoof<HOomS
67ooHaQoofLiOol3HaP1@Q010001Ool00004HaQoof<HHaP<Ool201l5Ool0
0`0OOol07`0201l5Ool00`0OOol07`0301l?Ool01P80Oomoo`8001moo`80
7`Aoo`0501moogooOol2000TOol01P0OOol07`0OOol07`9oo`0501l207oo
Ool20007Ool201lgOol01080Oomoo`8037oo00<207ooOol02Woo00@207oo
Ool200Aoo`0601moogoo01moo`0O0Woo00<07goo01l00Woo00<07goo01l0
0Woo00<07gooOol00Woo00D07gooOomoo`0O00=oo`807a5oo`030P1oogoo
015oo`0301moogoo00=oo`030P1oogoo00Yoo`040P1oogoo0P04Ool01P0O
Oomoo`0OOol07`9oo`0301moo`0O009oo`0301moo`0O009oo`0301moogoo
009oo`0501moogooOol07`03Ool201lhOol00`80Oomoo`0[Ool00`80Oomo
o`0@Ool00`80Oomoo`0nOol00`80Oomoo`0BOol046LiOomS67ooIcUoof<H
OomW>GooHaQoof<HOomS67oo0V<H0D8@0@000Goo000016LiOomS66Li<Woo
00D207ooOol2000O009oo`0301moogoo009oo`0501moogooOol2000TOol0
1P0OOomoo`0OOol07`9oo`0501l207ooOol20006Ool01`0OOol07`0OOol0
7goo00807`03Ool07goo00=oo`0401moo`0O01l2Ool00`0OOomoo`03Ool0
0`0OOomoo`02Ool00`0OOomoo`0FOol01@80Oomoogoo0P0037oo00<207oo
Ool02Woo00@207ooOol200Eoo`807`Eoo`0301moo`0O00807`Eoo`0301mo
o`0O00<07aYoo`030P1oogoo01Moo`030P1oogoo00Yoo`050P1oogooOol2
0004Ool201l5Ool00`0OOol07`0201l5Ool00`0OOol07`0301m1Ool00`80
Oomoo`0[Ool00`80Oomoo`0@Ool00`80Oomoo`0nOol00`80Oomoo`0COol0
3V<HOomS67ooHaQoof<HOomS67ooIcUoof<HOol3HaP1@Q010001Ool00004
HaQoof<HHaPaOol01P80Oomoogoo0P007`9oo`0301moo`0O00807`Aoo`03
0P1oogoo029oo`0501moogoo01moo`0301l00goo0P1oo`02Ool00`80Oomo
o`03Ool01`0OOomoo`0OOol07goo00807`04Ool07`0O01l2Ool0100OOol0
7`0O0goo00<07gooOol00`0O17oo00<07gooOol05Goo00<207ooOol00Woo
00<207ooOol02Woo00<207ooOol02Woo00D207ooOomoo`8003Eoo`030P1o
ogoo01Moo`030P1oogoo00Yoo`030P1oogoo009oo`030P1oogoo05Uoo`03
0P1oogoo02]oo`030P1oogoo011oo`030P1oogoo03ioo`030P1oogoo019o
o`0DIcUoofLiOomS67ooIcUoof<HOomS67ooHaQoof<HOomS66Li@Q00005o
o`0000AW>GooHaQW>C1oo`030P1oogoo009oo`070P007gooOol07goo01l0
1Woo00<207ooOol08Woo00D07gooOol07goo00807`03Ool07`8000Aoo`03
0P1oogoo009oo`0501moogoo01moo`0201l017oo01moo`0O0Woo00H07goo
01l07goo01l3Ool0100OOomoogoo0P0O17oo00<07gooOol057oo00<207oo
Ool00goo00<207ooOol02Woo00<207ooOol02Woo00<207ooOol00Woo00<2
07ooOol0<Woo00<207ooOol05goo00<207ooOol02Woo00<207ooOol00goo
00<207ooOol0F7oo00<207ooOol0:goo00<207ooOol047oo00<207ooOol0
?Woo00<207ooOol04goo00iS67ooHaQoof<HOomS67ooIcUoof<HOomW>Goo
0f<H0D8@0@000Goo000016<HOomS66<H;goo00<207ooOol00goo00@207oo
01l07`=oo`807`Aoo`030P1oogoo02=oo`807`Aoo`0301moo`8000Eoo`05
0P1oogooOol07`02Ool00`0OOol07`02Ool00`0OOol07`02Ool00`0OOol0
7`02Ool00`0OOomoo`02Ool01@0OOomoogoo01l00goo0P0O5Goo00<207oo
Ool017oo00<207ooOol02Woo00<207ooOol02Woo00<207ooOol00goo00<2
07ooOol0<Goo00<207ooOol05goo00<207ooOol02Woo00<207ooOol017oo
00<207ooOol0A7oo4P8000<07`80Ool0;7oo00<207ooOol047oo00<207oo
Ool0?Woo00<207ooOol04Woo011W>GooHaQoofLiOomS67ooHaQoof<HOomS
67ooHaQoo`9S60524040005oo`0000AW>GooHaQW>Bmoo`0301moogoo011o
o`030P1oogoo035oo`0301moogoo009oo`807`Eoo`0301moo`0O00807`Eo
o`0301moo`0O00<07aioo`0301moogoo015oo`030P1oogoo011oo`0301mo
ogoo035oo`030P1oogoo01Moo`0301moogoo015oo`0301moogoo04Aoo`03
0P1oogoo00moo`0301l207oo02aoo`030P1oogoo011oo`030P1oogoo03io
o`030P1oogoo01=oo`0>HaQoof<HOomS67ooIcUoof<HOomW>GooHaQoo`=S
60524040005oo`0000AS67ooHaQS62moo`0301moogoo011oo`030P1oogoo
035oo`0301moogoo03Moo`<07`Qoo`807`Moo`030P1oogoo00Eoo`807`Uo
o`0301moogoo035oo`030P1oogoo01Moo`0301moogoo00Aoo`807`]oo`03
01moogoo04Aoo`030P1oogoo011oo`030P1oogoo02]oo`030P1oogoo011o
o`030P1oogoo03ioo`030P1oogoo019oo`0DIcUoofLiOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS66Li@Q00005oo`0000AW>GooHaQW>Bmoo`0301mo
ogoo011oo`030P1oogoo035oo`0301moogoo03Moo`0401moo`0O01l3Ool0
100OOomoo`0O0Woo00<07gooOol017oo00<207ooOol017oo00@07goo01l0
7`=oo`0301moogoo009oo`0301moogoo035oo`030P1oogoo01Moo`0301mo
ogoo00=oo`0401moo`0O01l3Ool01@0OOomoogoo01l00Woo00<07gooOol0
A7oo00<207ooOol047oo00<207ooOol0:goo00<207ooOol047oo00<207oo
Ool0?Woo00<207ooOol04goo00iS67ooHaQoofLiOomS67ooIcUoof<HOomW
>Goo0f<H0D8@0@000Goo000016<HOomS66<H;goo00<07gooOol047oo00<2
07ooOol0<Goo00<07gooOol04goo0`0O0goo0P0O0goo0P0O5goo00@07goo
Ool07`=oo`0401moogoo01l2Ool00`0OOomoo`04Ool00`80Oomoo`04Ool0
100OOomoo`0O0goo00<07gooOol00Woo00<07gooOol0<Goo00<207ooOol0
5goo00<07gooOol00goo00@07gooOol07`=oo`0301moogoo009oo`0301mo
o`0O04Ioo`030P1oogoo011oo`030P1oogoo02]oo`030P1oogoo011oo`03
0P1oogoo03ioo`030P1oogoo019oo`0@IcUoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOol2HaP1@Q010001Ool00004IcUoof<HIcT_Ool00`0OOomo
o`0@Ool00`80Oomoo`0aOol00`0OOomoo`0FOol00`0OOol07`02Ool00`0O
Ool07`02Ool00`0OOomoo`0DOol0100OOomoo`0O0goo00@07gooOol07`9o
o`0301moogoo00Aoo`030P1oogoo00Aoo`0401moogoo01l3Ool00`0OOomo
o`02Ool00`0OOomoo`0aOol00`80Oomoo`0GOol00`0OOomoo`03Ool0100O
Oomoo`0O0goo00<07gooOol00Woo00<07goo01l0AWoo00<207ooOol047oo
00<207ooOol0:goo00<207ooOol047oo00<207ooOol0?Woo00<207ooOol0
4goo00iS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo0f<H0D8@0@000Goo
000016<HOomS66<H;goo00<207ooOol047oo00<207ooOol0<Goo00<07goo
Ool05Woo00<07goo01l00Woo00<07goo01l00Woo00<07gooOol057oo00@2
07ooOol07`9oo`807`9oo`0401moo`0O01l4Ool201lB0P000`0O0P1oo`0b
Ool00`80Oomoo`0MOol0100OOomoo`0O0Woo0P0O1Goo00<07`80Ool0AGoo
00<207ooOol047oo00<207ooOol0:goo00<207ooOol047oo00<207ooOol0
?Woo00<207ooOol04Woo01AW>GooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HIcU240000Goo000016LiOomS66Li;goo00<207ooOol047oo00<0
7gooOol0<Goo00<207ooOol05Goo00@07gooOol07`9oo`0301moo`0O009o
o`0301moogoo01Aoo`030P007`0O00Qoo`0501moogooOol07`05Ool00`0O
Oomoo`04Ool201l8Ool00`0O0P1oo`0bOol00`80Oomoo`0AOol00`80Oomo
o`02Ool00`80Oomoo`05Ool201l7Ool401l00`80Oomoo`14Ool00`0OOomo
o`0@Ool00`0OOomoo`0[Ool00`80Oomoo`0@Ool00`0OOomoo`0nOol00`80
Oomoo`0COol03V<HOomS67ooIcUoof<HOomW>GooHaQoofLiOol3HaP1@Q01
0001Ool00004HaQoof<HHaP_Ool00`80Oomoo`0@Ool00`0OOomoo`0aOol0
0`80Oomoo`0EOol01@0OOomoo`0OOol00P0O00=oo`0OOol00P0O5Woo00<2
07ooOol037oo00<07gooOol00goo00<07gooOol03goo00<207ooOol0<Goo
00<207ooOol04Goo00<207ooOol00`8057oo00<207ooOol0A7oo00<07goo
Ool047oo00<07gooOol0:goo00<207ooOol047oo00<07gooOol0?Woo00<2
07ooOol04Woo011W>GooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQoo`9S
60524040005oo`0000AW>GooHaQW>Bmoo`030P1oogoo011oo`0301moogoo
035oo`030P1oogoo01Aoo`807`=oo`0301moogoo009oo`0301moogoo01Io
o`030P1oogoo00aoo`0301moogoo00<07a9oo`030P1oogoo035oo`030P1o
ogoo015oo`060P1oogoo0P1oo`8057oo00<207ooOol0A7oo00<07gooOol0
47oo00<07gooOol0:goo00<207ooOol047oo00<07gooOol0?Woo00<207oo
Ool04goo00iS67ooHaQoof<HOomW>GooHaQoofLiOomS67oo0f<H0D8@0@00
0Goo000016<HOomS66<H;goo00<207ooOol047oo00<07gooOol0<Goo00<2
07ooOol057oo00D207ooOomoo`80009oo`030P1oogoo01Uoo`030P1oogoo
00]oo`807`9oo`0301moogoo019oo`030P1oogoo035oo`030P1oogoo015o
o`060P1oogoo0P1oo`8057oo00<207ooOol0A7oo00<07gooOol047oo00<0
7gooOol0:goo00<207ooOol047oo00<07gooOol0?Woo00<207ooOol04Woo
01AW>GooHaQoofLiOomS67ooHaQoof<HOomS67ooHaQoof<HIcU240000Goo
000016LiOomS66Li;goo00<207ooOol047oo00<07gooOol0<Goo00<207oo
Ool057oo00D207ooOomoo`80009oo`8201Yoo`030P1oogoo011oo`807a9o
o`030P1oogoo035oo`030P1oogoo015oo`030P1oo`80009oo`030P1oogoo
019oo`030P1oogoo04Aoo`0301moogoo011oo`0301moogoo02]oo`030P1o
ogoo011oo`0301moogoo03ioo`030P1oogoo01=oo`0>HaQoof<HOomS67oo
HaQoofLiOomS67ooIcUoo`=S60524040005oo`0000AS67ooHaQS62moo`03
0P1oogoo011oo`0301moogoo035oo`030P1oogoo01=oo`080P1oo`80Ool2
07oo0P1oo`8201Yoo`030P1oogoo02Aoo`030P1oogoo035oo`030P1oogoo
015oo`8200Qoo`807`ioo`030P1oogoo01Yoo`807bQoo`0301moogoo00ao
o`807`9oo`0301moogoo02]oo`030P1oogoo011oo`0301moogoo03ioo`03
0P1oogoo019oo`0@IcUoofLiOomS67ooIcUoof<HOomS67ooHaQoof<HOol2
HaP1@Q010001Ool00004IcUoof<HIcT_Ool00`80Oomoo`13Ool00`0O0P02
000;0P0601l3Ool01P80Ool207oo0P1oo`82009oo`030P007`0O00@07fL2
000301l2008000<2000301l2008000@2000301l2008000@200L07`030P1o
ogoo00Ioo`0701moo`0O01moo`0OOol00P0O00=oo`0OOol00goo00@07goo
0P007`9oo`0301moogoo00=oo`0301moogoo009oo`0301moogoo00Yoo`06
01moo`0O01moo`0O17oo00H07goo01l07goo01l5Ool00`0OOomoo`03Ool0
0`0OOomoo`02Ool01@0OOomoogoo0P001Woo00<207ooOol02Woo00<2000O
Ool00P0O00=oo`0OOol00goo00H07goo01l07goo01l5Ool00`0OOomoo`03
Ool00`0OOomoo`02Ool00`0OOomoo`0@Ool00`80Oomoo`0:Ool00`80Oomo
o`03Ool00`80Oomoo`0nOol00`80Oomoo`0COol03V<HOomS67ooHaQoof<H
OomS67ooIcUoof<HOol3HaP1@Q010001Ool00004HaQoof<HHaP_Ool00`80
Oomoo`0:Ool00`80Oomoo`030P0cOol00`0O0P1oo`0BOol20P03Ool01@80
Oomoogoo0P0077oo00<207ooOol097oo00<207ooOol0:Woo00<07`80Ool0
0goo00<07gooOol017oo00<07`80Ool02goo0P801goo00L07gooOol07goo
01moo`0201l017oo01l07`0O0Woo00@07goo0P007`=oo`0301moogoo00<0
7`Aoo`0301moogoo00Yoo`0501moogoo01moo`0301l2Ool01@0OOol07`0O
Ool00`0O17oo00<07gooOol00`0O17oo00D07gooOomoo`8000Eoo`030P1o
ogoo00]oo`060P007gooOol07`800`0O0Woo00D07goo01l07goo00<07`Ao
o`0301moogoo00<07`Aoo`0301moogoo011oo`030P1oogoo00Yoo`030P1o
ogoo009oo`030P1oogoo03moo`030P1oogoo019oo`0DIcUoof<HOomW>Goo
HaQoofLiOomS67ooHaQoof<HOomS66Li@Q00005oo`0000AW>GooHaQW>Bmo
o`030P1oogoo00Yoo`040P1oogooOol20P0dOol00`80Oomoo`0BOol01@80
Oomoogoo0P000goo00<207ooOol06Woo00<207ooOol097oo00<207ooOol0
:goo00<207ooOol01Goo0`0O0Woo00<2000O01l027oo0P0O00<207oo0P00
1Woo00D07gooOol07goo00807`04Ool07goo01l2Ool01P0OOol07`0O0P00
7`=oo`0401moogooOol201l4Ool00`0OOomoo`0:Ool01P0OOomoo`0OOol0
7`9oo`0801moo`0O01moo`0OOol07`9oo`0501moogooOol07`03Ool201l4
Ool01@0OOomoogoo0P0017oo00<207ooOol037oo00L2000OOomoo`0OOol0
7`02Ool0200OOol07`0OOol07goo01l2Ool01@0OOomoogoo01l00goo0P0O
17oo00<07gooOol047oo00<207ooOol02Woo00D207ooOomoo`80049oo`03
0P1oogoo01=oo`0>HaQoof<HOomS67ooHaQoof<HOomS67ooIcUoo`=S6052
4040005oo`0000AS67ooHaQS62moo`030P1oogoo00Yoo`060P1oogoo0P1o
o`80=7oo00<207ooOol0=goo00<207ooOol097oo00<207ooOol0:goo00<2
07ooOol00Woo00@07gooOol07`9oo`0401moo`80Ool201l3Ool0100OOomo
o`0O0Woo00@07gooOol200Eoo`0601moogoo01moo`0O0Woo00<07goo01l0
0Woo00H07goo01moo`8001l4Ool01@0OOomoogoo01l00goo0P0O37oo00H0
7gooOol07goo01l2Ool00`0OOol07`02Ool00`0OOol07`02Ool00`0OOomo
o`02Ool01@0OOomoogoo01l00goo0P0O0goo00<207ooOol00P803goo00L2
000OOol2000OOol07`02Ool00`0OOol07`02Ool00`0OOol07`02Ool00`0O
Oomoo`02Ool01@0OOomoogoo01l00goo0P0O4Woo00<207ooOol02Woo00@2
07ooOol204=oo`030P1oogoo019oo`0@IcUoofLiOomS67ooIcUoof<HOomW
>GooHaQoof<HOol2HaP1@Q010001Ool00004IcUoof<HIcT_Ool00`80Oomo
o`0:Ool00`80Ool20002Ool00`80Oomoo`0bOol00`80Oomoo`0gOol00`80
Oomoo`0TOol00`80Oomoo`0[Ool00`80Oomoo`02Ool01@0OOomoo`0OOol0
0P0O00Eoo`80Oomoo`0O00=oo`0401moogoo01l2Ool01@0OOomoogoo0P00
1Goo0P0O1Goo00<07goo01l00P0O17oo00<2000OOol0100O5Woo0P0O0Woo
0`0O1Goo00<07goo01l00P0O0Woo100O37oo00<207oo0P004Goo00@207oo
01l07`9oo`<07`Eoo`0301moo`0O00807`9oo`@07a]oo`030P1oogoo00Yo
o`030P007`0O04Aoo`030P1oogoo01=oo`0>HaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoo`=S60524040005oo`0000AS67ooHaQS62Moo`<07`Eoo`03
0P1oogoo00Yoo`8200Moo`807bmoo`030P1oogoo03Moo`030P1oogoo02Ao
o`030P1oogoo02]oo`030P1oogoo009oo`0301moogoo00<07`9oo`040P1o
ogoo01l3Ool00`0OOomoo`0301l00`80Oomoo`02Ool00`80Oomoo`0BOol0
0`80Oomoo`0mOol20P0BOol20P0bOol00`80Oomoo`0:Ool01P0O0P007`0O
Ool07`Aoo`0601moo`0O01moo`0O1Goo00<07gooOol00goo00<07gooOol0
0Woo00<07gooOol097oo00<207ooOol04Woo01AW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoof<HIcU240000Goo000016LiOomS66Li9goo00@0
7gooOol07`=oo`0301l2008000D200H07`030P1oogoo00Eoo`0701moo`0O
01moo`0OOol00P0O00=oo`0OOol00goo00@07goo01l07`9oo`0301moogoo
00=oo`0301moogoo009oo`0301moogoo00Qoo`<07`Aoo`030P1oogoo03Mo
o`030P1oogoo02Aoo`030P1oogoo02]oo`040P1oogooOol201l2Ool01P0O
Oomoo`0OOol2009oo`0301moogoo00807`9oo`807`03Ool07goo00Aoo`03
0P1oogoo011oo`0301l2008003L2000301l20080018200H07`030P1oogoo
011oobP200L07`9oo`0301moo`0O00807`9oo`0501moo`0O01moo`0301l4
Ool00`0OOomoo`0301l4Ool00`0OOomoo`0TOol00`80Oomoo`0COol03V<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOol3HaP1@Q010001Ool00004HaQo
of<HHaPWOol0100OOol07`0O0goo00<07`80Ool00goo0P0O1Woo0P801Woo
00L07gooOol07goo01moo`0201l017oo01l07`0O0Woo00@07goo01l07`=o
o`0301moogoo00<07`Aoo`0301moogoo00]oo`0501moogooOol2000NOol3
01lHOol00`80Oomoo`0TOol00`80Oomoo`0[Ool00`80Oomoo`06Ool201l2
Ool00`8001l07`09Ool00`0OOomoo`04Ool00`0OOomoo`0@Ool00`0O0P1o
o`0gOol00`0OOomoo`04Ool20P0BOol20P0AOol00`80Oomoo`0NOol00`80
Oomoo`0:Ool01P0O0P1oo`0OOol07`9oo`0801moo`0O01moo`0OOol07`9o
o`0501moogooOol07`03Ool201l4Ool00`0OOomoo`0TOol00`80Oomoo`0B
Ool046LiOomW>GooHaQoofLiOomS67ooIcUoof<HOomS67oo0V<H0D8@0@00
0Goo000016LiOomS66Li9goo0`0O1Goo00H207ooOomoo`0OOol201l2Ool0
1P0OOomoo`80Ool200Eoo`0501moogoo01moo`0201l017oo01moo`0O0Woo
00H07goo01l07goo01l3Ool0100OOomoogoo0P0O17oo00<07gooOol027oo
100O0goo00<207ooOol04Woo00<07goo01l017oo00D07gooOomoo`0O01Uo
o`030P1oogoo02Aoo`030P1oogoo02]oo`030P1oogoo00Yoo`030P1oogoo
011oo`0301moogoo015oo`030P1oogoo03eoo`030P1oo`8000@200eoo`03
0P1oo`8000<200eoo`030P1oogoo01ioo`030P1oogoo00Yoo`0601moo`80
01l2000O0Woo00<07goo01l00Woo00<07goo01l00Woo00<07gooOol00Woo
00D07gooOomoo`0O00=oo`807bIoo`030P1oogoo01=oo`0>HaQoof<HOomS
67ooHaQoof<HOomS67ooIcUoo`=S60524040005oo`0000AS67ooHaQS62Mo
o`0401moogoo01l4Ool01@80Oomoogoo01l00Woo00L07gooOomoo`0OOol2
0002Ool00`80Oomoo`02Ool01P0OOomoo`0OOol07`9oo`0301moo`0O009o
o`0301moo`0O009oo`0301moogoo009oo`0501moogooOol07`03Ool201l:
Ool0100OOomoo`0O0goo00<207ooOol04Woo0`0O17oo00<07gooOol00Woo
00<07gooOol05Woo00<207ooOol097oo00<207ooOol0:goo00<207ooOol0
2Woo00<207ooOol047oo00<07gooOol04Goo00<207ooOol0:Goo0P0O0Woo
0`0O0Woo0`0O27oo00@207oo0P02011oo`040P1oo`800P0?Ool00`80Oomo
o`0NOol0108001moogoo0`0O0goo0P0O00Ioo`8001l07`80Ool301l5Ool0
0`0OOol07`0201l2Ool401l_Ool00`80Oomoo`0BOol056LiOomS67ooIcUo
of<HOomW>GooHaQoof<HOomS67ooHaQW>D8@0001Ool00004IcUoof<HIcTX
Ool201l5Ool01@80Oomoogoo01l00Woo00L07gooOomoo`0OOol20002Ool0
0`80Oomoo`03Ool201l5Ool00`0OOol07`0201l5Ool00`0OOol07`0301lC
Ool00`0OOol07`04Ool00`80Oomoo`0BOol0100OOomoo`0O0goo00<07goo
Ool00goo00<07gooOol05Goo00<207ooOol097oo00<207ooOol0:goo00<2
07ooOol02Woo00<207ooOol047oo00<07gooOol04Goo00<207ooOol0:7oo
00@07goo01l07`9oo`0301moogoo009oo`0301moogoo00=oo`0901moogoo
Ool207oo0P1oo`8000moo`040P1oo`800P0?Ool00`80Oomoo`0MOol0100O
0P007`0O0Woo00D07gooOomoo`0O009oo`0301l207oo008204=oo`030P1o
ogoo01=oo`0>HaQoof<HOomS67ooHaQoof<HOomW>GooHaQoo`=S60524040
005oo`0000AS67ooHaQS62moo`050P1oogooOol07`02Ool00`0OOomoo`02
Ool00`0O0P1oo`02Ool00`80Oomoo`0]Ool00`0OOomoo`03Ool00`80Oomo
o`0BOol0100OOomoo`0O0Woo0P0O0Woo00@07goo01l07aMoo`030P1oogoo
02Aoo`030P1oogoo02]oo`030P1oogoo00Yoo`030P1oogoo011oo`0301mo
ogoo015oo`030P1oogoo02Qoo`0401moogoo01l3Ool00`0OOomoo`02Ool0
0`0OOomoo`02Ool01`0OOomoogoo0P1oo`80009oo`030P1oogoo00aoo`05
0P1oo`80Ool2000>Ool00`80Oomoo`0MOol0100O0P1oo`0O0goo00@07goo
Ool07`9oo`0601l207oo0P1oo`80@Woo00<207ooOol04Woo011W>GooIcUo
of<HOomW>GooHaQoof<HOomS67ooHaQoo`9S60524040005oo`0000AW>Goo
HaQW>Bmoo`030P1oogoo009oo`807`9oo`@07`030P1oogoo009oo`030P1o
ogoo039oo`030P1oogoo019oo`<07`Qoo`0301moogoo01Moo`030P1oogoo
02Aoo`030P1oogoo02]oo`030P1oogoo00Yoo`030P1oogoo011oo`0301mo
ogoo015oo`030P1oogoo02Qoo`0401moogoo01l4Ool00`0OOomoo`02Ool0
1@0OOomoogoo01l00goo00<207ooOol00goo00<207ooOol02goo00<207oo
Ool00Woo00<207ooOol02goo00<207ooOol00`0O6Woo00@07`80Ool07`Ao
o`0301moo`0O009oo`0301l207oo00=oo`030P1oogoo03moo`030P1oogoo
01=oo`0>HaQoof<HOomS67ooHaQoofLiOomS67ooIcUoo`=S60524040005o
o`0000AS67ooHaQS62moo`030P1oogoo00Yoo`030P1oogoo00=oo`030P1o
ogoo035oo`030P1oogoo03Moo`030P1oogoo02Aoo`030P1oogoo02]oo`03
0P1oogoo00Yoo`030P1oogoo011oo`030P1oogoo015oo`030P1oogoo02Qo
o`0701moogoo01moo`0OOol00P0O00=oo`0OOol00P0O0Woo0P0O:Woo00D2
07ooOomoo`0O00Eoo`0301moogoo01=oo`0701l207oo01moo`0OOol00P0O
00=oo`0OOol00P0OAgoo00<207ooOol04Woo01AW>GooHaQoofLiOomS67oo
HaQoof<HOomS67ooHaQoof<HIcU240000Goo000016LiOomS66Li;goo00<2
07ooOol047oo00<07gooOol0<Goo00<207ooOol0=goo00<207ooOol097oo
00<207ooOol0:goo00<207ooOol02Woo00<207ooOol047oo00<207ooOol0
4Goo00<207ooOol0:Goo0P0O0goo00<07gooOol00Woo00<07gooOol03Goo
0P0O0Woo0`0O0Woo0`0O0Woo0`0O0goo00<07gooOol02Woo00<207ooOol0
0Woo00<07gooOol00`0O5Woo0P0O0goo00<07gooOol00Woo00<07gooOol0
1Woo00<07gooOol0?Woo00<207ooOol04goo00iS67ooHaQoof<HOomW>Goo
HaQoofLiOomS67oo0f<H0D8@0@000Goo000016<HOomS66<H;goo00<207oo
Ool047oo00<07gooOol0<Goo00<207ooOol0=goo00<207ooOol097oo00<2
07ooOol0:goo00<207ooOol02Woo00<207ooOol047oo00<207ooOol04Goo
00<207ooOol0@Woo00@07goo01l07`9oo`0301moogoo009oo`0301moogoo
009oo`0301moogoo009oo`0301moogoo00Yoo`030P1oogoo00=oo`0301mo
ogoo00807aIoo`0301moogoo011oo`0301moogoo03ioo`030P1oogoo019o
o`0@IcUoofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOol2HaP1@Q010001
Ool00004IcUoof<HIcT_Ool00`80Oomoo`0@Ool00`0OOomoo`0aOol00`80
Oomoo`0gOol00`80Oomoo`0TOol00`80Oomoo`0[Ool00`80Oomoo`0:Ool0
0`80Oomoo`0@Ool00`80Oomoo`0AOol00`80Oomoo`12Ool0100OOol07`0O
0goo00<07gooOol00Woo00<07gooOol00Woo00D07gooOomoo`0O00aoo`05
0P1oogoo01moo`0201l3Ool00`0OOomoo`0DOol00`0OOomoo`0@Ool00`0O
Oomoo`0nOol00`80Oomoo`0COol03V<HOomS67ooIcUoof<HOomW>GooHaQo
ofLiOol3HaP1@Q010001Ool00004HaQoof<HHaP_Ool00`80Oomoo`0@Ool0
0`0OOomoo`0aOol00`80Oomoo`0gOol00`80Oomoo`0TOol00`80Oomoo`0[
Ool00`80Oomoo`0:Ool00`80Oomoo`0@Ool00`80Oomoo`0AOol00`80Oomo
o`12Ool0100OOol07`0O17oo00<07gooOol00Woo00<07gooOol00Woo00@0
7gooOol07`aoo`050P1oogooOol07`0LOol00`0OOomoo`0@Ool00`0OOomo
o`0nOol00`80Oomoo`0BOol056LiOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQW>D8@0001Ool00004IcUoof<HIcT_Ool00`80Oomoo`0@Ool0
0`0OOomoo`0aOol00`80Oomoo`0gOol00`80Oomoo`0TOol00`80Oomoo`0[
Ool00`80Oomoo`0:Ool00`80Oomoo`0@Ool00`80Oomoo`0AOol00`80Oomo
o`12Ool01`0OOol07`0OOol07goo00807`03Ool07goo00807`03Ool07goo
00807`9oo`0301moogoo00Yoo`030P1oogoo01ioo`0301moogoo011oo`03
01moogoo03ioo`030P1oogoo01=oo`0>HaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoo`=S60524040005oo`0000AS67ooHaQS62moo`030P1oogoo011o
o`030P1oogoo035oo`030P1oogoo03Moo`030P1oogoo02Aoo`030P1oogoo
02]oo`030P1oogoo00Yoofh2000501moogooOol07`04Ool00`0OOomoo`02
Ool00`0OOomoo`02Ool00`80Oomoo`0:Ool00`80Oomoo`0NOol00`80Oomo
o`03Ool00`80Oomoo`0:Ool00`0OOomoo`0nOol00`80Oomoo`0BOol046Li
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@0@000Goo0000
16LiOomS66Li;goo00<207ooOol047oo00<207ooOol0<Goo00<207ooOol0
=goo00<207ooOol097oo00<207ooOol0:goo00<207ooOol07Goo00<207oo
Ool04Goo00<207ooOol0Egoo00<207ooOol02Woo00<207ooOol07goo00<2
07ooOol00Woo00<207ooOol02Woo00<207ooOol0?Woo00<207ooOol04goo
00iS67ooHaQoofLiOomS67ooIcUoof<HOomW>Goo0f<H0D8@0@000Goo0000
16<HOomS66<H;goo00<207ooOol047oo00<207ooOol0<Goo00<207ooOol0
=goo00<207ooOol097oo00<207ooOol0:goo00<207ooOol07Goo00<207oo
Ool04Goo00<207ooOol0Egoo00<207ooOol02Woo00<207ooOol087oo00D2
07ooOomoo`8000aoo`030P1oogoo03ioo`030P1oogoo019oo`0DIcUoofLi
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS66Li@Q00005oo`0000AW>Goo
HaQW>Bmoo`030P1oogoo011oo`030P1oogoo035oo`030P1oogoo03Moo`03
0P1oogoo02Aoo`030P1oogoo02]oo`030P1oogoo01eoo`030P1oogoo015o
o`030P1oogoo05Moo`030P1oogoo00Yoo`030P1oogoo025oo`040P1oogoo
0P0<Ool00`80Oomoo`0nOol00`80Oomoo`0COol03V<HOomS67ooHaQoofLi
OomS67ooIcUoof<HOol3HaP1@Q010001Ool00004HaQoof<HHaP_Ool00`80
Oomoo`0@Ool00`80Oomoo`0aOol00`80Oomoo`0gOol00`80Oomoo`0TOol0
0`80Oomoo`0[Ool00`80Oomoo`0MOol00`80Oomoo`0AOol00`80Oomoo`1G
Ool00`80Oomoo`0:Ool00`80Oomoo`0QOol01080Oomoo`8037oo00<207oo
01l00P0O?7oo00<207ooOol04Woo011W>GooHaQoofLiOomS67ooHaQoof<H
OomS67ooHaQoo`9S60524040005oo`0000AW>GooHaQW>Bmoo`030P1oogoo
011oo`030P1oogoo035oo`030P1oogoo03Moo`030P1oogoo02Aoo`030P1o
ogoo02]oo`030P1oogoo01eoo`030P1oogoo015oo`030P1oogoo05Moo`03
0P1oogoo00Yoo`030P1oogoo009oo`807aioo`030P1oo`8000aoo`040P1o
ogoo01l4Ool00`0OOomoo`0fOol00`80Oomoo`0COol03V<HOomS67ooHaQo
of<HOomW>GooHaQoofLiOol3HaP1@Q010001Ool00004HaQoof<HHaP_Ool0
0`80Oomoo`0@Ool00`80Oomoo`0aOol00`80Oomoo`0gOol00`80Oomoo`0T
Ool00`80Oomoo`0[Ool00`80Oomoo`0MOol00`80Oomoo`0AOol00`80Oomo
o`1GOol00`80Oomoo`0:Ool01P80Oomoogoo01moo`807`03Ool07goo00=o
o`0601moo`0O01moo`0O1Goo00<07gooOol00goo00<07gooOol00Woo00@0
7goo0P0200aoo`050P1oogooOol07`04Ool00`0OOomoo`0eOol00`80Oomo
o`0BOol056LiOomW>GooHaQoofLiOomS67ooHaQoof<HOomS67ooHaQW>D8@
0001Ool00004IcUoof<HIcT_Ool00`80Oomoo`0@Ool00`80Oomoo`0aOol0
0`80Oomoo`0gOol00`80Oomoo`0TOol00`80Oomoo`0[Ool00`80Oomoo`0M
Ool00`80Oomoo`0AOol00`80Oomoo`1FOol00`0O0P02000<0P03Ool01@0O
Oomoo`0OOol00`0O0Woo00D07goo01l07goo00<07`Aoo`0301moogoo00<0
7`Aoo`0401moogoo0P0601l50P000`0O0P1oo`03Ool01@0OOomoogoo01l0
=goo00<207ooOol04goo00iS67ooHaQoof<HOomS67ooHaQoofLiOomS67oo
0f<H0D8@0@000Goo000016<HOomS66<H;goo00<207ooOol047oo00<207oo
Ool0<Goo00<207ooOol0=goo00<207ooOol097oo00<207ooOol0:goo00<0
7gooOol07Goo00<207ooOol04Goo00<207ooOol0EWoo00<07`80Ool03goo
00H07gooOol07goo01l2Ool0200OOol07`0OOol07goo01l2Ool01@0OOomo
ogoo01l00goo0P0O17oo00@07goo0P0200]oo`807`03Ool07goo00807`Ao
o`0301moogoo03Aoo`030P1oogoo019oo`0@IcUoof<HOomW>GooHaQoofLi
OomS67ooHaQoof<HOol2HaP1@Q010001Ool00004IcUoof<HIcT_Ool00`80
Oomoo`0@Ool00`80Oomoo`0aOol00`80Oomoo`0gOol00`80Oomoo`0TOol0
0`80Oomoo`0[Ool00`0OOomoo`0MOol00`80Oomoo`0AOol00`80Oomoo`1G
Ool00`80Oomoo`0>Ool01P0OOomoo`0OOol07`9oo`0301moo`0O009oo`03
01moo`0O009oo`0301moogoo009oo`0501moogooOol07`02Ool01P8001l0
7`80Ool200aoo`0401moogoo01l3Ool401lfOol00`80Oomoo`0COol03V<H
OomS67ooHaQoof<HOomS67ooHaQoofLiOol3HaP1@Q010001Ool00004HaQo
of<HHaP_Ool00`80Oomoo`0@Ool00`80Oomoo`0aOol00`80Oomoo`0gOol0
0`80Oomoo`0TOol00`80Oomoo`0[Ool00`0OOomoo`0MOol00`80Oomoo`0A
Ool00`80Oomoo`1GOol00`80Oomoo`0?Ool201l2Ool301l5Ool00`0OOol0
7`0201l2Ool401l8Ool20P000goo0P1oo`0;Ool00`0OOomoo`0nOol00`80
Oomoo`0BOol056LiOomW>GooHaQoofLiOomS67ooIcUoof<HOomS67ooHaQW
>D8@0001Ool00004IcUoof<HIcT_Ool00`80Oomoo`0@Ool00`80Oomoo`0a
Ool00`80Oomoo`0gOol00`80Oomoo`0TOol00`80Oomoo`0[Ool00`0OOomo
o`0MOol00`80Oomoo`0AOol00`80Oomoo`1GOol00`80Oomoo`0]Ool01@80
Ool207oo0P0037oo00<07gooOol0?Woo00<207ooOol04goo00iS67ooHaQo
of<HOomS67ooHaQoof<HOomS67oo0f<H0D8@0@000Goo000016<HOomS66<H
;goo00<207ooOol047oo00<207ooOol0<Goo00<207ooOol0=goo00<207oo
Ool097oo00<207ooOol0:goo00<07gooOol07Goo00<207ooOol04Goo00<2
07ooOol0Egoo00<207ooOol0;7oo00<207ooOol00Woo00<207ooOol02Woo
00<07gooOol0?Woo00<207ooOol04Woo011W>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoo`9S60524040005oo`0000AW>GooHaQW>Bmoo`030P1o
ogoo011oo`030P1oogoo035oo`030P1oogoo03Moo`030P1oogoo02Aoo`03
0P1oogoo01Qoo`<07`=oo`807`9oo`<07`Ioo`030P1oogoo01eoo`030P1o
ogoo015oo`030P1oogoo05Moo`030P1oogoo03ioo`030P1oogoo03ioo`03
0P1oogoo01=oo`0>HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoo`=S6052
4040005oo`0000AS67ooHaQS62moo`030P1oogoo011oo`030P1oogoo035o
o`030P1oogoo03Moo`030P1oogoo02Aoo`030P1oogoo01]oo`0301moo`0O
009oo`0301moo`0O009oo`0301moogoo00=oo`030P1oogoo01eoo`030P1o
ogoo015oo`030P1oogoo05Moo`030P1oogoo02]oo`0301moogoo00=oo`<0
7`9oo`<07`Eoo`030P1oogoo03ioo`030P1oogoo019oo`0DIcUoofLiOomS
67ooIcUoof<HOomW>GooHaQoof<HOomS66Li@Q00005oo`0000AW>GooHaQW
>Bmoo`030P1oogoo011oo`030P1oogoo035oo`030P1oogoo03Moo`030P1o
ogoo02Aoo`030P1oogoo01]oo`0301moo`0O009oo`0301moo`0O009oo`03
01moo`8000H201eoo`030P1oogoo015oo`030P1oogoo05Moo`030P1oogoo
01moo`807`9oo`<07`Eoo`0301moogoo00Aoo`0301moogoo009oo`0301mo
ogoo009oo`82045oo`030P1oogoo01=oo`0>HaQoof<HOomS67ooHaQoof<H
OomS67ooIcUoo`=S60524040005oo`0000AS67ooHaQS62moo`030P1oogoo
011oo`030P1oogoo035oo`030P1oogoo03Moo`030P1oogoo02Aoo`030P1o
ogoo01Yoo`0401moogoo01l2Ool00`0OOol07`0201lVOol00`80Oomoo`0A
Ool00`80Oomoo`1GOol00`80Oomoo`0NOol0100OOol07`0O0Woo00<07goo
Ool00goo0P0O1goo00<07gooOol00Woo00<07gooOol00goo0P80?goo00<2
07ooOol04Woo011W>GooHaQoofLiOomS67ooIcUoof<HOomS67ooHaQoo`9S
60524040005oo`0000AW>GooHaQW>Bmoo`030P1oogoo011oo`030P1oogoo
035oo`030P1oogoo03Moo`030P1oogoo00Aoo`<07aeoo`030P1oogoo01Yo
o`0501moogoo01moo`0201lZOol00`80Oomoo`0AOol00`80Oomoo`15Ool3
01l3Ool201l:Ool00`80Oomoo`0NOol0100OOomoo`0O0goo00<07gooOol0
0Woo0P0O27oo00<07gooOol00Woo00<07gooOol017oo0P80?Goo00<207oo
Ool04goo00iS67ooHaQoof<HOomS67ooHaQoofLiOomS67oo0f<H0D8@0@00
0Goo000016<HOomS66<H;goo00<207ooOol047oo00<207ooOol0<Goo00<2
07ooOol0=goo00<207ooOol01goo00<07gooOol06Woo00<207ooOol06Goo
0P0O0goo00<07gooOol01Woo1`807Goo00<207ooOol04Goo00<207ooOol0
B7oo00<07goo01l00Woo00@07goo01l07`Ioo`030P1oogoo01ioo`0401mo
ogoo01l4Ool0100OOomoogoo0P0O1Goo00L07goo01l07goo01moo`0201l4
Ool20P0oOol00`80Oomoo`0BOol056LiOomW>GooHaQoofLiOomS67ooHaQo
of<HOomS67ooHaQW>D8@0001Ool00004IcUoof<HIcT_Ool00`80Oomoo`0@
Ool00`80Oomoo`0aOol00`80Oomoo`0gOol00`80Oomoo`07Ool00`0OOomo
o`0JOol00`80Oomoo`0[Ool00`80Oomoo`0MOol00`80Oomoo`0AOol00`80
Oomoo`18Ool00`0OOol07`02Ool0100OOol07`0O1Woo00<207ooOol07Woo
00L07gooOol07goo01moo`0201l2Ool301l6Ool00`0OOomoo`02Ool00`0O
Oomoo`02Ool20P11Ool00`80Oomoo`0COol03V<HOomS67ooHaQoof<HOomW
>GooHaQoofLiOol3HaP1@Q010001Ool00004HaQoof<HHaP_Ool00`80Oomo
o`0@Ool00`80Oomoo`0NOom<0P000`0O0P1oo`07Ool00`0OOomoo`0KOol0
0`80Oomoo`0KOol201l^Ool00`80Oomoo`0AOol00`80Oomoo`15Ool301l2
Ool0200OOomoo`0OOol07goo01l5Ool00`80Oomoo`0OOol201l3Ool00`0O
Oomoo`04Ool00`0OOomoo`0@Ool20P0oOol00`80Oomoo`0BOol046LiOomS
67ooIcUoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@0@000Goo000016Li
OomS66Li;goo00<207ooOol047oo00<207ooOol07Woo00<207ooOol047oo
00<207ooOol0=Woo00<07`80Ool01goo00<07gooOol06goo00<207ooOol0
6Woo00<07gooOol017oo00<07gooOol01goo00<07gooOol07Goo00<207oo
Ool04Goo00<207ooOol0AGoo00<07gooOol00Woo00H07goo01l07goo01l7
Ool00`80Oomoo`0[Ool00`80Oomoo`0BOol20P0mOol00`80Oomoo`0COol0
3V<HOomS67ooHaQoofLiOomS67ooIcUoof<HOol3HaP1@Q0100010P000004
HaQoof<HHaP_Ool00`80Oomoo`0@Ool00`80Oomoo`0NOol00`80Oomoo`0@
Ool00`80Oomoo`0gOol00`80Oomoo`05Ool201lMOol00`80Oomoo`0JOol0
0`0OOomoo`04Ool00`0OOomoo`07Ool00`0OOomoo`0MOol00`80Oomoo`0A
Ool00`80Oomoo`16Ool201l3Ool00`0OOomoo`09Ool00`80Oomoo`0[Ool0
0`80Oomoo`0@Ool20P0oOol00`80Oomoo`0BOol046LiOomW>GooHaQoof<H
OomS67ooHaQoof<HOomS67oo0V<H0D8@0@000Goo000016LiOomS66Li;goo
00<207ooOol047oo00<207ooOol07Woo00<207ooOol047oo00<207ooOol0
=goo00<207ooOol097oo00<207ooOol06Woo00<07gooOol017oo00<07goo
Ool01goo00<07gooOol07Goo00<207ooOol04Goo00<207ooOol0Egoo00<2
07ooOol0:goo00<207ooOol00Woo00<07goo01l00goo00<07gooOol00goo
0P80@Goo00<207ooOol04goo00iS67ooHaQoofLiOomS67ooIcUoof<HOomW
>Goo0f<H0D8@0@000Goo000016<HOomS66<H;goo00<207ooOol047oo00<2
07ooOol07Woo00<207ooOol047oo00<207ooOol0=goo00<207ooOol097oo
00<207ooOol06Woo00@07gooOol07`9oo`807`Uoo`0301moogoo01eoo`03
0P1oogoo015oo`030P1oogoo04Moo`050P1oogooOol20003Ool00`80Oomo
o`05Ool00`80Oomoo`0[Ool00`80Oomoo`02Ool301l4Ool00`0OOomoo`04
Ool20P0oOol00`80Oomoo`0BOol056LiOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQW>D8@0001Ool00004IcUoof<HIcT_Ool00`80Oomoo`0@
Ool00`80Oomoo`0NOol00`80Oomoo`0@Ool00`80Oomoo`0gOol00`80Oomo
o`0TOol00`80Oomoo`0KOol201l>Ool00`0OOomoo`0MOol00`80Oomoo`0A
Ool00`80Oomoo`17Ool01@80Oomoogoo0P000goo00<207ooOol01Goo00<2
07ooOol0:goo00<207ooOol00Woo00@07gooOol07`=oo`0301moogoo00Io
o`8203eoo`030P1oogoo01=oo`0>HaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoo`=S60524040005oo`0000AS67ooHaQS62moo`0301moogoo011oo`03
0P1oogoo01ioo`030P1oogoo011oo`030P1oogoo03Moo`030P1oogoo02Ao
o`030P1oogoo02]oo`030P1oogoo01eoo`030P1oogoo015oo`030P1oogoo
035oo`<07`9oo`<07`Aoo`030P007`0O00@07`9oo`0:0P1oo`80Ool207oo
0P1oo`80Ool20P0501l00`80Oomoo`0[Ool00`80Oomoo`02Ool0100OOomo
o`0O17oo00<07gooOol017oo00<207ooOol0=Goo0P0O1Woo00<207ooOol0
4Woo011W>GooHaQoof<HOomS67ooHaQoof<HOomS67ooIcUoo`9S60524040
005oo`0000AW>GooHaQW>Bmoo`0301moogoo011oo`030P1oogoo01ioo`03
0P1oogoo011oo`0301moogoo03Moo`030P1oogoo02Aoo`030P1oogoo02]o
o`030P1oogoo01eoo`030P1oogoo015oo`030P1oogoo039oo`0301moogoo
00Aoo`0501moogooOol20006Ool02`80Ool207oo0P1oo`80Ool207oo0P00
1goo00<07`80Ool0;7oo00<207ooOol00Woo0`0O0Woo100O1Goo00<07goo
Ool0=Goo00@07gooOol07`Eoo`030P1oogoo01=oo`0>HaQoof<HOomW>Goo
HaQoofLiOomS67ooHaQoo`=S60524040005oo`0000AS67ooHaQS62moo`03
01moogoo011oo`030P1oogoo01ioo`030P1oogoo011oo`0301moogoo03Mo
o`030P1oogoo02Aoo`030P1oogoo02]oo`030P1oogoo01eoo`030P1oogoo
015oo`030P1oogoo03=oo`0301moogoo00=oo`0501moogooOol20007Ool0
1@80Oomoogoo0P000goo00<207ooOol01goo00<207ooOol0:goo00<207oo
Ool047oo00<07gooOol0=Goo00@07gooOol07`Eoo`030P1oogoo019oo`0D
IcUoofLiOomS67ooHaQoof<HOomS67ooIcUoof<HOomS66Li@Q00005oo`00
00AW>GooHaQW>Bmoo`0301moogoo011oo`030P1oogoo01ioo`030P1oogoo
011oo`0301moogoo03Moo`030P1oogoo02Aoo`030P1oogoo02]oo`030P1o
ogoo01eoo`030P1oogoo015oo`030P1oogoo03Aoo`0501moogooOol07`04
Ool00`80Oomoo`05Ool01@80Oomoogoo0P000goo00<207ooOol01goo00<2
07ooOol0:goo00<207ooOol047oo00<07gooOol0<Goo00D07gooOomoo`0O
009oo`0301moogoo00=oo`030P1oogoo01=oo`0>HaQoof<HOomS67ooIcUo
of<HOomS67ooHaQoo`=S60524040005oo`0000AS67ooHaQS62moo`0301mo
ogoo011oo`030P1oogoo01ioo`030P1oogoo011oo`0301moogoo03Moo`03
0P1oogoo02Aoo`030P1oogoo02]oo`030P1oogoo01eoo`030P1oogoo015o
o`030P1oogoo035oo`0401moo`0O01l3Ool00`0OOomoo`02Ool00`80Oomo
o`0GOol00`80Oomoo`0[Ool00`80Oomoo`0@Ool00`0OOomoo`0`Ool00`0O
Ool07`02Ool0100OOol07`0O1Goo00<207ooOol04Woo011W>GooHaQoofLi
OomS67ooHaQoofLiOomS67ooHaQoo`9S60524040005oo`0000AW>GooHaQW
>Bmoo`0301moogoo011oo`030P1oogoo01ioo`030P1oogoo011oo`0301mo
ogoo03Moo`030P1oogoo02Aoo`030P1oogoo02]oo`030P1oogoo01eoo`03
0P1oogoo015oo`030P1oogoo00=oo`0501moogooOol07`0ZOol00`0OOomo
o`02Ool201l4Ool00`80Oomoo`0GOol00`80Oomoo`0[Ool00`80Oomoo`0@
Ool00`0OOomoo`0_Ool0100OOomoo`0O0goo00<07gooOol01Goo00<207oo
Ool04goo00iS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo0f<H0D8@0@00
0Goo000016<HOomS66<H;goo00<07gooOol047oo00<207ooOol07Woo00<2
07ooOol047oo00<07gooOol0=goo00<207ooOol097oo00<207ooOol0:goo
00<207ooOol07Goo00<207ooOol04Goo00<207ooOol00goo00<07gooOol0
0Woo00<07gooOol0<Woo00<207ooOol03goo0P0O1Woo00<207ooOol0:goo
00<207ooOol047oo00<07gooOol077oo00<07gooOol00P0O3Woo00D07goo
Oomoo`0O00Yoo`030P1oogoo019oo`0DIcUoofLiOomS67ooIcUoof<HOomS
67ooIcUoof<HOomS66Li@Q00005oo`0000AW>GooHaQW>Bmoo`030P1oogoo
00=oo`030P1oogoo00Yoo`030P1oogoo01ioo`030P1oogoo00Yoo`030P1o
ogoo00=oo`030P1oogoo03Moo`030P1oogoo02Aoo`030P1oogoo02]ooc<2
000301l207oo00Aoo`0301moogoo009oo`0301moogoo039oo`030P1oogoo
00Aoo`0301moo`0O00Aoo`0401moogoo01l2Ool00`0OOomoo`03Ool00`0O
Oomoo`0[Ool00`80Oomoo`0@Ool00`0OOomoo`0LOol00`0OOomoo`0201l=
Ool601l:Ool00`80Oomoo`0COol03V<HOomS67ooHaQoof<HOomW>GooHaQo
of<HOol3HaP1@Q010001Ool00004HaQoof<HHaP`Ool00`80Oomoo`02Ool0
0`80Oomoo`0:Ool00`80Oomoo`0NOol00`80Oomoo`0:Ool00`80Oomoo`02
Ool00`80Oomoo`0hOol00`80Oomoo`0TOol00`80Oomoo`1;Ool00`80Oomo
o`0@Ool00`0O0P1oo`03Ool201l5Ool00`0OOomoo`0aOol00`80Oomoo`04
Ool301l4Ool0100OOomoo`0O0Woo00<07gooOol00goo00<07gooOol0:goo
00<207ooOol047oo00<207ooOol077oo00H07gooOol07goo01l?Ool00`0O
Oomoo`0:Ool00`80Oomoo`0BOol046LiOomS67ooIcUoof<HOomS67ooHaQo
of<HOomW>Goo0V<H0D8@0@000Goo000016LiOomS66Li<Goo00D207ooOomo
o`8000aoo`030P1oogoo01ioo`030P1oogoo00Yoo`050P1oogooOol2000k
Ool00`80Oomoo`0TOol00`80Oomoo`1;Ool00`80Oomoo`0AOol00`80Oomo
o`06Ool401lcOol00`80Oomoo`04Ool0100OOomoo`0O0goo00@07gooOol0
7`9oo`0301moogoo00=oo`0301moogoo02]oo`030P1oogoo011oo`030P1o
ogoo01]oo`807`9oo`0301moogoo00moo`0301moogoo00Yoo`030P1oogoo
01=oo`0>HaQoof<HOomS67ooIcUoof<HOomW>GooHaQoo`=S60524040005o
o`0000AS67ooHaQS639oo`040P1oogoo0P0<Ool00`80Oomoo`0NOol00`80
Oomoo`0:Ool01080Oomoo`80?7oo00<207ooOol097oo00<207ooOol0Bgoo
00<207ooOol04Goo00<207ooOol0?Goo00<207ooOol017oo00@07gooOol0
7`9oo`807`9oo`0401moo`0O01l5Ool00`0OOomoo`0[Ool00`80Oomoo`0@
Ool00`80Oomoo`0aOol00`0OOomoo`0:Ool00`80Oomoo`0BOol056LiOomW
>GooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQW>D8@0001Ool00004IcUo
of<HIcTDOol201lMOol00`80Ool2000<Ool00`80Oomoo`0NOol00`80Oomo
o`0:Ool01080Ool07`0O?7oo00<207ooOol097oo00<207ooOol0Bgoo00<2
07ooOol04Goo00<207ooOol0?Goo00<207ooOol017oo0`0O27oo00<07goo
Ool01Goo00<07gooOol0:goo00<207ooOol047oo00<207ooOol06goo00D2
07ooOomoo`8000=oo`030P1oogoo00]oo`0301moogoo00Yoo`030P1oogoo
01=oo`0>HaQoof<HOomW>GooHaQoofLiOomS67ooHaQoo`=S60524040005o
o`0000AS67ooHaQS61=oo`0601moo`0O01moo`0O17oo00H07goo01l07goo
01l5Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0O0P02000<Ool00`80
Oomoo`0NOol00`80Oomoo`0:Ool00`8001moo`0201l00goo01moo`03Ool0
1P0OOol07`0OOol07`Eoo`0301moogoo00=oo`0301moogoo009oo`0301mo
ogoo01aoo`030P1oogoo02Aoo`030P1oogoo04]oo`030P1oogoo015oo`03
0P1oogoo03eoo`030P1oogoo01Moo`0301moogoo02]oo`030P1oogoo011o
o`030P1oogoo01]oo`050P1oogooOol20003Ool00`80Oomoo`0;Ool00`0O
Oomoo`0:Ool00`80Oomoo`0BOol046LiOomS67ooHaQoof<HOomS67ooHaQo
ofLiOomS67oo0V<H0D8@0@000Goo000016LiOomS66Li4goo00D07gooOol0
7goo00<07`9oo`0501moo`0O01moo`0301l4Ool00`0OOomoo`0301l4Ool0
0`0OOol2000601lV0P000`0O0P0200040P0701l01P8001moogoo01moo`<0
7`9oo`0501moo`0O01moo`0301l4Ool00`0OOomoo`0301l4Ool00`0OOomo
o`0LOol00`80Oomoo`0TOol00`80Oomoo`1;Ool00`80Oomoo`0AOol00`80
Oomoo`0mOol00`80Oomoo`14Ool00`0O0P02000@0P000`0O0P02000A0P07
01l20P002Woo0P1oo`80Ool207oo0P1oo`800Woo1@0O1P8000<07`800P00
2P8000<07`80Ool057oo00iS67ooIcUoof<HOomW>GooHaQoof<HOomS67oo
0f<H0D8@0@000Goo000016<HOomS66<H4goo00H07gooOol07goo01l2Ool0
200OOol07`0OOol07goo01l2Ool01@0OOomoogoo01l00goo0P0O17oo00<0
7`800P0037oo00<207ooOol07Goo00<07gooOol02goo00L2000OOomoo`0O
Ool07`02Ool0200OOol07`0OOol07goo01l2Ool01@0OOomoogoo01l00goo
0P0O17oo00<07gooOol077oo00<207ooOol097oo00<207ooOol0Bgoo00<2
07ooOol04Goo00<207ooOol0?Goo00<207ooOol04Goo00<207ooOol00Woo
00<207ooOol0:goo00<07`80Ool047oo0P0O4Woo100O17oo00/207oo0P1o
o`80Ool207oo0P1oo`8000eoo`0301moogoo00Yoo`0301l207oo01=oo`0D
IcUoof<HOomS67ooHaQoof<HOomW>GooHaQoof<HOomS66Li@Q00005oo`00
00AW>GooHaQW>A=oo`0601moogoo01moo`0O0Woo00<07goo01l00Woo00<0
7goo01l00Woo00<07gooOol00Woo00H07gooOomoo`0OOol20P0201l00goo
0P1oo`0;Ool00`80Oomoo`0[Ool01`8001l2008001l2000O009oo`0301mo
o`0O009oo`0301moo`0O009oo`0301moogoo009oo`0501moogooOol07`03
Ool201lNOol00`80Oomoo`0TOol00`80Oomoo`1;Ool00`80Oomoo`0AOol0
0`80Oomoo`0mOol00`80Oomoo`0AOol00`80Oomoo`030P0^Ool00`80Oomo
o`0@Ool00`0OOomoo`08Ool301l3Ool201l2Ool0100OOol07`0O0goo00D2
07ooOomoo`8000=oo`030P1oogoo01Eoo`807`=oo`030P1oogoo01=oo`0>
HaQoof<HOomW>GooHaQoof<HOomS67ooIcUoo`=S60524040005oo`0000AS
67ooHaQS61Aoo`807`9oo`<07`Eoo`0301moo`0O00807`9oo`@07`Moo`82
0003Ool207oo009oo`807`9oo`<07`9oo`030P1oogoo02]oo`8200807`9o
o`<07`Eoo`0301moo`0O00807`9oo`@07bMoo`030P1oogoo02Aoo`030P1o
ogoo04]oo`030P1oogoo015oo`030P1oogoo03eoo`030P1oogoo015oo`06
0P1oogoo0P1oo`80;Woo00<207ooOol047oo00<07gooOol02Goo00D07goo
Oomoo`0O009oo`0301moo`0O00=oo`0401moogoo0P03Ool01@80Oomoogoo
0P005Woo00@07gooOol07`9oo`030P1oogoo019oo`0@IcUoofLiOomS67oo
HaQoofLiOomS67ooHaQoof<HOol2HaP1@Q010001Ool00004IcUoof<HIcTb
Ool20P001Woo0P1oogoo01moo`807`Aoo`0301moo`8002=oo`807`Qoo`82
0003Ool207oo03]oo`030P1oogoo02Aoo`030P1oogoo04]oo`030P1oogoo
015oo`030P1oogoo03eoo`030P1oogoo015oo`060P1oogoo0P1oo`80;Woo
00<207ooOol047oo00<07gooOol02Woo00@07gooOol07`9oo`0301moogoo
00<07`]oo`<07aAoo`0401moogoo01l2Ool00`80Oomoo`0COol03V<HOomS
67ooHaQoof<HOomS67ooIcUoof<HOol3HaP1@Q010001Ool00004HaQoof<H
HaPaOol01@80Oomoogoo0P000Woo00@07gooOol07`Aoo`0301moo`80029o
o`0401moo`0O01l3Ool01@0OOomoogoo0P000goo00<207ooOol0>Goo00<2
07ooOol097oo00<207ooOol0Bgoo00<207ooOol04Goo00<207ooOol0?Goo
00<207ooOol04Goo00<207oo0P000Woo00<207ooOol00Woo0P0O:7oo00<2
07ooOol047oo00<07gooOol02goo00<07goo01l00P0O0goo00L07goo01mo
o`0OOol07`04Ool00`0OOomoo`03Ool00`0OOomoo`0AOol0100OOomoo`0O
0Woo00<207ooOol04Woo01AW>GooHaQoofLiOomS67ooHaQoof<HOomS67oo
HaQoof<HIcU240000Goo000016LiOomS66Li<7oo00<207ooOol00Woo00@2
07ooOol07`9oo`0501moogooOol07`02Ool00`80Oomoo`0POol01@0OOomo
o`0OOol00`0O0goo00<207ooOol00Woo00<207ooOol0>7oo00<207ooOol0
97oo00<207ooOol0Bgoo00<207ooOol04Goo00<207ooOol0?Goo00<207oo
Ool04Goo0P801goo00L07goo01l07goo01moo`0201l00goo01moo`03Ool0
100OOol07`0O0Woo00<07gooOol00goo00<07gooOol00Woo00<07gooOol0
27oo00<207ooOol047oo00<07gooOol027oo00D07goo01l07goo00807`03
Ool07goo00Aoo`@07`Aoo`0301moogoo00=oo`0301moogoo015oo`0401mo
o`0O01l2Ool00`80Oomoo`0COol03V<HOomS67ooIcUoof<HOomW>GooHaQo
ofLiOol3HaP1@Q010001Ool00004HaQoof<HHaPhOol0100OOomoo`0O0goo
00@07gooOol2029oo`0401moogoo01l2Ool201m3Ool00`80Oomoo`0TOol0
0`80Oomoo`1;Ool00`80Oomoo`0AOol00`80Oomoo`0lOol201l=0P0601l0
0`80Oomoo`06Ool01`0OOomoo`0OOol07goo00807`04Ool07`0O01l2Ool0
100OOol07`0O0goo00<07gooOol00`0O17oo00<07gooOol027oo00<207oo
Ool047oo00<207ooOol02Goo00<07gooOol00goo00<07gooOol01Goo00@0
7gooOol07`=oo`0301moogoo009oo`0301moogoo01=oo`0301moogoo009o
o`030P1oogoo019oo`0@IcUoofLiOomS67ooHaQoof<HOomS67ooHaQoof<H
Ool2HaP1@Q010001Ool00004IcUoof<HIcT_Ool00`0OOomoo`07Ool201l3
Ool201l2Ool00`80Oomoo`0POol0100OOomoo`0O0goo00<07gooOol01goo
00<07gooOol0=goo00<207ooOol097oo00<207ooOol0Bgoo00<207ooOol0
4Goo00<207ooOol0?7oo0P0O4goo0P801goo00D07gooOol07goo00807`04
Ool07goo01l2Ool01P0OOol07`0OOol07`=oo`0401moogooOol201l4Ool0
0`0OOomoo`08Ool00`80Oomoo`0?Ool00`80Oomoo`0HOol401l2Ool201l4
Ool00`0OOomoo`0HOol00`80Oomoo`0COol03V<HOomS67ooHaQoofLiOomS
67ooIcUoof<HOol3HaP1@Q010001Ool00004HaQoof<HHaP_Ool00`0OOomo
o`0@Ool00`80Oomoo`0QOol201l>Ool00`0OOomoo`0gOol00`80Oomoo`0T
Ool00`80Oomoo`1;Ool00`80Oomoo`0AOol00`80Oomoo`0mOol00`0OOomo
o`0AOol00`80Ool20006Ool01P0OOomoo`0OOol07`9oo`0301moo`0O009o
o`0301moo`0O009oo`0301moogoo009oo`0501moogooOol07`03Ool201l:
Ool00`80Oomoo`02Ool301l9Ool20P0JOol401l7Ool201lJOol00`80Oomo
o`0BOol056LiOomS67ooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQW>D8@
0001Ool00004IcUoof<HIcT_Ool00`0OOomoo`0@Ool00`80Oomoo`0aOol0
0`0OOomoo`0gOol00`80Oomoo`0TOol00`80Oomoo`1;Ool00`80Oomoo`0A
Ool00`80Oomoo`0mOol00`0OOomoo`05Ool201l7Ool301l01080Oomoo`80
1Woo0P0O1Goo00<07goo01l00P0O1Goo00<07goo01l00`0O4goo00<207oo
Ool00goo00<07gooOol00Woo00<07gooOol01Goo0P8077oo00<07gooOol0
87oo00<207ooOol04goo00iS67ooHaQoof<HOomS67ooIcUoof<HOomW>Goo
0f<H0D8@0@000Goo000016<HOomS66<H;goo00<07gooOol047oo00<207oo
Ool0<Goo00<07gooOol0=goo00<207ooOol097oo00<207ooOol0Bgoo00<2
07ooOol04Goo00<207ooOol0?Goo00<07gooOol017oo00@07goo01l07`=o
o`0301moogoo00=oo`0501moogooOol2000_Ool00`80Oomoo`04Ool00`0O
Oomoo`02Ool00`0OOomoo`06Ool20P0KOol301lOOol00`80Oomoo`0BOol0
46LiOomW>GooHaQoofLiOomS67ooHaQoof<HOomS67oo0V<H0D8@0@000Goo
000016LiOomS66Li;goo00<07gooOol047oo00<207ooOol0<Goo00<07goo
Ool0=goo00<207ooOol097oo00<207ooOol0Bgoo00<207ooOol04Goo00<2
07ooOol0?Goo00<07gooOol017oo00@07gooOol07`=oo`0301moogoo00@0
7`Aoo`030P1oogoo02aoo`030P1oogoo00Eoo`0501moogooOol07`06Ool2
0P0LOol01@0OOomoogoo01l07Woo00<207ooOol04goo00iS67ooHaQoof<H
OomS67ooHaQoofLiOomS67oo0f<H0D8@0@000Goo000016<HOomS66<H;goo
00<207ooOol047oo00<207ooOol0<Goo00<207ooOol0=goo00<207ooOol0
97oo00<07gooOol0Bgoo00<207ooOol04Goo00<207ooOol0A7oo00@07goo
Ool07`=oo`0401moogoo01l2Ool00`0OOomoo`03Ool00`80Oomoo`0[Ool0
0`0OOomoo`02Ool0100OOol07`0O17oo00@07gooOomoo`<201aoo`0301mo
ogoo00807`03Ool07goo01aoo`030P1oogoo019oo`0DIcUoof<HOomW>Goo
HaQoofLiOomS67ooHaQoof<HOomS66Li@Q00005oo`0000AW>GooHaQW>Bmo
o`030P1oogoo011oo`030P1oogoo035oo`030P1oogoo03Moo`030P1oogoo
02Aoo`0301moogoo04]oo`030P1oogoo015oo`030P1oogoo03Moo`030P1o
ogoo00<200Moo`0401moogoo01l2Ool201l2Ool00`0OOol07`06Ool00`0O
Oomoo`0[Ool00`0OOomoo`03Ool0100OOomoogoo100O1Woo0`806Goo00<0
7gooOol00P0O00=oo`0OOol077oo00<207ooOol04goo00iS67ooHaQoof<H
OomS67ooHaQoof<HOomW>Goo0f<H0D8@0@000Goo000016<HOomS66<H;goo
00<207ooOol047oo00<207ooOol0<Goo00<207ooOol0=goo00<207ooOol0
97oo00<07gooOol0Bgoo00<207ooOol04Goo00<207ooOol0=goo00@207oo
Oomoo`8200Qoo`807`Qoo`0301moogoo00Eoo`0301moogoo02]oo`0301mo
ogoo00Uoo`807`Eoo`8201aoo`807`03Ool07`0O01ioo`030P1oogoo019o
o`0@IcUoofLiOomS67ooIcUoof<HOomW>GooHaQoof<HOol2HaP1@Q010001
Ool00004IcUoof<HIcT_Ool00`80Oomoo`0201l>Ool00`80Oomoo`0aOol0
0`80Oomoo`0gOol00`80Oomoo`0TOol00`0OOomoo`1;Ool00`80Oomoo`0A
Ool00`80Oomoo`0gOol01P80Oomoo`80Ool201Yoo`0301moogoo02]oo`03
01moogoo00=oo`0301moo`0O009oo`0401moogoo01l2Ool20P0OOol301lO
Ool00`80Oomoo`0COol03V<HOomS67ooHaQoof<HOomS67ooHaQoof<HOol3
HaP1@Q010001Ool00004HaQoof<HHaP_Ool00`80Ool07`02Ool00`0OOomo
o`0;Ool00`80Oomoo`0aOol01080Oomoo`0O=Woo00<207ooOol097oo00<0
7gooOol0Bgoo00<207ooOol04Goo00<207ooOol0=goo00H207ooOol207oo
0P0JOol00`0OOomoo`0[Ool00`0OOomoo`03Ool301l2Ool0100OOomoo`0O
17oo0P80?goo00<207ooOol04Woo01AW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoof<HIcU240000Goo000016LiOomS66Li;goo00<207oo01l0
0Woo00<07gooOol02goo00<207ooOol0<Goo00D207ooOomoo`0O03Eoo`03
0P1oogoo02Aoo`0301moogoo04]oo`030P1oogoo015oo`030P1oogoo03Mo
o`030P1oo`80009oo`030P007`0O01Qoo`0301moogoo02]oo`0301moogoo
00=oo`0501moogoo01moo`0301l7Ool20P0mOol00`80Oomoo`0COol03V<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOol3HaP1@Q010001Ool00004HaQo
of<HHaP_Ool00`80Ool07`0201l>Ool00`80Oomoo`0aOol01@80Oomoogoo
01l0=Goo00<207ooOol097oo00<07gooOol0Bgoo00<207ooOol04Goo00<2
07ooOol0=goo0P800goo00L07goo01l07goo01moo`0201l00goo01moo`03
Ool0100OOol07`0O0Woo00<07gooOol00goo00<07gooOol00Woo00<07goo
Ool09Woo00<07gooOol00goo00D07gooOol07goo00807`03Ool07goo00Ao
o`8203ioo`030P1oogoo019oo`0@IcUoofLiOomS67ooIcUoof<HOomW>Goo
HaQoof<HOol2HaP1@Q010001Ool00004IcUoof<HIcT_Ool01P0OOol07`0O
Ool07`eoo`030P1oogoo035oo`0301moogoo009oo`0301moogoo039oo`03
0P1oogoo02Aoo`030P1oogoo04]oo`030P1oogoo015oo`030P1oogoo02=o
o`h200H07`030P1oogoo009oo`0701moogoo01moo`0OOol00P0O00Aoo`0O
01l07`9oo`0401moo`0O01l3Ool00`0OOomoo`0301l4Ool00`0OOomoo`0/
Ool301l4Ool00`0OOomoo`14Ool00`80Oomoo`0COol03V<HOomS67ooHaQo
of<HOomS67ooHaQoofLiOol3HaP1@Q010001Ool00004HaQoof<HHaP_Ool0
1@0OOomoogoo01l03Woo00<207ooOol0<Goo00<07goo01l00`0O=7oo00<2
07ooOol08goo00<207ooOol0C7oo00<207ooOol04Goo00<207ooOol08goo
00<207ooOol04Goo0P800goo00D07gooOol07goo00807`04Ool07goo01l2
Ool01P0OOol07`0OOol07`=oo`0601moogooOol07`8017oo00<07gooOol0
9goo0`800Woo00<207ooOol02Woo00<07gooOol0?Woo00<207ooOol04Woo
01AW>GooHaQoofLiOomS67ooIcUoof<HOomS67ooHaQoof<HIcU240000Goo
000016LiOomS66Li;goo00<07gooOol047oo00<207ooOol0<Goo00<07goo
Ool0=goo00<207ooOol067oo0P0O27oo0P80CWoo00<207ooOol04Goo00<2
07ooOol08goo00<207ooOol01Goo0P0O1goo0`0O00<207oo0P000Woo00H0
7gooOol07goo01l2Ool00`0OOol07`02Ool00`0OOol07`02Ool00`0OOomo
o`02Ool01@0OOomoogoo0P000goo0P0O:Goo0P800goo00<207ooOol02Woo
00<07gooOol0?Woo00<207ooOol04goo00iS67ooHaQoof<HOomS67ooHaQo
ofLiOomS67oo0f<H0D8@0@000Goo000016<HOomS66<H;goo00<07gooOol0
47oo00<207ooOol0<Goo00<07gooOol0=goo00<207ooOol057oo00@07goo
Ool07`9oo`0401moo`0O01l6Ool20P1<Ool00`80Oomoo`0AOol00`80Oomo
o`0SOol00`80Oomoo`04Ool0100OOol07`0O0goo00@07gooOol07`9oo`04
01moogoo0P02Ool201l5Ool00`0OOol07`0201l5Ool00`0OOol07`0301l3
Ool00`80Oomoo`0/Ool00`80Ool20002Ool00`80Oomoo`0:Ool00`0OOomo
o`0nOol00`80Oomoo`0BOol046LiOomW>GooHaQoofLiOomS67ooHaQoof<H
OomS67oo0V<H0D8@0@000Goo000016LiOomS66Li;goo00<07gooOol047oo
00<207ooOol0<Goo00<07gooOol0=goo00<207ooOol04Woo0`0O0Woo00D0
7gooOol07goo00807`Moo`<204Yoo`030P1oogoo015oo`030P1oogoo02=o
o`030P1oogoo00Aoo`0401moogoo01l3Ool01@0OOomoo`0OOol00P0O0goo
00<207ooOol06Goo00<207ooOol0;7oo00H207ooOol207oo0P0<Ool00`0O
Oomoo`0nOol00`80Oomoo`0COol03V<HOomS67ooHaQoof<HOomW>GooHaQo
ofLiOol3HaP1@Q010001Ool00004HaQoof<HHaP_Ool00`0OOomoo`0@Ool0
0`80Oomoo`0aOol00`0OOomoo`0gOol00`80Oomoo`0COol201l2Ool0200O
Oomoo`0OOol07goo01l3Ool30P1=Ool00`80Oomoo`0AOol00`80Oomoo`0S
Ool00`80Oomoo`04Ool0100OOomoo`0O0goo00<07gooOol00`0O00<207oo
Ool00Woo00<207ooOol067oo00<207ooOol02Goo0P0O9Goo0P8037oo00<0
7gooOol0?Woo00<207ooOol04Woo01AW>GooHaQoofLiOomS67ooHaQoof<H
OomS67ooHaQoof<HIcU240000Goo000016LiOomS66Li@Woo00<207ooOol0
Jgoo00<207ooOol057oo00D07gooOol07goo00807`03Ool07goo00Ioo`82
04aoo`030P1oogoo015oo`030P1oogoo02=oo`030P1oogoo00Aoo`0401mo
ogoo01l2Ool201l2Ool0100OOomoo`0O1Goo00<207ooOol05goo00<207oo
Ool027oo00L07goo01l07goo01moo`0201l00goo01moo`03Ool0100OOol0
7`0O0Woo00<07gooOol00goo00<07gooOol00Woo00<07gooOol01Woo00<2
000O01l01@0O108000<07`80Ool0?goo00<207ooOol04goo00iS67ooHaQo
of<HOomW>GooHaQoofLiOomS67oo0f<H0D8@0@000Goo000016<HOomS66<H
57oo00<07gooOol04Goo00<207ooOol010804goo00<207ooOol0<Woo1080
0Woo00<207ooOol0<7oo00<207ooOol067oo00<07gooOol02goo0P80BWoo
00<207ooOol04Goo00<207ooOol08goo00<207ooOol01Goo0P0O27oo0P0O
1Woo00<07gooOol05goo00<207ooOol027oo00L07gooOol07goo01moo`02
01l017oo01l07`0O0Woo00@07goo01l07`=oo`0301moogoo00<07`Aoo`03
01moogoo00Eoo`8200]oo`0301l207oo03moo`030P1oogoo019oo`0@IcUo
ofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOol2HaP1@Q010001Ool00004
IcUoof<HIcTBOol301lCOol00`80Oomoo`02Ool00`80Oomoo`0BOol00`80
Oomoo`0bOol20P04Ool00`80Oomoo`0`Ool00`80Oomoo`0MOol301l4Ool2
0P1<Ool00`80Oomoo`0AOol00`80Oomoo`0SOol00`80Oomoo`0GOol00`0O
Oomoo`0GOol00`80Oomoo`08Ool01@0OOomoo`0OOol00P0O00Aoo`0OOol0
7`9oo`0601moo`0O01moo`0O0goo00@07gooOomoo`807`Aoo`0301moogoo
00Aoo`030P1oo`8000aoo`030P1oogoo03ioo`030P1oogoo01=oo`0>HaQo
of<HOomW>GooHaQoofLiOomS67ooIcUoo`=S60524040005oo`0000AS67oo
HaQS61=oo`807a=oo`040P1oogooOol20P0DOol00`80Oomoo`0bOol00`80
Ool20003Ool00`80Oomoo`0`Ool00`80Oomoo`0HOol00`0OOol07`05Ool0
100OOol20080CWoo00<207ooOol04Goo00<207ooOol08goo00<207ooOol0
5goo00<07gooOol05goo00<207ooOol027oo00H07gooOol07goo01l2Ool0
0`0OOol07`02Ool00`0OOol07`02Ool00`0OOomoo`02Ool01@0OOomoogoo
01l00goo0P0O1Goo00@207ooOol200aoo`030P1oo`0O00807`9oo`<07cMo
o`030P1oogoo019oo`0DIcUoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS66Li@Q00005oo`0000AW>GooHaQW>AAoo`0301moogoo015oo`060P1o
ogoo0P1oo`8057oo00<207ooOol03goo0P0O8Goo00@207ooOol2009oo`03
0P1oogoo031oo`030P1oogoo01Qoo`<07`Eoo`0401moogooOol20P1<Ool0
0`80Oomoo`0AOol00`80Oomoo`0SOol00`80Oomoo`0GOol00`0OOomoo`0G
Ool00`80Oomoo`09Ool201l5Ool00`0OOol07`0201l5Ool00`0OOol07`03
01l>Ool01080Oomoo`8037oo00@207ooOol07`Ioo`0301moogoo03Aoo`03
0P1oogoo01=oo`0>HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoo`=S6052
4040005oo`0000AS67ooHaQS62Qoo`030P1oo`80009oo`030P1oogoo00=o
o`807`eoo`030P1oogoo00ioo`0701moo`0O01moo`0OOol00P0O00=oo`0O
Ool00goo00@07goo01l07`9oo`0301moogoo00=oo`0301moogoo009oo`05
01moogooOol20003Ool00`80Ool2000bOol00`80Oomoo`0HOol01@0OOomo
o`0OOol00`0O1Woo0P80BWoo00<207ooOol04Goo00<207ooOol08goo00<2
07ooOol05goo00<07gooOol05goo00<207ooOol0;Goo00D207ooOomoo`80
00aoo`050P1oogooOol07`05Ool00`0OOomoo`0dOol00`80Oomoo`0BOol0
46LiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@0@000Goo
000016LiOomS66Li:7oo0P8027oo00L07goo01l07goo01moo`0201l00goo
01moo`03Ool0100O0P007`0O0Woo00<07gooOol00goo00<07gooOol00Woo
0P0O0Woo00@07goo01moo`807`04Ool07`0O01l2Ool0100OOol07`0O0goo
00<07gooOol00`0O17oo00<07gooOol01Woo0P80<Woo00<207ooOol067oo
00H07gooOol07goo01l7Ool20P1;Ool00`80Oomoo`0AOol00`80Oomoo`0S
Ool00`80Oomoo`0GOol00`0OOomoo`0GOol00`80Oomoo`0/Ool00`80Oomo
o`02Ool00`80Oomoo`0:Ool00`80Oomoo`02Ool00`0OOol07`0201lgOol0
0`80Oomoo`0COol03V<HOomS67ooIcUoof<HOomW>GooHaQoofLiOol3HaP1
@Q010001Ool00004HaQoof<HHaPEOol>0P0501l00`80Oomoo`07Ool01`0O
Oomoo`0OOol07goo00807`04Ool07`0O01l2Ool0100O0P007`0O0goo00<0
7gooOol00`0O17oo0P0O0Woo00P07goo01l07goo01moo`0O0Woo00H07goo
01l07goo01l3Ool0100OOomoogoo0P0O17oo00<07gooOol01goo00<2000O
01l00`0O1`809Woo00<207ooOol067oo0`0O0goo0P0ODWoo00<207ooOol0
4Goo00<207ooOol08goo00<207ooOol05goo6@8000<07`80Ool0;7oo0P0O
17oo00<207ooOol00`0O1goo00@207oo01moo`807`03Ool07goo03Qoo`03
0P1oogoo019oo`0DIcUoofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
66Li@Q00005oo`0000AW>GooHaQW>AEoo`030P1oogoo011oo`8200Qoo`05
01moogoo01moo`0201l017oo01moo`0O0Woo00H07goo01l207oo01l3Ool0
100OOomoogoo0P0O17oo0P0O0Woo00<07goo01l00Woo00<07goo01l00Woo
00<07goo01l00Woo00<07gooOol00Woo00D07gooOomoo`0O00=oo`807`Qo
o`8200]oo`030P1oogoo02Aoo`030P1oogoo02Aoo`0301moogoo04]oo`03
0P1oogoo015oo`030P1oogoo02=oo`030P1oogoo031oo`0301l207oo02]o
o`@07`=oo`0301moogoo00=oo`0301moogoo00Aoo`0401moogoo01l4Ool2
01lgOol00`80Oomoo`0COol03V<HOomS67ooHaQoofLiOomS67ooIcUoof<H
Ool3HaP1@Q010001Ool00004HaQoof<HHaPEOol00`80Oomoo`09Ool201l5
Ool00`80Ool20007Ool01P0OOomoo`0OOol07`9oo`0301moo`0O009oo`06
01moo`0O0P1oo`0O17oo00D07gooOomoo`0O00=oo`807`03Ool07`0O00Eo
o`0301moo`0O00807`Eoo`0301moo`0O00<07a1oo`030P1oo`8000]oo`03
0P1oogoo02Aoo`030P1oogoo02Aoo`0301moogoo04]oo`030P1oogoo015o
o`030P1oogoo02=oo`030P1oogoo035oo`030P1oogoo02Yoo`807`03Ool0
7goo009oo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo03ioo`03
0P1oogoo019oo`0@IcUoof<HOomW>GooHaQoof<HOomS67ooHaQoof<HOol2
HaP1@Q010001Ool00004IcUoof<HIcTEOol00`80Oomoo`08Ool0100OOol0
7`0O0goo00@07`80Oomoo`8200Ioo`807`Eoo`0301moo`0O00807`=oo`04
0P1oo`0OOol401l_Ool20P02Ool00`8001l07`02Ool301l4Ool00`80Oomo
o`0TOol00`80Oomoo`0TOol00`0OOomoo`1;Ool00`80Oomoo`0AOol00`80
Oomoo`0SOol00`80Oomoo`0aOol00`80Oomoo`0ZOol201l00goo01moo`02
Ool00`0OOomoo`0301l7Ool00`0OOomoo`0nOol00`80Oomoo`0COol03V<H
OomS67ooHaQoof<HOomW>GooHaQoofLiOol3HaP1@Q010001Ool00004HaQo
of<HHaPEOol00`80Oomoo`08Ool0100OOomoo`0O0goo00<07`80Ool00goo
00<207ooOol04Woo00<207ooOol0<goo00<207ooOol00Woo00@07goo01l0
7`9oo`0301moogoo00=oo`030P1oogoo02Aoo`030P1oogoo02Aoo`0301mo
ogoo04]oo`030P1oogoo015oo`030P1oogoo02=oo`030P1oogoo035oo`03
0P1oogoo02Yoo`807`04Ool07gooOol201l2Ool00`0OOomoo`07Ool00`0O
Oomoo`0nOol00`80Oomoo`0BOol056LiOomW>GooHaQoofLiOomS67ooHaQo
of<HOomS67ooHaQW>D8@0001Ool00004IcUoof<HIcTEOol00`80Oomoo`08
Ool0100OOomoo`0O0goo00<07`80Ool017oo00<207ooOol04Goo00<207oo
Ool0<Woo00<207ooOol00goo00@07gooOol07`=oo`0301moogoo009oo`03
0P1oogoo02Aoo`030P1oogoo02Aoo`0301moogoo04]oo`030P1oogoo015o
o`030P1oogoo02=oo`030P1oogoo035oo`030P1oogoo02]oo`807`Qoo`80
7`Moo`0301moogoo03ioo`030P1oogoo01=oo`0>HaQoof<HOomS67ooHaQo
of<HOomW>GooHaQoo`=S60524040005oo`0000AS67ooHaQS61Eoo`0301mo
ogoo00Qoo`0401moogoo01l2Ool201l00`80Oomoo`04Ool00`80Oomoo`0@
Ool00`80Oomoo`0aOol00`80Oomoo`04Ool0100OOomoo`0O17oo00D07goo
Oomoo`8002Ioo`030P1oogoo02Aoo`030P1oogoo04]oo`030P1oogoo015o
o`030P1oogoo02=ooc<2000301l207oo02aoo`0301moogoo055oo`030P1o
ogoo019oo`0@IcUoof<HOomW>GooHaQoofLiOomS67ooHaQoof<HOol2HaP1
@Q010001Ool00004IcUoof<HIcTEOol00`0OOomoo`09Ool201l<Ool00`0O
Oomoo`0@Ool00`80Oomoo`0aOol00`0OOomoo`04Ool01`0OOomoo`0OOol0
7goo00807`=oo`030P1oogoo02Aoo`030P1oogoo02Aoo`030P1oogoo04]o
o`030P1oogoo015oo`030P1oogoo05Ioo`0301l207oo02aoo`030P1oogoo
00Yoo`030P1oogoo00<2045oo`0301moogoo01=oo`0>HaQoof<HOomS67oo
HaQoof<HOomS67ooIcUoo`=S60524040005oo`0000AS67ooHaQS61Eoo`03
01moogoo01Moo`0301moogoo011oo`030P1oogoo035oo`0301moogoo00Eo
o`807`=oo`0301moogoo00=oo`030P1oogoo02Aoo`030P1oogoo02Aoo`03
0P1oogoo04]oo`030P1oogoo015oo`030P1oogoo05Moo`030P1oogoo02]o
o`030P1oogoo00Yoo`040P1oogooOol20P11Ool00`0OOomoo`0BOol056Li
OomW>GooHaQoofLiOomS67ooIcUoof<HOomS67ooHaQW>D8@0001Ool00004
IcUoof<HIcTEOol00`0OOomoo`0GOol00`0OOomoo`0@Ool00`80Oomoo`0a
Ool00`0OOomoo`0@Ool00`80Oomoo`0TOol00`80Oomoo`0TOol00`80Oomo
o`0QOol201lXOol00`80Oomoo`0AOol00`80Oomoo`1GOol00`80Oomoo`0[
Ool00`80Oomoo`0:Ool01P80Oomoo`80Ool2045oo`0301moogoo01=oo`0>
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoo`=S60524040005oo`0000AS
67ooHaQS61Eoo`0301moogoo01Moo`0301moogoo011oo`030P1oogoo035o
o`0301moogoo011oo`030P1oogoo02Aoo`030P1oogoo02Aoo`030P1oogoo
01eoo`0401moogoo01l2Ool00`0OOomoo`0UOol00`80Oomoo`0AOol00`80
Oomoo`1GOol00`80Oomoo`0[Ool00`80Oomoo`0:Ool01P80Oomoo`80Ool2
045oo`0301moogoo019oo`0@IcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOol2HaP1@Q010001Ool00004IcUoof<HIcTEOol00`0OOomoo`0GOol0
0`0OOomoo`0@Ool00`80Oomoo`0FOol301lHOol00`0OOomoo`0@Ool00`80
Oomoo`0TOol00`80Oomoo`0TOol00`80Oomoo`0MOol0100OOomoo`0O0Woo
00<07gooOol09Goo00<207ooOol04Goo00<207ooOol0Egoo00<207ooOol0
:goo00<207ooOol02Woo00<207oo0P000Woo00<207ooOol00Woo0P0O>goo
00<07gooOol04goo00iS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo0f<H
0D8@0@000Goo000016<HOomS66<H5Goo00<07gooOol05goo00<07gooOol0
47oo00<207ooOol05goo00<07gooOol05goo00<07gooOol047oo00<207oo
Ool097oo00<207ooOol097oo00<207ooOol07Goo00<07gooOol00`0O:7oo
00<207ooOol04Goo00<207ooOol0Egoo00<207ooOol0:goo00<207ooOol0
2Woo0P801goo00L07goo01l07goo01moo`0201l00goo01moo`03Ool0100O
Ool07`0O0Woo00<07gooOol00goo00<07gooOol00Woo00<07gooOol06goo
00<07gooOol04Woo01AW>GooIcUoof<HOomW>GooHaQoofLiOomS67ooHaQo
of<HIcU240000Goo000016LiOomS66Li;goo00<07gooOol047oo00<207oo
Ool067oo00<07gooOol05Woo00<207ooOol047oo00<207ooOol097oo00<2
07ooOol08goo00<07`800P006@8017oo0P0O0Woo0P0O00=oo`0OOol09Woo
00<207ooOol04Goo00<207ooOol047ooAP8000<07`800P00:`8000<07`80
0P0010801`0O00<207ooOol01Woo00L07gooOol07goo01moo`0201l017oo
01l07`0O0Woo00@07goo01l07`=oo`0301moogoo00<07`Aoo`0301moogoo
035oo`0>HaQoof<HOomS67ooHaQoof<HOomS67ooIcUoo`=S60524040005o
o`0000AS67ooHaQS619oo`D201Qoo`030P1oogoo011oo`030P1oogoo01Uo
o`0301moogoo01Eoo`030P1oogoo011oo`030P1oogoo02Aoo`030P1oogoo
02=oo`0301l207oo01Qoo`030P1oogoo00Qoo`0301moogoo02Ioo`030P1o
ogoo015oo`030P1oogoo011oo`030P1oogoo03Eoo`<07`9oo`<07`Ioo`03
01moogoo02]oo`0301moogoo00]oo`8200Moo`0501moogoo01moo`0201l0
17oo01moo`0O0Woo00H07goo01l07goo01l3Ool0100OOomoogoo0P0O17oo
00<07gooOol067oo1@804goo011W>GooHaQoofLiOomS67ooIcUoof<HOomS
67ooHaQoo`9S60524040005oo`0000AW>GooHaQW>A5oo`040P1oogoo0P02
Ool00`80Oomoo`0EOol00`80Oomoo`0@Ool00`80Oomoo`0FOol0100OOol0
7`0O5goo00<207ooOol047oo00<207ooOol097oo00<207ooOol097oo00<2
07ooOol05goo00<207ooOol0<Goo00<207ooOol04Goo00<207ooOol047oo
00<207ooOol0=Woo00<07gooOol00Woo00<07gooOol0@Goo00<207oo0P00
1Woo00H07gooOol07goo01l2Ool00`0OOol07`02Ool00`0OOol07`02Ool0
0`0OOomoo`02Ool01@0OOomoogoo01l00goo0P0O6Goo00<207ooOol01080
4goo00iS67ooHaQoof<HOomS67ooHaQoofLiOomS67oo0f<H0D8@0@000Goo
000016<HOomS66<H47oo00<207ooOol01Goo00<207ooOol057oo00<207oo
Ool047oo00<207ooOol05goo00<07gooOol05goo00<207ooOol047oo00<2
07ooOol097oo00<207ooOol097oo00<207ooOol05goo00<207ooOol0<Goo
00<207ooOol04Goo00<207ooOol047oo00<207ooOol0=goo00<07gooOol0
0Woo00<07gooOol0=7oo0P0O2Woo00@207ooOol200Ioo`807`Eoo`0301mo
o`0O00807`Eoo`0301moo`0O00<07b5oo`030P1oogoo00Eoo`030P1oogoo
00moo`0DIcUoofLiOomS67ooIcUoof<HOomS67ooHaQoof<HOomS66Li@Q00
005oo`0000AW>GooHaQW>@moo`030P1oogoo00Moo`030P1oogoo01=oo`03
0P1oogoo011oo`030P1oogoo035oo`030P1oogoo011oo`030P1oogoo02Ao
o`030P1oogoo02Aoo`030P1oogoo01Moo`030P1oogoo035oo`030P1oogoo
015oo`030P1oogoo011oo`030P1oogoo03Qoo`0301moogoo009oo`0301mo
ogoo039oo`0401moo`0O01l3Ool00`0OOomoo`02Ool00`0O0P1oo`02Ool0
0`80Oomoo`0jOol00`80Oomoo`07Ool00`80Oomoo`0?Ool03V<HOomS67oo
HaQoof<HOomW>GooHaQoofLiOol3HaP1@Q010001Ool00004HaQoof<HHaP?
Ool00`80Oomoo`07Ool00`80Oomoo`0COol00`80Oomoo`0@Ool00`80Oomo
o`0aOol00`80Oomoo`0@Ool00`80Oomoo`0TOol00`80Oomoo`0TOol00`80
Oomoo`0GOol00`80Oomoo`0aOol00`80Oomoo`0AOol00`80Oomoo`0@Ool0
0`80Oomoo`0eOol01`0OOol07`0OOol07goo00807cAoo`0401moogoo01l3
Ool00`0OOomoo`0301l00`80Oomoo`02Ool00`80Oomoo`0iOol00`80Oomo
o`07Ool00`80Oomoo`0>Ool046LiOomS67ooIcUoof<HOomS67ooHaQoof<H
OomS67oo0V<H0D8@0@000Goo000016LiOomS66Li3Woo00<207ooOol02Goo
00<207ooOol04Woo;08000<07`800P005`8000<07`80Ool04Goo00<207oo
Ool097oo00<07gooOol097oo00<07gooOol05goo00<207ooOol0<Goo00<2
07ooOol04Goo00<07gooOol047oo00<207ooOol0=Woo00<07gooOol00Woo
00<07gooOol0=7oo00@07gooOol07`=oo`0401moogooOol201l00`80Oomo
o`03Ool00`80Oomoo`0gOol00`80Oomoo`09Ool00`80Oomoo`0>Ool03V<H
OomS67ooHaQoofLiOomS67ooIcUoof<HOol3HaP1@Q010001Ool00004HaQo
of<HHaP>Ool00`80Oomoo`09Ool00`80Oomoo`0UOol00`80Oomoo`0FOol2
01lHOol00`0O0P1oo`0AOol00`80Oomoo`0TOol00`0OOomoo`0TOol00`0O
Oomoo`0GOol00`80Oomoo`0aOol00`80Oomoo`0AOol00`0OOomoo`0@Ool0
0`0OOomoo`1bOol0100OOomoo`0O0Woo0P0O17oo00<07gooOol017oo00<0
7gooOol0=goo00<207ooOol02Goo00<207ooOol03Goo01AW>GooIcUoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HIcU240000Goo000016LiOomS66Li
3Woo00<207ooOol02Goo00<207ooOol09Goo00<207ooOol05goo00<07goo
Ool05goo00<207ooOol047oo00<207ooOol097oo00<07gooOol097oo00<0
7gooOol05goo00<207ooOol0<Goo00<207ooOol04Goo00<07gooOol047oo
00<07gooOol0Lgoo0P0O47oo00<07gooOol0=goo00<207ooOol02Goo00<2
07ooOol03Woo00iS67ooHaQoofLiOomS67ooIcUoof<HOomW>Goo0f<H0D8@
0@000Goo000016<HOomS66<H3goo00@207ooOomoo`<200=oo`030P1oogoo
02Ioo`030P1oogoo01Moo`0301moogoo01Moo`030P1oogoo011oo`030P1o
ogoo02Aoo`0301moogoo02Aoo`0301moogoo01Moo`030P1oogoo035oo`03
0P1oogoo015oo`0301moogoo011oo`0301moogoo08Eoo`0301moogoo03Qo
o`030P1oogoo00Moo`030P1oogoo00ioo`0@IcUoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOol2HaP1@Q01000100000004IcUoof<HIcT?Ool00`80
Oomoo`07Ool00`80Oomoo`0VOol00`80Oomoo`0GOol00`0OOomoo`0GOol0
0`80Oomoo`0@Ool00`80Oomoo`0TOol00`0OOomoo`0TOol00`0OOomoo`0G
Ool00`80Oomoo`0aOol00`80Oomoo`0AOol00`0OOomoo`0@Ool00`0OOomo
o`25Ool00`0OOomoo`0hOol00`80Oomoo`02Ool30P02Ool00`80Oomoo`0?
Ool03V<HOomW>GooHaQoofLiOomS67ooIcUoof<HOol3HaP1@Q010001HaP0
0004HaQoof<HHaP@Ool00`80Oomoo`05Ool00`80Oomoo`0WOol00`80Oomo
o`0GOol00`0OOomoo`0GOol00`80Oomoo`0@Ool00`80Oomoo`0TOol00`0O
Oomoo`0TOol00`0OOomoo`0GOol00`80Oomoo`0aOol00`80Oomoo`0AOol0
0`0OOomoo`0@Ool00`0OOomoo`25Ool00`0OOomoo`0iOol00`80Oomoo`02
Ool01080Oomoo`804Goo011W>GooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoo`9S60524040005W>@0000AW>GooHaQW>A5oo`030P1oogoo00=oo`03
0P1oogoo02Qoo`030P1oogoo01Moo`0301moogoo00Qoo`807`eoo`030P1o
ogoo00ioo`807`030P1oogoo02Aoo`0301moogoo02Aoo`0301moogoo00Qo
o`807`eoo`030P1oogoo01]oo`807aAoo`030P1oogoo015oo`0301moogoo
011oo`0301moogoo08Eoo`0301moogoo03Yoo`030P1oogoo00=oo`030P1o
ogoo015oo`0>HaQoof<HOomW>GooHaQoofLiOomS67ooIcUoo`=S60524040
005S600000AS67ooHaQS619oo`D202]oo`030P1oogoo01Moo`030P1oogoo
00Aoo`050P1oogoo01moo`0201l00goo01moo`03Ool01`0OOol07`0OOol0
7`8000Aoo`0301moogoo00=oo`0301moogoo009oo`0601moo`0O0P1oo`0O
17oo00H07goo01l07goo01l5Ool00`0OOomoo`03Ool00`0OOomoo`02Ool0
1@0OOomoogoo0P001Goo00<207ooOol097oo00<207ooOol017oo00D207oo
Ool07goo00807`03Ool07goo00=oo`0701moo`0O01moo`0O0P0017oo00<0
7gooOol00goo00<07gooOol00Woo00<07gooOol02Woo00H07goo01l07goo
01l4Ool01P0OOol07`0OOol07`Eoo`0301moo`8000=oo`0301moogoo009o
o`0501moogooOol20006Ool00`80Oomoo`09Ool00`80Oomoo`04Ool00`80
Oomoo`25Ool00`0OOomoo`0kOol50P0COol056LiOomW>GooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQW>D8@0001Ool00004IcUoof<HIcTEOol00`0O
Oomoo`08Ool201lPOol00`80Oomoo`0HOol00`80Oomoo`03Ool01080Oomo
o`0O0Woo00<07goo01l00P0O0Woo00P07goo01l07goo01l2000O17oo00<0
7gooOol00`0O17oo00D07gooOol207oo00<07`9oo`0501moo`0O01moo`03
01l4Ool00`0OOomoo`0301l4Ool01@0OOomoogoo0P0017oo00<207ooOol0
9Woo00<207ooOol00goo00@207ooOol07`9oo`0301moo`0O00807`9oo`08
01moo`0O01moo`0O0P007`Aoo`0301moogoo00<07`Aoo`0301moogoo00Yo
o`0501moogoo01moo`0301l2Ool01@0OOol07`0OOol00`0O17oo00<07`80
Ool00`0O17oo00D07gooOomoo`8000Eoo`030P1oogoo00Yoo`030P1oogoo
00=oo`030P1oogoo08Ioo`030P1oogoo03ioo`0501moogooOol07`04Ool0
0`0OOomoo`0:Ool03V<HOomS67ooHaQoofLiOomS67ooIcUoof<HOol3HaP1
@Q010001HaP00004HaQoof<HHaPEOol00`0OOomoo`02Ool0200OOomoo`0O
Ool07goo01lPOol00`80Oomoo`0IOol00`80Oomoo`02Ool01080Oomoo`0O
0Woo00<07goo01l00Woo00/07goo01l07goo01moo`0O0P1oo`0O00=oo`04
01moogooOol201l4Ool01P0OOomoo`80Ool07`9oo`0801moo`0O01moo`0O
Ool07`9oo`0501moogooOol07`03Ool201l4Ool01@0OOomoogoo0P000goo
00<207ooOol0:7oo00<207ooOol00Woo00@207ooOol07`9oo`0301moo`0O
009oo`0;01moo`0O01moo`0OOol07`80Ool07`03Ool0100OOomoogoo0P0O
17oo00<07gooOol02Woo00H07gooOol07goo01l2Ool0200OOol07`0OOol0
7goo01l2Ool01P0OOomoogoo01l2009oo`807`Aoo`0501moogooOol20004
Ool00`80Oomoo`0;Ool00`80Oomoo`02Ool00`80Oomoo`27Ool00`80Oomo
o`0nOol01P0OOomoo`0OOol07`=oo`0301moogoo00Uoo`0@IcUoof<HOomW
>GooHaQoof<HOomS67ooHaQoofLiOol2HaP1@Q010001HaP00004IcUoof<H
IcTEOol03@0OOomoogoo01moo`0OOol07goo01moo`0O021oo`030P1oogoo
01Yoo`82009oo`040P1oogoo01l2Ool00`0OOol07`02Ool00`0OOol07`02
Ool01P0OOol07`80Ool07`Aoo`0501moogooOol07`03Ool201l2Ool00`80
Ool07`02Ool00`0OOol07`02Ool00`0OOol07`02Ool00`0OOomoo`02Ool0
1@0OOomoogoo01l00goo0P0O0goo00@207ooOol202aoo`82009oo`040P1o
ogoo01l2Ool00`0OOol07`02Ool00`0OOol07`02Ool01P0OOol07`80Ool0
7`Aoo`0501moogooOol07`03Ool201l<Ool01P0OOomoo`0OOol07`9oo`03
01moo`0O009oo`0301moo`0O009oo`0301moogoo009oo`050P1oogooOol0
7`03Ool201l3Ool00`80Oomoo`020P0>Ool00`80Oomoo`020P2:Ool00`80
Oomoo`0nOol01P0OOomoo`0OOol07`=oo`0301moogoo00Yoo`0>HaQoof<H
OomS67ooHaQoofLiOomS67ooHaQoo`=S60524040005S600000AS67ooHaQS
61Eoo`0901moogooOol07goo01moo`0O009oo`807b1oo`030P1oogoo01ao
o`030P1oo`8000=oo`807`9oo`<07`Eoo`0501moo`0O0P007`02Ool401l9
Ool201l00`80Ool07`0201l5Ool00`0OOol07`0201l2Ool401l<Ool00`80
Ool2000_Ool00`80Ool20003Ool201l2Ool301l5Ool01@0OOol07`8001l0
0Woo100O5Woo0P0O0Woo0`0O1Goo00<07goo01l00P0O0Woo0`0O00<207oo
Ool02Woo00<207oo0P0047oo00<207oo0P000P0ORWoo00<207ooOol0?Woo
00<07goo01l00Woo00<07gooOol00P0O2goo01AW>GooIcUoof<HOomW>Goo
HaQoof<HOomW>GooHaQoof<HIcU240000F<H000016LiOomS66Li5Goo00@0
7gooOol07`9oo`0301moo`0O00=oo`0301moogoo01ioo`030P1oogoo01eo
o`82019oo`030P1oogoo011oo`030P1oogoo01ioo`82035oo`82019oo`03
0P1oogoo035oo`030P1oogoo00Yoo`82015oo`82000601moo`0O01moo`0O
17oo00H07goo01l07goo01l5Ool00`0OOomoo`03Ool00`0OOomoo`02Ool0
0`0OOomoo`1ZOol00`80Oomoo`0nOol00`0OOomoo`02Ool00`0OOomoo`0>
Ool03V<HOomS67ooHaQoof<HOomS67ooHaQoof<HOol3HaP1@Q010001HaP0
0004HaQoof<HHaPEOol00`80Oomoo`03Ool00`0OOol07`0TOol00`80Oomo
o`0NOol00`8001l07`0401l;0P000`0O0P02000/0P0601l00`80Oomoo`0a
Ool00`8001l07`0301l<0P000`0O0P02000h0P0201lC0P0501l00`80Ool0
7`02Ool00`0OOol07`0201l2Ool01@0OOol07`0OOol00`0O17oo00<07goo
Ool00`0O17oo00<07gooOol0JWoo00<207ooOol0?Woo00<07gooOol04Woo
011W>GooHaQoofLiOomS67ooIcUoof<HOomS67ooHaQoo`9S60524040005S
600000AW>GooHaQW>AEoo`030P1oogoo02Yoo`030P1oogoo01eoo`82015o
o`0301moogoo015oo`030P1oogoo01ioo`82035oo`82015oo`0301moogoo
039oo`030P1oogoo00=oo`0301moogoo00Aoo`82015oo`82000601moogoo
01moo`0O0Woo00P07goo01l07goo01moo`0O0Woo00D07gooOomoo`0O00=o
o`807`Aoo`0301moogoo06Yoo`030P1oogoo03ioo`030P1oogoo01=oo`0>
HaQoof<HOomS67ooHaQoof<HOomW>GooHaQoo`=S60524040005S600000AS
67ooHaQS61Eoo`030P1oogoo02Yoo`030P1oogoo01Qoo`D20003Ool207oo
02Aoo`030P1oogoo01ioo`030P1oo`8000<202Uoo`@20003Ool207oo04Eo
o`030P1oogoo00Yoo`030P1oo`8000<200eoo`030P1oo`0O0082000301l2
000O009oo`0301moo`0O009oo`0301moo`0O009oo`0301moogoo009oo`05
01moogooOol07`03Ool201m/Ool00`80Oomoo`0nOol00`80Oomoo`0BOol0
56LiOomW>GooHaQoofLiOomS67ooHaQoof<HOomW>GooHaQW>D8@0001HaP0
0004IcUoof<HIcTEOol00`80Oomoo`0ZOol00`80Oomoo`0KOol20P000goo
0P1oo`02Ool201l2Ool301lKOol00`80Oomoo`0DOol201l2Ool301l3Ool0
1080Ool20080;Goo0P8000=oo`80Ool00Woo0P0O1goo0`0O<7oo0P0O1Goo
00<207oo01l00P0O27oo00@207oo0P0200moo`030P1oo`8000807`9oo`<0
7`Eoo`0301moo`0O00807`9oo`@07gEoo`030P1oogoo03ioo`030P1oogoo
01=oo`0>HaQoof<HOomS67ooHaQoof<HOomW>GooHaQoo`=S60524040005S
600000AS67ooHaQS61Eoo`030P1oogoo02Yoo`030P1oogoo01Yoo`050P1o
o`80Ool20002Ool01P0OOol07`0OOol07`9oo`0301moogoo01Qoo`030P1o
ogoo01=oo`0401moo`0O01l4Ool01@0OOomoo`80Ool00P80;7oo00D207oo
0P1oo`80009oo`0401moo`0O01l3Ool01@0OOomoogoo01l0<7oo00@07goo
01l07`=oo`0301l207oo00=oo`0501moogooOol07`03Ool01@80Ool207oo
0P003Woo00D207oo0P1oo`8008Yoo`030P1oogoo03ioo`030P1oogoo019o
o`0@IcUoof<HOomW>GooHaQoofLiOomS67ooHaQoof<HOol2HaP1@Q010001
HaP00004IcUoof<HIcTEOol00`80Oomoo`0ZOol00`80Oomoo`0IOol00`80
Oomoo`02Ool01080Oomoo`0O0Woo00@07goo01moo`807aYoo`030P1oogoo
01=oo`0501moogoo01moo`0401l2Ool01@80Oomoogoo0P00:Woo00<207oo
Ool00Woo00@207ooOol07`9oo`0501moogooOol07`04Ool00`0OOomoo`0]
Ool0100OOomoo`0O0goo00<07`80Ool00goo00D07gooOomoo`0O00=oo`03
0P1oogoo009oo`030P1oogoo00]oo`030P1oogoo009oo`030P1oogoo08Mo
o`030P1oogoo03ioo`030P1oogoo01=oo`0>HaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoo`=S60524040005S600000AS67ooHaQS61Eoo`030P1oogoo
02Yoo`030P1oogoo01Qoo`030P1oogoo00=oo`040P1oogoo01l2Ool00`0O
Ool07`0201lKOol00`80Oomoo`0COol01P0OOomoo`0OOol07`9oo`0401mo
ogoo0P04Ool00`80Oomoo`0VOol00`80Oomoo`03Ool01080Oomoo`0O0Woo
00D07gooOomoo`0O00Eoo`0301moogoo02aoo`0401moogoo01l3Ool00`0O
0P1oo`02Ool00`0OOomoo`02Ool01@0OOomoogoo0P001Goo00<207ooOol0
2Woo00<207ooOol00goo00<207ooOol0QWoo00<207ooOol0?Woo00<207oo
Ool04Woo01AW>GooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HIcU2
40000F<H000016LiOomS66Li5Goo00<207ooOol0:Woo00<207ooOol08Goo
00H07gooOol07goo01l2Ool00`0OOomoo`0HOol00`80Oomoo`0COol0200O
Oomoo`0OOol07goo01ljOol0100OOomoo`0O0Woo0P0O0Woo00@07goo01l0
7bioo`0401moogoo01l2Ool201l01@80Oomoogoo01l00goo0P0OYGoo00<2
07ooOol0?Woo00<207ooOol04Woo40000V<H0D8@0@000F<H000016<HOomS
66<H5Goo00<207ooOol0:Woo00<207ooOol05goo00<07gooOol027oo0P0O
0goo0P0O6goo00<207ooOol057oo0P0O0goo00<07gooOol027oo00<07goo
Ool097oo00<07gooOol027oo0P0O27oo00<07gooOol0;goo0P0O1Goo00<2
07ooOol00P0O3Goo0`0O1Woo0`0O0Woo0`0O17oo00<07gooOol0QGoo00<2
07ooOol0?Woo00<207ooOol04Woo00=S648@@Q00348@00D006<HHaQ24000
005S600000AW>GooHaQW>AEoo`030P1oogoo02Yoo`030P1oogoo01Moo`03
01moogoo02Yoo`030P1oogoo02Aoo`0301moogoo02Aoo`0301moogoo04]o
o`030P1oogoo00ioo`0401moo`0O01l3Ool00`0OOomoo`03Ool0100OOomo
o`0O1Goo00<07gooOol0QGoo00<207ooOol0?Woo00<207ooOol04Woo011W
>GooHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li@Q00009S60524040005S6000
00AS67ooHaQS61Eoo`030P1oogoo02Yoo`030P1oogoo01Moo`0301moogoo
02Yoo`030P1oogoo02Aoo`0301moogoo02Aoo`0301moogoo04]oo`030P1o
ogoo00ioo`0401moogoo01l3Ool00`0OOomoo`03Ool01@0OOomoogoo01l0
17oo00<07gooOol0QGoo00<207ooOol0?Woo00<207ooOol04Woo00=S67oo
IcT02f<H00I24000HaQS648@0001HaP00004IcUoof<HIcTEOol00`80Oomo
o`0ZOol00`80Oomoo`0GOol00`0OOomoo`0ZOol00`80Oomoo`0TOol00`0O
Oomoo`0TOol00`0OOomoo`1;Ool00`80Oomoo`0>Ool0100OOomoo`0O0goo
00<07gooOol00Woo00<07gooOol00goo00D07gooOomoo`0O08Moo`030P1o
ogoo03ioo`030P1oogoo019oo`03IcUoof<H00]S6006@Q0006<HHaQ24000
0F<H000016<HOomS66<H5Goo00<207ooOol0:Woo00<207ooOol05goo00<0
7gooOol0:Woo00<207ooOol097oo00<07gooOol097oo00<07gooOol0Bgoo
00<207ooOol03Woo00@07gooOol07`9oo`807`Aoo`0501moogoo01moo`02
01l3Ool00`0OOomoo`25Ool00`80Oomoo`0nOol00`80Oomoo`0BOol02f<H
OomS66<HIcUS66LiHaQW>F<HIcT00f<H00I24000HaQS648@0001HaP00004
IcUoof<HIcTEOol00`80Oomoo`0ZOol00`80Oomoo`0GOol00`0OOomoo`0Z
Ool00`80Oomoo`0TOol00`80Oomoo`0TOol00`80Oomoo`1;Ool00`80Oomo
o`0?Ool201l00`80Oomoo`05Ool201l3Ool00`0OOomoo`03Ool00`80Oomo
o`25Ool00`80Oomoo`0nOol00`80Oomoo`0BOol00fLiOomS6009HaP016Li
HaQ240000V<H0D8@0@000F<H000016<HOomS66<H5Goo00<207ooOol0:Woo
00<207ooOol05goo00<207ooOol0:Woo00<207ooOol097oo00<207ooOol0
97oo00<207ooOol0Bgoo00<207ooOol04Goo00<207ooOol047oo00<207oo
Ool0QGoo00<207ooOol0?Woo00<207ooOol04Woo00YS67ooHaQW>F<HIcUS
66LiHaQW>@AS6006@Q0006<HHaQ240000F<H000016LiOomS66Li5Goo00<2
07ooOol0:Woo00<207ooOol05goo00<207ooOol0:Woo00<207ooOol097oo
00<207ooOol097oo00<207ooOol0Bgoo00<207ooOol04Goo00<207ooOol0
47oo00<207ooOol0QGoo00<207ooOol0?Woo00<207ooOol04Woo00=W>Goo
HaP01f<H00IW>F<HIcUS648@0002HaP1@Q010001HaP00004HaQoof<HHaPE
Ool00`80Oomoo`0ZOol00`80Oomoo`0GOol00`80Oomoo`0ZOol00`80Oomo
o`0TOol00`80Oomoo`0TOol00`80Oomoo`1;Ool00`80Oomoo`0AOol00`80
Oomoo`0@Ool00`80Oomoo`25Ool00`80Oomoo`0nOol00`80Oomoo`0BOol0
2F<HOomS66<HIcUS66LiHaQW>@05HaP01T8@001S66<H@Q00005S600000AW
>GooHaQW>AEoo`030P1oogoo02Yoo`030P1oogoo01Moo`030P1oogoo02Yo
o`030P1oogoo02Aoo`030P1oogoo02Aoo`030P1oogoo04]oo`030P1oogoo
015oo`030P1oogoo011oo`030P1oogoo08Eoo`030P1oogoo03ioo`030P1o
ogoo019oo`04HaQoof<HIcT6HaP01VLiHaQW>F<H@Q00009S605240400052
400000AS67ooHaQS61Eoo`030P1oogoo02Yoo`030P1oogoo01Moo`030P1o
ogoo02Yoo`030P1oogoo02Aoo`030P1oogoo02Aoo`030P1oogoo04]oo`03
0P1oogoo015oo`030P1oogoo011oo`030P1oogoo08Eoo`030P1oogoo03io
o`030P1oogoo019oo`03IcUoof<H009S6003IcUS66Li00IS6006@Q0006<H
HaQ240000F<H000016LiOomS66Li5Goo00<207oo01l00P0O0Woo0`0O8goo
6@8000<07`800P00D@8000<07`800P00908000<07`800P00B`8000<07`80
0P004@8000<07`800P00408000<07`800P00Q@8000<07`800P00@08057oo
00ES67ooHaQS66Li00=S6008IcUS66LiHaQW>F<H@Q00009S60524040005S
600000AS67ooHaQS61Eoo`040P1oogoo01l3Ool0100OOomoo`0O>goo00<0
7gooOol0:goo00<207ooOol08goo00<07gooOol097oo00<07gooOol0Bgoo
00<07gooOol04Goo00<07gooOol047oo00<07gooOol0QGoo00<07gooOol0
E7oo00=W>GooHaP00f<H00=W>F<HHaP01F<H00I24000HaQS648@0001HaP0
0004IcUoof<HIcTEOol01@80Oomoogoo01l00Woo00@07goo01l07fUoo`03
0P1oogoo0?mooimoo`03HaQoogoo00]oo`06@Q0006<HHaQ240000F<H0000
16<HOomS66<H5Goo00<207ooOol00Woo00<07goo01l00P0OJWoo00<207oo
Ool0ogoo27oo00<07gooOol0U7oo00=W>F<HHaP036<H00D006<HHaQ24000
005S600000AW>GooHaQW>AEoo`040P1oo`0OOol201l01Goo01moogoo01l0
JGoo00<207ooOol0ogoo27oo00<07gooOol0UGoo00iS67ooHaQoof<HOomS
67ooHaQoof<HOomS67oo0f<H0D8@0@000F<H000016<HOomS66<H5Goo00@2
07ooOol07`Aoo`807fYoo`030P1oogoo0?moo`Qoo`0301moogoo09Aoo`0D
IcUoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS66Li@Q00005S6000
00AW>GooHaQW>AEoo`030P1oogoo075oo`030P1oogoo0?moo`Moo`807iMo
o`0>HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoo`=S60524040005W>@00
00AS67ooHaQS61Eoo`030P1oogoo075oo`030P1oogoo0?mooimoo`0@IcUo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOol2HaP1@Q010001HaP00004
IcUoof<HIcTEOol00`80Oomoo`1aOol00`80Oomoo`3oOonPOol03V<HOomW
>GooHaQoof<HOomS67ooHaQoof<HOol3HaP1@Q010001IcT00004HaQoof<H
HaPEOol00`80Oomoo`1aOol00`80Oomoo`3oOonOOol056LiOomS67ooHaQo
of<HOomS67ooHaQoofLiOomS67ooHaQW>D8@0001HaP00004IcUoof<HIcTE
Ool00`80Oomoo`1aOol00`80Oomoo`3oOonPOol03V<HOomS67ooIcUoof<H
OomW>GooHaQoof<HOol3HaP1@Q010001IcT00004HaQoof<HHaPEOol00`80
Oomoo`1aOol00`80Oomoo`3oOonOOol046LiOomW>GooHaQoof<HOomW>Goo
HaQoof<HOomW>Goo0V<H0D8@0@000F<H000016LiOomS66Li5Goo00<207oo
Ool0LGoo00<207ooOol0ogooX7oo00iS67ooHaQoofLiOomS67ooHaQoofLi
OomS67oo0f<H0D8@0@000FLi000016<HOomS66<H5Goo00<207ooOol0LGoo
00<207ooOol0ogooWgoo01AW>GooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HIcU240000F<H000016LiOomS66Li5Goo00<207ooOol03Woo1@80
GWoo00<207ooOol05Goo1@80ogooQWoo00iS67ooIcUoof<HOomS67ooIcUo
of<HOomS67oo0f<H0D8@0@000FLi000016<HOomS66<H5Goo00<207ooOol0
3Goo00<207ooOol00goo00<207ooOol0Fgoo00<207ooOol057oo00<207oo
Ool00goo00<207ooOol0ogooPWoo011W>GooHaQoof<HOomW>GooHaQoof<H
OomW>GooHaQoo`9S60524040005S600000AW>GooHaQW>AEoo`030P1oogoo
00aoo`030P1oogoo00Eoo`030P1oogoo05Yoo`030P1oogoo01=oo`030P1o
ogoo00Eoo`030P1oogoo011oo`807omoog1oo`0>IcUoof<HOomS67ooHaQo
of<HOomS67ooHaQoo`=S60524040005W>@0000AS67ooHaQS61Eoo`030P1o
ogoo00]oo`030P1oogoo00Moo`030P1oogoo05Uoo`030P1oogoo019oo`03
0P1oogoo00Moo`030P1oogoo00aoo`0301moo`0O009oo`0301moogoo0?mo
ofaoo`0DIcUoof<HOomW>GooHaQoofLiOomS67ooHaQoofLiOomS66Li@Q00
005S600000AW>GooHaQW>AEoo`030P1oogoo00]oo`030P1oogoo00Moo`03
0P1oogoo05Uoo`030P1oogoo019oo`030P1oogoo00Moo`030P1oogoo00ao
o`<07`9oo`0301moogoo0?moofeoo`0>IcUoof<HOomS67ooHaQoof<HOomW
>GooHaQoo`=S60524040005W>@0000AS67ooHaQS61Eoo`030P1oogoo00Yo
o`030P1oo`8000Moo`030P1oo`8005Yoo`030P1oogoo015oo`040P1oogoo
0P07Ool20P0=Ool00`0OOol07`02Ool00`0OOomoo`3oOom/Ool046LiOomS
67ooIcUoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@0@000F<H000016Li
OomS66Li5Goo1P801`0O00<207oo0P001goo0`8000=oo`0O01l0100ODP80
00<07`800P0030801P0O00@207oo0P0200Moo`820003Ool07`0O00/07`03
Ool07`0O00807omoofmoo`0>IcUoof<HOomW>GooHaQoofLiOomS67ooHaQo
o`=S60524040005W>@0000AS67ooHaQS629oo`030P1oo`8000Moo`030P1o
o`8005Uoo`0301moogoo019oo`040P1oogoo0P07Ool20P0=Ool0100OOol0
7`0OogooL7oo01AW>GooHaQoof<HOomS67ooHaQoof<HOomW>GooHaQoof<H
IcU240000F<H000016LiOomS66Li8goo00<207ooOol01goo00<207ooOol0
KWoo00<207ooOol01goo00<207ooOol037oo0P0OogooLgoo00iS67ooIcUo
of<HOomW>GooHaQoof<HOomS67oo0f<H0D8@0@000FLi000016<HOomS66<H
8goo00<207ooOol01goo00<207ooOol01Goo0P0O0Woo0`0OHWoo00<207oo
Ool01goo00<207ooOol0ogooP7oo011W>GooHaQoof<HOomS67ooHaQoofLi
OomS67ooHaQoo`9S60524040005S600000AW>GooHaQW>BAoo`030P1oogoo
00Eoo`030P1oogoo009oo`0401moogoo01l2Ool01@0OOomoogoo01l0Ggoo
0P0O0Woo00<207ooOol01Goo00<207ooOol0ogooPWoo00iW>GooHaQoofLi
OomS67ooHaQoof<HOomW>Goo0f<H0D8@0@000@0@000016<HOomS66<H9Goo
00<207ooOol00goo00<207ooOol00Woo00D07goo01moo`0O009oo`0301mo
o`0O00807daoo`<07`Yoo`0601moogoo01moo`0O1Goo00<207ooOol00goo
00<207ooOol0ogooPWoo01AW>GooHaQoofLiOomS67ooIcUoof<HOomS67oo
HaQoof<HIcU240000@0@000016LiOomS66Li9Woo1@801Goo00<07goo01l0
0Woo0P0O0Woo0`0OCgoo00<07gooOol01Woo00T07goo01moo`0OOol07goo
01l017oo1@80ogooQWoo00iW>GooHaQoof<HOomS67ooHaQoofLiOomS67oo
0f<H0D8@0@000@0@000016<HOomS66<H;goo00@07gooOol07eQoo`0301mo
ogoo00Ioo`0501moo`0OOol07`02Ool201ooOon>Ool046LiOomS67ooHaQo
ofLiOomS67ooHaQoof<HOomS67oo0V<H0D8@0@000@0@000016LiOomS66Li
<Woo00<07gooOol0Dgoo0`0O27oo00H07gooOol07goo01ooOonCOol03V<H
OomW>GooHaQoof<HOomW>GooHaQoofLiOol3HaP1@Q01000101000004HaQo
of<HHaR8Ool00`0OOomoo`0;Ool00`0OOol07`3oOonBOol046LiOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@0@000@0@000016LiOomS
66LiRGoo0P0OogooXGoo00iS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
0f<H0D8@0@000@0@000016<HOomS66<Hogooogoo;7oo011W>GooHaQoof<H
OomS67ooHaQoof<HOomS67ooIcUoo`9S605240400040400000AW>GooHaQW
>Omooomoobeoo`0>HaQoof<HOomW>GooHaQoofLiOomS67ooHaQoo`=S6052
40400040400000AS67ooHaQS6?mooomoobaoo`0@IcUoofLiOomS67ooHaQo
of<HOomS67ooIcUoof<HOol2HaP1@Q01000101000004IcUoof<HIcWoOooo
Ool]Ool03V<HOomS67ooHaQoofLiOomS67ooHaQoof<HOol3HaP1@Q010001
01000004HaQoof<HHaSoOoooOol/Ool046LiOomS67ooIcUoof<HOomS67oo
IcUoof<HOomS67oo0V<H0D8@0@000@0@000016LiOomS66Liogooogoo;Goo
00iS67ooHaQoof<HOomS67ooHaQoof<HOomW>Goo0f<H0D8@0@000@0@0000
16<HOomS66<Hogooogoo;7oo011W>GooIcUoof<HOomW>GooHaQoof<HOomS
67ooHaQoo`9S605240400040400000AW>GooHaQW>Omooomoobeoo`0>HaQo
of<HOomS67ooIcUoof<HOomW>GooHaQoo`=S605240400040400000AS67oo
HaQS6?mooomoobaoo`0@IcUoof<HOomW>GooHaQoof<HOomS67ooHaQoofLi
Ool2HaP1@Q01000101000004IcUoof<HIcWoOoooOol]Ool03V<HOomS67oo
HaQoof<HOomW>GooHaQoof<HOol3HaP1@Q01000101000004HaQoof<HHaSo
OoooOol/Ool046LiOomW>GooHaQoofLiOomS67ooHaQoofLiOomS67oo0V<H
0D8@0@000@0@000016LiOomS66Liogooogoo;Goo00iS67ooHaQoof<HOomS
67ooHaQoof<HOomS67oo0f<H0D8@0@000F<H000016<HOomS66<Hogooogoo
;7oo01AW>GooHaQoofLiOomS67ooIcUoof<HOomS67ooIcUoof<HIcU24000
0F<H000016LiOomS66Liogooogoo;Goo00iS67ooHaQoof<HOomS67ooHaQo
ofLiOomS67oo0f<H0D8@0@000Goo000016<HOomS66<Hogooogoo;7oo011W
>GooIcUoof<HOomW>GooHaQoof<HOomS67ooHaQoo`9S60524040005S6000
00AW>GooHaQW>Omooomoobeoo`0>HaQoof<HOomS67ooHaQoofLiOomS67oo
HaQoo`=S60524040005cW00000AS67ooHaQS6?mooomoobaoo`0DIcUoof<H
OomW>GooHaQoof<HOomS67ooIcUoof<HOomS66Li@Q00005cW00000AW>Goo
HaQW>Omooomoobeoo`0>HaQoof<HOomS67ooIcUoof<HOomS67ooHaQoo`=S
60524040005cW00000AS67ooHaQS6?mooomoobaooa00009S60524040005c
W00000AW>GooHaQW>Omooomoobaoo`03IcU2448@00a24005001S66<H@Q00
0001Li`00004HaQoof<HHaSoOoooOol/Ool046<HOomW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQ240000V<H0D8@0@000G>L000016LiOomS66Liogooogoo
;7oo00=W>GooHaP02f<H00I24000HaQS648@0001Li`00004HaQoof<HHaSo
OoooOol/Ool00f<HOomS600;HaP01T8@001S66<H@Q00005cW00000AW>Goo
HaQW>Omooomoobaoo`03IcUoof<H00=S6004IcUS66<HIcT2HaP016LiHaQ2
40000V<H0D8@0@000G>L000016<HOomS66<Hogooogoo;7oo00AS67ooHaQW
>@L000=S6006@Q0006<HHaQ240000G>L000016LiOomS66Liogooogoo;7oo
00=W>GooHaP00V<H1@0016<H00I24000HaQS648@0001Li`00004HaQoof<H
HaSoOoooOol/Ool00f<HOomS6003HaP30003HaP016LiHaQ240000V<H0D8@
0@000G>L000016LiOomS66Liogooogoo;7oo00=W>GooHaP00V<H00=W>F<H
00000V<H00IW>F<HHaQS648@0002HaP1@Q010001Li`00004HaQoof<HHaSo
OoooOol/Ool00f<HOomS6009HaP016LiHaQ240000V<H0D8@0@000G>L0000
16LiOomS66Liogooogoo;7oo00AW>GooHaQW>@IS6006IcUS66<HHaQ24000
0V<H0D8@0@000G>L000016<HOomS66<Hogooogoo;7oo00=S67ooHaP00V<H
00=W>F<HHaP016<H00AW>F<H@Q00009S60524040005cW00000AW>GooHaQW
>Omooomoobaoo`04HaQoof<HIcT4HaP00fLiHaQW>@03HaP01T8@001S66<H
@Q00005cW00000AS67ooHaQS6?mooomoobaoo`03IcUoogoo00]oo`06@Q00
06<HHaQ240000G>L000016LiOomS66Liogooogoo;7oo3f<H00D006<HHaQ2
4000005cW00000AS67ooHaQS6?l00?l003`0009S60524040005cW00000EW
>GooHaQS66Li0?mS6?mS62aS6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H
00=W>F<HHaP00V<H0D8@0@000G>L00000f<HOomW>@06HaP00fLiHaP0000M
00000f<H0000000L00000f<H0000000L000016<HIcUS66Li16<H00=W>@00
0000700000US66LiHaQW>F<HIcUS66LiHaP07P0000=S60000000700000=S
60000000700000=S60000000700000US66LiHaQW>F<HIcUS66LiHaP07P00
00=S60000000700000=S60000000700000=S60000000700000=S60000000
700000AS66LiHaQW>@AS601aIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>@0AHaP00fLi@Q000001Li`00003HaQoof<H
00MS60030012448@01a240030012448@01a240030012448@01a24003001S
66<H00ES60030012448@01a24003001S66<H00ES60030012448@01a24003
0012448@01a240030012448@01a240030012448@01a24003001S66<H00ES
60030012448@01a240030012448@01a240030012448@01a240030012448@
01a240030012448@01a24003001S66<H08QS60524040005cW00000=S67oo
HaP00f<H00IW>F<HHaQS6000OolM@Q000`00Oom2400L@Q000`00Oom2400L
@Q000`00HaQS6003HaP016LiHaP007oo7D8@00<006<HHaP01F<H00<007oo
@Q00748@00<007oo@Q00748@00<007oo@Q00748@00<007oo@Q00748@00<0
06<HHaP01F<H00<007oo@Q00748@00<007oo@Q00748@00<007oo@Q00748@
00<007oo@Q00748@00<007oo@Q00748@00<006<HHaP00f<H00=W>F<HOol0
P7oo0V<H0D8@0@000G>L00001FLiOomS66<HIcT01F<H00<007ooHaP06V<H
0T8@00<007ooHaP06V<H0T8@00<007ooHaP06V<H0T8@00D006<HHaQS66Li
00=S6003001oof<H01YS60924003001S66<H009S6005IcUS66<H001oo`0K
HaP2@Q000`00OomS600JHaP2@Q000`00OomS600JHaP2@Q000`00OomS600J
HaP2@Q000`00HaQS6002HaP01FLiHaQS6000Ool06f<H0T8@00<007ooHaP0
6V<H0T8@00<007ooHaP06V<H0T8@00<007ooHaP06V<H0T8@00<007ooHaP0
6V<H0T8@00D006<HHaQS66Li00=S6003@Q1S66<H07iS6004IcUS648@0001
Li`00003HaQoof<H009S6003IcUS66Li009S6003001oofLi01YS60924003
001oofLi01YS60924003001oofLi01YS60924004001S66<HIcT4HaP00`00
OomW>@0JHaP2@Q001000HaQS66Li16<H00<007ooIcT056<H00=206<HHaP0
0f<H0T8@00<007ooIcT056<H00=206<HHaP00f<H0T8@00<007ooIcT056<H
00=206<HHaP00f<H0T8@00<007ooIcT056<H00=206<HHaP00f<H0T8@00@0
06<HHaQW>@AS6003001oofLi00]S60=24004001207oP0003On000`00On12
0002HaP2@Q000`00OomW>@0;HaP3@Q001000@P1oh0000WoP00Ioo`00On1o
h6LiHaP2@Q000`00OomW>@0JHaP2@Q000`00OomW>@0:HaP6@Q0:HaP2@Q00
0`00OomW>@06HaP20009HaP30006HaP2@Q001000HaQS66Li0V<H00AW>F<H
@Q00079oo`d0009S60524040005cW00000EW>GooHaQS66Li00ES6003001o
of<H00=S6003IcU2448@00m24005HaQW>F<HIcUS6002@Q000`00OomS6002
HaP066LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS60924003001oof<H00=S6003IcU2448@00m24005HaQW>F<HIcUS
6002@Q000`00HaQS6002HaP01FLiHaQS6000Ool00f<H00=W>F<H00003P00
00MS66LiHaQW>F<HIcUS6002@Q000`00HaQS6002HaP01FLiHaQS6000Ool0
16<H01MW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS6480001206Li
HaQW>F<H00924003001oof<H00=S600GIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQ20000@P1W>F<HIcUS6002@Q000`00OomS6003HaP05fLi
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H@P000480IcUS66LiHaP0
0T8@00<007ooHaP00f<H01MW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS6480001206LiHaQW>F<H00924003001S66<H009S6005IcUS66<H001o
o`03HaP026LiHaQW>F<HIcUS66LiHaP3@Q001000@P1oh0000goP00@007oP
@P00009S60924003001oof<H009S6008IcUS66LiHaQW>F<HIcUS60=24004
001207oP0002On001Goo001oh7oP00000V<H0T8@00<007ooHaP00V<H01QW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaP2@Q000`00OomS6002HaP01VLiHaQW>F<HIcUS60P07`0:@Q1S66LiHaQW
>F<HIcUS66LiHaP2@Q000`00OomS6003HaP00fLiHaP00002@P002@00HaQW
>F<HIcUS66LiHaP00003@P001P00HaQW>F<HIcUS60924003001S66<H00ES
6003@Q0007oo075oo`03IcU2448@00Y2409S60524040005cW00000=S67oo
HaP00V<H00=W>F<HIcT00V<H00H007ooHaQS66LiHaPA00000d8@HaQS6003
HaP2@Q000`00OomS600A0009HaP2@Q001P00OomS66<HIcUS61800003@Q1S
66<H009S60924004001S66<HIcT4HaP00`00OomS6003HaP00`000ol3o`0;
0ol00`000Q000006HaP2@Q001000HaQS66Li16<H00D007ooHaQS66Li009S
600301mS66<H00]S6005@P00048000120003HaP2@Q001@00OomS66<HIcT0
46<H00E20000@P00048000=S60924005001oof<HHaQW>@0@HaP01D800012
0000@P000f<H0T8@00D007ooHaQS66Li011S6005@P00048000120003HaP2
@Q001000HaQS66Li16<H00<007ooHaP02V<H0T8@00@00480On0000=oh004
001oh4800003HaP2@Q000`00OomS600:HaP2@Q001000@P1oh0000WoP00Eo
o`00On1oh00000=S60924003001oof<H00US60a240ES60924003001oof<H
00MS60X07`03@Q1S66<H00IS60924005001oof<HHaQW>@03HaP01@00On12
048000001F<H00<00480@P000WoP00<006<HHaP00f<H0T8@00H006<HHaQW
>F<HIcT2HaP00d8@001oo`1aOol00fLiOomW>@02HaP016LiHaQS66Li1F<H
00=W>D8@00000G>L00001FLiOomS66<HIcT01F<H00<007ooHaP00f<H00<0
07ooOol03Goo00L0048@HaQW>F<HIcUS6002@Q000`00OomS6002000?@P00
0`00HaQW>@02HaP016LiHaQW>F<H0T8@00<007ooHaP00V<H00@007`0O01l
00800003HaQW>F<H00P0009l0005001246<HIcUS6002@Q000`00HaQS6002
HaP02FLiHaQS6000OomS66LiHaP0000>0ol02@000Q024000HaQW>F<HIcUS
6002@Q000`00HaQS6002HaP01FLiHaQS6000Ool01F<H00<07f<HIcT00V<H
00iW>F<HIcUS66LiHaQW>F<H@P000480Oomoh0000f<H0T8@00<007ooHaP0
0V<H1`0O00iW>F<HIcUS66LiHaQW>F<H@P000480Oomoh0000f<H0T8@00<0
07ooHaP00V<H01EW>F<HHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQ20000
@P1oogoP00000f<H0T8@00<007ooHaP00V<H01EW>F<HHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQ20000@P1oogoP00000f<H0T8@00<006<HHaP00V<H
00EW>F<HHaP007oo009S6008IcUS66LiHaQW>F<HIcUS60924004001207oP
0003On001000On1200000V<H00IW>F<H@Q124000Ool2HaP026LiHaQW>F<H
IcUS66LiHaP2@Q001000@P1oh0000WoP00Eoo`00On1oh00000AS6092400<
001oof<HHaQW>F<HIcUS66LiHaQW>F<H348@00ES66LiHaQW>F<H00924007
001oof<HHaQW>F<HIcT00V<H1@0O00=246<HHaP00V<H0P0O00Q246LiHaQS
66LiHaQW>F<H0T8@00<007ooHaP01F<H00D007oPOn12000000AS60030012
0480009oh003001S66<H009S6007IcUS648@@Q0006<HIcT00f<H00AW>F<H
@Q00079oo`03HaQoof<H00US6005IcUS66<H@Q000001Li`00003HaQoof<H
009S6003IcUS66Li009S6007001oof<HHaQW>F<H00003goo00<0048@HaP0
0f<H00UW>D8@@Q0007ooIcT007oP00003d8000<006<HHaP016<H00EW>D8@
@Q0007oo00=S6004001l07`0O0020003HaP80002O0000`00@Q1S6002HaP2
@Q001000HaQS66Li16<H00<007ooHaP00V<H00<000?o0ol030?o0P000P8@
00<006<HHaP00V<H0T8@00@006<HHaQW>@AS6005001oof<HIcUS600501l9
HaP01T80001207ooOn0000AS60924003001oof<H009S60L07`MS6006@P00
0480Oomoh00016<H0T8@00<007ooHaP016<H00=W>F<HHaP02F<H00I20000
@P1oogoP0004HaP2@Q000`00OomS6004HaP00fLiHaQS6009HaP01T800012
07ooOn0000AS60924004001S66<HIcT4HaP00`00OomS6009HaP01D8@0012
07oP00000goP00@007oP@P0000ES60924003001oof<H00US6005@Q000480
On000002On001Goo001oh7oP000016<H00EW>D8@@Q0007oo00QS60`00092
40AS6005IcU2448@001oo`07HaP401l00d8@HaQS6004HaP00`0O@Q1S6005
HaP026Li@Q124000OomS66LiHaP40004On0500001480HaQoh00016<H00=W
>F<HHaP00T8@00D006<HHaQS66Li00=S6003@Q0007oo075oo`05IcUoof<H
HaQW>@02HaP01FLiHaQW>F<HIcT00f<H0D8@0@000G>L00001FLiOomS66<H
IcT01F<H00<007ooHaP00f<H00<007ooOol03Goo00D0048@IcUS66Li009S
60924004001oof<H0002On000`00@P12000=@P001@00HaQW>F<HIcT00V<H
0T8@00<007ooHaP00V<H00@007`0O01l008000=S60P0009l0005001246<H
IcUS6002@Q000`00HaQS6002HaP01FLiHaQS6000Ool00V<H4`0000H24000
HaQS66LiHaP2@Q000`00HaQS6002HaP01FLiHaQS6000Ool01F<H00<07f<H
HaP00V<H00aW>F<HIcUS66LiHaQ20000@P1oogoP0003HaP026LiHaQ2448@
001oof<HIcT:HaP02VLiHaQW>F<H@P000480Oomoh0000f<H00YW>F<H@Q12
4000OomS66LiHaQW>@9S60X00006@P000480Oomoh0000f<H00IW>F<H@Q12
4000Ool2HaP056LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQ20000@P1o
ogoP0003HaP01FLiHaQ2448@000016<H00EW>F<HHaP007oo00=S6009IcUS
66LiHaQW>F<H@Q0007oo008000=oh004001oh4800006HaP2@Q000`00OomS
6002HaP02FLiHaQW>F<HIcUS648@001S60020002On001Goo001oh7oP0000
0f<H00=W>F<HHaP00T8@00<007ooHaP00V<H00=W>F<HIcT00V<H00<007oo
Ool027oo00<0048@@Q000V<H00=W>F<HHaP00T8@00<007ooHaP00V<H00=W
>F<HHaP01@0O00E246<HHaQS66Li00IS6003IcUS66Li009S60924003001o
of<H009S6003001oogoo008000=oh005001oogoo00120003On001000HaQS
66Li16<H0T8@00<006<HIcT00f<H00AW>F<H@Q00079oo`03HaQoof<H009S
6003IcUS66<H00ES6004IcUS648@0001Li`00003HaQoof<H009S6003IcUS
66Li009S6003001oof<H00=S6003001oogoo00eoo`03001246<H00AS6092
4004001oofLi0003On000`00@P12000=@P000`00HaQS6003HaP2@Q000`00
OomS6002HaP01000O01l07`00P000f<H20000W`000<0048@HaP00V<H0T8@
00@006<HHaQW>@AS6005001oof<HHaP0000@0ol010000Q00000016<H0T8@
00@006<HHaQW>@AS6005001oof<HHaQW>@02HaP00`0OHaQS6007HaP01T80
001207ooOn0000IS60924003001oof<H00QS6003IcUS66<H00=S6006@P00
0480Oomoh0001V<H0T8@00<007ooHaP01F<H00<007ooOol01Woo00E20000
@P1oogoP008000ES60924003001oof<H00AS6003IcUS66<H00MS6006@P00
0480Oomoh0001V<H0T8@00@006<HHaQW>@AS6004001oof<HIcT7HaP01D8@
001oogoo00000WoP00H007oP@P0006<HIcT3HaP026LiHaQ2448@001oof<H
IcT7HaP0248@001S66<H001oh7oo0002On000`00HaQS6005HaP2@Q001000
OomS66Li1F<H0`0@2Goo00P0048@@Q1S66LiHaQW>F<H0T8@00@007ooHaQW
>@AS60D07`03@Q1S66Li009S60924003IcUS66<H00IS60924003001oof<H
009S6005001oogooOol00004On001000Ool004800WoP00<006<HHaP00f<H
00=W>F<HIcT00T8@00D006<HHaQS66Li00=S6005@Q0007ooOol00007Ool0
0`00Oomoo`1UOol00fLiOomS6004HaP00fLiHaQW>@05HaP1@Q010001Li`0
0005IcUoof<HHaQW>@05HaP01000OomS66Li0V<H00<007ooOol03Goo00L0
048@HaQW>F<HIcUS6002@Q001000OomS600017oP00<00480@P003D8000D0
06<HHaQW>F<H00924003001oofLi009S6004001l07`0O0020003HaP80002
O0001@00@Q1S66LiHaP00T8@00<006<HHaP00V<H00EW>F<HHaP007oo009S
60030003o`?o00h3o`040002408@0002HaP01FLiHaQ2448@000016<H00IW
>F<HHaP007ooIcT7HaP500001f<H@P000480Oomoh00000ES6006IcUS648@
@Q0007oo16<H00AW>F<HIcUS60D00007HaQ20000@P1oogoP00001F<H00YW
>F<H@Q124000OomS66LiHaQW>@9S6003001oo`0000@0009oo`08001207oo
On0007oo001W>@9S6006IcUS648@@Q0007oo0V<H00IW>F<HIcUS66LiHaP5
0002HaP01@00@P1oogoP00001F<H00EW>F<H@Q12400000AS6005IcUS66<H
001oo`04HaP01VLiHaQW>F<H@Q0000Aoo`800003On12000000QS60924003
001oof<H00=S6006IcUS66LiHaQ240000f<H00=oo`0000000WoP00D006<H
HaQS66Li00AS60924003001oof<H00=S60H040Uoo`030012448@00ES6092
4003001oof<H009S6003IcUS66<H00D07`05@Q1S66<HIcU2400201l02D8@
HaQS66LiHaQW>F<HIcUS6002@Q000`00OomS60030004Ool01000On1oh7oP
0P0000A206<HOn1oh08000=S6004IcUS66<HHaP2@Q000`00HaQS6003HaP0
16LiHaQ240000Woo00<007ooOol017oo00<007ooOol0IWoo00MS67ooHaQS
66LiHaQW>@04HaP01VLiHaQW>F<H@Q00005cW00000=S67ooHaP00V<H00=W
>F<HIcT00V<H00<007ooHaP00f<H00<007ooOol03Goo00<0048@HaP00f<H
00MW>D8@@Q0007ooIcT00005On000`00@P12000=@P001000HaQS66<H0T8@
00<007ooHaP00V<H00@007`0O01l008000=S60P0009l0003001246<H009S
60924004001S66<HIcT4HaP01@00OomS66<H000040?o00D0008@0Q024000
00=S60924004001S66<HIcT4HaP00`00OomS6002HaP00fLiHaQS60020005
HaP20000148@Oomoh0000f<H00=W>F<HHaP00V<H0T8@00@007ooHaQW>@AS
608000ES60800004@Q1oogoP0003HaP00fLiHaQS6002HaP2@Q000`00OomS
6003HaP016LiHaP000001Goo0`0000=oogoP00000Woo00<006<HHaP00f<H
0T8@00<007ooHaP016<H00=W>@0000001F<H0P0000A247ooOn0000=S6003
IcUS66<H009S60924004001S66<HIcT4HaP01@00OomS66<HIcT01F<H00=2
4000Ool017oo00<0048000001F<H00AW>F<HIcUS60924005001oof<HHaQW
>@05HaP0148@001S66<H0goo00<007oP00000f<H00IW>F<HHaQW>F<HIcT2
@Q001@00OomS66<HIcT00V<H00=W>F<H01000P0@2Goo00P0048@@Q1S66Li
HaQW>F<H0T8@00<007ooHaP01T8@100O0T8@0V<H100O0d8@16<H00EW>D8@
@Q0007oo00=S6006001oo`00001oo`000goP00=20000@P000goP0P001F<H
00EW>F<H@Q124000009S6007IcUS66<HHaQW>D8@00000Woo00<007ooOol0
17oo00<007ooOol0IWoo00=W>GooHaP016<H00<006<HIcT01F<H0D8@0@00
0G>L00001FLiOomS66<HIcT01F<H00@007ooHaQW>@9S6003001oogoo00eo
o`05001246<HHaQW>@02HaP2@Q001000OomS60001WoP00<00480@P003D80
00<006LiHaP00T8@00<007ooHaP00V<H00@007`0O01l00d0009l00050012
46<HIcUS6002@Q000`00HaQS6002HaP01FLiHaQS6000Ool00V<H4`000P8@
00@006<HIcUS60924003001S66<H009S6007IcUS66<H001oof<HIcT00f<H
00<006<HHaP01F<H00EW>Goo0012400000MS6006IcUS648@@Q0007oo1F<H
00<006<HHaP01F<H00EW>Goo0012400000MS6006IcUS648@@Q0007oo0V<H
00AW>F<HHaP000Uoo`<000=oo`06001S66<HHaQW>F<H0T8@00D007ooHaQS
66Li009S6003001S66<H00MS60030012400000MS6005IcUS648@@Q000004
HaP01fLiHaQS6000OomS66Li00=S6004IcUS648@0007Ool01@00HaQS66<H
IcT01V<H0T8@00@007ooHaQW>@=S6006IcUS648@001S66Li1Goo00<006<H
HaP026<H0T8@00<007ooIcT01f<H00<007ooOol027oo00@0048@@Q1W>@AS
60924003001oof<H00El0003@Q007`0O00<07`=240@07`<20003@Q1S66Li
009S60924003001oof<H009S608000920006001S6000HaQ200000T800WoP
00@007oo001S60800004IcUS66<HHaP2@Q000`00HaQW>@02HaP01FLiHaQS
648@00000Woo00<007ooOol017oo00<007ooOol0IWoo00IS67ooHaQS66Li
HaP30002HaP01VLiHaQW>F<H@Q00005cW00000=S67ooHaP00V<H00=W>F<H
IcT00V<H00<007ooHaP00f<H00<007ooOol03Goo00<0048@HaP016<H0T8@
00@007ooIcT000Moh0l000=S60924003001oof<H009S6003001l07`0011l
0003001246<H009S60924004001S66<HIcT4HaP01@00OomW>F<H000040?o
00D0008@0002400000=S60924004001S66<HIcT4HaP00`00OomS6002HaP0
1VLi001S66<HIcUS60<07`=S6003Ool006<H009S6007IcUS66<HHaQW>F<H
IcT00T8@00L007ooHaQS66LiHaP00003HaP00fLiHaQS6004HaP00goo001S
6002HaP01fLiHaQS66<HIcUS66Li00924003001oof<H00=S6003001oogoo
00Uoo`03001oogoo009oo`04001S66<HIcT2HaP2@Q000`00OomS6002HaP0
0fLi001S600901l00f<H001S6002HaP01fLiHaQS66<HIcUS66Li00924004
001S66<HIcT4HaP00`00OomS6002HaP01VLiHaQS66<H@Q0000Eoo`8000IS
6003IcUS66Li009S60924003001oof<H009S6007IcUS66<HHaQ24000HaP0
17oo0P0016<H00AW>F<HHaQW>@=S60924005001oof<HHaQW>@03HaP00fLi
HaP0000:Ool00`00@Q124002HaP00fLiHaQS6002@Q000`00OomS6005O000
0d8@HaP07`0901l2HaP30P00148@HaQS66<H0T8@00<007ooIcT00V<H0P00
0d800`0000=20000@P000goP00@007ooOol0009oo`04001S66<HIcT2@Q00
2P00HaQS66<HIcUS66LiHaQ240000Woo1`00JGoo00=W>GooHaP00V<H1@00
16<H00=W>D8@00000G>L00001FLiOomS66<HIcT01F<H00<007ooHaP00f<H
00<007ooOol03Goo00L0048@HaQW>F<HIcUS6002@Q001000OomS600047oP
00<006<HHaP01V<H0T8@00<007ooHaP00V<H00@007`0O01l00`000=l0005
001246<HIcUS6002@Q000`00HaQS6002HaP01FLiHaQS6000Ool00f<H00<0
00?o0ol03@?o00<0008@0Q000P000f<H0T8@00<006<HHaP00V<H00EW>F<H
HaP007oo00AS6003001S66<H009S60<07`=S6004Ool006<HIcT4HaP016Li
HaQS66<H0T8@00<007ooIcT00f<H00<006<HIcT016<H00QW>F<HHaQS67oo
001S66Li16<H00AW>F<HHaQS60924004001oof<HIcT2HaP00`00Oomoo`09
Ool00`00Oomoo`02Ool00`00HaQS6003HaP2@Q001000OomS66Li0V<H00<0
06<H01l01goo00<07f<H00001V<H00AW>F<HHaQS60924003001S66<H009S
6005IcUS66<H001oo`02HaP00fLiHaQW>@02HaP30002Ool20007HaP01VLi
HaQW>F<HIcUS60924007001oof<HHaQW>F<HIcT00V<H0`000Woo0P0000EW
>F<HHaQS66Li00IS6006IcUS648@@Q0007oo0f<H00AW>F<HHaQS60<040Uo
o`080012448@HaQW>F<HIcUS60924004001oof<HHaP3O0001D8@HaQW>F<H
O0001`0O00A246<HHaQS60<20003@Q1W>F<H00924003001oof<H009S6080
0003@P1S67oP009200800005@P1oh7oPOn000003Ool00`00Oomoo`020002
HaP2@Q000`00HaQW>@05HaP01D8@001oogoo00001Goo00<007ooOol0Igoo
00AS67ooHaQS60L00006HaQW>F<HHaQ240000G>L00000f<HOomS6002HaP0
0fLiHaQW>@02HaP01000OomS66Li0V<H00<007ooOol03Goo00<0048@HaP0
0f<H00MW>D8@@Q0007ooIcT0000@On000`00HaQS6005HaP01FLi@Q124000
Ool00f<H00@007`0O00000aoo`05001l07`000124003HaP2@Q001000HaQS
66Li16<H00<007ooIcT00f<H3`00108@00@006<HHaQW>@924004001S66<H
IcT4HaP01P00OomS66LiHaP0009S6003IcUS66<H00<07`AS6003Ool006<H
00=S6003IcUS66Li009S60924003001oof<H009S6003001S66<H00MS6005
IcUS66<HOol00004HaP00fLiHaQW>@02HaP2@Q000`00OomS6002HaP00`00
Oomoo`0701l4Ool01@00Oomoogoo00000V<H00=W>F<HIcT00T8@00<007oo
HaP00V<H00@006<HHaP07`Moo`0401mS66<H0004HaP00fLiHaQW>@02HaP2
@Q001000HaQS66Li16<H00<007ooHaP01V<H1@000V<H00AW>F<HHaQW>@IS
6003IcUS66Li00924003001oof<H00IS60D000US6003IcUS66Li00=S6092
4004001oof<HIcT2HaP60109Ool00`00@Q124005HaP2@Q001000OomW>F<H
0g`000A246<HHaQS60=l0003@Q1S608000820004@Q1S66LiHaP30P000d8@
HaQS6002@Q000`00OomS6002HaP01000Ool004800WoP14800goP00D007oo
Oomoo`00009oo`04001S66<HHaP2@Q002P00HaQS66<HIcUS66LiHaQ24000
0Woo00<007ooOol017oo00<007ooOol0IWoo00=W>GooHaP02f<H00=W>D8@
00000G>L00001FLiOomS66<HIcT01F<H00<007ooHaP00f<H00<007ooOol0
3Goo00D0048@HaQS66Li009S60924004001oof<H000@On001@00HaQS66<H
IcT016<H0T8@00<007ooIcT00V<H00@007`0O00000aoo`08001l07`00012
46<HIcUS60924003001S66<H009S6005IcUS66<H001oo`03HaP00fLiHaP0
000<Ool200030Q001000HaQS66<H0T8@00<006<HHaP00V<H00EW>F<HHaP0
07oo00=S6003001S66<H00T07`9S6005001S66<HHaQW>@05HaP2@Q000`00
OomS6002HaP00`00IcUS6003HaP00fLiHaQW>@05HaP01@00HaQS66<HIcT0
1F<H0T8@00<007ooHaP00V<H00@007ooOol07`Eoo`0301moogoo009oo`05
001oogooOol00005HaP2@Q000`00OomS6002HaP01000HaQS600O1goo00@0
7f<HHaP000=S6003IcUS66<H00=S60924003001S66<H009S6005IcUS66<H
001oo`02HaP00fLiHaQW>@02HaP30009HaP01FLiHaQW>F<HIcT00f<H0T8@
00L007ooHaQS66LiHaQW>@02HaP30006HaP01FLiHaQS66<HIcT016<H00IW
>F<H@Q124000Ool4HaP00fLiHaQS60030109Ool02000@Q1246<HIcUS66Li
HaP2@Q001000OomS66<H0g`000A246<HHaQS60=l0003@Q1S608000820004
@Q1S66<HHaP30P000d8@IcUS6002@Q000`00OomS6002HaP01@00Oomoo`00
@P000WoP0T8017oP00D007ooOol006<H008000AS60924003001S66<H00ES
6005@Q0007ooOol00006Ool00`00Oomoo`1VOol016<HOomS66Li26<H00EW
>F<HHaQ24000005cW00000=S67ooHaP00V<H00=W>F<HIcT00V<H00<007oo
HaP00f<H00<007ooOol03Goo00L0048@HaQW>F<HIcUS6002@Q001000OomW
>@001WoP2P001V<H00=W>F<HHaP00T8@00<007ooHaP00V<H00@007`0O000
00aoo`05001l07`000124003HaP2@Q001000HaQS66Li16<H00<007ooHaP0
16<H00<007ooOol02goo0P000P8@00@006<HHaQS60924003001S66Li00=S
6004IcUS6000Ool3HaP00`00HaQS600901l2HaP00`00HaQS6003HaP016Li
HaQW>F<H0T8@00<007ooHaP00V<H00D006<HHaQS66Li00D07`AS6003001S
66<H00=S6004IcUS66LiHaP2@Q000`00OomS6002HaP01000Oomoo`0O1Goo
00<07gooOol00Woo00D007ooOomoo`00009S6003IcUS66<H00924003001o
of<H009S6004001S66<H01l7Ool0100OHaQS60000V<H00MW>F<HIcUS66Li
HaQW>@02@Q001000HaQS66Li16<H00<007ooHaP02F<H00=W>F<HHaP00V<H
00AW>F<HHaQW>@ES6003IcUS66<H00924003001oof<H00=S61E2409S6092
4005001oof<HHaQW>@03HaP00fLiHaP0000:Ool00`00@Q124004HaP01FLi
@Q124000Ool00V<H2W`000=246Li0P000P8000=246<HHaP00`8000A246<H
HaQS60924003001oofLi009S6005001oogooOol00007On001@00Oomoogoo
00001F<H00EW>F<H@Q124000009S6003IcUS66Li009S6005@Q0007ooOol0
0005Ool00`00Oomoo`1WOol00fLiOomS6002HaP01VLiHaQS66LiHaQW>@AS
60524040005cW00000EW>GooHaQS66Li00ES6004001oof<HIcT2HaP00`00
Oomoo`0=Ool00`00HaQS6004HaP2@Q001@00OomS66<H000017oP00<006<H
HaP02F<H100016<H0T8@00<007ooHaP00V<H00@007`0O00000aoo`08001l
07`0001246<HIcUS60924003001S66<H009S6005IcUS66<H001oo`06HaP0
0`00Oomoo`070004Ool30002HaP01FLiHaQ2448@00000f<H00IW>F<HHaQS
6000Ool3HaP00`00OomS600901l2HaP01P00HaQS66LiHaQW>@AS60924007
001oof<HIcUS6000Ool02F<H00AW>F<HHaP0009S6003IcUS66Li00AS6092
4003001oofLi009S6004001oogoo01l5Ool00`0OOomoo`02Ool01`00Oomo
ogoo001S66Li00=S60924006001oof<HIcUS60000V<H00<07gooOol01Goo
00@07f<HHaP000US60924003001S66<H009S6009IcUS66<H001oof<HIcUS
66Li01E2409S60924005001oof<HIcUS600F00001fLiHaQ2448@001oofLi
00MS6003001oogoo00Qoo`030012448@009S6003IcUS66<H00924004001o
of<HHaP:O0000d8@HaP200020P000d8@HaP200020P001D8@HaQS66LiHaP0
0T8@00<007ooHaP00`000goo00<00480On001GoP00D007ooOol006Li00=S
6004IcUS66<HHaP2@Q000`00HaQW>@05HaP0148@001oogoo1P00JWoo00=S
67ooHaP00f<H00=W>F<HHaP016<H00AW>F<H@Q00005cW00000=S67ooHaP0
0V<H00=W>F<HIcT00V<H00<007ooHaP00f<H00<007ooOol027oo1P000V<H
00AW>F<HIcUS60924003001oofLi009S60@0009S6007IcUS66LiHaQW>F<H
IcT016<H0`000V<H00IW>F<H@Q124000Ool3HaP01000O01l000037oo00D0
07`0O000048@00=S60924004001S66<HIcT4HaP01@00OomS66<HIcT00f<H
00<007ooOol02goo00<006<HHaP016<H0T8@00H006<HHaQW>F<HIcT2HaP0
0`00OomS6002HaP00`00OomS6003HaP301l5HaP00`00HaQS6003HaP016Li
HaQW>F<H0T8@00<007ooHaP00V<H00<007ooHaP01V<H00IW>F<HHaQS66Li
0005HaP016LiHaQW>F<H0T8@00<007ooHaP00V<H00@007ooOol07`Eoo`03
01moogoo009oo`05001oogooOol00003HaP01VLiHaQ2448@001oo`=S6004
001S66<H01l7Ool03@0OHaQS6000HaQW>F<HIcUS66LiHaQW>F<H00924004
001S66<HIcT4HaP00`00OomS6002HaPF0002HaP2@Q000`00OomS6002HaPF
0002HaP2@Q000`00OomS6002HaP016LiHaQS66<H0`0@2Goo00P0048@@Q1S
66LiHaQW>F<H0T8@00@007ooIcUS60=l0004@Q1S66<HHaP3O0000d8@HaP2
00060P001T8@HaQS66LiHaQW>@924003001oofLi009S6006001oogooOol0
04801GoP00<007ooOol00P001V<H00EW>F<H@Q12400000=S6006IcUS66Li
HaQ24000LWoo00AW>GooHaQW>@AS6009IcUS66LiHaQW>F<HIcU24000005c
W00000EW>GooHaQS66Li00ES6004001oof<HIcT2HaP00`00Oomoo`08Ool0
1@00Oomoogoo00001f<H0T8@00<007ooHaP04V<H00AW>F<H000000AS6092
4003001oof<H009S6004001l07`0000<Ool02000O01l0000@Q1S66LiHaP2
@Q000`00HaQS6002HaP01VLiHaQS6000OomW>@ES6003001oogoo00]oo`03
001S66<H00AS60924003001S66<H00ES6004001oof<HIcT2HaP00`00OomS
6002HaP301l4HaP01`00HaQS66<HIcUS66Li00AS60924003001oof<H00=S
6006001oof<HIcUS66Li1V<H00L006<HHaQS66LiHaQW>@04HaP2@Q000`00
OomS6003HaP00`00Ool07`05Ool01@0OOomoogoo000017oo00<006<HIcT0
0f<H0T8@00<007ooHaP00f<H00<006<H01l01goo00@07f<H001W>@US6092
4003001S66<H009S6007IcUS66<H001oof<HIcT026<H00=W>F<HHaP036<H
00IW>F<H@Q124000Ool3HaPF0002HaP2@Q000`00OomS6003HaP60109Ool0
0`00@Q124005HaP2@Q001000OomS66<H0g`000A246<HHaQS60=l0003@Q1S
608000820003@Q1S608000820003@Q1W>F<H009S60924006001oof<HIcUS
60000Woo00<00480On001GoP00@007oo000000ES6004IcUS66<HHaP2@Q00
0`00HaQW>@05HaP00d8@001oo`1aOol00f<HOomS6002HaP00fLiHaQW>@07
HaP1@Q010001Li`00003HaQoof<H009S6003IcUS66Li009S6003001oof<H
00=S6003001oogoo00Qoo`04001oogoo0003HaP00fLiHaQW>@02HaP2@Q00
0`00OomW>@0<HaP00`00HaQS6004HaP00`00HaP00002HaP01VLiHaQ2448@
001oo`=S6004001l07`0000<Ool01@00O01l0000@Q000f<H0T8@00@006<H
HaQW>@AS6005001oof<HHaQW>@04HaP00`00Oomoo`080002Ool01000HaQS
66Li0V<H00AW>D8@@Q00009S6003IcUS66Li009S6003001oof<H00=S6003
001oof<H009S60<07`9S6003IcUS6000009S6008IcUS66<HHaQW>F<HIcUS
60924003001oof<H00=S6003001oof<H00AS6003IcUS66Li009S6003001S
66<H00AS6004IcUS66LiHaP2@Q000`00OomS6003HaP00`00Ool07`0601l3
Ool60003HaP026LiHaQ2448@001oof<HIcT2HaP00`00HaP07`0801l036<H
001S66<HIcUS66LiHaQW>F<HIcUS60924004001S66<HIcT4HaP00`00OomS
600BHaP016LiHaQS66Li16<H0T8@00<007ooHaP05f<H00=W>F<HHaP00T8@
00@007ooHaQW>@=S6003IcUS600@008040Uoo`080012448@HaQW>F<HIcUS
60924004001oof<HHaP3O000148@HaQS66<H0g`000=246<H0P000P8000=2
46<HHaP00`8000A246<HIcUS60924003001oofLi009S60@00003@P1oh7oP
00Aoh08000ES6006IcUS66<HHaQW>F<H0T8@00X006<HHaQS66LiHaQW>F<H
@Q00079oo`03IcUoogoo00Yoo`9S60524040005cW00000EW>GooHaQS66Li
00ES6004001oof<HIcT2HaP00`00Oomoo`08Ool00`00Ool00005HaP016Li
HaQW>F<H0T8@00<007ooHaP016<H00AW>F<HHaQW>@9S6006IcUS66<H001S
66Li0V<H00<006<HHaP01F<H0T8@00<007ooIcT00V<H00@007`0O00000ao
o`08001l07`0001246<HIcUS60924003001S66<H009S6005IcUS66<H001o
o`04HaP016LiHaQS60003Goo00<006<HHaP00f<H0T8@00<006<HIcT01F<H
00@007ooHaQW>@=S6003001oogoo00MS6003001S66<H009S6003IcUS66Li
00AS60924005001oof<HHaQW>@02HaP01P00OomoofLiHaQW>@AS6008001S
66<HIcUS66LiHaQW>@AS60924004001oof<HIcT3HaP00`00Oomoo`07Ool0
0`00HaQS6005HaP016LiHaQS66<H0T8@00<007ooHaP016<H00<006<HHaP0
1f<H00<006<HHaP02F<H0T8@00<006<HHaP00V<H00EW>F<HHaP007oo009S
6005IcUS66LiHaQW>@0:HaP00fLiHaQS6005HaP026LiHaQ2448@001oof<H
IcT5HaP03FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00MS60924003001o
of<H00MS6003001oogoo00Qoo`04001S66<HIcT4HaP2@Q000`00OomS6002
HaP3O0000d8@HaQl0002O0000d8@HaQS60030P000d8@HaQS60030P00148@
HaQS66<H0T8@00<007ooHaP01F<H00<00480On0017oP00<006<HHaP00f<H
00=W>F<HHaP00V<H00=W>F<HHaP00T8@00<006<HHaP01F<H00=24000Ool0
LGoo3F<H00AW>F<H@Q00005cW00000=S67ooHaP00V<H00=W>F<HIcT00V<H
00<007ooHaP00f<H00<007ooOol027oo0P0016<H00=W>F<HHaP00f<H0T8@
00<007ooHaP00V<H00=W>F<HHaP016<H00=W>F<HHaP00V<H10001F<H00=W
>F<HHaP00T8@00<007ooHaP00V<H00@007`0O00000aoo`05001l07`00012
4003HaP2@Q001000HaQS66Li16<H00D007ooHaQS66Li00AS6003001oogoo
00]oo`04001S66<HIcT2HaP2@Q001@00HaQS66<HIcT00f<H00<007ooHaP0
0V<H00=W>F<HHaP00P000f<H00AW>F<H0000009S6003IcUS66<H00=S6004
IcUS66LiHaP2@Q000`00OomS6005HaP20004HaP00fLi00000008HaP016Li
HaQW>F<H0T8@00<007ooHaP01F<H0P001Goo0P000V<H00=W>F<HIcT01F<H
00IW>F<H@Q124000Ool3HaP00fLiHaQS60020005HaP20003HaP01fLiHaQW
>F<HIcUS66Li009S60924004001S66<HIcT4HaP00`00OomS6007HaP01fLi
HaQW>F<HIcUS66Li00AS6004IcUS66<HIcT4HaP2@Q000`00OomS6002HaP0
0fLiHaQS600DHaP01FLi@Q124000Ool00V<H00=W>F<HHaP00V<H00=W>@00
00002P0016<H00=W>F<HHaP00T8@00<007ooIcT00V<H0g`000=246<HO000
0W`000=246<HHaP00`8000=246<HIcT00`8000A246<HIcUS60924003001o
of<H00AS6003IcT0048000Eoh003001S66Li00ES6006IcUS66LiHaQW>F<H
0T8@00H006<HHaQW>F<HIcT2HaP00d8@0000001n0002HaP1@Q010001Li`0
0005IcUoof<HHaQW>@05HaP01000OomS66Li0V<H30000f<H00QW>F<HHaQS
66LiHaQW>F<H0T8@00@007ooHaQW>@AS6003IcUS66Li00AS6003IcUS66<H
00AS6007IcUS66<HIcUS66LiHaP00T8@00<007ooHaP00V<H50000V<H00EW
>F<H@Q12400000AS6009IcUS66<H001oof<HIcUS66Li00=S60l000=S6005
IcUS648@@Q000002HaP00fLiHaQW>@02HaP00`00OomS6005HaP00fLiHaP0
00040005HaP01FLiHaQW>F<HIcT016<H0T8@00D007ooHaQS66Li00ES60D0
009S6008IcUS66<HIcUS66LiHaQW>@AS60924003001oof<H009S6003IcUS
66<H009S60D00003IcUS66<H00MS6004IcUS66<HHaP2@Q001000OomS66Li
1V<H1@0016<H00YW>F<HIcUS66LiHaQW>F<HIcUS60924003001S66<H009S
600=IcUS66<H001oof<HIcUS66LiHaQW>F<HIcT01f<H00=W>F<HIcT00V<H
00=W>F<HHaP00V<H00QW>F<H@Q124000OomS66Li0f<H00=W>F<HHaP03V<H
00=W>F<HIcT00V<H0T8@00@007ooHaQW>AES6004IcUS66LiHaP2@Q000`00
OomS6002HaP8O0000d8@HaP200030P000d8@HaP200020P000d8@HaQS6002
HaP2@Q001@00OomS66<HIcT00V<H2@001V<H00=W>F<HHaP016<H0T8@00P0
06<HIcUS66LiHaQW>F<HPD8@0V<H0D8@0@000G>L00000f<HOomS6002HaP0
0fLiHaQW>@02HaP00`00OomS600DHaP00fLiHaQS6002HaP01FLi@Q124000
Ool00f<H00=W>F<HHaP00f<H00=W>F<HIcT036<H00=W>F<HIcT00T8@00<0
07ooHaP05F<H00=W>F<HHaP00V<H0T8@00@006<HHaQW>@AS6003001oof<H
00AS6003IcUS66<H00mS6004IcUS66<HHaP2@Q000`00HaQS6005HaP01@00
OomS66<HIcT02f<H00=W>F<HHaP01V<H00AW>F<HIcUS60924003001oof<H
009S6003IcUS66<H00]S6003IcUS66<H00=S6004IcUS66LiHaP2@Q001000
OomS66Li4f<H00IW>F<HHaQS66LiHaP2@Q000`00OomS600AHaP02FLiHaQW
>F<HIcUS66LiHaQW>@02@Q001000HaQS66Li16<H00<007ooHaP01f<H00=W
>F<HIcT00V<H00=W>F<HHaP01V<H00EW>F<HIcUS66Li00924003001oof<H
009S600CIcUS66<HHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT0
1F<H0T8@00<007ooHaP00V<H00=W>F<HHaP00V<H00=W>F<HHaP00V<H00=W
>F<HIcT01F<H00=W>F<HHaP00f<H0T8@00<007ooHaP016<H17`000A246<H
HaQS60P20006@Q1S66LiHaQW>F<H0T8@00<007ooHaP046<H00YW>F<HIcUS
66LiHaQW>F<HIcUS60924003001S66<H009S6003IcUS66Li00=S6004IcUS
66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2
HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016Li
HaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li
0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW
>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW
>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@=S6003
IcU24000005cW00000EW>GooHaQS66Li00ES6005001oof<HHaQW>@05HaP0
1FLiHaQW>F<HIcT01f<H00EW>F<HHaQS66Li009S60924004001oof<HIcT3
HaP00fLiHaQW>@05HaP01FLiHaQS66<HIcT00f<H00=W>F<HIcT00f<H0T8@
00@007ooHaQW>@ES600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@07HaP01FLi
HaQ2448@000016<H00UW>F<HHaP007ooHaQW>F<HIcT01f<H00MW>F<HIcUS
66LiHaQW>@07HaP01FLiHaQ2448@00000V<H00=W>F<HIcT00V<H00<007oo
IcT00f<H00=W>F<HHaP01F<H00=W>F<HHaP00f<H00EW>F<HIcUS66Li00AS
60924004001oof<HIcT4HaP00fLiHaQS6007HaP01fLiHaQW>F<HIcUS66Li
00AS60924005001oof<HHaQW>@02HaP00fLiHaQS6009HaP00fLiHaQW>@03
HaP016LiHaQS66<H0T8@00L007ooHaQS66LiHaQW>@02HaP00fLiHaQS6003
HaP02fLiHaQS66<HIcUS66LiHaQW>F<HIcT00f<H0T8@00<006<HHaP00V<H
00EW>F<HHaP007oo00=S6005IcUS66LiHaQW>@03HaP00fLiHaQS6003HaP0
1FLiHaQW>F<HIcT01F<H0T8@00@007ooHaQW>@AS6003IcUS66<H00iS6004
IcUS66LiHaP2@Q001@00OomS66<HIcT00V<H00=W>F<HHaP02f<H00QW>F<H
HaQS66LiHaQW>F<H0T8@00D007ooHaQS66Li01QS60924006001oof<HIcUS
66Li16<H00=W>F<HIcT01F<H00=W>F<HHaP026<H0T8@00D006<HHaQS66Li
08IS60524040005cW00000=S67ooHaP00V<H00=W>F<HIcT00V<H00<007oo
Ool06goo00=24000Ool077oo00=24000Ool077oo00E24000HaQS66Li00AS
6003001oogoo01]oo`03@Q0006<H00AS6003IcUS600001eoo`03@Q0007oo
01aoo`03@Q0007oo01aoo`03@Q0007oo01aoo`05@Q0006<HHaQW>@04HaP0
0`00Oomoo`0KOol00d8@001oo`0LOol00d8@001oo`0LOol00d8@001oo`0L
Ool00d8@001oo`0LOol02d8@001S66<HIcUS66LiHaQW>F<HIcT0M6<H00AW
>F<HHaQW>@9S6009IcUS66<HIcUS66LiHaQ24000005cW00000EW>GooHaQS
66Li00IS61h00003HaP0000001`00003HaP0000001`000IS6003IcUS66<H
01h0009S6003IcUS66Li00AS61h00003HaP0000001`00003HaP0000001`0
0003HaP0000001`0009S6005IcUS66<HHaQW>@02HaPN00000f<H0000000L
00000f<H0000000L00000f<H0000000L00000f<H0000000L000<HaP0LFLi
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT0
0V<H00AW>F<HHaQW>@=S6003IcUS66<H009S60524040005cW00000=S67oo
HaP00V<H00=W>F<HIcT08F<H00=W>F<HHaP076<H00=W>F<HHaP07V<H00=W
>F<HIcT09f<H00=W>F<HHaP07V<H00=W>F<HHaP07F<H00=W>F<HHaP076<H
00=W>F<HHaP086<H00=W>F<HHaP086<H00=W>F<HHaP076<H00=W>F<HHaP0
76<H00=W>F<HHaP076<H00=W>F<HHaP07F<H00]W>F<HIcUS66LiHaQW>F<H
IcUS66Li07QS6009IcUS66<HHaQW>F<HIcU24000005cW00000EW>GooHaQS
66Li00AS6003IcUS66<H009S600GIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>@08HaP05fLiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT026<H01MW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00ES6003IcUS
66<H00=S6003IcUS66<H009S600GIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>@07HaP01FLiHaQS66<HIcT01F<H01EW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT02F<H
01MW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66Li00QS600GIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>@08HaP04fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66Li00=S6003IcUS66<H00ES6005IcUS66<HHaQW>@04HaP05fLi
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT0
26<H01MW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66Li00QS600GIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>@08HaP05fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcT026<H01MW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li01=S601eIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00=S
6006IcUS66<HHaQ240000G>L00000f<HOomS6002HaP00fLiHaQW>@03HaP0
0fLiHaQS601LHaP00fLiHaQW>@03HaP00fLiHaQS600JHaP00fLiHaQW>@03
HaP01FLiHaQS66<HIcT0N6<H00UW>F<HIcUS66LiHaQW>F<HIcT0Vf<H011W
>F<HHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>GES6005IcUS66LiHaQW
>@02HaP1@Q010001Li`00004HaQoof<HIcT4HaP00a24@Q12400<@Q000b48
HaQS600>HaP01FLiHaQW>F<HIcT06V<H00EW>F<HIcUS66Li01US6005IcUS
66LiHaQW>@04HaP00fLiHaQS600KHaP00fLiHaQS6002HaP01FLiHaQS66<H
IcT00f<H00=W>F<HHaP05f<H00EW>F<HIcUS66Li01US6007IcUS66LiHaQW
>F<HIcT06F<H00EW>F<HIcUS66Li01ES6003IcUS66<H00eS6003IcUS66Li
01US6005IcUS66LiHaQW>@0IHaP01fLiHaQW>F<HIcUS66Li01YS6005IcUS
66LiHaQW>@0IHaP01FLiHaQW>F<HIcT06F<H00EW>F<HHaQS66Li00eS601e
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66Li00=S6006IcUS66LiHaQ240000G>L00000fLiOomS6002HaP0
16LiHaQS61cW2CgW0QcP01ANigo_G^lQ26<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66Li1V<H01UW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>@06HaP05fLiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01V<H00=W>F<HIcT00f<H
01]W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT00f<H00EW>F<HHaQS66Li00=S6003IcUS66<H009S600G
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>@07HaP05FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>@0;HaP05fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT01f<H015W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66Li00ES600=IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H01MW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
00MS600EIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66Li00]S600IIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcT01V<H01MW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66Li00MS600GIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@03HaP03fLiHaQS66<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>@17HaPP0002HaP@0004HaP1@Q010001Li`0
0005HaQoof<HHaQW>@03HaP01CgWOnmokekW?NL01Wo_00D00480OnmNkb48
00IS60H000MS6003IcUS66Li00aS60L000US6003IcUS66Li00]S60P000ES
6005IcUS66LiHaQW>@05HaP00fLiHaQS600;HaP80008HaP016LiHaQS66Li
0f<H100000=W>F<HIcT06F<H1`0056<H00QW>F<HIcUS66LiHaQW>F<H2000
00=S6000HaP046<H00EW>F<HIcUS66Li011S60L000iS60800003IcUS66<H
01ES6003IcUS66<H00L001=S6009IcUS66LiHaQW>F<HIcUS66Li00=S60T0
015S6003IcUS66Li01ES60/001MS6005IcUS66<HHaQW>@0<HaP80000?6<H
IcUS66LiHaQW>F<HIcUS6000HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@9S6003Oom2448@00a24003
001ood8@00e24004001S66<HOol>@Q001`00HaQS66LiHaQ24000005cW000
00=W>GooHaP00f<H00=W>F<H?NL00Wo_0SgW00=Nkgo_Onl00Wo_00Xmkd80
8@1Niek_8@QS66LiHaQW>@US6005IcUS66LiHaQW>@04HaP02FLiHaQW>F<H
IcUS66LiHaQW>@0;HaP01fLiHaQW>F<HIcUS66Li00AS6009IcUS66LiHaQW
>F<HIcUS66Li00]S6003IcUS66Li00IS600AIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@0;HaP02FLiHaQW>F<HIcUS66LiHaQW>@03HaP0
0fLiHaQS6003HaP06`00HaQS66<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>@09HaP04FLiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcT04f<H014006<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66Li00IS600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@02HaP0
0fLiHaQS6008HaP02fLiHaQW>F<HIcUS66LiHaQW>F<HIcT016<H01L006<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00=S
6003IcUS66<H00IS600?IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
009S6003IcUS66<H00MS6003IcUS66<H00YS600?IcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66Li00AS600CIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcT03V<H01EW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcT00f<H00eW>F<HHaQS66LiHaQW>F<HIcUS66Li
HaQW>@0CHaP00`00HaQS600aHaP01FLiOomS66<HIcT00V<H00AW>F<HHaQW
>@9S6008IcUS648@001oofLiHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQ2
40000V<H00=oof<HIcT00V<H00AW>F<HHaQW>@9S6005IcUS66<H@Q000004
HaP1@Q010001Li`00005HaQoof<HHaQW>@03HaP00cgWOnlmi`03?NL00ek_
Onmok`02?NL01Fm_8@1205k_8@P016<H00AW>F<HHaP000ES6003001S6000
009S60<00003IcUS66<H00QS6003IcUS66<H00D000=S60@00006HaP006<H
HaP006Li36<H100016<H00@006<HHaQS60@0009S6005001S66<HHaP0000;
HaP016LiHaQS600016<H00@006<HHaQS60@000=S6005001S66LiHaP00002
HaP40002HaP40002HaP00`00HaQS6003000@HaP00`00HaQS6002HaP00`00
HaQS60030003HaP01@00HaQS66<H00000f<H00UW>F<HIcUS66LiHaQW>F<H
IcT00f<H10000f<H10000f<H00<006<H00000V<H0`000V<H00D006<HIcUS
6000009S608000QS6003IcUS66<H009S6003001S66<H00=S6003001S6000
00=S6003001S66<H00@00005HaP006<HHaP00004HaP20002HaP00`00HaQS
6002000:HaP00fLiHaQS6003HaP00`00HaQS6003HaP30003HaP30002HaP0
0`00HaQS6002000036<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@9S6003001S
66<H00=S6004001S66<HHaP400001F<H001S66<H00000f<H00<006<HHaP0
0`000V<H00@006<HHaQS608000aS6005IcUS66<HHaP00003HaP00`00HaQS
6002HaP00`00HaP00003HaP00`00HaQS60040002HaP30003HaP01`00IcUS
66<H001S66Li00YS6003IcUS600000AS6004001W>F<HHaP3000016LiHaP0
06<H100002mW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66Li009S6004OomS66<HHaP60004HaP00d8@001oo`02HaP6
0005HaP01D8@001S66<HOol03F<H00Q24000HaQS66LiHaQ240000G>L0000
0fLiOomS6002HaP016LiHaQS63gW0go_00<migo_Onl017o_00DmicgP8@12
2248009S6006IcUS66<HHaQW>@000V<H00QW>F<HHaP006<H001S60000f<H
00T006<HIcUS66LiHaQW>F<HIcT01F<H00<006<HIcT00f<H00=W>@00HaP0
0V<H00D006<H001S600000=S6009IcUS66LiHaQW>F<HIcUS66Li009S600<
001S66LiHaP006<HIcUS6000HaQW>@000f<H00@006<HHaP0009S600<IcT0
06<HIcUS66LiHaQW>F<HIcUS66Li0f<H00=W>@00HaP00V<H0P000V<H00D0
06<HHaQS6000009S6003IcT006<H009S6003001S6000009S6004IcT006<H
0003HaP00`00HaP00002HaP05@00HaQS66<H001S66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaP00002HaP01FLiHaP006<H00000f<H00@006<HHaP0
00=S6003001S66Li00]S6004IcT006<HIcT2HaP02P00HaQS6000HaQW>F<H
001S60000V<H00<006<H00000f<H00<006<H00000f<H00<006<H00000V<H
00L006<HIcUS66LiHaQW>@03HaP01VLiHaQS6000HaQW>@=S6003001S6000
00=S6003001S600000=S6003001S6000009S6080009S6008001S66<H001S
6000HaP0009S6007001S66LiHaQW>F<HIcT01F<H00EW>F<HIcUS6000009S
6003IcUS600000=S6003001S600000=S6005001S6000HaP00002HaP00`00
HaQS6009HaP00fLiHaP00002HaP01`00HaQS6000HaQW>@0000=S6003001S
6000009S6004001S66<H0002HaP01`00HaQS66<H001S6000009S600>001S
66<H001S66LiHaQW>F<HIcUS66LiHaQW>@=S6003IcUS600000=S6008001S
66<HIcUS6000HaP000=S6003001S600000=S6003001S600000=S6004001S
66<H0002HaP00fLi001S6002HaP01fLiHaQW>F<HIcUS66Li00AS6003001S
66Li009S6004001S66<H0003HaP02@00HaP006<H001S66LiHaP0000`HaP0
17ooHaQS66<H1P0016<H00I24000OomW>F<H0003HaP01FLi001S66<HIcT0
0V<H00E24000HaQS67oo009S6005IcT00000HaQW>@02HaP20002HaP00d8@
001S6002HaP00fLi@Q000001Li`00004HaQoof<HIcT4HaP01CgWOnmokgo_
?NL01go_00ANk`00<HPQ20AS6004IcUS66<H0005HaP01@00HaP006<H0000
1V<H00UW>F<HIcUS66LiHaQW>F<HIcT00V<H00<006<HHaP016<H00/006<H
HaQS6000HaP006<H001S66Li00aS6003001S66<H009S6004001S66<H0002
HaP03@00HaQS66<H001S6000HaP006<H001S600000YS6004IcUS66<H0003
HaP20002HaP01@00HaQS66<H00000V<H00<006<H00000V<H00<006<H0000
0f<H00<006<H00000f<H00<006<H00000V<H00<006<HHaP046<H00<006<H
00000f<H00<006<H00001F<H00L006<H001S6000HaP00002HaP02FLiHaQW
>F<HIcUS66LiHaQW>@02HaP00`00HaQS6002HaP01000HaQS60000f<H00<0
06<H00000V<H00<006<H00000f<H00<006<H00000f<H00D006<HHaQS6000
00MS6003IcUS66Li00AS60D0009S6007001S66LiHaP006<H00000f<H00D0
06<H001S6000009S6005001S66<HHaP00002HaP01@00HaQS66<H00001f<H
00EW>F<HIcUS66Li00AS6003001S66<H009S6007001S66<HHaP006<H0000
0f<H00<006<H00000f<H00`006<HHaQW>F<HIcUS66LiHaQW>F<HIcT3HaP0
1000HaQS60000V<H00@006<HHaP000=S6003001S6000009S6003001S6000
00=S6003001S66<H00=S6003001S66<H009S6003001S66<H00YS600:IcUS
66<H001S6000HaP006<H0003HaP00`00HaP00003HaP00`00HaP00003HaP0
0`00HaP00003HaP05`00HaP006<H001S6000HaP006<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<H000016<H00@006<HHaP000ES6003001S600000=S6004
001S66<HIcT2HaP0:FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcT00V<H00Eoof<HHaQS66Li00MS6005IcUS648@001oo`02HaP00`00
IcUS6002HaP00`00HaQS6003HaP01D8@001S66<HOol016<H0P000V<H0P00
0f<H00A24000HaQW>@9S60524040005cW00000=W>GooHaP00V<H00AW>F<H
HaPmi`=ok`068@@micgW<H0mh5kW0go_00=NkacW8@P00V<H00=W>F<HHaP0
0V<H00X006<HIcUS66LiHaP006<H001S60D000=S6005IcUS66LiHaQW>@03
HaP00fLiHaP00006HaP02@00HaQS66<H001S6000HaP00003HaP02FLiHaQW
>F<HIcUS66LiHaQW>@02HaP00`00HaQS6002HaP01000HaQS60000f<H1000
00QS6000HaP006<H001S60000V<H00MW>F<HIcUS66LiHaQW>@04HaP01P00
HaQS6000HaP000=S60@0009S6003001S6000009S6003001S600000=S6003
001S66<H00@00004HaP006<HHaP5000036<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>@9S6003001S600000=S6003001S600000@00008HaP006<H001S6000
HaP000eS6003001S66<H009S6004001S66<H0003HaP00`00HaP00002HaP0
0`00HaP00003HaP01`00HaP006<HIcUS6000009S6008001S66<HIcUS66Li
HaQW>@AS6009IcUS66LiHaP006<HIcUS6000009S6005001S66<HHaP00002
HaP4000016<H001S60000V<H00@006<HHaP000=S6004001S66<H0002HaP0
1FLiHaQW>F<HIcT01V<H00EW>F<HHaQS6000009S6003IcUS600000=S6003
001S600000=S6003001S6000009S6003001S66<H00YS600:IcUS66<H001S
6000HaP006<H0003HaP4000016<H001S66<H0P0016<H1@0000IS6000HaQS
66Li0002HaP02FLiHaQW>F<HIcUS66LiHaQW>@05HaP01`00HaP006<H001S
600000=S6003001S600000=S6003001S600000=S6003001S600000=S6009
001S6000HaP006<H001S600000AS6005IcUS66LiHaQW>@04HaP01P00HaQS
66LiHaP0009S60D00004HaP006<H0003HaP00`00HaQS6002HaP00fLiHaQS
600XHaP00fLiOomS600<HaP01T8@001oofLiHaP000AS60<00005HaQW>F<H
@Q000002HaP00gooHaQS6003HaP40004HaP00d8@001S6003HaP1@Q010001
Li`00004HaQoof<HIcT4HaP01CgWOnmokgo_?NL00Wo_00MNk`00:DHaP480
G^Mok`028@P4HaP00fLiHaQS60040002HaP01@00HaP006<H00000f<H00P0
06<HHaQW>F<HIcUS66Li0V<H00AW>F<HHaQS60@00004HaQW>F<H0003HaP0
1`00HaP006<H001S66Li00aS6003001S66<H009S6004001S66<H0004HaP0
1FLiHaP006<H00000V<H00H006<HHaP006<HIcT8HaP01VLiHaQS6000HaP0
009S6003001S66<H009S6005IcUS6000HaP00003HaP01@00HaP006<H0000
0f<H00T006<HHaQS66LiHaP006Li00000V<H00D006<HHaQS600000eS6005
001S66<HHaP00002HaP02@00HaP006<HIcUS6000HaP00002HaP04P00HaQS
6000HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaP000AS6004001S66<H0003
HaP00`00HaP00002HaP00`00HaP00003HaP01000HaP000000V<H00<006<H
00000V<H00<006<HHaP00f<H00=W>F<HIcT01F<H00D006<HHaQS6000009S
6080009S600;001S66<HHaQW>F<H001W>@00HaP00002HaP00`00HaP00002
HaP01@00HaP006<H00000V<H00<006<HHaP016<H00MW>F<HIcUS66LiHaQW
>@02HaP00`00HaQS6002HaP01`00HaQS66<H001S600000=S6005001S6000
HaP00002HaP02P00IcUS66LiHaQW>F<HIcUS66Li16<H00L006<H001S6000
HaP00004HaP01FLiHaP006Li00000V<H00@006<H001W>@9S6007001S66<H
HaP006<H00000V<H018006<HHaP006<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<H0003HaP01@00HaQS66<H00000V<H00@006<H0000009S6003001S6000
00=S6003001S600000=S6003001S6000009S6004001S66<H0003HaP01FLi
HaQW>F<HIcT00V<H00=W>F<HHaP01P000V<H00T006<HIcUS6000HaP006<H
00000f<H02l006<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66Li009S6004OomS66<HIcT6HaP01fLiHaQW>F<H@Q0007oo
009S60H00003HaP006<H009S6005@Q0006<HHaQoo`02HaP016LiHaQS66<H
0P000f<H00AW>F<H@Q00009S6004IcUS648@0001Li`00003IcUoof<H009S
6004IcUS66<H?NL2Onl00ekW?NMok`02Onl01SgWIcTicR44<H12008@Q09S
6003IcUS66<H009S6003001S66Li00=S6003001W>@00009S60<000AS6005
IcUS66LiHaQW>@03HaP01FLiHaP006<HIcT01F<H100000=W>@00HaP00P00
0V<H00UW>F<HIcUS66LiHaQW>F<HIcT00V<H00<006<HIcT00V<H00<006<H
HaP00P000V<H0`0000=S66Li00000V<H00@006<HHaP000=S6005IcUS66Li
HaQW>@05HaP00`00HaP00002HaP01000HaQS66Li0`000V<H00T006<HHaQS
6000HaP006LiHaP010000V<H0`000V<H0P000V<H0`000V<H00eW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaP00003HaP01P00HaQS6000IcUS60<00003HaQW
>@00009S6004001S66<H000=HaP01P00HaQS66LiHaP0009S60@0009S6080
0004HaP006<HHaP3000016<HIcT006<H0P000f<H0P000V<H00=W>F<HIcT0
16<H00=W>F<HIcT00f<H00<006<H00000f<H00@006<H000000=S60<0009S
6003001S6000009S6003001S66<H0080009S6003001S66<H0080009S6003
IcUS66Li00US6003IcUS6000009S6003IcUS66<H00<000=S60<00003HaQW
>@00009S608000YS6004IcUS66LiHaP20003HaP20003HaP30002HaP20000
1F<H001S66<H00000f<H0`0000AS66Li0000009S608000ES6005IcUS66Li
HaQW>@04HaP01@00HaQS66<H00000f<H00L006<HHaP006<H001S60020003
HaP40002HaP300000f<HIcT00002HaP01000HaQS60000V<H00MW>F<HIcUS
66LiHaQW>@04HaP00`00HaQW>@02HaP01000HaQS66<H0`0000AS66Li001S
60@0035S6003OomS66<H009S6005IcUS66LiHaQW>@04HaP01D8@001oofLi
HaP01P0000=S6000HaP00V<H00E24000HaQS67oo00ES60@000AS6003@Q00
06<H00=S60524040005cW00000AS67ooHaQW>@AS6005?NMokek_@P0mi`03
Onl01Uk_G_M_Nd00<00aP08000AS6004IcUS66<H0007HaP00`00HaQW>@06
HaP00fLiHaQW>@04HaP01FLiHaQS66<H000016<H00MW>F<HHaQS66LiHaP0
0003HaP00`00HaQS600<HaP00`00HaQS6002HaP00`00HaQS6004HaP00fLi
HaQS600;HaP02FLiHaQW>F<HIcUS66LiHaQW>@02HaP20003HaP01@00HaQS
66<HIcT04f<H00IW>F<HHaQW>F<H000DHaP01@00HaQS66<H00001F<H00=W
>F<HHaP02f<H00UW>F<HIcUS66LiHaQW>F<HIcT00V<H00<006<HHaP00V<H
00<006<HHaP016<H00=W>F<H00006F<H00=W>F<HIcT01V<H00<006<H0000
36<H00AW>F<HIcT001IS6007IcUS66LiHaQW>F<HIcT00f<H00<006LiHaP0
3V<H00<006<HHaP016<H00MW>F<HIcUS66LiHaQW>@05HaP20003HaP20003
HaP016LiHaQS66Li16<H00<006<HHaP04f<H00]W>F<HIcUS66LiHaQW>F<H
IcUS600000=S6005001S66<HHaP0000<HaP00fLiHaP0000?HaP01FLiHaQW
>F<HIcT016<H00AW>F<HHaP000AS6005001S66<HHaQW>@04HaP00`00IcUS
6007HaP0:fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66Li009S6005OomS66LiHaQW>@07HaP01FLiHaQ24000Ool016<H00/006<H
HaQS66Li001S66LiHaQ24000009S6005OomS66<HIcUS60020002HaP20000
1F<HIcUS648@00000V<H00AW>F<H@Q00005cW00000=W>GooHaP00V<H00AW
>F<HHaPmi`9ok`03G^LmicgW00=ok`05?NM/ib`0@00`00020002HaP00fLi
HaQS6002HaP01000HaQS66Li16<H00<006<HHaP016<H00=W>F<HHaP00V<H
00=W>F<HIcT01F<H00<006<HHaP016<H00IW>F<HHaQS6000IcT2HaP04000
HaQS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS60000V<H00EW>@00HaQS66Li
01ES6003IcUS66Li00=S6004IcUS60000003HaP00`00HaQS6007HaP00fLi
HaQS600@HaP00`00HaQS6004HaP02fLiHaQW>F<HIcUS66LiHaQW>F<HIcT0
0V<H00@006<HHaQW>@9S6003001S66<H00iS6003IcUS66<H00QS6003IcUS
6000009S6003IcUS600000QS6003001S66<H00aS6003IcUS66Li009S6005
IcUS66LiHaQW>@04HaP00fLiHaQW>@04HaP01@00HaQS66<HIcT00f<H00=W
>F<HIcT01V<H00<006<HHaP00V<H00AW>F<HHaQW>@AS6008IcUS66<HIcUS
66LiHaQW>@YS6003IcUS6000009S6003IcUS66<H00]S6003001S66<H00]S
6003IcUS66Li009S6003001S66<H00=S6003001S66<H00US6005001S66<H
HaQW>@0=HaP00fLiHaQW>@04HaP00fLiHaQW>@03HaP00`00HaQS6004HaP0
16LiHaQS60003F<H00<006<HHaP046<H00EW>F<HIcUS66Li00AS6003001S
66<H009S6003001S66<H00IS6003001S66<H00AS6003IcUS66Li02aS6003
IcUoof<H00AS6005IcUS66LiHaQW>@03HaP00d8@001oo`04HaP60003HaP0
1D8@001S66<HOol00f<H0P0000AS66LiHaQW>@80009S6003@Q0006<H00=S
60524040005cW00000AS67ooHaQW>@AS6005?NMokek_@P0mi`04Onl01ek_
G>Mlib`0@00`000000AS6003IcUS66<H00D00004HaP006<H0004HaP01fLi
HaQS66<HIcUS66Li00ES6003IcUS66<H00D00003IcUS66<H00=S6003001S
6000011S60@000ES6003IcUS66Li00AS600?IcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66Li009S6005IcUS66<HHaP00004HaP01000HaQS66Li16<H
00EW>F<HHaQS66Li009S6004001S66<HIcT3HaP00fLiHaQS6009HaP00fLi
HaQS600<HaP00`00IcUS6003HaP00`00HaP00008HaP01FLiHaQW>F<HIcT0
16<H00MW>F<HIcUS66LiHaQW>@04HaP40002HaP016LiHaQS66Li1V<H00`0
06LiHaQW>F<HIcUS66LiHaQW>F<HIcT4HaP00fLiHaQS6004HaP00fLiHaQW
>@04HaP01VLiHaQS6000HaQW>@=S6003IcUS66<H00QS6004001S66<HIcT2
HaP01fLiHaQS66<HIcUS6000009S6003IcUS66<H00AS6007IcUS66LiHaQW
>F<HIcT00V<H1@000V<H00UW>F<HIcUS66LiHaQW>F<HIcT00f<H00d006<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>@06HaP00`00HaQW>@03HaP01000HaQS
66Li26<H00<006<HIcT00V<H00=W>F<HIcT00V<H00QW>F<HHaQW>F<HIcUS
66Li16<H00EW>F<HIcUS66Li009S6003IcUS6000009S6003IcUS66Li00AS
600;001S6000HaQW>F<HIcUS66LiHaQW>@03HaP01000HaQS66Li0V<H00mW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H00=W>F<H000016<H
00<006<HIcT01V<H00<006<HHaP00f<H02mW>F<HHaQS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li009S6006OomS66<HIcUS
66Li1V<H00EW>F<H@Q0007oo00AS60H000=S6007@Q0006<HHaQoof<HIcT0
2f<H00Q24000HaQS66LiHaQ240000G>L00000fLiOomS6002HaP016LiHaQS
63gW0Wo_00=NicgW?NL017o_00INkecWO>L/0400<002HaP00fLiHaQS600<
HaP00fLiHaQS6002HaP00fLiHaQS6002HaP01fLiHaQW>F<HIcUS66Li00QS
6003IcUS66<H00IS600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@08HaP00fLi
HaQW>@05HaP00fLiHaQW>@0=HaP00fLiHaQW>@03HaP00fLiHaQS6002HaP0
1FLiHaQS66<HIcT00V<H00=W>F<HIcT00V<H00EW>F<HHaQS66Li009S6004
IcUS66<HIcT3HaP00fLiHaQW>@03HaP00fLiHaQW>@03HaP02fLiHaQW>F<H
IcUS66LiHaQW>F<HIcT01F<H00=W>F<HHaP016<H00MW>F<HIcUS66LiHaQW
>@05HaP00fLiHaQW>@08HaP00fLiHaQS6009HaP016LiHaQS66Li46<H00=W
>F<HIcT00f<H00=W>F<HIcT01F<H00=W>F<HIcT026<H00UW>F<HHaQS66Li
HaQW>F<HIcT00V<H00=W>F<HHaP01f<H00=W>F<HHaP00f<H00IW>F<HHaQW
>F<HIcT9HaP00fLiHaQS600@HaP00fLiHaQS600<HaP00fLiHaQW>@07HaP0
0fLiHaQS6004HaP00fLiHaQW>@0<HaP01FLiHaQS66<HIcT01F<H00=W>F<H
IcT016<H00=W>F<HIcT01F<H00=W>F<HHaP00V<H00=W>F<HHaP02f<H00=W
>F<HHaP01F<H00=W>F<HHaP02f<H00MW>F<HIcUS66LiHaQW>@04HaP00fLi
HaQS6004HaP00fLiHaQW>@05HaP00fLiHaQW>@02HaP00fLiHaQS600/HaP0
0gooHaQS6003HaP01FLiHaQW>F<HIcT00f<H00A24000OomW>@aS6005@Q00
06<HHaQoo`0=HaP00d8@001S6002HaP00fLi@Q000001Li`00004HaQoof<H
IcT4HaP011cP?NLLib401cgW00DQ15cWO>L/030000AS6003IcUS66Li00MS
6007IcUS66<HHaQW>F<HIcT00f<H00=W>F<HIcT046<H00=W>F<HIcT00f<H
00=W>F<HHaP02V<H00=W>F<HIcT02V<H00=W>F<HIcT016<H00aW>F<HHaQW
>F<HIcUS66LiHaQW>F<HIcT4HaP00fLiHaQS6006HaP00fLiHaQS6005HaP0
1FLiHaQS66<HIcT02V<H00=W>F<HHaP00f<H00=W>F<HHaP00f<H00=W>F<H
HaP02V<H00=W>F<HHaP00V<H00IW>F<HHaQW>F<HIcT9HaP00fLiHaQW>@05
HaP01FLiHaQW>F<HIcT016<H00=W>F<HHaP016<H00=W>F<HHaP01F<H00=W
>F<HIcT00V<H00UW>F<HIcUS66LiHaQW>F<HIcT01F<H00UW>F<HHaQS66Li
HaQW>F<HIcT00f<H00AW>F<HHaQW>@9S6003IcUS66<H009S6003IcUS66<H
00=S6003IcUS66<H00=S6005IcUS66LiHaQW>@03HaP00fLiHaQW>@08HaP0
1fLiHaQW>F<HIcUS66Li00QS600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@04
HaP036LiHaQS66LiHaQW>F<HIcUS66LiHaQW>@ES6004IcUS66<HIcT5HaP0
0fLiHaQW>@04HaP00fLiHaQW>@02HaP01FLiHaQW>F<HIcT00f<H00=W>F<H
HaP00V<H00=W>F<HIcT016<H00=W>F<HIcT016<H00=W>F<HIcT016<H00mW
>F<HHaQS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00V<H00IW>F<HHaQW>F<H
IcT4HaP03FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00MS6005IcUS66<H
HaQW>@03HaP00fLiHaQS6002HaP016LiHaQS66Li1f<H02]W>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@02HaP?Ool00`00Oomo
o`0=Ool00`00HaQS600?Ool00`00HaQW>@02HaP1@Q010001Li`00003IcUo
of<H009S6003IcUS66<H00aS6003001LiecW00=S6003IcUS66<H00=S6006
IcUS66<HIcUS66Li0V<H00=W>F<HHaP00V<H00=W>F<HHaP00f<H00MW>F<H
IcUS66LiHaQW>@03HaP01FLiHaQW>F<HIcT01F<H00mW>F<HHaQS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcT016<H00MW>F<HIcUS66LiHaQW>@05HaP00fLi
HaQW>@03HaP00fLiHaQS6007HaP00fLiHaQW>@03HaP01FLiHaQW>F<HIcT0
16<H00EW>F<HIcUS66Li00=S600;IcUS66<HHaQW>F<HIcUS66LiHaQW>@04
HaP00fLiHaQW>@03HaP00fLiHaQW>@03HaP02FLiHaQW>F<HIcUS66LiHaQW
>@04HaP00fLiHaQS6002HaP00fLiHaQS6002HaP01fLiHaQW>F<HIcUS66Li
00AS600=IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00f<H00AW>F<HHaQW
>@9S6007IcUS66LiHaQW>F<HIcT016<H00=W>F<HHaP01f<H00UW>F<HIcUS
66LiHaQW>F<HIcT01F<H00EW>F<HIcUS66Li00IS6003IcUS66<H009S6003
IcUS66Li00=S6003IcUS66Li00IS6003IcUS66<H00=S6007IcUS66LiHaQW
>F<HIcT026<H00=W>F<HIcT00V<H00=W>F<HHaP02f<H00=W>F<HIcT00f<H
00=W>F<HHaP01f<H00EW>F<HIcUS66Li00ES6003IcUS66Li00AS6003IcUS
66Li00]S6007IcUS66<HHaQW>F<HIcT016<H00=W>F<HIcT016<H00=W>F<H
IcT016<H00=W>F<HIcT00f<H00=W>F<HHaP03V<H00=W>F<HHaP00V<H00=W
>F<HHaP02f<H00MW>F<HIcUS66LiHaQW>@04HaP01FLiHaQS66<HIcT00f<H
00=W>F<HHaP00V<H00QW>F<HHaQW>F<HIcUS66Li;F<H00=W>F<HHaP04F<H
00UW>F<HIcUS66LiHaQW>F<HIcT06V<H0D8@0@000G>L000016<HOomS66Li
0f<H00=W>F<HHaP03F<H00=W>F<HHaP00V<H00=W>F<HIcT00f<H00=W>F<H
HaP01F<H00UW>F<HIcUS66LiHaQW>F<HIcT026<H00=W>F<HHaP01F<H00=W
>F<HIcT016<H00=W>F<HHaP02F<H00=W>F<HIcT026<H00EW>F<HIcUS66Li
00ES600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@05HaP00fLiHaQS6004HaP0
0fLiHaQW>@07HaP01FLiHaQS66<HIcT026<H00=W>F<HIcT01F<H00=W>F<H
HaP00f<H00=W>F<HHaP026<H00MW>F<HIcUS66LiHaQW>@03HaP00fLiHaQW
>@08HaP00fLiHaQW>@05HaP01FLiHaQW>F<HIcT016<H00AW>F<HHaQW>@=S
6003IcUS66<H00IS600=IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H
00UW>F<HHaQS66LiHaQW>F<HIcT00f<H00MW>F<HHaQS66LiHaQW>@03HaP0
0fLiHaQW>@04HaP00fLiHaQS6004HaP00fLiHaQW>@04HaP00fLiHaQW>@08
HaP01fLiHaQW>F<HIcUS66Li00=S6003IcUS66<H009S600;IcUS66LiHaQW
>F<HIcUS66LiHaQW>@05HaP02fLiHaQW>F<HIcUS66LiHaQW>F<HIcT01f<H
00=W>F<HIcT016<H00=W>F<HIcT01F<H00eW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>@04HaP00fLiHaQW>@04HaP00fLiHaQW>@04HaP00fLiHaQW>@05
HaP04FLiHaQS66<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00f<H01=W
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@06HaP00fLi
HaQW>@03HaP01FLiHaQS66<HIcT00f<H00=W>F<HHaP026<H02]W>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@0THaP00fLiHaQS
600?HaP016LiHaQ240000G>L00000fLiOomS600;HaP00fLiHaQS6009HaP0
0fLiHaQS6002HaP00fLiHaQS6002HaP01FLiHaQW>F<HIcT02V<H00MW>F<H
IcUS66LiHaQW>@03HaP00fLiHaQW>@06HaP00fLiHaQW>@03HaP02FLiHaQW
>F<HIcUS66LiHaQW>@04HaP01fLiHaQW>F<HIcUS66Li00IS6003IcUS66Li
00=S6003IcUS66<H00MS600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@04HaP0
1FLiHaQW>F<HIcT016<H00UW>F<HHaQS66LiHaQW>F<HIcT01F<H01EW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT016<H00EW
>F<HHaQS66Li00ES6007IcUS66LiHaQW>F<HIcT016<H00eW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@06HaP02FLiHaQS66<HIcUS66LiHaQW>@05HaP0
0fLiHaQS6007HaP02FLiHaQW>F<HIcUS66LiHaQW>@05HaP02fLiHaQW>F<H
IcUS66LiHaQW>F<HIcT01F<H00=W>F<HIcT00f<H00]W>F<HIcUS66LiHaQW
>F<HIcUS66Li00AS6007IcUS66LiHaQW>F<HIcT026<H00=W>F<HIcT00V<H
00=W>F<HIcT02f<H00=W>F<HIcT00f<H00=W>F<HHaP01f<H00EW>F<HIcUS
66Li00ES6003IcUS66Li00AS6009IcUS66LiHaQW>F<HIcUS66Li00ES6007
IcUS66<HHaQW>F<HIcT016<H00=W>F<HIcT016<H00=W>F<HIcT016<H00eW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@09HaP00fLiHaQS6003HaP00fLi
HaQS600;HaP01fLiHaQW>F<HIcUS66Li00AS600EIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li02aS6004IcUS66<HIcT2HaP0
16LiHaQS66Li0V<H00AW>F<HHaQW>@9S6003IcUS66<H00US6005IcUS66Li
HaQW>@03HaP03fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@03HaP1
@Q010001Li`00004HaQoof<HHaSo013o010l010016LiHaQ240000G>L0000
16LiOomS66<H0P0@00<@Q48@@Q00348@00<Q200@0100o`0@o`0@:00@0V<H
0D8@0@000G>L000016<HOomS66Li0P0@00<LicgW?NL01cgW00HLh240G^Mo
kek_8@So013e010P0002010@00020102HaP1@Q010001Li`00004IcUoof<H
HaP201001CgWOnmokekW?NL01Wo_00D00480OnmNkb48050040=ooe00409o
oaD0409oobT0409oo`H040=oool040D04003Oom2448@00a24003001ood8@
00e240040000400@Ool>@Q001`00010046<HIcU24000005cW00000AS67oo
HaQS60804003?NMokgo_008mi`03G^mokgo_009ok`06?Nm20240G^MNkacW
D00@0WooD@0@0Woo500@0Woo:`0@0Woo1P0@0Wooo`0@1@0@00=oof<HHaP0
2f<H00=24000Ool03F<H00I24000010047ooIcT2HaP016LiHaQS66Li0V<H
00IW>F<HIcUS648@00020102HaP1@Q010001Li`00004IcUoof<HHaP20100
0cgWOnlmi`03?NL00ek_Onmok`02?NL01Fm_8@1205k_8@P0100@17oo100@
17oo0P0@0Woo0P0@0Woo0P0@17oo0P0@0Woo00@047ooOol0409oo`8040Eo
o`80409oo`03011oogoo008040Aoo`<040=oo`h0409oo`L040Eoo`80409o
o`@0409oo`80409oo`L0409oo`@0409oo`<0409oo`<040Aoo`@040Eoo`80
409oo`<0409oo`X040Eoo`80409oo`@0409oo`L0409oo`<040Aoo`<040Eo
o`03011oogoo0080409oo`<040Aoo`80409oo`80409oo`80409oo`80409o
o`H0409oool040D04004OomW>F<HHaP60004HaP01D8@001oofLiHaP02@00
0V<H00E24000010047oo00eS6004@Q00000@0102HaP1@Q010001Li`00004
HaQoof<HHaP201001CgWOnmokgo_?NL01Wo_00DmicgP8@12224800<0409o
o`80409oo`80409oo`80409oo`03011oogoo0080409oo`03011oogoo0080
409oo`04011oogoo0102Ool0100@Oomoo`0@0Woo0P0@0Woo00<047ooOol0
0P0@0Woo00<047ooOol00P0@0Woo00@047ooOol0409oo`d0409oo`H0409o
o`<0409oo`03011oogoo00@0409oo`80409oo`L0409oo`@0409oo`L0409o
o`80409oo`80409oo`<0409oo`03011oogoo00<0409oo`X0409oo`80409o
o`L0409oo`L0409oo`80409oo`80409oo`04011oogoo0103Ool00`0@Oomo
o`020102Ool20102Ool20102Ool00`0@Oomoo`020102Ool00`0@Oomoo`03
0102Ool60102Oooo0105010017ooHaQS66<H1P000V<H00EW>F<H@Q0007oo
009S6003001S66<H00ES6005001S66<H@Q000002010017ooHaQS66<H0P00
0V<H00AW>F<H0000009S6008@Q00000@011W>F<H@Q00005cW00000AW>Goo
HaQS60804005?NMokgo_Onlmi`07Onl015k_000aR2481`0@0Woo0P0@0Woo
1@0@0Woo0P0@0Woo00<047ooOol01@0@0Woo00@047ooOol0409oo`03011o
ogoo0080409oo`03011oogoo0080409oo`03011oogoo00L0409oo`h0409o
o`H0409oo`<0409oo`8040Ioo`<0409oo`@040Ioo`<0409oo`/0409oo`80
409oo`H0409oo`<0409oo`X0409oo`80409oo`L0409oo`L0409oo`80409o
o`D0409oo`80409oo`03011oogoo0080409oo`80409oo`D0409oo`80409o
o`03011oogoo00<0409oo`H0409oool040D04003OomS66<H00]S6003@Q00
07oo009S6003001S66<H00ES6005001S66<H@Q00000201001GooHaQS66Li
HaP00P000V<H0P000f<H00A240000100409S60524040005cW00000AS67oo
HaQS60804005?NMokgo_OnlQ1002?NL00beP@P1Ni`03Onl00ek_8@PLi`07
0102Ool20102Ool50102Ool20102Ool00`0@Oomoo`04Ool0100@Oomoo`0@
0Woo00<047ooOol00P0@1Goo00<047ooOol00P0@0Woo00<047ooOol01P0@
0Woo1`0@0goo1@0@0Woo1P0@0Woo0`0@0Woo0P0@0Woo0P0@0Woo100@0Woo
0`0@0Woo00<047ooOol0100@0Woo2`0@0Woo0P0@0Woo1P0@0Woo0`0@0Woo
2P0@0Woo0P0@0Woo1`0@0Woo1`0@0Woo0P0@0Woo1@0@0Woo0P0@0Woo00<0
47ooOol00P0@0Woo0P0@1Woo00<047ooOol00P0@0Woo00<047ooOol00`0@
0Woo1P0@0Wooo`0@1@0@00=oof<HHaP01f<H00MW>F<HIcUS648@001oo`02
HaP00`00HaQS6005HaP01@00HaQS648@00000P0@00=oofLiHaP00f<H1000
0V<H00AW>F<H@Q000080409S60524040005cW00000AW>GooHaQS60804005
?NMokgo_Onlmi`02Onl02Ek_000YAS60@P1Nigo_7>LQ20040104Ool30102
Ool20102Ool01@0@Oomoogoo01000Woo00<047ooOol00P0@0Woo00@047oo
Ool0409oo`03011oogoo00D0409oo`03011oogoo0080409oo`03011oogoo
0080409oo`04011oogoo0102Ool=0102Ool60102Ool30102Ool20102Ool2
0102Ool40102Ool40104Ool40102Ool80104Ool30102Ool60107Ool:0102
Ool20102Ool70102Ool70102Ool20102Ool20102Ool00`0@Oomoo`020102
Ool00`0@Oomoo`020102Ool20102Ool20102Ool01@0@Oomoogoo01000Woo
00<047ooOol00`0@0Woo1P0@0Wooo`0@1@0@00Eoof<HIcUS66Li00US6006
@Q0007ooIcUS60000V<H00=W>F<HIcT00V<H00D006<HHaQ2400000804003
OomS66<H00AS608000ES6004@Q00000@0102HaP1@Q010001Li`00004HaQo
of<HHaP201001CgWOnmokekW?NL00go_00HmifLi>LhQ1360@P0248@30102
Ool70104Ool20105Ool30104Ool20107Ool30104Ool20103Ool00`0@Oomo
o`020104Ool30103Ool>0102Ool60102Ool30102Ool30104Ool60102Ool3
0104Ool40102Ool70102Ool60102Ool60102Ool30102Ool:0105Ool80102
Ool70102Ool30104Ool20102Ool20102Ool01@0@Oomoogoo01000goo0P0@
17oo0P0@1Goo0P0@0goo0P0@0Woo1P0@0Wooo`0@1@0@00=oof<HHaP01F<H
00=W>F<HHaP00f<H00=24000Ool00V<H00<006LiHaP01F<H00D006<HHaQ2
400000804004OomS66<HIcT2HaP40002HaP016LiHaQ240000P0@0V<H0D8@
0@000G>L000016LiOomS66<H0P0@00Dmigo_G^m203gW00=ok`06G^mNmfmk
@00`03600P000`0@0Woo3@0@0Woo700@0Woo7P0@0Woo1P0@0Woo0`0@0Woo
0`0@17oo1P0@0Woo100@0goo100@0Woo1`0@0Woo1P0@0Woo1P0@0Woo0`0@
0Woo5`0@0Woo1`0@0Woo9P0@0Woo0`0@0Woo1P0@0Wooo`0@1@0@00Moof<H
HaQS66LiHaQW>@03HaP01fLiHaQW>F<H@Q0007oo009S6003001S66<H00AS
6006IcT006<HHaQ240000P0@00=oof<HHaP00V<H0P000V<H0P000f<H00Q2
4000010046<HIcU240000G>L000016<HOomS66<H0P0@00@migo_OnmNi`8m
i`=ok`05?NM/ib`0@00`000200030102Ool20102Ool90102OolL0102OolN
0102Ool60102Ool30102Ool40102Ool80102Ool30103Ool20104Ool70102
Ool20102Ool20102Ool30102Ool00`0@Oomoo`030102OolE0104Ool70102
OolV0102Ool30102Ool60102Oooo0105010017ooHaQS66Li1F<H00=W>F<H
HaP00V<H00=24000Ool00V<H2@000V<H00I24000010047ooIcT2HaP20000
16<HIcUS66<H0P000V<H00A240000100409S60524040005cW00000AW>Goo
HaQS60804005?NMokek_@P0mi`04Onl01ek_G>Mlib`0@00/000000@040Ao
o`X0409oob00409ooaX040=oo`D0409oo`<0409oo`@0409oo`@040Ioo`@0
409oo`@0409oo`P040Aoo`@040Eoo`80409oo`<0409ooaL0409oo`P0409o
obT0409oo`H040=oool040D04003OomS66<H009S6003IcUS66Li00=S6008
IcUS66<H@Q0007ooIcUS60T0009S6005@Q00000@011oo`0<HaP00fLi@Q00
00020102HaP1@Q010001Li`00004HaQoof<HHaP2010013gWOnmokekW0SgW
17o_00INkecWO>L/0400;03o013e01001GooHaQW>F<HIcT01F<H00MW>F<H
HaQS648@001oo`0=HaP01D8@0000400@Ool03F<H00A240000100409S6052
4040005cW00000AW>GooHaQS608040047>0mib447>07?NL01B44G>Mlib`0
<000o`0@m@0@3goo00<007ooOol03Goo00<0000@01003goo00L0000@011S
66Li@Q000001Li`00004HaQoof<HHaP>01000`00G>MLi`3o013o010[0102
HaP1@Q010001Li`00004IcUoof<HHaSo013o010l010016<HIcU240000G>L
00000f<HOomS603oHaSoHaPmHaP016LiHaQ240000G>L00000fLiOomS6007
HaP01fLiHaQS66<HIcUS66Li009S6003IcUS66<H0?mS6?mS62aS60524040
005cW00000=S67ooOol0ogooogoo?goo0D8@0@000G>L0000ofLiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>@00ofLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@00?FLiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66Li00IS6040005cW000\
\>"], "Picture",
  ImageSize->{579, 431},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Start with PSpice Circuit Analysis", "ExampleSection"],

Cell["\<\
Extract lower corner frequency of the voltage gain (without feedback) using \
PROBE:\
\>", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008o0001ZA000`40O003
h00O8goo00<207ooOol047oo00<07gooOol0<Goo00<207ooOol04goo00P2
07oo0P1oo`80Ool207oo0P806Woo00<207ooOol097oo00<207ooOol0<Goo
00<207ooOol04Goo0P8027oo0P0O3Woo00<207ooOol06Woo0P0O:7oo00<0
7gooOol037oo0P0O0Woo00<07gooOol0:goo00<207ooOol047oo00<07goo
Ool0?Woo00<207ooOol04Woo011S67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoo`9S6003@Q0007oo00aoo`00o`00o`00@0000Goo00000f<H@Q12
403o@Q3o@Q0l@Q010001Ool0003oIcUoof<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H003oIcUoof<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<H0010IcUoof<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcT1Ool00003HaQoofLi0?mS6?mS63]S60524040005oo`0000AW>Goo
HaQS6?l00?l003P0009S60524040005oo`0000=S67ooHaP0of<Hof<H>f<H
0D8@0@000Goo00000fLiOomS603oHaSoHaPkHaP1@Q010001Ool00003HaQo
ofLi009S6003IcUS66<H0?mS6?mS639S6006IcUS66LiHaQ240000Goo0000
0f<HOomS6005HaP0ofLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@00ofLiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>@00<FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66Li00ES60524040005oo`0000MS67ooHaQS66LiHaQW>@3o
HaSoHaPbHaP00fLiHaQW>@02HaP1@Q010001Ool00004HaQoof<HIcT5HaP0
ofLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@00ofLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@00;fLiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT016<H
00AW>F<H@Q00005oo`0000=W>GooHaP00V<H00=W>F<HIcT0of<Hof<H<6<H
00=W>F<HIcT00f<H0D8@0@000Goo00001F<HOomS66<HIcT01F<H0?mW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT00?mW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT002eW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H00AW>F<H@Q00
005oo`0000=W>GooHaP00f<H00=W>F<HIcT0of<Hof<H;V<H00=W>F<HIcT0
16<H0D8@0@000Goo00001V<HOomS66LiHaQW>@AS603oIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66Li003oIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66Li000]IcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00ES6004IcUS648@0001Ool00003
IcUoof<H00AS6003IcUS66<H0?mS6?mS62eS6005IcUS66LiHaQW>@02HaP1
@Q010001Ool0003oHaQoof<HHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li003oHaQoof<HHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
000gHaQoof<HHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H00AW>F<H@Q00005oo`0000=W
>GooHaP016<H00=W>F<HHaP0of<Hof<H;F<H00EW>F<HIcUS66Li009S6052
4040005oo`000?mS67ooHaQS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00?mS67ooHaQS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT0
03MS67ooHaQS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>@07HaP1@Q010001Ool00003IcUoof<H
00AS6003IcUS66<H0?mS6?mS62eS6009IcUS66LiHaQW>F<HIcU24000005o
o`000?mS67ooHaQS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcT00?mS67ooHaQS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT003MS67oo
HaQS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@07HaP1@Q010001Ool00003IcUoof<H00AS6003
IcUS66<H0?mS6?mS62eS6005IcUS66LiHaQW>@02HaP1@Q010001Ool0003o
HaQoof<HHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66Li003oHaQoof<HHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li000gHaQoof<HHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT01f<H0D8@0@000Goo00000fLiOomS6004HaP00fLiHaQS
603oHaSoHaP]HaP02FLiHaQW>F<HIcUS66Li@Q000001Ool0003oHaQoof<H
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66Li003oHaQoof<HHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li000gHaQoof<HHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcT01f<H0D8@0@000Goo00000fLiOomS6004HaP00fLiHaQS603oHaSo
HaP]HaP01FLiHaQW>F<HIcT00V<H0D8@0@000Goo0000of<HOomS66<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>@00of<HOomS66<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>@00=f<HOomS66<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
00MS60524040005oo`0000=W>GooHaP016<H00=W>F<HHaP0of<Hof<H;F<H
00UW>F<HIcUS66LiHaQW>D8@00000Goo000016<HOomS66<Ho`00o`00>000
0V<H0D8@0@000Goo000016LiOomS66<Hogoo<goo0P008Goo1000gGoo0V<H
0D8@0@000Goo000016<HOomS66<Hogoo<goo0P0097oo0P00g7oo0V<H0D8@
0@000Goo000016LiOomS66<Hogoo<goo0P009Goo0P00fgoo00AW>F<H@Q00
005oo`0000AS67ooHaQW>OmooaMoo`8000Ioo`8000Moo`@000Aoo`D000=o
o`D000=oo`@000=oo`80009oo`8000=oo`@000Aoo`@00=]oo`9S60524040
005oo`0000AW>GooHaQS6?mooaMoo`8000Ioo`8000Ioo`8000Ioo`80009o
o`80009oo`80009oo`80009oo`8000Ioo`80009oo`80009oo`80009oo`80
009oo`80009oo`800=Yoo`04IcUS648@0001Ool00004HaQoof<HIcWoOolG
Ool20006Ool20006Ool20006Ool20002Ool20002Ool20002Ool20002Ool2
0006Ool20002Ool20002Ool20006Ool20002Ool2003JOol2HaP1@Q010001
Ool00004IcUoof<HHaSoOolGOol20006Ool20006Ool60002Ool20002Ool2
0002Ool20002Ool20002Ool60002Ool20002Ool20002Ool20006Ool20002
Ool2003JOol016LiHaQ240000Goo000016<HOomS66Liogoo5goo1@000goo
0`001Goo0P000Woo0P000Woo0P000Woo0P000Woo0P000Woo0P000Woo0P00
0Woo0P000Woo0P000Woo0P000Woo0P001Woo0P000Woo0P00fWoo0V<H0D8@
0@000Goo000016LiOomS66<Hogoo5goo0P001Woo0P0000Aoo`000000009o
o`80009oo`80009oo`80009oo`80009oo`80009oo`80009oo`80009oo`80
009oo`80009oo`80009oo`80009oo`80009oo`80009oo`800=Yoo`04IcUS
648@0001Ool00004HaQoof<HIcWoOolGOol20006Ool20002Ool20003Ool4
0004Ool50002Ool20002Ool20003Ool40003Ool50004Ool40003Ool20002
Ool2003JOol2HaP1@Q010001Ool00004IcUoof<HHaSoOolGOol2003oOolO
Ool016LiHaQ240000Goo000016<HOomS66Liogoo5goo1P00ogoo6goo0V<H
0D8@0@000@80000016LiOomS66<Hogooogoo>7oo00AW>F<H@Q00005oo`00
00AS67ooHaQW>OmooomoocQoo`9S60524040005oo`0000AW>GooHaQS641o
o`<00005Ool00000001oo`03003oOoo/Ool016LiHaQ240000Goo000016<H
OomS66Liogooogoo>7oo0V<H0D8@0@000Goo000016LiOomS66<H?Woo00<0
07ooOol02goo00<007ooOol07Goo0P00;7oo0P00ogooVgoo00AW>F<H@Q00
005oo`0000AS67ooHaQW>Cioo`03001oogoo00]oo`03001oogoo01aoo`80
02ioo`800?mooiYoo`9S60524040005oo`0000AW>GooHaQS63ioo`03001o
ogoo00]oo`03001oogoo00Aoo`8000Eoo`D0009oo`D000Eoo`8000Aoo`80
009oo`8000Eoo`8000Aoo`@000Eoo`<000Ioo`8000Eoo`800?mooiYoo`04
IcUS648@0001Ool00004HaQoof<HIcU3Ool5:1l:Ool40003Ool20002Ool2
0002Ool20002Ool20003Ool20005Ool20002Ool20005Ool20003Ool20002
Ool20004Ool30006Ool20006Ool2003oOonIOol2HaP1@Q010001Ool00004
IcUoof<HHaPnOol00`00Oomoo`02Ool01BPOOomoogoo:1l017oo00<007oo
Ool00Woo0P000Woo0P000Woo0P000Woo0P000Woo0P000Woo0P000goo0P00
1Goo0P000Woo0P001Goo0P000goo0P000Woo0P003Goo0P001Woo0P00ogoo
VGoo00AW>F<H@Q00005oo`0000AS67ooHaQW>Cioo`03001oogoo009oo`05
:1moogooOolX7`04Ool00`00Oomoo`02Ool20002Ool20002Ool20002Ool2
0002Ool20002Ool20003Ool20005Ool200000goo00000006Ool20007Ool2
000=Ool20006Ool2003oOonIOol2HaP1@Q010001Ool00004IcUoof<HHaPn
Ool00`00Oomoo`02Ool01BPOOomoogoo:1l017oo00<007ooOol00Woo0P00
0Woo0P000Woo0P000Woo0P000Woo0P000Woo0P000goo0P001Goo1@001Woo
0P001Goo0`003Woo0P001Woo0P00ogooVGoo00AW>F<H@Q00005oo`0000AS
67ooHaQW>D=oo`DX7`Uoo`80009oo`80009oo`80009oo`80009oo`80009o
o`8000=oo`8000Eoo`80009oo`8000Eoo`8000Moo`8000Aoo`<000Ioo`80
00Ioo`800?mooiUoo`9S60524040005oo`0000AW>GooHaQS63ioo`03001o
ogoo00]oo`03001oogoo009oo`80009oo`8000=oo`D0009oo`D000Eoo`80
00Aoo`80009oo`80009oo`D000=oo`80009oo`8000Aoo`<000=oo`D000Eo
o`800?mooiYoo`04IcUS648@0001Ool00004HaQoof<HIcTnOol00`00Oomo
o`0;Ool00`00Oomoo`02Ool20002Ool20006Ool20002Ool20008Ool20004
Ool20002Ool20004Ool30003Ool20002Ool2000<Ool30005Ool2003oOonJ
Ool2HaP1@Q010001Ool00004IcUoof<HHaPnOol00`00Oomoo`0;Ool00`00
Oomoo`02Ool20002Ool20006Ool20002Ool20009Ool20003Ool50006Ool2
0004Ool4000>Ool20004Ool2003oOonKOol016LiHaQ240000Goo000016<H
OomS66Liogooogoo>7oo0V<H0D8@0@000Goo000016LiOomS66<H@7oo0`00
00Eoo`00000007oo00<00?moonaoo`04IcUS648@0001Ool00004HaQoof<H
IcWoOoooOolhOol2HaP1@Q010001Ool00004IcUoof<HHaSoOoooOolhOol0
16LiHaQ240000Goo000016<HOomS66Liogooogoo>7oo0V<H0D8@0@000Goo
000016LiOomS66<Hogooogoo>7oo00AW>F<H@Q00005oo`0000AS67ooHaQW
>Beoo`8000Eoo`@000Aoo`@0009oo`8000=oo`800003Ool00000009oo`80
009oo`H005Uoo`8000Eoo`@0009oo`80009oo`80009oo`H005Uoo`8000Eo
o`<000Eoo`@0009oo`80009oo`80009oo`80009oo`80009oo`H0055oo`80
00Eoo`@000Aoo`@0009oo`80009oo`80009oo`80009oo`80009oo`H0045o
o`8000Eoo`@0009oo`8000=oo`800003Ool00000009oo`80009oo`H000Io
o`9S60524040005oo`0000AW>GooHaQS62eoo`8000Aoo`80009oo`80009o
o`80009oo`800006Ool00000Ool007oo0P0000=oo`0000000Woo0P000Woo
0P00GGoo0P0017oo0P000Woo0P0000=oo`0000000Woo0P000Woo0P00GGoo
0P001Goo0`0017oo0P000Woo0P0000=oo`0000000Woo0P000Woo0P000Woo
0P000Woo0P00EGoo0P0017oo0P000Woo0P000Woo0P000Woo0P0000=oo`00
00000Woo0P000Woo0P000Woo0P000Woo0P00AGoo0P0017oo0P000Woo0P00
00=oo`0000000goo0P0000=oo`0000000Woo0P000Woo0P002Woo00AW>F<H
@Q00005oo`0000AS67ooHaQW>Beoo`8000Aoo`<00003Ool00000009oo`<0
0004Ool00000Ool200000goo001oo`0200000goo00000002Ool20003Ool2
001LOol20004Ool3000017oo000007oo0P000Woo0P000goo0P00G7oo0P00
37oo0`0000Aoo`00001oo`800003Ool0000000=oo`80009oo`8000=oo`80
05Aoo`8000Aoo`<00003Ool00000009oo`<00004Ool00000Ool200000goo
00000003Ool20002Ool20003Ool20014Ool20004Ool3000017oo000007oo
0P000goo0P0000=oo`0000000Woo0P000goo0P002Goo0V<H0D8@0@000Goo
000016LiOomS66<H;Goo0P0017oo0`0000=oo`0000000Woo0`0000Aoo`00
001oo`800003Ool007oo00800003Ool00000009oo`8000Aoo`8005]oo`80
00Aoo`<00004Ool00000Ool20002Ool20004Ool2001KOol2000<Ool30000
17oo000007oo0P0000=oo`0000000goo0P000Woo0P0017oo0P00Dgoo0P00
17oo0`0000=oo`0000000Woo0`0000Aoo`00001oo`800003Ool0000000=o
o`80009oo`8000Aoo`8004=oo`8000Aoo`<00004Ool00000Ool200000goo
001oo`0200000goo00000002Ool20004Ool20008Ool016LiHaQ240000Goo
000016<HOomS66Li;Goo0P0017oo0P000Woo0P000Woo0P000Woo0P0000Io
o`00001oo`00Ool200000goo000000040005Ool2001JOol20004Ool20002
Ool200000goo000000040005Ool2001JOol2000<Ool20002Ool200000goo
000000020004Ool60005Ool2001BOol20004Ool20002Ool20002Ool20002
Ool200000goo000000020004Ool60005Ool20012Ool20004Ool20002Ool2
00001Woo000007oo001oo`800003Ool0000000@000Eoo`8000Moo`9S6052
4040005oo`0000AW>GooHaQS62eoo`8000Aoo`800004Ool000000002Ool2
00001Goo00000000Ool00P0000=oo`00Ool00P0000=oo`0000000Woo0P00
1Woo0P00FGoo0P0017oo0P0000Eoo`00000007oo0080009oo`8000Ioo`80
05Uoo`8000aoo`800005Ool00000001oo`0200000goo00000003Ool20002
Ool20006Ool2001AOol20004Ool2000017oo000000000Woo0P0000Eoo`00
000007oo00800003Ool0000000=oo`80009oo`8000Ioo`80045oo`8000Ao
o`800005Ool00000001oo`0200000goo001oo`0200000goo00000002Ool2
0006Ool20006Ool016LiHaQ240000Goo000016<HOomS66Li:Woo1@0017oo
0P0000Aoo`000000009oo`800005Ool00000001oo`060002Ool20002Ool2
0002Ool6001FOol50004Ool200001Goo00000000Ool00P000Woo0P000Woo
1P00EWoo1@0037oo0P0000Eoo`00000007oo00800003Ool0000000=oo`80
009oo`80009oo`H004ioo`D000Aoo`800004Ool000000002Ool200001Goo
00000000Ool00P0000=oo`0000000goo0P000Woo0P000Woo1P00?Woo1@00
17oo0P0000Eoo`00000007oo00<00005Ool00000001oo`020002Ool20002
Ool60006Ool2HaP1@Q010001Ool00004IcUoof<HHaP/Ool30004Ool20002
Ool20002Ool20002Ool20009Ool20002Ool2001POol30004Ool20002Ool2
00000goo00000002Ool2001POol3000<Ool20002Ool200000goo00000002
Ool20002Ool20002Ool2001HOol30004Ool20002Ool20002Ool20002Ool2
00000goo00000002Ool20002Ool20002Ool20018Ool30004Ool20002Ool2
00000goo00000003Ool200000goo00000002Ool2000>Ool016LiHaQ24000
0Goo000016<HOomS66Li;Goo0P001Goo100017oo10002Woo0P000Woo0P00
HGoo0P001Goo10000Woo0P000Woo0P00HGoo0P003Goo10000Woo0P000Woo
0P000Woo0P000Woo0P00FGoo0P001Goo100017oo10000Woo0P000Woo0P00
0Woo0P000Woo0P00BGoo0P001Goo10000Woo0P000goo0P0000=oo`000000
0Woo0P003Woo0V<H0D8@0@000Goo000016LiOomS66<Hogooogoo>7oo00AW
>F<H@Q00005oo`0000AS67ooHaQW>OmooomoocQoo`9S60524040005oo`00
00AW>GooHaQS6?mooomoocQoo`04IcUS648@0001Ool00004HaQoof<HIcWo
OoooOolhOol2HaP1@Q010001Ool00004IcUoof<HHaSoOoooOolhOol016Li
HaQ240000Goo000016<HOomS66Liogooogoo>7oo0V<H0D8@0@000Goo0000
16LiOomS66<H9Goo0P000goo10001Woo100027oo00<007ooOol0NGoo00<0
07ooOol0NGoo00<007ooOol0NGoo00<007ooOol0NGoo00<007ooOol00goo
00AW>F<H@Q00005oo`0000AS67ooHaQW>BEoo`8000Ioo`8000Aoo`80009o
o`8000Moo`03001oogoo07Uoo`03001oogoo07Uoo`03001oogoo07Uoo`03
001oogoo07Uoo`03001oogoo00=oo`9S60524040005oo`0000AW>GooHaQS
62Eoo`8000Moo`8000=oo`<00003Ool0000000Moo`03001oogoo07Uoo`03
001oogoo07Uoo`03001oogoo07Uoo`03001oogoo07Uoo`03001oogoo00=o
o`04IcUS648@0001Ool00004HaQoof<HIcTUOol20007Ool20003Ool30000
0goo00000007Ool00`00Oomoo`1iOol00`00Oomoo`1iOol00`00Oomoo`1i
Ool00`00Oomoo`1iOol00`00Oomoo`03Ool2HaP1@Q010001Ool00004IcUo
of<HHaPJOol60005Ool20003Ool50004Ool20002Ool20003Ool90003Ool5
0003Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003
Ool50003Ool50003Ool300000goo001oo`02Ool50003Ool50003Ool50003
Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003Ool5
0003Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003
Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003Ool5
0003Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003
Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003Ool5
0003Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003Ool50003
Ool50003Ool50003Ool00`00Oomoo`03Ool016LiHaQ240000Goo000016<H
OomS66Li9Goo0P000goo0P001goo0P0000Aoo`00000000Moo`03001oogoo
00=oo`03001oogoo0?moonQoo`03001oogoo00=oo`9S60524040005oo`00
00AW>GooHaQS629oo`D000=oo`8000Moo`800004Ool000000007Ool00`00
Oomoo`3oOoo^Ool00`00Oomoo`03Ool016LiHaQ240000Goo000016<HOomS
66Li97oo0`000goo0P001goo0P000Woo0P001goo00<007ooOol00goo00<0
07ooOol0ogooj7oo00<007ooOol00goo0V<H0D8@0@000Goo000016LiOomS
66<H9Goo0P000goo1P0017oo100027oo00<007ooOol0F7oo00<007ooOol0
ogooTgoo00<007ooOol00goo00AW>F<H@Q00005oo`0000AS67ooHaQW>DIo
o`03001oogoo0?moonioo`9S60524040005oo`0000AW>GooHaQS6?mooomo
ocQoo`04IcUS648@0001Ool00004HaQoof<HIcU6Ool00`00Oomoo`3oOoo^
Ool2HaP1@Q010001Ool00004IcUoof<HHaQ0Ool00`00Oomoo`1HOol00`00
Oomoo`3oOonCOol00`00Oomoo`03Ool016LiHaQ240000Goo000016<HOomS
66Li@7oo00<007ooOol00goo00<007ooOol0ogooj7oo00<007ooOol00goo
0V<H0D8@0@000Goo000016LiOomS66<H@7oo00<007ooOol0ogookWoo00<0
07ooOol00goo00AW>F<H@Q00005oo`0000AS67ooHaQW>D1oo`03001oogoo
00=oo`03001oogoo0?moonQoo`03001oogoo00=oo`9S60524040005oo`00
00AW>GooHaQS641oo`03001oogoo05Qoo`03001oogoo0?mooi=oo`03001o
ogoo00=oo`04IcUS648@0001Ool00004HaQoof<HIcU6Ool00`00Oomoo`3o
Ooo^Ool2HaP1@Q010001Ool00004IcUoof<HHaSoOoooOolhOol016LiHaQ2
40000Goo000016<HOomS66LiAWoo00<007ooOol0ogookWoo0V<H0D8@0@00
0Goo000016LiOomS66<H@7oo00<007ooOol0F7oo00<007ooOol0ogooTgoo
00<007ooOol00goo00AW>F<H@Q00005oo`0000AS67ooHaQW>D1oo`03001o
ogoo00=oo`03001oogoo07=oo`03001oogoo07Uoo`03001oogoo07Uoo`03
001oogoo07Uoo`03001oogoo00=oo`9S60524040005oo`0000AW>GooHaQS
641oo`03001oogoo0?moonioo`03001oogoo00=oo`04IcUS648@0001Ool0
0004HaQoof<HIcU0Ool00`00Oomoo`03Ool00`00Oomoo`3oOooXOol00`00
Oomoo`03Ool2HaP1@Q010001Ool00004IcUoof<HHaQ0Ool00`00Oomoo`1H
Ool00`00Oomoo`3oOonCOol00`00Oomoo`03Ool016LiHaQ240000Goo0000
16<HOomS66LiAWoo00<007ooOol0ogookWoo0V<H0D8@0@000Goo000016Li
OomS66<Hogooogoo>7oo00AW>F<H@Q00005oo`0000AS67ooHaQW>DIoo`03
001oogoo0?moonioo`9S60524040005oo`0000AW>GooHaQS641oo`03001o
ogoo05Qoo`03001oogoo0?mooi=oo`03001oogoo00=oo`04IcUS648@0001
Ool00004HaQoof<HIcU0Ool00`00Oomoo`03Ool00`00Oomoo`3oOooXOol0
0`00Oomoo`03Ool2HaP1@Q010001Ool00004IcUoof<HHaQ0Ool00`00Oomo
o`3oOoo^Ool00`00Oomoo`03Ool016LiHaQ240000Goo000016<HOomS66Li
@7oo00<007ooOol00goo00<007ooOol0ogooj7oo00<007ooOol00goo0V<H
0D8@0@000Goo000016LiOomS66<H@7oo00<007ooOol0F7oo00<007ooOol0
ogooTgoo00<007ooOol00goo00AW>F<H@Q00005oo`0000AS67ooHaQW>DIo
o`03001oogoo0?moonioo`9S60524040005oo`0000AW>GooHaQS6?mooomo
ocQoo`04IcUS648@0001Ool00004HaQoof<HIcU6Ool00`00Oomoo`3oOoo^
Ool2HaP1@Q010001Ool00004IcUoof<HHaQ0Ool00`00Oomoo`1HOol00`00
Oomoo`3oOonCOol00`00Oomoo`03Ool00fLiHaQ2400200000004HaQoof<H
IcU0Ool00`00Oomoo`03Ool00`00Oomoo`3oOooXOol00`00Oomoo`03Ool2
HaP1@Q010001HaP00004IcUoof<HHaQ0Ool00`00Oomoo`1iOol00`00Oomo
o`1iOol00`00Oomoo`1iOol00`00Oomoo`1iOol00`00Oomoo`03Ool00fLi
HaQ2400200000004HaQoof<HIcU0Ool00`00Oomoo`03Ool00`00Oomoo`3o
OooXOol00`00Oomoo`03Ool2HaP1@Q010001@Q000004IcUoof<HHaQ0Ool0
0`00Oomoo`1HOol00`00Oomoo`3oOonCOol00`00Oomoo`03Ool016LiHaQ2
40000D8@000016<HOomS66LiAWoo00<007ooOol0Fgoob000bWoo0V<H0D8@
0@000F<H000016LiOomS66<HY7oo00=S648@@Q00a48@00<007ooOol0b7oo
00AW>F<H@Q00005W>@0000AS67ooHaQW>DIoo`03001oogoo05]oo`38IcUo
of<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li@Q000<Yoo`9S6052
4040005S600000AW>GooHaQS641oo`03001oogoo05Qoo`03001oogoo00Io
o`03HaQoofLi009S6003Ool00000009oo`8000Aoo`8000Eoo`8002Eoo`80
00Qoo`<000Aoo`8000Moo`8000Eoo`80009oo`8000Aoo`8000Eoo`<002=o
o`80009oo`8000Aoo`<000Aoo`80009oo`8000Aoo`8000=oo`80009oo`80
009oo`80009oo`800004OomS648@0034Ool00`00Oomoo`03Ool016LiHaQ2
40000F<H000016<HOomS66Li@7oo00<007ooOol00goo00<007ooOol0Fgoo
00IW>GooHaQS66LiOol20002Ool20004Ool20005Ool2000VOol2000>Ool2
0008Ool20004Ool300000goo00000005Ool2000ZOol20002Ool2000;Ool3
00000goo00000004Ool20003Ool20002Ool20002Ool20002Ool2000017oo
IcU24000a7oo00<007ooOol00goo0V<H0D8@0@000F<H000016LiOomS66<H
@7oo00<007ooOol0HGoo00=S67ooHaP00V<H00=oo`0000000Woo0P0017oo
0P001Goo0P001Goo1P0077oo0P003Woo0P001Goo1@000goo0`0000=oo`00
00001Goo0P00;Woo0P002goo0`0000=oo`00000017oo0P001goo0P000Woo
0P000Woo0P0000Aoof<H@Q000<Aoo`03001oogoo00=oo`04IcUS648@0001
HaP00004HaQoof<HIcU0Ool00`00Oomoo`03Ool00`00Oomoo`1KOol00fLi
OomS6002HaP00goo00000002Ool20004Ool20004Ool6000JOol60005Ool2
000=Ool20004Ool20002Ool20003Ool20002Ool200000goo00000003000]
Ool3000<Ool20002Ool20004Ool20005Ool30003Ool20002Ool2000017oo
IcU24000a7oo00<007ooOol00goo0V<H0D8@0@000F<H000016LiOomS66<H
@7oo00<007ooOol0F7oo00<007ooOol01Woo00=S67ooHaP00V<H00=oo`00
00000Woo0P0017oo0P001Goo0P001Goo1P007Woo0P003Goo0P000goo0P00
0Woo0P000goo0P0000Eoo`00000007oo0080039oo`8000]oo`800004Ool0
00000004Ool20007Ool20002Ool50002Ool00f<H@Q000034Ool00`00Oomo
o`03Ool016LiHaQ240000F<H000016<HOomS66LiAWoo00<007ooOol0Fgoo
00EW>GooHaQS66Li009oo`D0009oo`@000Eoo`8002Eoo`80009oo`8000eo
o`8000=oo`80009oo`8000=oo`800005Ool00000001oo`02000^Ool20002
Ool2000;Ool200001Goo00000000Ool01@000goo0P000Woo0P000goo0P00
17oo00=W>D8@0000bWoo0V<H0D8@0@000F<H000016LiOomS66<HY7oo00=S
67ooHaP00V<H1Goo0P002goo0P009Goo0P000Woo0P003Woo0P000Woo0P00
0Woo0P000goo0P000Woo0P0000=oo`000000;Woo0P000Woo0P002goo0P00
0Woo0P000goo0`000goo0P000Woo0P0017oo0P000goo00=W>D8@0000QWoo
00<X7gooOol0@Goo00AW>F<H@Q00005S600000AS67ooHaQW>DIoo`03001o
ogoo05]oo`05IcUoof<HHaQW>@05Ool20004Ool20006Ool4000SOol4000;
Ool60003Ool40005Ool40002Ool6000[Ool4000=Ool40005Ool20004Ool4
0005Ool30002Ool00f<H@Q000024Ool2:1m4Ool2HaP1@Q010001HaP00004
IcUoof<HHaQ0Ool00`00Oomoo`1HOol00`00Oomoo`06Ool00f<HOomS6002
HaP;Ool2002cOol00fLi@Q000022Ool2:1m0Ool00`00Oomoo`03Ool016Li
HaQ240000F<H000016<HOomS66Li@7oo00<007ooOol00goo00<007ooOol0
Fgoo00EW>GooHaQS66Li0<1oo`03HaQ24000081oo`8X7d9oo`03001oogoo
00=oo`9S60524040005S600000AW>GooHaQS641oo`03001oogoo065oo`03
HaQoof<H009S6<1oo`03IcU2400007ioo`8X7dAoo`03001oogoo00=oo`04
IcUS648@0001HaP00004HaQoof<HIcU0Ool00`00Oomoo`03Ool00`00Oomo
o`1KOol01FLiOomS66<HIcT0`7oo00=S648@0000B7oo00<007ooOol0<Goo
0RPOAWoo00<007ooOol00goo0V<H0D8@0@000F<H000016LiOomS66<H@7oo
00<007ooOol0F7oo00<007ooOol01Woo00=S67ooHaP00V<HJgoo0P00Dgoo
00=W>D8@0000NWoo0RPOB7oo00<007ooOol00goo00AW>F<H@Q00005S6000
00AS67ooHaQW>DIoo`03001oogoo05]oo`05IcUoof<HHaQW>@1/Ool2001B
Ool00f<H@Q00001hOol2:1m@Ool2HaP1@Q010001HaP00004IcUoof<HHaRT
Ool00f<HOomS6002HaP00goo00000002Ool20002Ool6000ZOol60004Ool3
0004Ool30007Ool20004Ool40005Ool40004Ool3000VOol20003Ool40006
Ool30004Ool40004Ool20005Ool40003Ool00fLi@Q00001fOol2:1mBOol0
16LiHaQ240000F<H000016<HOomS66LiAWoo00<007ooOol0Fgoo00=W>Goo
HaP00V<H00=oo`0000000Woo0P000Woo0P00;Woo0P0027oo0`001Goo0P00
1goo0P000goo0P000Woo0P000goo0P000Woo0P000goo0`009Woo0P001Woo
0P001Goo0`000goo0P000Woo0P000goo0P0027oo0P000Woo00=S648@0000
M7oo0RPOE7oo0V<H0D8@0@000F<H000016LiOomS66<H@7oo00<007ooOol0
F7oo00<007ooOol01Woo00=S67ooHaP00V<H00=oo`0000000Woo0P000goo
0P00;Woo0P0047oo0P001Woo0P000goo0P000Woo0P000goo0`0000=oo`00
0000;7oo0P001goo0P002Woo0P000Woo0P000goo0P002Goo0P0000AoofLi
@Q00079oo`8X7e1oo`03001oogoo00=oo`04IcUS648@0001HaP00004HaQo
of<HIcU0Ool00`00Oomoo`03Ool00`00Oomoo`1KOol01VLiOomS66LiHaQo
o`H000Aoo`8000aoo`H001aoo`8000eoo`D000Eoo`8000=oo`80009oo`80
00=oo`<00003Ool0000002aoo`8000Moo`8000Yoo`800004Ool000000004
Ool20008Ool2000017ooHaQ24000LGoo00<X7gooOol0D7oo00<007ooOol0
0goo0V<H0D8@0@000F<H000016LiOomS66<H@7oo00<007ooOol0HGoo00=S
67ooHaP00V<H00=oo`0000000Woo0P001Goo0P00;Woo0P002goo0P000Woo
0P001Goo0P000goo0P000Woo0P000goo0P000Woo0P008Goo1P001Goo0P00
0goo1@0037oo10001Goo0P0017oo1@000Woo00=W>D8@0000Kgoo0RPODgoo
00<007ooOol00goo00AW>F<H@Q00005S600000AS67ooHaQW>D1oo`03001o
ogoo00=oo`03001oogoo05]oo`03IcUoof<H009S6003Ool00000009oo`80
00Ioo`8000Yoo`H001ioo`8000Yoo`80009oo`8000Eoo`8000=oo`D000Ao
o`800004Ool00000000/Ool20003Ool2000>Ool300000goo00000005Ool2
0003Ool20005Ool00f<H@Q00001]Ool2:1mEOol00`00Oomoo`03Ool2HaP1
@Q010001HaP00004IcUoof<HHaQ0Ool00`00Oomoo`1HOol00`00Oomoo`06
Ool00f<HOomS6002HaP00goo00000002Ool20002Ool20002Ool2000ZOol2
0002Ool2000:Ool20002Ool20002Ool50004Ool20006Ool2000017oo0000
0000:Goo1@000goo0P003Woo0P000Woo0P001Goo0P000goo0P001Goo00=W
>D8@0000K7oo00<X7gooOol0EGoo00<007ooOol00goo00AW>F<H@Q00005S
600000AS67ooHaQW>DIoo`03001oogoo05]oo`05IcUoof<HHaQW>@02Ool4
0003Ool20002Ool2000ZOol20002Ool2000:Ool20002Ool20004Ool30005
Ool20005Ool20002Ool2000[Ool30003Ool2000>Ool20002Ool20006Ool2
0002Ool20005Ool00f<H@Q00001ZOol2:1mNOol2HaP1@Q010001HaP00004
IcUoof<HHaRTOol00f<HOomS6002HaP3Ool20005Ool4000/Ool4000<Ool4
0006Ool20005Ool30005Ool4000]Ool20003Ool6000;Ool40003Ool60002
Ool6000017ooIcU24000J7oo0RPOH7oo00AW>F<H@Q00005oo`0000AS67oo
HaQW>DIoo`03001oogoo05]oo`05IcUoof<HHaQW>@30Ool00f<H@Q00001W
Ool00bPOOomoo`1POol2HaP1@Q01000100000004IcUoof<HHaQ0Ool00`00
Oomoo`1HOol00`00Oomoo`06Ool00f<HOomS6002HaS0Ool00fLi@Q00001U
Ool2:1mMOol00`00Oomoo`03Ool016LiHaQ240000F<H000016<HOomS66Li
@7oo00<007ooOol00goo00<007ooOol0Fgoo00EW>GooHaQS66Li0<1oo`03
HaQ2400006=oo`8X7emoo`03001oogoo00=oo`9S60524040005S600000AW
>GooHaQS641oo`03001oogoo065oo`03HaQoof<H009S6<1oo`03IcU24000
069oo`03:1moogoo05moo`03001oogoo00=oo`04IcUS648@0001HaP00004
HaQoof<HIcU0Ool00`00Oomoo`03Ool00`00Oomoo`1KOol01FLiOomS66<H
IcT0Jgoo0P00Dgoo00=S648@0000H7oo0RPOHWoo00<007ooOol00goo0V<H
0D8@0@000F<H000016LiOomS66<H@7oo00<007ooOol0F7oo00<007ooOol0
1Woo00=S67ooHaP00V<HK7oo0P00DWoo00=W>D8@0000B7oo00<007ooOol0
4goo0RPOI7oo00<007ooOol00goo00AW>F<H@Q00005S600000AS67ooHaQW
>DIoo`03001oogoo05]oo`03IcUoof<H009S6003Ool00000009oo`8000Eo
o`8001ioo`8000=oo`H0009oo`@000Ioo`<000Moo`8000=oo`@000=oo`@0
00Aoo`8000=oo`8000=oo`<002Ioo`8000=oo`H000Aoo`<000Aoo`@000Ao
o`@000=oo`H00004OomS648@001MOol00bPOOomoo`1ZOol2HaP1@Q010001
HaP00004IcUoof<HHaRTOol00f<HOomS6002HaP00goo00000002Ool20005
Ool2000NOol20003Ool20009Ool20005Ool30007Ool20002Ool20002Ool2
0005Ool20003Ool200000goo001oo`020003Ool3000VOol20003Ool20008
Ool30003Ool20002Ool20002Ool20002Ool20002Ool20005Ool00fLi@Q00
001KOol2:1m]Ool016LiHaQ240000F<H000016<HOomS66LiAWoo00<007oo
Ool0Fgoo00IW>GooHaQS66LiOol20002Ool20005Ool2000NOol20004Ool2
0009Ool2000:Ool700000goo00000002Ool20006Ool20002Ool200000goo
001oo`02000/Ool20004Ool2000=Ool20002Ool20002Ool20002Ool20003
Ool20004Ool00f<H@Q00001IOol2:1m_Ool2HaP1@Q010001IcT00004IcUo
of<HHaQ0Ool00`00Oomoo`1HOol00`00Oomoo`06Ool00f<HOomS6002HaP0
0goo000000040005Ool2000;Ool6000=Ool20005Ool20008Ool2000:Ool2
0002Ool20002Ool2000017oo000000001Woo0P000Woo0P0000=oo`00Ool0
0P00;7oo0P001Goo0P0037oo0P0000Aoo`000000009oo`80009oo`8000Ao
o`8000=oo`03IcU2400005Moo`8X7f]oo`03001oogoo00=oo`04IcUS648@
0001HaP00004HaQoof<HIcU0Ool00`00Oomoo`03Ool00`00Oomoo`1KOol0
0fLiOomS6002HaP00goo00000002Ool20005Ool2000NOol20006Ool20003
Ool5000<Ool200000goo00000003Ool40003Ool50003Ool200000goo001o
o`02000QOol60005Ool20006Ool2000<Ool40003Ool20002Ool20005Ool2
0002Ool00f<H@Q00001EOol2:1m]Ool00`00Oomoo`03Ool2HaP1@Q010001
HaP00004IcUoof<HHaQ0Ool00`00Oomoo`1QOol00f<HOomS6002HaP00goo
00000002Ool20005Ool2000;Ool6000=Ool20007Ool20002Ool2000?Ool2
00000goo00000002Ool300000goo00000002Ool20006Ool200000goo001o
o`02000/Ool20007Ool2000:Ool300000goo00000002Ool50007Ool20000
17ooIcU24000Dgoo0RPOKgoo00<007ooOol00goo00AW>F<H@Q00005S6000
00AS67ooHaQW>D1oo`03001oogoo00=oo`03001oogoo05]oo`06IcUoof<H
IcUS67oo0P000Woo0P000Woo1@006goo1@000goo0P000Woo0P000Woo0P00
3goo0P0000=oo`0000000Woo0P000Woo0P000Woo0P001Woo1P00:Woo1@00
0goo0P000Woo0P002Woo0P000Woo0P000goo0P001Goo0P000Woo0P0000Ao
of<H@Q00055oo`8X7g5oo`03001oogoo00=oo`9S60524040005S600000AW
>GooHaQS641oo`03001oogoo05Qoo`03001oogoo00Ioo`03HaQoof<H009S
609oo`@000Eoo`<001eoo`<000=oo`80009oo`80009oo`8000moo`8000Eo
o`80009oo`80009oo`8003Qoo`<000=oo`80009oo`8000Yoo`80009oo`80
00Aoo`8000Aoo`80009oo`800004OomW>D8@001?Ool2:1mcOol00`00Oomo
o`03Ool016LiHaQ240000F<H000016<HOomS66LiAWoo00<007ooOol0Fgoo
00EW>GooHaQS66Li00=oo`8000Moo`8001ioo`8000Aoo`@000=oo`H000]o
o`8000Ioo`@000=oo`H003Eoo`8000Aoo`@000aoo`@000Eoo`<000Aoo`@0
009oo`03HaQ2400004eoo`8X7g]oo`9S60524040005S600000AW>GooHaQS
6:Aoo`03HaQoof<H009S6<1oo`03IcU2400004]oo`8X7geoo`04IcUS648@
0001HaP00004HaQoof<HIcU6Ool00`00Oomoo`1KOol00fLiOomS6002HaS0
Ool00f<H@Q000019Ool2:1moOol2HaP1@Q010001HaP00004IcUoof<HHaQ0
Ool00`00Oomoo`1HOol00`00Oomoo`06Ool00f<HOomS6002HaS0Ool00fLi
@Q000018Ool00bPOOomoo`1iOol00`00Oomoo`03Ool016LiHaQ240000F<H
000016<HOomS66Li9Goo0P001Goo100017oo100027oo00<007ooOol00goo
00<007ooOol0Fgoo0<QW>GooHaQS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQ24000AWoo0RPOO7oo00<007ooOol00goo0V<H0D8@0@000F<H0000
16LiOomS66<H9Goo0P0017oo0P000Woo0P000Woo0P000Woo0P001goo00<0
07ooOol0HGoo00=S67ooHaP0`T8@00=S648@0000A7oo0RPOOWoo00<007oo
Ool00goo00AW>F<H@Q00005S600000AS67ooHaQW>BEoo`8000Aoo`<00003
Ool00000009oo`<00003Ool0000000Moo`03001oogoo00=oo`03001oogoo
05]oo`03IcUoof<H0<924003HaQ24000049oo`8X7h1oo`03001oogoo00=o
o`9S60524040005S600000AW>GooHaQS62Eoo`8000Aoo`<00003Ool00000
009oo`<00003Ool0000000Moo`03001oogoo05Qoo`03001oogoo00Ioo`03
HaQoof<H0<924003HaQ24000041oo`8X7h9oo`03001oogoo00=oo`04IcUS
648@0001HaP00004HaQoof<HIcTJOol60005Ool20004Ool20002Ool20002
Ool20002Ool20003Ool50005Ool00`00Oomoo`0EOol00`00Oomoo`0MOol0
0`00Oomoo`0KOol00`00Oomoo`05Ool00f<HOomS6032@Q000f<H@Q00000:
Ool00`00Oomoo`0KOol00`00Oomoo`0COol2:1l8Ool00`00Oomoo`0KOol0
0`00Oomoo`0MOol00`00Oomoo`0KOol00`00Oomoo`0SOol2HaP1@Q010001
01000004IcUoof<HHaPUOol20004Ool2000017oo000000000Woo0P0000Ao
o`00000006]oo`03IcUoof<H0<924003HaQ2400003aoo`8X7haoo`04IcUS
648@000101000004HaQoof<HIcTROol50004Ool2000017oo000000000Woo
0P0000Aoo`00000000eoo`03001oogoo05]oo`03HaQoof<H00=2409S60I2
409S60=240AS609240ES60=240AS60M240ES60=240ES6003@Q1S66<H00=2
40=S60=240AS6092409S67Q24003HaQ2400003Yoo`8X7hioo`9S60524040
0040400000AW>GooHaQS62Aoo`<000Aoo`80009oo`80009oo`80009oo`80
00Moo`03001oogoo05Qoo`03001oogoo00Ioo`03IcUoof<H00=24003HaQW
>D8@00E24006HaQW>D8@@Q1S66Li0T8@0V<H00=246<HIcT00T8@0V<H00=2
46<HIcT00T8@0V<H1D8@00=S66Li@Q000T8@00aW>F<H@Q1S66Li@Q1S66Li
HaQ246<HIcT2@Q000f<HIcU24002HaP00d8@HaQW>@02@Q02HaP00d8@HaQW
>@1h@Q000f<H@Q00000hOol2:1n:Ool00`00Oomoo`03Ool016LiHaQ24000
0@0@000016<HOomS66Li9Goo0P001Goo100017oo100027oo00<007ooOol0
0goo00<007ooOol0Fgoo00=S67ooHaP00d8@0V<H1T8@0V<H0T8@0V<H0T8@
00=S66Li@Q000V<H0T8@00=S66Li@Q000V<H2D8@0V<H1T8@0V<H0T8@0V<H
00=246<HHaP0148@00AS66Li@Q12409S60924003HaQW>D8@009S67Q24003
HaQ2400003Ioo`8X7haoo`03001oogoo00=oo`9S605240400040400000AW
>GooHaQS641oo`03001oogoo065oo`03IcUoof<H00=24003IcUS648@00E2
4006HaQW>D8@@Q1S66Li0T8@00EW>F<H@Q1W>F<H0092409S6007@Q1W>F<H
HaQW>F<HIcT01D8@00=S66Li@Q001D8@00US66Li@Q1246LiHaQ246LiHaP0
0d8@00=W>F<H@Q000T8@00AW>F<H@Q12409S6003@Q1S66Li07Q24003HaQ2
400003Aoo`8X7hioo`03001oogoo00=oo`04IcUS648@000101000004HaQo
of<HIcU0Ool00`00Oomoo`03Ool00`00Oomoo`1KOol00f<HOomS6003@Q02
HaP016LiHaQS66<H0T8@0V<H0T8@0V<H0T8@00=S66Li@Q000V<H0T8@00=S
66Li@Q000V<H0T8@0V<H1D8@0V<H1T8@0V<H0T8@0V<H00=246<HHaP00T8@
0V<H00A246LiHaQ2409S60924003HaQW>D8@009S67Q24003HaQ2400003=o
o`03:1moogoo08ioo`03001oogoo00=oo`9S605240400040400000AW>Goo
HaQS641oo`03001oogoo05Qoo`03001oogoo00Ioo`03IcUoof<H00=2409S
60=24006IcUS648@IcUS66Li0T8@00AW>F<HIcUS60924005HaQW>F<HIcUS
6003@Q0016LiHaQS66Li1T8@00=W>F<H@Q001D8@00YW>F<H@Q1246LiHaQ2
46LiHaQW>@924003IcUS66<H00=24004IcUS66<HIcT2@Q000fLiHaQS601g
@Q000f<H@Q00000aOol2:1nAOol00`00Oomoo`03Ool016LiHaQ240000@0@
000016<HOomS66LiAWoo00<007ooOol0Fgoo00=S67ooHaP00d8@00=S66Li
@Q000T8@0V<H348@0V<H448@00=S66Li@Q00Ud8@00=S648@0000;goo0RPO
VGoo0V<H0D8@0@000@0@000016LiOomS66<HY7oo00=W>GooHaP00d8@0V<H
0d8@00=S66Li@Q002d8@00=W>F<H@Q003d8@0V<H0d8@00=S66Li@Q00TT8@
00=S648@0000;Woo00<X7gooOol0VGoo00AW>F<H@Q000040400000AS67oo
HaQW>DIoo`03001oogoo05]oo`03HaQoof<H00=24006HaQW>F<HHaQW>F<H
3D8@00=S66Li@Q00448@00EW>F<HHaQW>F<H09A24003HaQ2400002aoo`8X
7iaoo`9S605240400040400000AW>GooHaQS641oo`03001oogoo05Qoo`03
001oogoo00Ioo`03IcUoof<H0<924003HaQ2400002Yoo`8X7iQoo`03001o
ogoo00=oo`04IcUS648@000101000004HaQoof<HIcU0Ool00`00Oomoo`03
Ool00`00Oomoo`1KOol00f<HOomS6032@Q000f<H@Q00000YOol00bPOOomo
o`2HOol00`00Oomoo`03Ool2HaP1@Q01000101000004IcUoof<HHaQ0Ool0
0`00Oomoo`1QOol00fLiOomS6032@Q000f<H@Q00000WOol2:1nKOol00`00
Oomoo`03Ool016LiHaQ240000@0@000016<HOomS66Li@7oo00<007ooOol0
0goo00<007ooOol0Fgoo00=S67ooHaP0`T8@00=S648@00009Goo0RPOWGoo
00<007ooOol00goo0V<H0D8@0@000@0@000016LiOomS66<H@7oo00<007oo
Ool0F7oo00<007ooOol01Woo00=W>GooHaP00V<H01=W>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@02HaP026LiHaQS66LiHaQW>F<H
IcT2HaP06fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@02HaP02VLiHaQS66LiHaQW>F<HIcUS66Li0V<H
00=W>F<HHaP0M6<H00AW>F<H@Q0002Aoo`03:1moogoo09eoo`03001oogoo
00=oo`04IcUS648@000101000004HaQoof<HIcU6Ool00`00Oomoo`1KOol0
0f<HOomoo`33Ool00d8@001oo`0QOol2:1nVOol2HaP1@Q01000101000004
IcUoof<HHaRTOol00fLiHaQS6034HaP00`00Oomoo`0NOol2:1lVOol00`00
Oomoo`1oOol016LiHaQ240000@0@000016<HOomS66LiAWoo00<007ooOol0
ogoo@goo00<X7gooOol0Z7oo0V<H0D8@0@000F<H000016LiOomS66<H@7oo
00<007ooOol0F7oo00<007ooOol0jgoo0RPOYGoo00<007ooOol00goo00AW
>F<H@Q00005S600000AS67ooHaQW>D1oo`03001oogoo00=oo`03001oogoo
0?moocmoo`8X7jMoo`03001oogoo00=oo`9S60524040005oo`0000AW>Goo
HaQS641oo`03001oogoo0?mood=oo`8X7jUoo`03001oogoo00=oo`04IcUS
648@0001HaP00004HaQoof<HIcU0Ool00`00Oomoo`03Ool00`00Oomoo`3o
OolkOol2:1n[Ool00`00Oomoo`03Ool2HaP1@Q010001Mkd00004IcUoof<H
HaQ0Ool00`00Oomoo`1HOol00`00Oomoo`3SOol2:1n]Ool00`00Oomoo`03
Ool016LiHaQ240000G>L000016<HOomS66LiAWoo00<007ooOol0ogoo=goo
0RPO]Goo0V<H0D8@0@000G>L000016LiOomS66<HogooOWoo0RPO]goo00AW
>F<H@Q00005cW00000AS67ooHaQW>DIoo`03001oogoo0?mooc=oo`8X7kUo
o`9S60524040005g_@0000AW>GooHaQS641oo`03001oogoo05Qoo`03001o
ogoo0=]oo`8X7kEoo`03001oogoo00=oo`04IcUS648@0001Li`00004HaQo
of<HIcU0Ool00`00Oomoo`03Ool00`00Oomoo`3oOol_Ool2:1ngOol00`00
Oomoo`03Ool2HaP1@Q010001Li`00004IcUoof<HHaQ0Ool00`00Oomoo`3o
OoldOol00bPOOomoo`2gOol00`00Oomoo`03Ool016LiHaQ240000G>L0000
16<HOomS66Li@7oo00<007ooOol00goo00<007ooOol0ogoo;7oo0RPO^Woo
00<007ooOol00goo0V<H0D8@0@000GNm000016LiOomS66<H@7oo00<007oo
Ool0F7oo00<007ooOol0e7oo0RPO_7oo00<007ooOol00goo00AW>F<H@Q00
005cW00000AS67ooHaQW>DIoo`03001oogoo0?moobQoo`8X7lAoo`9S6052
4040005cW00000AW>GooHaQS6?moofmoo`8X7lIoo`04IcUS648@0001Li`0
0004HaQoof<HIcU6Ool00`00Oomoo`1cOol00`00Oomoo`1iOol00`00Oomo
o`0aOol2:1m6Ool00`00Oomoo`1oOol2HaP1@Q010001Mkd00004IcUoof<H
HaQ0Ool00`00Oomoo`1HOol00`00Oomoo`3<Ool2:1o4Ool00`00Oomoo`03
Ool016LiHaQ240000G>L000016<HOomS66Li@7oo00<007ooOol00goo00<0
07ooOol0ogoo87oo0RPOaWoo00<007ooOol00goo0V<H0D8@0@000G>L0000
16LiOomS66<H@7oo00<007ooOol0ogoo97oo0RPOb7oo00<007ooOol00goo
00AW>F<H@Q00005cW00000AS67ooHaQW>D1oo`03001oogoo00=oo`03001o
ogoo0?mooaaoo`8X7lYoo`03001oogoo00=oo`9S60524040005g_@0000AW
>GooHaQS641oo`03001oogoo05Qoo`03001oogoo0<Aoo`8X7laoo`03001o
ogoo00=oo`04IcUS648@0001Li`00004HaQoof<HIcU6Ool00`00Oomoo`3o
OolIOol00bPOOomoo`3BOol2HaP1@Q010001Li`00004IcUoof<HHaSoOomP
Ool2:1oEOol016LiHaQ240000G>L000016<HOomS66LiAWoo00<007ooOol0
ogoo5Goo0RPOegoo0V<H0D8@0@000GNm000016LiOomS66<H@7oo00<007oo
Ool0F7oo00<007ooOol0_Woo00<X7gooOol0dGoo00<007ooOol00goo00AW
>F<H@Q00005cW00000AS67ooHaQW>D1oo`03001oogoo00=oo`03001oogoo
0?mooa9oo`8X7mAoo`03001oogoo00=oo`9S60524040005cW00000AW>Goo
HaQS641oo`03001oogoo0?mooaIoo`8X7mIoo`03001oogoo00=oo`04IcUS
648@0001Li`00004HaQoof<HIcU0Ool00`00Oomoo`03Ool00`00Oomoo`3o
Ool?Ool00bPOOomoo`3FOol00`00Oomoo`03Ool2HaP1@Q010001Mkd00004
IcUoof<HHaQ0Ool00`00Oomoo`1HOol00`00Oomoo`2gOol2:1oIOol00`00
Oomoo`03Ool016LiHaQ240000G>L000016<HOomS66LiAWoo00<007ooOol0
ogoo2goo0RPOhGoo0V<H0D8@0@000G>L000016LiOomS66<HogooDgoo00<X
7gooOol0hGoo00AW>F<H@Q00005cW00000AS67ooHaQW>DIoo`03001oogoo
0?moo`Qoo`8X7nAoo`9S60524040005g_@0000AW>GooHaQS641oo`03001o
ogoo05Qoo`03001oogoo01ioo`03001oogoo07Uoo`03001oogoo01=oo`8X
7fAoo`03001oogoo07Uoo`03001oogoo00=oo`04IcUS648@0001Li`00004
HaQoof<HIcU0Ool00`00Oomoo`03Ool00`00Oomoo`3oOol5Ool00bPOOomo
o`3POol00`00Oomoo`03Ool2HaP1@Q010001Li`00004IcUoof<HHaQ0Ool0
0`00Oomoo`3oOol9Ool2:1oSOol00`00Oomoo`03Ool016LiHaQ240000G>L
000016<HOomS66Li@7oo00<007ooOol00goo00<007ooOol0ogoo0Goo0RPO
iGoo00<007ooOol00goo0V<H0D8@0@000GNm000016LiOomS66<H@7oo00<0
07ooOol0F7oo00<007ooOol0ZGoo0RPOigoo00<007ooOol00goo00AW>F<H
@Q00005cW00000AS67ooHaQW>DIoo`03001oogoo0?aoo`8X7nmoo`9S6052
4040005cW00000AW>GooHaQS6?moodAoo`8X7o5oo`04IcUS648@0001Li`0
0004HaQoof<HIcU6Ool00`00Oomoo`3hOol2:1ocOol2HaP1@Q010001Mkd0
0004IcUoof<HHaQ0Ool00`00Oomoo`1HOol00`00Oomoo`2QOol2:1o_Ool0
0`00Oomoo`03Ool016LiHaQ240000G>L000016<HOomS66Li@7oo00<007oo
Ool00goo00<007ooOol0m7oo0RPOlGoo00<007ooOol00goo0V<H0D8@0@00
0G>L000016LiOomS66<H@7oo00<007ooOol0n7oo0RPOlgoo00<007ooOol0
0goo00AW>F<H@Q00005cW00000AS67ooHaQW>D1oo`03001oogoo00=oo`03
001oogoo0?1oo`8X7oEoo`03001oogoo00=oo`9S60524040005g_@0000AW
>GooHaQS641oo`03001oogoo05Qoo`03001oogoo09Yoo`03:1moogoo0?Eo
o`03001oogoo00=oo`04IcUS648@0001Li`00004HaQoof<HIcU6Ool00`00
Oomoo`3]Ool2:1onOol2HaP1@Q010001Li`00004IcUoof<HHaSoOoleOol2
:1ooOol1Ool016LiHaQ240000G>L000016<HOomS66LiAWoo00<007ooOol0
jGoo0RPOogoo0goo0V<H0D8@0@000GNm000016LiOomS66<H@7oo00<007oo
Ool0F7oo00<007ooOol0TWoo0RPOoWoo00<007ooOol00goo00AW>F<H@Q00
005cW00000AS67ooHaQW>D1oo`03001oogoo00=oo`03001oogoo07=oo`03
001oogoo06moo`8X7`Qoo`03001oogoo07Uoo`03001oogoo07Uoo`03001o
ogoo00=oo`9S60524040005cW00000AW>GooHaQS641oo`03001oogoo0>Uo
o`8X7omoo`=oo`03001oogoo00=oo`04IcUS648@0001Li`00004HaQoof<H
IcU0Ool00`00Oomoo`03Ool00`00Oomoo`3QOol2:1ooOol5Ool00`00Oomo
o`03Ool2HaP1@Q010001Mkd00004IcUoof<HHaQ0Ool00`00Oomoo`1HOol0
0`00Oomoo`2:Ool2:1ooOol7Ool00`00Oomoo`03Ool016LiHaQ240000G>L
000016<HOomS66LiAWoo00<007ooOol0gGoo0RPOogoo3goo0V<H0D8@0@00
0G>L000016LiOomS66<Hogoo9Goo0RPOogoo4Goo00AW>F<H@Q00005cW000
00AS67ooHaQW>DIoo`03001oogoo0=Yoo`03:1moogoo0?mooa5oo`9S6052
4040005g_@0000AW>GooHaQS641oo`03001oogoo05Qoo`03001oogoo08=o
o`8X7omoo`ioo`03001oogoo00=oo`04IcUS648@0001Li`00004HaQoof<H
IcU0Ool00`00Oomoo`03Ool00`00Oomoo`3FOol2:1ooOol@Ool00`00Oomo
o`03Ool2HaP1@Q010001Li`00004IcUoof<HHaQ0Ool00`00Oomoo`3KOol0
0bPOOomoo`3oOol@Ool00`00Oomoo`03Ool016LiHaQ240000G>L000016<H
OomS66Li@7oo00<007ooOol00goo00<007ooOol0dgoo0RPOogoo4goo00<0
07ooOol00goo0V<H0D8@0@000GNm000016LiOomS66<H@7oo00<007ooOol0
F7oo00<007ooOol0O7oo0RPOogoo5Goo00<007ooOol00goo00AW>F<H@Q00
005cW00000AS67ooHaQW>DIoo`03001oogoo0=1oo`03:1moogoo0?mooa]o
o`9S60524040005cW00000AW>GooHaQS62Yoo`@000Ioo`@00=moo`8X7omo
oaioo`04IcUS648@0001Li`00004HaQoof<HIcT]Ool20004Ool20002Ool2
000=Ool00`00Oomoo`3<Ool2:1ooOolPOol2HaP1@Q010001Mkd00004IcUo
of<HHaP^Ool20003Ool300000goo00000007Ool00`00Oomoo`1HOol00`00
Oomoo`1fOol00bPOOomoo`3oOolJOol00`00Oomoo`03Ool016LiHaQ24000
0G>L000016<HOomS66Li;Woo0P000goo0`0000=oo`0000001goo00<007oo
Ool00goo00<007ooOol0bGoo0RPOogoo7Goo00<007ooOol00goo0V<H0D8@
0@000G>L000016LiOomS66<H8Woo1P000Woo1@0017oo0P000Woo0P000goo
1@007Goo00<007ooOol07Goo00<007ooOol06goo00<007ooOol07Goo00<0
07ooOol06goo00<007ooOol07Goo00<007ooOol04goo0RPO1Woo00<007oo
Ool07Goo00<007ooOol06goo00<007ooOol07Goo00<007ooOol06goo00<0
07ooOol07Goo00<007ooOol06goo00<007ooOol07Goo00<007ooOol06goo
00<007ooOol07Goo00<007ooOol00goo00AW>F<H@Q00005cW00000AS67oo
HaQW>BYoo`8000Moo`800004Ool000000007Ool00`00Oomoo`03Ool00`00
Oomoo`36Ool00bPOOomoo`3oOolOOol00`00Oomoo`03Ool2HaP1@Q010001
Mkd00004IcUoof<HHaPZOol20007Ool2000017oo000000001goo00<007oo
Ool0F7oo00<007ooOol0Kgoo0RPOogoo8Woo00<007ooOol00goo00AW>F<H
@Q00005cW00000AS67ooHaQW>BYoo`8000Moo`80009oo`8000eoo`03001o
ogoo0<9oo`8X7omoobYoo`9S60524040005cW00000AW>GooHaQS62Yoo`H0
00Aoo`@00=5oo`8X7omoobaoo`04IcUS648@0001Li`00004HaQoof<HIcU6
Ool00`00Oomoo`2nOol2:1ooOol^Ool2HaP1@Q010001Mkd00004IcUoof<H
HaQ0Ool00`00Oomoo`1HOol00`00Oomoo`1WOol2:1ooOolZOol00`00Oomo
o`03Ool016LiHaQ240000G>L000016<HOomS66Li@7oo00<007ooOol00goo
00<007ooOol0^Woo0RPOogoo;7oo00<007ooOol00goo0V<H0D8@0@000G>L
000016LiOomS66<H@7oo00<007ooOol0_Woo0RPOogoo;Woo00<007ooOol0
0goo00AW>F<H@Q00005cW00000AS67ooHaQW>D1oo`03001oogoo00=oo`03
001oogoo0;Ioo`8X7omooc1oo`03001oogoo00=oo`9S60524040005g_@00
00AW>GooHaQS641oo`03001oogoo05Qoo`03001oogoo05moo`8X7omooc9o
o`03001oogoo00=oo`04IcUS648@0001Li`00004HaQoof<HIcU6Ool00`00
Oomoo`2bOol2:1ooOoljOol2HaP1@Q010001Li`00004IcUoof<HHaSjOol0
0bPOOomoo`3oOoljOol016LiHaQ240000G>L000016<HOomS66LiAWoo00<0
07ooOol0[goo0RPOogoo?Goo0V<H0D8@0@000GNm000016LiOomS66<H@7oo
00<007ooOol0F7oo00<007ooOol0F7oo0RPOogoo>Goo00<007ooOol00goo
00AW>F<H@Q00005cW00000AS67ooHaQW>D1oo`03001oogoo00=oo`03001o
ogoo0:]oo`8X7omooc]oo`03001oogoo00=oo`9S60524040005cW00000AW
>GooHaQS641oo`03001oogoo0:moo`8X7omooceoo`03001oogoo00=oo`04
IcUS648@0001Li`00004HaQoof<HIcU0Ool00`00Oomoo`03Ool00`00Oomo
o`1cOol00`00Oomoo`0aOol2:1m6Ool00`00Oomoo`1iOol00`00Oomoo`1i
Ool00`00Oomoo`03Ool2HaP1@Q010001Mkd00004IcUoof<HHaQ0Ool00`00
Oomoo`1HOol00`00Oomoo`1@Ool2:1ooOom1Ool00`00Oomoo`03Ool016Li
HaQ240000G>L000016<HOomS66LiAWoo00<007ooOol0Xgoo0RPOogooBGoo
0V<H0D8@0@000G>L000016LiOomS66<HjWoo0RPOogooBgoo00AW>F<H@Q00
005cW00000AS67ooHaQW>DIoo`03001oogoo09moo`8X7omoodeoo`9S6052
4040005g_@0000AW>GooHaQS641oo`03001oogoo05Qoo`03001oogoo04Qo
o`8X7omoodUoo`03001oogoo00=oo`04IcUS648@0001Li`00004HaQoof<H
IcU0Ool00`00Oomoo`03Ool00`00Oomoo`2LOol00bPOOomoo`3oOom9Ool0
0`00Oomoo`03Ool2HaP1@Q010001Li`00004IcUoof<HHaQ0Ool00`00Oomo
o`2POol2:1ooOom<Ool00`00Oomoo`03Ool016LiHaQ240000G>L000016<H
OomS66Li@7oo00<007ooOol00goo00<007ooOol0V7oo0RPOogooCWoo00<0
07ooOol00goo0V<H0D8@0@000GNm000016LiOomS66<H@7oo00<007ooOol0
F7oo00<007ooOol0@Goo0RPOogooD7oo00<007ooOol00goo00AW>F<H@Q00
005cW00000AS67ooHaQW>DIoo`03001oogoo09Aoo`8X7omooeQoo`9S6052
4040005cW00000AW>GooHaQS6=aoo`03:1moogoo0?mooeQoo`04IcUS648@
0001Li`00004HaQoof<HIcU6Ool00`00Oomoo`2AOol2:1ooOomKOol2HaP1
@Q010001Mkd00004IcUoof<HHaQ0Ool00`00Oomoo`1HOol00`00Oomoo`0j
Ool2:1ooOomGOol00`00Oomoo`03Ool016LiHaQ240000G>L000016<HOomS
66Li@7oo00<007ooOol00goo00<007ooOol0SGoo0RPOogooFGoo00<007oo
Ool00goo0V<H0D8@0@000G>L000016LiOomS66<H@7oo00<007ooOol0TGoo
0RPOogooFgoo00<007ooOol00goo00AW>F<H@Q00005cW00000AS67ooHaQW
>D1oo`03001oogoo00=oo`03001oogoo08Uoo`8X7omooeeoo`03001oogoo
00=oo`9S60524040005g_@0000AW>GooHaQS641oo`03001oogoo05Qoo`03
001oogoo01ioo`03001oogoo019oo`03:1moogoo06Aoo`03001oogoo07Uo
o`03001oogoo07Uoo`03001oogoo00=oo`04IcUS648@0001Li`00004HaQo
of<HIcU6Ool00`00Oomoo`26Ool2:1ooOomVOol2HaP1@Q010001Li`00004
IcUoof<HHaS=Ool2:1ooOomXOol016LiHaQ240000G>L000016<HOomS66Li
AWoo00<007ooOol0PWoo0RPOogooJWoo0V<H0D8@0@000GNm000016LiOomS
66<H@7oo00<007ooOol0F7oo00<007ooOol0:goo0RPOogooIWoo00<007oo
Ool00goo00AW>F<H@Q00005cW00000AS67ooHaQW>D1oo`03001oogoo00=o
o`03001oogoo07ioo`8X7omoofQoo`03001oogoo00=oo`9S60524040005c
W00000AW>GooHaQS641oo`03001oogoo089oo`8X7omoofYoo`03001oogoo
00=oo`04IcUS648@0001Li`00004HaQoof<HIcU0Ool00`00Oomoo`03Ool0
0`00Oomoo`1jOol2:1ooOom/Ool00`00Oomoo`03Ool2HaP1@Q010001Mkd0
0004IcUoof<HHaQ0Ool00`00Oomoo`1HOol00`00Oomoo`0SOol2:1ooOom^
Ool00`00Oomoo`03Ool016LiHaQ240000G>L000016<HOomS66LiAWoo00<0
07ooOol0MWoo0RPOogooMWoo0V<H0D8@0@000G>L000016LiOomS66<H_Goo
0RPOogooN7oo00AW>F<H@Q00005cW00000AS67ooHaQW>DIoo`03001oogoo
079oo`8X7omoogYoo`9S60524040005g_@0000AW>GooHaQS641oo`03001o
ogoo05Qoo`03001oogoo01]oo`8X7omoogIoo`03001oogoo00=oo`04IcUS
648@0001Li`00004HaQoof<HIcU0Ool00`00Oomoo`03Ool00`00Oomoo`1^
Ool2:1ooOomhOol00`00Oomoo`03Ool2HaP1@Q010001Li`00004IcUoof<H
HaQ0Ool00`00Oomoo`1bOol2:1ooOomjOol00`00Oomoo`03Ool016LiHaQ2
40000G>L000016<HOomS66Li@7oo00<007ooOol00goo00<007ooOol0JWoo
0RPOogooO7oo00<007ooOol00goo0V<H0D8@0@000GNm000016LiOomS66<H
@7oo00<007ooOol0F7oo00<007ooOol04goo0RPOogooOWoo00<007ooOol0
0goo00AW>F<H@Q00005cW00000AS67ooHaQW>DIoo`03001oogoo06Ioo`8X
7`]oo`03001oogoo07Uoo`03001oogoo07Uoo`03001oogoo07moo`9S6052
4040005cW00000AW>GooHaQS6:eoo`8X7omoohQoo`04IcUS648@0001Li`0
0004HaQoof<HIcU6Ool00`00Oomoo`1ROol2:1ooOon:Ool2HaP1@Q010001
Mkd00004IcUoof<HHaQ0Ool00`00Oomoo`1HOol00`00Oomoo`0;Ool2:1oo
Oon6Ool00`00Oomoo`03Ool016LiHaQ240000G>L000016<HOomS66Li@7oo
00<007ooOol00goo00<007ooOol0GGoo0bPOogooR7oo00<007ooOol00goo
0V<H0D8@0@000G>L000016LiOomS66<H@7oo00<007ooOol0Ggoo12POogoo
Rgoo00<007ooOol00goo00AW>F<H@Q00005cW00000AS67ooHaQW>D1oo`03
001oogoo00=oo`03001oogoo05Eoo`@X7omoohmoo`03001oogoo00=oo`9S
60524040005g_@0000AW>GooHaQS641oo`04001oogoo0003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00<007ooOol012PO00=oo`00Ool00Woo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol00003
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogooOol0
0003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`05
001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000=oo`04001oogooOol20005Ool016LiHaQ240000G>L
000016<HOomS66LiAWoo00<007ooOol0CGoo12POogooWGoo0V<H0D8@0@00
0G>L000016LiOomS66<HSWoo22POogooXGoo00AW>F<H@Q00005cW00000AS
67ooHaQW>DIoo`03001oogoo03]oo`XX7omoojUoo`9S60524040005g_@00
00AW>GooHaQS641oo`03001oogoo035ooa0X7aMoo`03001oogoo0?mooi=o
o`03001oogoo00=oo`04IcUS648@0001Li`00004HaQoof<HIcU0Ool01EOP
:1mGh2POEn000bPO0?mGh2POEn0X7eOP:1mGh2POEn0X7eOP:1mGh2POEn0X
7eOP:1mGh2POEn0X7eOP:1mGh2POEn0X7eOP:1mGh2POEn0X7eOP:1mGh2PO
En0X7eOP:1mGh2PO001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool0
07oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00
Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001o
o`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo
001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool0
07oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00
Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001o
o`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo
001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool0
07oo001oo`00Ool007oo001oo`00Ool007oo00000>QGh2POEn0X7eOP:1mG
h2POEn0X7eOP:1mGh2POEn0X7eOP:1mGh2POEn0X7eOP:1mGh2POEn0X7eOP
:1mGh2POEn0X7eOP:1mGh2POEn0X7eOP:1mGh2PO001oo`00Ool007oo001o
o`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo
001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool0
07oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00
Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001o
o`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo
001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool0
07oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00
Ool007oo001oo`00Ool007oo001oo`00Ool007oo001oo`00Ool007oo001o
o`Moo`9S60524040005cW00000AW>GooHaQS641oo`03001oogoo0?moonio
o`03001oogoo00=oo`04IcUS648@0001Li`00004HaQoof<HIcU0Ool00`00
Oomoo`03Ool00`00Oomoo`3oOooXOol00`00Oomoo`03Ool2HaP1@Q010001
Mkd00004IcUoof<HHaQ0Ool00`00Oomoo`1HOol00`00Oomoo`3oOonCOol0
0`00Oomoo`03Ool016LiHaQ240000G>L000016<HOomS66LiAWoo00<007oo
Ool0ogookWoo0V<H0D8@0@000G>L000016LiOomS66<H_7oo00<007ooOol0
NGoo00<007ooOol0NGoo00<007ooOol0Ogoo00AW>F<H@Q00005cW00000AS
67ooHaQW>DIoo`03001oogoo0?moonioo`9S60524040005g_@0000AW>Goo
HaQS641oo`03001oogoo05Qoo`03001oogoo0?mooi=oo`03001oogoo00=o
o`04IcUS648@0001Li`00004HaQoof<HIcU0Ool00`00Oomoo`03Ool00`00
Oomoo`3oOooXOol00`00Oomoo`03Ool2HaP1@Q010001Li`00004IcUoof<H
HaQ0Ool00`00Oomoo`3oOoo^Ool00`00Oomoo`03Ool016LiHaQ240000G>L
000016<HOomS66Li@7oo00<007ooOol00goo00<007ooOol0ogooj7oo00<0
07ooOol00goo0V<H0D8@0@000GNm000016LiOomS66<H@7oo00<007ooOol0
F7oo00<007ooOol0ogooTgoo00<007ooOol00goo00AW>F<H@Q00005cW000
00AS67ooHaQW>DIoo`03001oogoo0?moonioo`9S60524040005cW00000AW
>GooHaQS6?mooomoocQoo`04IcUS648@0001Li`00004HaQoof<HIcU6Ool0
0`00Oomoo`3oOoo^Ool2HaP1@Q010001Mkd00004IcUoof<HHaQ0Ool00`00
Oomoo`1HOol00`00Oomoo`3oOonCOol00`00Oomoo`03Ool016LiHaQ24000
0G>L000016<HOomS66Li@7oo00<007ooOol00goo00<007ooOol0ogooj7oo
00<007ooOol00goo0V<H0D8@0@000G>L000016LiOomS66<H@7oo00<007oo
Ool0ogookWoo00<007ooOol00goo00AW>F<H@Q00005cW00000AS67ooHaQW
>CAoo`@000Qoo`03001oogoo00=oo`03001oogoo0?moonQoo`03001oogoo
00=oo`9S60524040005g_@0000AW>GooHaQS63=oo`80009oo`8000Moo`03
001oogoo05Qoo`03001oogoo0?mooi=oo`03001oogoo00=oo`04IcUS648@
0001Li`00004HaQoof<HIcTcOol300000goo00000007Ool00`00Oomoo`03
Ool00`00Oomoo`3oOooXOol00`00Oomoo`03Ool2HaP1@Q010001Li`00004
IcUoof<HHaPcOol300000goo00000007Ool00`00Oomoo`3oOoo^Ool00`00
Oomoo`03Ool016LiHaQ240000G>L000016<HOomS66Li<goo0P000Woo0P00
0goo2@0000=oo`00Ool01@000goo1@000goo1@000goo1@000goo1@000goo
1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo1@00
0goo1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo
1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo1@00
0goo1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo
1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo1@00
0goo1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo
1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo1@000goo1@00
0goo1@000goo1@000goo1@000goo00<007ooOol00goo0V<H0D8@0@000GNm
000016LiOomS66<H<goo0P0000Aoo`0000000?moooioo`04IcUS648@0001
Li`00004HaQoof<HIcTcOol2000017oo00000000ogoooWoo0V<H0D8@0@00
0G>L000016LiOomS66<H<goo0P000Woo0P00ogoooWoo00AW>F<H@Q00005c
W00000AS67ooHaQW>CAoo`@00?mooomoo`9S60524040005g_@0000AW>Goo
HaQS6?mooomoocQoo`04IcUS648@0001Li`00004HaQoof<HIcWoOoooOolh
Ool2HaP1@Q010001Li`00004IcUoof<HHaSoOoooOolhOol016LiHaQ24000
0G>L000016<HOomS66Liogooogoo>7oo0V<H0D8@0@000GNm000016LiOomS
66<Hogooogoo>7oo00AW>F<H@Q00005cW00000AS67ooHaQW>OmooomoocQo
o`9S60524040005cW00000AW>GooHaQS6?mooomoocQoo`04IcUS648@0001
Li`00004HaQoof<HIcWoOoooOolhOol2HaP1@Q010001Mkd00004IcUoof<H
HaSo003o000h0002HaP1@Q010001Li`00003HaQoof<H0?mS6?mS63]S6052
4040005cW00000=W>GooHaP00f<H00EW>F<HHaQS66Li01h00003HaP00000
01`00003HaP0000001`00009HaQW>F<HIcUS66LiHaQW>F<H01h00003HaP0
000001`00003HaP0000001`00004HaQW>F<HIcT4HaP00fLi0000000L0000
0f<H0000000L00000f<H0000000L00000f<H0000000L000016<HIcUS66Li
16<H00=W>@000000700000=S60000000700000=S60000000700000US66Li
HaQW>F<HIcUS66LiHaP07P0000=S60000000700000=S60000000700000AS
66LiHaQW>@AS6003IcT0000001D0009S60524040005cW00000=S67ooHaP0
1f<H00<0048@@Q00748@00<0048@@Q00748@00<0048@@Q00748@00<006<H
HaP01F<H00<0048@@Q00748@00<0048@@Q00748@00<0048@@Q00748@00<0
06<HHaP01F<H00<0048@@Q00748@00<0048@@Q00748@00<0048@@Q00748@
00<0048@@Q00748@00<006<HHaP01F<H00<0048@@Q00748@00<0048@@Q00
748@00<0048@@Q00748@00<006<HHaP01F<H00<0048@@Q00748@00<0048@
@Q00748@00<0048@@Q00748@00<006<HHaP01F<H00<0048@@Q005D8@0V<H
0D8@0@000GNm00001FLiOomS66<HIcT00f<H00AW>F<H001ooae24003001o
od8@01a24003001ood8@01a24003001S66<H00ES6003001ood8@01a24003
001ood8@01a24003001ood8@01a24003001S66<H00=S6004IcUS6000OolM
@Q000`00Oom2400L@Q000`00Oom2400L@Q000`00Oom2400L@Q000`00HaQS
6003HaP016LiHaP007oo7D8@00<007oo@Q00748@00<007oo@Q00748@00<0
06<HHaP01F<H00<007oo@Q00748@00<007oo@Q00748@00<007oo@Q00748@
00<006<HHaP00f<H00AW>F<H001ooaI2409S60524040005cW00000=S67oo
IcT00f<H00IW>F<HHaQS6000OolKHaP2@Q000`00OomS600A0009HaP2@Q00
0`00OomS600JHaP2@Q000`00HaQS6002HaP01FLiHaQS6000Ool026<H00AW
>GooOomoo`mS60924003001oof<H01YS60924003001oof<H00US6003IcUo
ogoo00aoo`9S60924005001S66<HHaQW>@03HaP00`00OomS600JHaP2@Q00
0`00OomS600JHaP2@Q000`00OomS600JHaP2@Q000`00OomS600JHaP2@Q00
1@00HaQS66<HIcT00f<H00<007ooIcT067oo0V<H0T8@00<007ooHaP06V<H
0T8@00<007ooIcT067oo0V<H0T8@00<006<HHaP00V<H00IW>F<HHaP007oo
HaPH0002HaP2@Q000`00OomS600JHaP2@Q000`00OomS600JHaP2@Q001@00
HaQS66<HIcT00f<H00<007ooIcT00P0O5F<H0D8@0@000G>L00001FLiOomS
66<HIcT01F<H00<007ooIcT06V<H0T8@00<007ooIcT00P003ekP00<006<H
HaP01V<H0T8@00<007ooIcT06V<H0T8@00@006<HHaQW>@AS6003001oofLi
00MS60=24003IcUoof<H00eS60924003001oofLi00YS60ioo`07IcUS648@
@Q0007ooIcT016<H1Goo3T8@00=oofLiHaP00T8@00@006<HHaQW>@AS6003
001oofLi01AS6003G^1S66<H00=S60924003001oofLi01AS6003G^1S66<H
00=S60924003001oofLi01AS6003G^1S66<H00=S60924003001oofLi01AS
6003G^1S66<H00=S60924004001S66<HIcT4HaP01000OomS67oo5P0000=o
ofLiHaP00T8@00<007ooIcT067`00V<H0T8@00@007ooHaQooaH00003OomW
>F<H00924004001S66<HIcT4HaP01000OomW>@005F<H00AW>@00HaQW>@92
4003001oofLi00YS60I240YS60924003001oofLi00mS608000US60924004
001S66<HIcT4HaP01000OomS66<H0P0O26<H0P001V<H00IW>F<HIcUS648@
0001Mkd00003HaQoof<H00AS6005IcUS66<H001oo`03HaP066LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS60924006
001oof<H001oh0003ekP00P006<HIcUS66LiHaQW>F<H0T8@00<007ooHaP0
0V<H00=W>F<H00003P0000MS66LiHaQW>F<HIcUS6002@Q000`00HaQS6002
HaP01FLiHaQS6000Ool00f<H00IW>F<HIcUS648@Ool2HaP01T8@OomS66<H
IcUS60=oo`07HaQW>F<HIcUS66LiHaP00T8@00<007ooHaP00f<H00IW>F<H
IcUS66LiHaP>@Q000gooHaQS6002@Q001P00OomS66<HIcUS60M2400>OomS
66<HIcUS66LiHaQW>F<HIcUS66Li@Q1oo`9S60924003001S66<H009S6005
IcUS66<H001oo`03HaP066LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUNh000G^1W>F<HIcUS60924003001oof<H009S600HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>EkP001Nh6LiHaQW>F<H0T8@00<0
07ooHaP00V<H01QW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
G^0005kPIcUS66LiHaP2@Q000`00OomS6002HaP066LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUNh000G^1W>F<HIcUS60924003001S66<H
009S6008IcUS66<H001oofLiOol000Eoo`05001oogooOol00002Ool01P00
Ool007oo001oo`<00003OomS66<H00924003001oof<H01Ql009S60924005
001oofLiOol0000DOol01000OomS66<H0T8@00<006<HHaP00V<H00aW>F<H
HaP007ooHaP006<HIcT006<HIcT3HaP01FLiHaQS66<HIcT00f<H00AW>F<H
IcT0009S6003001S66<H00924003001oof<H009S6006IcUS66LiHaQW>F<H
200O00Y246<HIcUS66LiHaQW>F<HIcUS60924003001oof<H00=S6004IcUS
66LiHaP2O00016<HIcUS66Li0V<H0P000f<H00IW>F<HIcUS66LiHaP2@Q00
0`00HaQS6002HaP01FLiHaQS6000Ool00f<H0P0O00MS66LiHaQW>F<HIcUS
60020002HaP00fLiHaQW>@02HaP01@0OHaQS648@00000G>L00001fLiOomS
66<HIcUS66Li00=S6003001oof<H014000US60924004001oofLi0002On00
0`00G^1Nh00=G^000`00HaQS6004HaP2@Q000`00OomS6003HaP00`000ol3
o`0;0ol00`000_L00006HaP2@Q001000HaQS66Li16<H00<007ooHaP01V<H
00I247ooHaQS648@Ool3HaP3@Q000f<HOomS6005HaP2@Q001@00OomS66<H
IcT01f<H00=247ooIcT02V<H00A247ooHaQS60924003001oof<H009S60Q2
4003OomW>Goo00Uoo`04@Q1oof<HHaP2@Q001000HaQS66Li16<H00<007oo
HaP016<H00<07f<HHaP02f<H00ENh000G^0005kP00=S60924003001oof<H
019S6005G^0005kP001Nh003HaP2@Q000`00OomS600BHaP01EkP001Nh000
G^000f<H0T8@00<007ooHaP04V<H00ENh000G^0005kP00=S60924004001S
66<HIcT4HaP01@00OomS67oo00001Goo00D007ooOomoo`00009oo`06001o
o`00Ool007oo0`0000=oof<HHaP00T8@00<007ooIcT016<H0W`01V<H0W`0
0f<H0P0000=S67`0O00016<H0T8@00D007ooHaQoo`0001Aoo`04001oof<H
HaP2@Q001000HaQS66Li16<H00P007ooIcT006<H001S60003f<H00@006<H
HaP0009S60924003001oof<H00MS60X07`03@Q1S66<H00IS60924005001o
of<HHaQW>@04HaP4O005HaP20002HaP00fLiHaQS6004HaP2@Q001000HaQS
66Li16<H00<007ooIcT00f<H0P0O1V<H0P001V<H0P0O0V<H0D8@0@000G>L
000016<HOomS66Li1V<H00<007ooHaP00P003ekP00<006<HIcT00V<H00AW
>F<HIcUS60924004001oof<H0003On000`00G^1Nh00=G^001P00HaQW>F<H
IcUS60924006001oof<HIcUS60003P?o00T000;g0_L006<HIcUS66LiHaP0
0T8@00<006<HHaP00V<H00iW>F<HHaP007ooHaQW>F<HIcUS66LiHaQ247oo
0V<H00I247ooHaQS648@Ool2HaP0248@OomS66<HIcUS66LiHaP2@Q000`00
OomS6002HaP02FLiHaQS66LiHaQW>F<H@Q1oo`0;HaP0148@OomS66<H0T8@
00@007ooHaQS60U24003Oom2448@00Q24003IcU247oo009S60924003001S
66<H009S6005IcUS66<H001oo`02HaP016LiHaQS600O0f<H00MW>F<HIcUS
66LiHaQW>@02HaP01UkP001Nh7ooOn0000=S60924005001oof<HIcUS6007
01l01V<HIcUS66LiHaQW>@9S6006G^0005kPOomoh0000f<H0T8@018007oo
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT2HaP01UkP001Nh7oo
On0000=S6092400B001oof<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66Li0V<H00INh000G^1oogoP0003HaP2@Q000`00HaQS6002HaP026LiHaQS
6000OomW>Goo0005Ool01@00Oomoogoo00000Woo00H007oo001oo`00Ool3
00000gooHaQS6002@Q000`00OomS6004HaP2O006HaP2O003HaP200000f<H
O01l0002HaP02FLiHaQ2448@001oofLiOol0000DOol01000OomS66<H0T8@
00<006<HHaP00V<H00]W>F<HHaP007ooHaP006<H001S6000009S6005IcUS
66<HHaQW>@03HaP00fLiHaQS6002HaP01000HaQS60000V<H0T8@00L007oo
HaQS66LiHaQW>@02HaP501l00d8@HaQS6002HaP201l0248@IcUS66<HIcUS
66LiHaP2@Q000`00OomS6002HaP00fLiHaQS6002O002HaP2O002HaP00fLi
HaQS6006HaP016LiHaQW>F<H0T8@00<006<HHaP00V<H00EW>F<HHaP007oo
00ES600601mS66<HIcUS66Li1F<H00EW>F<HIcUS600O00=S60524040005g
_@0000=W>GooHaP00V<H00=W>F<HIcT00V<H00H007ooIcT007oP000?G^00
0`00HaQS6004HaP01fLi@Q124000OomW>@0000Aoh003001Nh5kP00eNh003
001S66<H009S60924003001oof<H009S60030003o`?o00`3o`800082m`03
001S66<H009S60924004001S66<HIcT4HaP00`00OomS6006HaP01T8@OomS
66<H@Q1oo`9S6006@Q1oof<HHaQ247oo1F<H00EW>D8@@Q0007oo00=S60Mo
o`04@Q1oof<HHaP4Ool01f<HOomoogooHaQ247oo009S60924004001oof<H
HaP9@Q000gooIcUoo`09Ool0148@OomS66<H0T8@00@006<HHaQW>@AS6003
001oof<H009S60D07`US6006G^0005kPOomoh00016<H0T8@00<007ooHaP0
0V<H1`0O1f<H00INh000G^1oogoP0004HaP2@Q000`00OomS600@HaP01UkP
001Nh7ooOn0000AS60924003001oof<H011S6006G^0005kPOomoh00016<H
0T8@00@006<HHaQW>@AS6005001oof<HOol00005Ool01@00Oomoogoo0000
0Woo00H007oo001oo`00Ool300000gooHaQS6002@Q001@00OomS66<HIcT0
0V<H0W`00V<H0P000V<H0W`00V<H00AW>@00001S609l00AS60924005001o
of<HOol0000DOol01000OomS66<H0T8@00@006<HHaQW>@AS6007001oofLi
001S66Li00001F<H00EW>F<HHaQS66Li00=S6003IcUS66<H00=S6003001S
66<H00924003001oof<H00IS60@07`03@Q1S66<H00AS600301m246<H00ES
6005IcU2448@001oo`05HaP2O004HaP2O005HaP00fLiHaQW>@05HaP016Li
@Q1240000V<H00=W>F<HHaP00V<H00D007ooHaQS66Li009S60807`QS6004
IcUS66<HHaP201l3HaP1@Q010001Li`00005HaQoof<HHaQW>@05HaP01000
OomS60000WoP00<005kPG^003EkP00D006<HIcUS66Li009S60924004001o
of<H0005On000`00G^1Nh00=G^001000HaQW>F<H0T8@00@007ooHaQS61<0
00060_L006<HHaQW>F<H0T8@00<006<HHaP00V<H00EW>F<HHaP007oo00=S
6006IcUS66LiHaQ246<H0Woo00I247ooHaQS648@Ool2HaP01T8@OomS66Li
HaQW>@9S60924004001oofLiHaP9@Q000gooHaQ24003@Q0016<H@Q12448@
0V<H00A247ooIcUS60924004001oof<HIcT9@Q000goo@Q124008@Q000fLi
@Q1oo`02HaP2@Q000`00HaQS6002HaP01fLiHaQS6000OomS66Li00=S6003
01mS66<H00=S6003IcUS66Li009S6006G^0005kPOomoh0000f<H00IW>F<H
@Q124000Ool=HaP02FLiHaQS65kP001Nh7ooOn000003HaP026LiHaQ2448@
001oof<HIcT2HaP00fLiHaP0000900001UkP001Nh7ooOn0000=S6006IcUS
648@@Q0007oo0f<H00]W>F<HIcUS66LiHaQW>F<HIcUS66Li009S6006G^00
05kPOomoh0000f<H00EW>F<H@Q12400000AS6008IcUS66<H001oofLiOol0
00Eoo`05001oogooOol00002Ool01P00Ool007oo001oo`<00003OomS66<H
00924003001oof<H00AS609l009S6080009S609l00=S608000MS60924005
001oofLiOol0000DOol01000OomS66<H0T8@00<006<HHaP00V<H00MW>F<H
HaP007ooHaP00003HaP00fLi0000000>0002HaP00`00HaQS6002@Q000`00
OomS6002HaP00fLiHaQS600501l01D8@HaQS66<HIcT01V<H00=W>F<HIcT0
0V<H0T8@00H007ooHaQS66LiHaP2O006HaP2O00016LiHaP0000016<H00=W
>F<HIcT00V<H0T8@00<006<HHaP00V<H00EW>F<HHaP007oo00IS600601mS
66<HHaQW>F<H0P001F<H00L07f<HHaQW>F<H@Q000001Li`00003IcUoof<H
00=S6008IcUS66<HHaP007ooIcT000=oh003001Nh5kP00eNh003001S66<H
00=S60924004001oofLi0006On000`00G^1Nh00=G^000`00HaQS6002@Q00
1@00OomS66<H000040?o00@000;g000000AS60924004001S66<HIcT4HaP0
1000OomS66Li1V<H148@00Aoof<HHaQ240=oo`03@Q1S66<H00ES60924006
001oof<HHaQ247oo1V<H00=247ooHaP02V<H00A247ooHaQS60924004001o
of<HHaP9@Q000gooHaQoo`09Ool0148@OomW>F<H0T8@00@006<HHaQW>@AS
6003001oof<H00AS600601mS66<HIcUS66Li16<H00INh000G^1oogoP0006
HaP2@Q001000OomS66Li1f<H00=W>F<HHaP00f<H00INh000G^1oogoP0006
HaP2@Q000`00OomS6002HaP016LiHaQS600027oo00ENh000G^1oogoP0080
00ES60924004001oof<HIcT=HaP01UkP001Nh7ooOn0000IS60924004001S
66<HIcT4HaP01@00OomS67oo00001Goo00D007ooOomoo`00009oo`06001o
o`00Ool007oo0`0000=oof<HHaP00T8@00@007ooHaQW>@9S6003IcUl07`0
009S6080009S609l00=S608000=S6004IcUS66<HHaP2@Q001000OomS67oo
5P0000=oof<HHaP00T8@00@006<HHaQW>@AS6006001oofLi001S66Li0V<H
00<006<HIcT03f<H00<006<HHaP00T8@00@007ooHaQW>@AS60D07`03@Q1S
66Li009S60924003IcUS66<H00IS60924003001oof<H009S609l00=S6003
IcUS66<H009S6003O01S66<H00800003HaQW>F<H00ES6006IcU2448@001S
66Li1F<H00@007ooHaQW>@AS60807`AS6080009S6004IcUS600O01l4HaP1
@Q010001Mkd00008HaQoof<HIcUS66LiHaQW>@9S6004001oof<H0004On00
0`00G^1Nh00=G^001@00HaQS66LiHaP00T8@00@007ooHaP000Moh0l000=S
60924005001oof<HHaP0000@0ol010000_L2m`000V<H00EW>F<H@Q124000
00AS6005IcUS66<H001oo`02HaP01VLiHaQS66LiHaQW>@=S6004@Q1oof<H
HaP4@Q04HaP016LiHaQW>F<H0T8@00H007ooHaQS648@Ool3HaP01FLiHaQS
648@Ool00V<H0goo00QS67ooOomS67ooHaQ247oo0V<H0T8@00@007ooHaQS
60U24003Oom2448@00Q24003IcU247oo009S60924003001S66<H009S6005
IcUS66<H001oo`03HaP00fLiHaQS6002HaP500001f<HG^0005kPOomoh000
00ES6006IcUS648@@Q0007oo16<H00AW>F<HIcUS60D00007HaQNh000G^1o
ogoP00001F<H00IW>F<H@Q124000Ool2HaP01VLiHaQS66<H001oo`D0009o
o`08001Nh7ooOn0007oo001W>@9S6006IcUS648@@Q0007oo16<H00AW>F<H
IcUS60D0009S6005001Nh7ooOn000005HaP01FLiHaQ2448@000016<H00QW
>F<HHaP007ooIcUoo`001Goo00D007ooOomoo`00009oo`06001oo`00Ool0
07oo0`0000=oofLiHaP00T8@00<007ooHaP016<H0W`00V<H0P000V<H0W`0
0f<H0P0000=S66LiHaP00V<H00UW>F<H@Q124000OomW>Goo000057oo00@0
07ooIcUS60924003001S66<H009S6007IcUS66<H001oof<H000016<H00<0
06<HHaP03f<H00<006LiHaP00T8@00<007ooHaP00V<H00=W>F<HHaP01@0O
00E246<HHaQW>D8@00807`09@Q1S66<HIcUS66LiHaQW>F<H00924003001o
ofLi009S6004O01S66<HIcT3HaP00fLiHaQS6002O0000f<H00000002HaP0
1FLiHaQW>F<HIcT00V<H0T8@00<006<HHaP00V<H00EW>F<HHaP007oo00AS
6006IcUS66<H01mS66Li0V<H0P0000EW>F<HHaQS600O00=S6004IcUS648@
0001Li`00003IcUoof<H00MS6004001oofLi0005On000`00G^1Nh00=G^00
1000HaQS66<H0T8@00@007ooIcT0011oh003001S66<H00IS60924005001o
of<HHaP0000@0ol01@000_L2m`;g00000f<H0T8@00@006<HHaQW>@AS6003
001oof<H00=S6003IcUS66<H009S6007IcUS648@HaQoof<H@Q0016<H00=W
>F<HIcT00f<H00EW>D8@@Q0007oo009S6004@Q1oof<HHaP3Ool016<H@Q1o
of<H0d8@00ES648@@Q1S648@009S6004@Q1oof<HHaP2@Q001000OomS66Li
2D8@00=oof<HOol01Goo00IW>F<HIcUS648@Ool2HaP2@Q001000HaQS66Li
16<H00@007ooHaQW>@AS608000ES60800004@Q1oogoP0003HaP00fLiHaQS
6002HaP2@Q000`00OomS6005HaP20005HaP20000148@Oomoh0000f<H00=W
>F<HHaP00V<H0T8@00<007ooHaP00f<H00AW>F<H000000Eoo`<00003Oomo
h000009oo`03001S66<H00=S60924005001oof<HHaQW>@03HaP20005HaP2
0000148@Oomoh0000f<H00=W>F<HHaP00V<H0T8@00@006<HHaQW>@AS6005
001oof<HOol00005Ool01@00Oomoogoo00000Woo00H007oo001oo`00Ool3
00000gooHaQS6002@Q001000OomS66<H0P0000=S67`0O0000V<H0P001F<H
00AW>F<H000000MS60924005001oof<HOol0000DOol01000OomS66<H0T8@
00@006<HHaQW>@AS6004001oofLi0004HaP00`00HaQS6002HaP016LiHaQS
66Li0V<H00QW>F<HHaQW>F<HIcUS60000V<H0T8@00<007ooHaP01T8@100O
0T8@0V<H100O0d8@16<H00EW>D8@@Q0007oo009S609l00YS609l00]S6092
4004001S66<HIcT2HaP016LiHaP007oo0V<H00=W>F<HHaP00V<H0P0O26<H
0P0O1F<H0D8@0@000G>L00000f<HOomS6002HaP00fLiHaQW>@02HaP01000
OomS60001WoP00<005kPG^003EkP00<006LiHaP00T8@00@007ooHaP0011o
h003001S66<H00AS6006IcUS648@@Q0007oo0V<H4`000P;g00@006<HIcUS
60924003001S66<H009S6005IcUS66<H001oo`03HaP01FLiHaQW>F<HIcT0
16<H00A247oo@Q1oo`=S6003IcUS66<H009S6003IcUS66<H00924007001o
of<HHaQ247ooHaP00d8@00AS648@@Q1oo`]S6004@Q1oofLiHaP2@Q001000
OomS66<H2D8@00=ood8@@Q00148@00=S66LiOol00Woo00A247ooHaQS6092
4003001S66<H009S6005IcUS66<H001oo`03HaP00fLiHaP00008HaP017oo
001240001f<H00IW>F<H@Q124000Ool2HaP016LiHaQS600026<H00Aoo`00
@Q0000MS6006IcUS648@@Q0007oo0V<H00AW>F<HHaP000Uoo`<000=oo`06
001S66<HHaQW>F<H0T8@00@007ooHaQW>@=S6003001S66<H00MS60030012
400000MS6005IcUS648@@Q000004HaP026LiHaQS6000OomW>Goo0005Ool0
1@00Oomoogoo00000Woo00H007oo001oo`00Ool300000gooHaQS6002@Q00
1000OomS66<H0P0000=S67`0O0000V<H0P0000=S66LiHaP016<H0P000f<H
00AW>F<HIcUS60924005001oofLiOol0000DOol01000OomS66<H0T8@00<0
06<HHaP00V<H00MW>F<HHaP007ooHaP00004HaP01000HaQS66Li0V<H00AW
>F<HHaQW>@9S6003IcUS66<H00=S6003001S66<H00924003001oof<H00El
0003@Q007`0O00<07`=240@07`<2h003@Q1S66Li009S60924003001oof<H
009l0003HaQW>F<H00=S6003IcUS66<H009S609l00ES6006IcUS66LiHaQW
>F<H0T8@00D006<HIcUS66Li00=S6003001oof<H00AS6006IcUS66<H01mS
66Li1V<H00<07f<HIcT00V<H00AW>F<H@Q00005g_@0000AW>GooHaQW>@AS
6006IcUS6000OomW>@001goP3`000f<H0T8@00@007ooIcT0011oh003001S
66<H009S6004IcUS66<HHaP2@Q001@00OomW>F<H000040?o00D000;g0002
m`0000=S60924004001S66<HIcT4HaP01000OomS66Li1V<H00AW>F<HIcUS
60=2409S600:IcUS66<HHaQW>F<HIcUS66LiHaP2@Q001P00OomS66<H@Q1o
o`IS6004@Q1oof<HHaP6Ool01F<HIcUS648@Ool00V<H0T8@00@007ooHaQS
60U24003OomS67oo00Eoo`E2409S6004IcU2448@0002HaP00fLiHaQS6002
HaP00`00OomS6003HaP00`00HaQS6002HaP301l3HaP00goo001S6002HaP0
1fLiHaQS66<HIcUS66Li00924003001oof<H00=S6003001S66<H009S6004
IcUS66<HIcT2HaP00goo001S6002HaP01fLiHaQS66<HIcUS66Li00924003
001oof<H00=S6003001oogoo00Uoo`03001oogoo009oo`04001S66<HIcT2
HaP2@Q000`00OomS6002HaP00fLi001S600901l00f<H001S6002HaP01fLi
HaQS66<HIcUS66Li00924004001S66<HIcT4HaP01@00OomS67oo00001Goo
00D007ooOomoo`00009oo`06001oo`00Ool007oo0`0000=oof<HHaP00T8@
00@007ooHaQS60800003HaQl07`0009S60H000=S608000IS6007IcU2448@
001oof<HOol05P0000=oof<HHaP00T8@00@006<HHaQW>@AS6004001oofLi
0002HaP016LiHaP007`01f<H00=l06<HHaP00V<H00EW>F<HHaQS6000009S
60924003001oof<H00El0003@Q1S600O00T07`9S60<2h004@Q1S66<HHaP2
@Q001000OomS67`016<H00EW>F<HIcUS66Li009S6003IcUS67`000800003
HaQW>F<H00ES6004IcU2448@0005HaP016LiHaP007oo0V<H00=W>F<HHaP0
0f<H0P0O0V<H0P000V<H0P0O1V<H0D8@0@000G>L00000f<HOomS6003HaP0
26LiHaQS66<H001oof<H000@On000`00HaQS6006HaP2@Q001000OomS6000
1WoP2P000f<H00=W>F<HHaP00f<H0T8@00<007ooHaP00V<H00<000?o0ol0
3@?o00<000;g0_L00P000f<H0T8@00<006<HHaP00V<H00EW>F<HHaP007oo
00AS6003IcUS66Li00IS6003@Q1oogoo00AS6003IcUS66<H00AS60924006
001oof<HHaQ247oo0V<H0Woo00ES67oo@Q1oof<H00I240Aoo`04@Q1oof<H
HaP2@Q001000OomS66<H2D8@00=ood8@@Q00148@00EW>D8@OomS648@00AS
60924003001S66<H009S6005IcUS66<H001oo`02HaP00fLiHaP00002HaP0
0fLiHaP07`0201l2HaP00fLiOol00006HaP016LiHaQS66<H0T8@00@007oo
HaQW>@9S6004001S66<HIcT7HaP00goo001S6005HaP016LiHaQS66<H0T8@
00@007ooHaQW>@9S6003001oogoo00Uoo`03001oogoo009oo`03001S66<H
00=S60924003001oof<H00=S6003001S600O00Moo`0501mS6000HaQW>@04
HaP016LiHaQS66<H0T8@00<006<HHaP00V<H00QW>F<HHaP007ooIcUoo`00
1Goo00D007ooOomoo`00009oo`06001oo`00Ool007oo0`0000=oof<HHaP0
0T8@00@007ooHaQS60800003HaQl07`0009S60H000=S6080009S6003IcUS
66Li009S60924005001oofLiOol0000DOol01000OomS66<H0T8@00<006<H
HaP00V<H00MW>F<HHaP007ooHaP00004HaP02000O01l06<HIcUS66LiHaP3
O0001F<HIcUS66<HIcT00V<H00<006<HHaP00T8@00@007ooHaQS60=l0005
@Q1S66LiHaQl000701l0148@HaQS66<H0`;P00=246LiHaP00T8@00<007oo
HaP00`000V<H0`000V<H0`0000=S67`000000P000V<H0`0000=W>F<HHaP0
0T8@00D006<HHaQS66Li00=S6006001oof<HIcUS66Li0V<H00AW>F<HHaP0
7`9S6080009S600:01mS66<HHaQW>F<HIcUS648@0001Li`00005IcUoof<H
HaQW>@03HaP01VLiHaP007ooIcT0011oh003001S66<H00=S6003IcUS66<H
00924005001oofLiHaP00004On000`00HaQS6009HaP40002HaP01fLiHaQ2
448@001oofLi00=S60l000@2m`04001S66<HIcT2@Q001000HaQS66Li16<H
00D007ooHaQS66Li00AS6003IcUS66Li009S60=24004OomS66<HIcT3HaP0
0fLiHaQW>@02HaP2@Q001`00OomS66<H@Q1oof<H00924005HaQ2448@@Q1o
o`06HaP6@Q03HaP2@Q001000OomS66Li2D8@00aoof<HHaQS66LiHaQW>F<H
@Q1ood8@Ool2HaP01fLiHaQ2448@001S66Li00ES6003001oof<H009S6004
001S66<HIcT2HaP301l4HaP017oo001S66Li1F<H00IW>F<H@Q124000Ool3
HaP00`00HaQW>@04HaP00fLiHaQW>@03HaP017oo001S66Li1F<H00IW>F<H
@Q124000Ool3HaP00`00Oomoo`0701l4Ool01@00Oomoogoo00000V<H00=W
>F<HIcT00T8@00H007ooHaQW>F<H0002HaP00`0OOomoo`05Ool0100OHaQS
60001f<H00EW>F<H@Q124000009S6003IcUS66<H009S6005001oof<HOol0
0005Ool01@00Oomoogoo00000Woo00H007oo001oo`00Ool300000gooHaQS
6002@Q001000OomW>F<H0P0000=S67`0O0000V<H0P001f<H0P001f<H0T8@
00D007ooHaQoo`0001Aoo`04001oof<HHaP2@Q001000HaQS66Li16<H00@0
07ooIcT000AS6004001S67`0O003HaP2O0000f<HO01l0003HaP01W`0HaQS
6000HaQW>@924004001oofLiHaP3O000148@HaQS66<H0g`000=246<H0^00
0P;P00A246<HHaQS60<2h003@Q1S66<H00924003001oofLi00<0009S60<0
009S60<0009S60<0009S60<000=S60924006001S66<HIcUS66Li0V<H00<0
07ooHaP016<H00AW>F<HHaQS60807`04HaP00000HaP201l7HaP1@Q010001
Mkd00003HaQoofLi00=S6008IcUS66<HHaP007ooHaP0011oh005001S66<H
HaQW>@04HaP2@Q000`00OomS6002HaP40003HaP01FLiHaQW>F<HIcT00f<H
00=W>F<H00000P0016<H0T8@00<007ooHaP00V<H00=W>F<H000037oo0P00
0`;g00@006<HHaQS60924003001S66<H009S6006IcUS66<H001oofLi0f<H
00=W>F<HIcT00f<H00aW>F<H@Q1S648@HaQoofLiHaQW>F<HIcT3HaP01VLi
HaQ2448@001oo`9S6003@Q1oof<H00ES6004@Q1oof<HHaP4Ool01D8@OomS
66<H@Q000V<H00IW>F<H@Q124000Ool2HaP9@Q08Ool3@Q000gooIcUS6002
HaP2@Q000`00HaQS6002HaP01FLiHaQS6000Ool00f<H00<006<HHaP02@0O
0V<H00L006<HHaQS66LiHaQW>@03HaP2@Q000`00OomS6002HaP00`00HaQS
6003HaP00fLiHaQS6005HaP01`00HaQS66<HIcUS66Li00=S60924003001o
of<H009S6004001oogoo01l5Ool00`0OOomoo`02Ool01@00Oomoogoo0000
1F<H0T8@00<007ooHaP00V<H00@006<HHaP07`Moo`0401mS66<H0003HaP0
0fLiHaQW>@03HaP2@Q000`00HaQS6002HaP026LiHaQS6000OomW>Goo0005
Ool01@00Oomoogoo00000Woo00H007oo001oo`00Ool300000gooIcUS6002
@Q001000OomS66<H0P0000=S67`0O0000V<H0P0000=S66LiHaP02P0000=S
66LiHaP00T8@00@007ooIcUooaH00003OomW>F<H00924003001S66<H009S
6009IcUS66<H001oof<H001S66Li009S6003001W>F<H009l0003HaQl07`0
00=S609l0003HaQl07`0009S6003001S66<H00924004001oof<HHaP3O000
148@HaQS66<H0g`000=246<H0^000P;P00A246<HHaQS60<2h003@Q1W>F<H
00924003001oof<H011S609l00QS60924003001S66<H00ES6006001oof<H
IcUS66Li1V<H0P0O0V<H0P0O0f<H00MW>F<HHaQW>F<H@Q000001Li`00005
IcUoof<HHaQW>@05HaP01000OomW>@001WoP2P001f<H00MW>F<H@Q124000
OomW>@0DHaP20002HaP01VLiHaQ2448@001oo`ES6003001oogoo00]oo`80
0082m`04001S66<HHaP2@Q000`00HaQW>@03HaP016LiHaP007oo0V<H00=W
>F<HHaP00V<H00IW>F<HIcUS648@Ool2HaP00d8@OomS6004HaP01FLiHaQW
>F<HIcT00T8@00P007ooHaQS648@OomS66Li17oo00=247ooHaP0148@00ES
648@OomS648@00ES60924004001oof<HHaPD@Q001GooHaQS66<HIcT00T8@
00@006<HHaQW>@9S6008IcUS6000OomS66LiHaP0009S60T07`9S6003001S
66<H00AS6003IcUS66<H00924006001oof<HIcUS60000f<H00=W>@0O01l0
0`0O00ES66LiHaQS600000IS6003IcUS66<H00924003001oof<H009S6004
001oogoo01l5Ool00`0OOomoo`02Ool01@00Oomoogoo00000V<H00=W>F<H
HaP00T8@00<007ooHaP00V<H00@006<HHaP07`Moo`0401mS66<H0006HaP0
0fLiHaQS6002@Q001000HaQS66Li16<H00D007ooHaQoo`0000Eoo`05001o
ogooOol00002Ool01P00Ool007oo001oo`<00003OomS66<H00924004001o
of<HHaP600000f<H00000003HaP:0003HaP2@Q001@00OomS67oo000057oo
00@007ooHaQS60924004001S66<HIcT4HaP01000OomW>@0016<H00@006<H
HaQS60=l00ES60=l00=S6003001S66<H00924004001oof<HHaP:O0000d8@
IcT2h0020^000d8@HaQS60030^00148@HaQS66<H0T8@00<007ooIcT016<H
00EW>F<HHaQS66Li00QS609l00ES6005IcUS648@@Q000002HaP00fLiHaQW
>@02HaP00`00OomS6003HaP00fLiHaQS6004HaP401l6HaP01FLiHaQS648@
00000G>L00000f<HOomS6004HaP01FLiHaQS6000Ool00V<H00<007oPOn00
0WoP00<006<HHaP02F<H100000AS66LiHaQS60924003001oof<H009S6003
IcT0000000MS6003001S66<H00AS6003001S600000AS60924003001oof<H
00ES6003001oogoo00L000Aoo`<0009S6005IcUS648@@Q000003HaP01VLi
HaQS66<H001oo`AS6003IcUS66Li00AS6006@Q1oof<HHaQ247oo0V<H00=W
>F<HIcT01F<H0T8@00L007ooHaQS648@OomS6006@Q000gooHaQS6004HaP0
0d8@Oom24002HaP016LiHaQW>F<H0T8@00@007ooHaQS61A24003OomS66Li
009S60924005001S66LiHaQW>@03HaP00`00OomS6002HaP00`00OomS6009
01l2HaP02P00HaQS66<HIcUS66LiHaQW>F<H0T8@00<007ooHaP00V<H00<0
07ooIcT02f<H00X006<HHaQS66LiHaQW>F<HIcUS60924003001oofLi009S
6004001oogoo01l5Ool00`0OOomoo`02Ool01`00Oomoogoo001S66Li00=S
60924003001oof<H009S6004001S66<H01l7Ool0100OHaQS60000V<H00=W
>F<HIcT016<H0T8@00<006<HHaP00V<H00QW>F<HHaP007ooIcUoo`001Goo
00D007ooOomoo`00009oo`06001oo`00Ool007oo0`0000=oof<HHaP00T8@
00@007ooHaQS60H00003HaP0000000iS6008IcUS648@@Q0007ooIcUooaH0
0003OomS66<H00924003001S66<H009S6007IcUS66<H001oof<H000016<H
00<006<HHaP00V<H00=l06<HHaP01F<H00=l06<HHaP00V<H00<006<HHaP0
0T8@00@007ooHaQS60Yl0003@Q1S60;P0082h003@Q1S60;P0082h003@Q1S
66<H009S60924003001oof<H009S6003IcUS66<H00IS6004IcUS66LiHaP2
000016<HO01l06Li0V<H00=W>F<HHaP00T8@00<006<HIcT01F<H00<007oo
HaP00`000V<H100000AS60000000009S60<0009S6005001W>F<H@Q000001
Mkd0000=IcUoof<HHaQW>F<HIcUS66LiHaP007ooIcT00V<H10000V<H00MW
>F<HIcUS66LiHaQW>@04HaP30003HaP01FLi@Q124000Ool016<H0P000V<H
00=W>F<HIcT00f<H00<006<HIcT00V<H00<006<HHaP00f<H00IW>F<H@Q12
4000Ool2HaP01FLiHaQS66<H00003Goo00<006<HHaP016<H0T8@00H006<H
HaQW>F<HIcT2HaP01@00OomS66<HIcT016<H00EW>F<HIcUS648@00=S6003
@Q1S67oo00ES6004IcUS66LiHaP2@Q001P00OomS66<H@Q1oo`IS6003@Q1o
ogoo00Eoo`92409S6005IcUS66LiHaQW>@02@Q001000OomS66Li548@00=o
of<HHaP00V<H0T8@00<006<HHaP00f<H00AW>F<H001oo`=S6003001oof<H
00=S60<07`ES6003001S66<H00MS60924003001oof<H009S6003001oof<H
00IS6006IcUS66<HIcUS60000V<H00=W>F<HHaP016<H0T8@00<007ooHaP0
0V<H00@007ooOol07`Eoo`0301moogoo009oo`05001oogooOol00003HaP0
2VLiHaQ2448@001oof<HIcUS60000V<H00<07gooOol01Goo00@07f<HHaP0
00ES6004IcUS66LiHaP2@Q001000HaQS66Li16<H00D007ooHaQoo`0000Eo
o`05001oogooOol00002Ool01P00Ool007oo001oo`<00003OomS66<H0092
4004001oofLiHaP200001F<HO01l06<HIcT00P001V<H00=W>F<HIcT01f<H
0T8@00D007ooHaQoo`0001Aoo`04001oof<HHaP2@Q001000HaQS66Li16<H
00@007ooIcT0009S6003IcUS600000IS6003IcUS66Li00ES6006IcUS66<H
001S66Li0T8@00@007ooIcUS60=l0004@Q1S66<HHaP3O0000d8@HaP2h006
0^001T8@HaQS66<HIcUS60924003001oof<H00ES6003IcUS66<H00MS6080
009S609l00AS6004IcU2448@0003HaP01fLiHaQS66<H001oof<H00<0009S
60@00004HaP000000002HaP30002HaP01@00HaQS648@00000G>L000016<H
OomS66Li1V<H00<007ooHaP04V<H00AW>F<H000000AS60924003001oof<H
00=S608000IS6003IcUS66<H00@000ES6003IcUS66<H00924003001oofLi
00ES6003001oogoo00]oo`03001S66<H00AS60924003001S66<H00ES6003
001oofLi00AS6003IcUS66<H009S6008@Q1oofLiHaQW>F<H@Q1oo`9S6003
IcUS66Li00AS60924006001oof<HHaQ247oo0V<H0goo00=S648@@Q001d8@
0V<H00=W>F<HIcT00f<H0T8@00@007ooHaQS61A240=S6005IcUS648@@Q00
0003HaP01VLiHaQS66<H001oo`AS6003001oof<H009S60<07`AS600;001S
66<HIcUS66LiHaQW>F<HIcUS6002@Q001000OomS66Li0V<H00@007ooHaQW
>@9S6004IcUS66<HIcT2HaP00`00HaQS6002HaP01VLiHaQW>F<HIcUS6092
4003001oof<H00=S6003001oo`0O00Eoo`0501moogooOol00004Ool00`00
HaQW>@03HaP2@Q000`00OomS6003HaP00`00HaP07`07Ool00`0OHaP00003
HaP00fLiHaQW>@04HaP2@Q000`00HaQS6002HaP026LiHaQS6000OomW>Goo
0005Ool01@00Oomoogoo00000Woo00H007oo001oo`00Ool300000gooHaQS
6002@Q001000OomS66<H0P0000=S67`0O0000V<H2@0016<H00EW>F<HHaQW
>F<H00924004001oofLiOolF00000gooHaQS6002@Q000`00HaQS6002HaP0
1fLiHaQS6000OomS600000AS6006001S66<HIcUS66Li1f<H00=W>F<HHaP0
0V<H00<006<HHaP00T8@00@007ooHaQS60=l0004@Q1S66<HHaP3O0000d8@
HaP2h0020^000d8@HaP2h0020^000d8@HaQW>@02HaP2@Q000`00OomS6002
HaP02FLiHaQW>F<HIcUS66LiHaQW>@04HaP20003HaP2O00016<HIcUS66<H
0T8@00<006<HIcT01F<H00<007ooHaP02f<H0P002V<H0D8@0@000G>L0000
0fLiOomS6002HaP00fLiHaQW>@02HaP00`00OomW>@0<HaP00`00HaQS6004
HaP00`00HaP00004HaP2@Q000`00OomS6008000;HaP01fLiHaQS66LiHaQW
>F<H00924005001oof<HHaQW>@04HaP00`00Oomoo`080002Ool01`00HaQS
66<HIcUS66Li00924006001S66<HIcUS66Li0V<H00h007ooHaQS66LiHaQW
>F<HIcUS66LiHaQ247oo16<H00=247ooHaP016<H00AW>F<HIcUS60924007
001oof<HHaQ247ooHaP00d8@0V<H00A247ooHaQ240QS6003IcUS66Li009S
60924003001oof<H009S6192409S6004IcUS66<HHaP2@Q001P00HaQS66Li
HaQW>@9S6004001oof<HIcT2HaP00`00OomS6002HaP301l2HaP00fLiHaP0
0009HaP01FLi@Q124000Ool016<H00<007ooHaP00V<H00=W>F<HHaP016<H
00<006<HIcT01f<H00EW>D8@@Q0007oo00AS6003001oo`0O00H07`=oo`H0
00=S6006IcUS648@@Q0007oo16<H00<006<H01l0200O00AS6000HaQW>@ES
6003IcUS66<H00924004001S66<HIcT4HaP01@00OomS67oo00001Goo00D0
07ooOomoo`00009oo`06001oo`00Ool007oo0`0000=oof<HHaP00T8@00@0
07ooIcUS60800003HaQl07`0009S60T000IS6003IcUS66<H00924005001o
of<HOol0000DOol01000OomS66<H0T8@00@006<HHaQW>@AS6004001oofLi
0004HaP00`00HaQS6007HaP00fLiHaQS6003HaP00fLiHaP00002HaP2@Q00
1000OomS66<H0g`000A246<HHaQS60=l0003@Q1S60;P0082h003@Q1S66<H
00<2h004@Q1S66<HIcT2@Q001000OomS66Li2f<H00=W>F<HHaP01V<H0W`0
0f<H0T8@00/006<HHaQS66LiHaQW>F<H001oofLi00=S6003IcUS66<H00aS
6007IcUS66<HHaQW>D8@00000G>L00001F<HOomS66<HIcT01F<H00<007oo
HaP016<H00AW>F<HHaQW>@9S6006IcUS66<H001S66Li0V<H00<006<HHaP0
0f<H00MW>F<H@Q124000OomS600800001V<HIcUS66LiHaQW>@=S6005IcUS
66<HHaQW>@04HaP2@Q000`00OomS6003HaP016LiHaQS60003Goo00<006Li
HaP00f<H0T8@00<006<HIcT01F<H00<007ooHaP016<H00=W>F<HHaP00V<H
00Q247ooHaQS66LiHaQ247oo0V<H00=W>F<HIcT016<H0T8@00H007ooHaQS
648@Ool6HaP00d8@Oom24006HaP01FLiHaQW>F<HIcT00f<H0T8@00H007oo
HaQS66LiHaP@@Q000f<HIcUS6002HaP01FLiHaQ2448@00001f<H00<007oo
HaP016<H00<007ooOol01f<H00<006<HHaP00V<H00EW>F<HIcUS66Li009S
60924003001oof<H00AS6003001oogoo00=S6005IcUS66LiHaP00004HaP0
1FLiHaQW>F<HIcT00V<H0T8@00@007ooHaQW>@=S6003001oogoo00Moo`03
001S66<H00ES6004IcUS66<HHaP2@Q001@00OomS66<HIcT00V<H00<006<H
HaP01f<H00<006<HHaP00f<H00IW>F<HIcUS66LiHaP2@Q000`00HaQS6002
HaP026LiHaQS6000OomW>Goo0005Ool01@00Oomoogoo00000Woo00H007oo
001oo`00Ool300000gooIcUS6002@Q001000OomS66<H0P0016<H00=W>F<H
HaP02F<H00=W>F<HIcT016<H0T8@00@007ooIcUooaH00003OomW>F<H0092
4003001S66<H009S6007IcUS66<H001oof<H00000V<H00AW>F<H001W>@IS
6003IcUS66<H00=S6005IcUS66<HHaP00002HaP2@Q000`00OomS6002HaP3
O0000d8@HaQl0002O0000d8@HaQS60030^000d8@HaQS60030^00148@IcUS
66<H0T8@00<007ooHaP016<H00MW>F<HIcUS66LiHaQW>@0;HaP2O0001FLi
HaQ2448@00001f<H00<007ooHaP01f<H00=W>F<HHaP01F<H00=W>F<HHaP0
0V<H00EW>F<HHaQ24000005g_@0000=W>GooHaP00f<H00IW>F<HHaQS6000
Ool3HaP00fLiHaQS6004HaP00fLiHaQS6002HaP40007HaP01VLi@Q124000
OomW>@=S608000YS6005IcUS66<HHaQW>@03HaP00fLiHaQW>@02@Q001@00
OomS66<HIcT016<H00<007ooOol02goo00@006<HHaQW>@9S60924005001S
66<HHaQW>@03HaP01P00OomS66LiHaQW>@9S6006IcUS66LiHaQ247oo16<H
00=247ooHaP016<H00AW>F<HIcUS60924005001oof<HHaQ24007Ool2@Q02
HaP01FLiHaQW>F<HIcT00f<H00EW>F<HIcUS66Li00924003001oof<H009S
6003IcUS66<H009S60Q240MS6004IcUS66<HHaP2@Q001P00HaQS66LiHaQW
>@9S6005001oof<HHaQW>@03HaP20003HaP016LiHaP000000V<H00=W>F<H
IcT01f<H0T8@00H007ooHaQW>F<HIcT2HaP20005HaP20003HaP00fLiHaQS
6006HaP2@Q000`00OomS6005HaP20005Ool20002HaP00fLiHaQW>@05HaP0
1VLiHaQ2448@001oo`IS608000ES608000AS6003IcUS66<H009S6003IcUS
66Li00924004001S66<HIcT4HaP01@00OomS67oo00001Goo00D007ooOomo
o`00009oo`06001oo`00Ool007oo0`0000=oof<HHaP00T8@00@007ooIcUS
608000US6003IcUS66<H00=S6003IcUS66<H009S6003IcUS66Li00924004
001oof<HOolF00000gooHaQS6002@Q001000HaQS66Li16<H00@007ooIcT0
00QS6004IcUS66<HIcT2HaP00fLiHaQW>@03HaP00fLiHaP00002HaP2@Q00
0`00OomW>@02HaP3O0000d8@HaQl0002O0000d8@HaQS60030^000d8@HaQS
60030^00148@HaQS66<H0T8@00L007ooHaQS66LiHaQW>@07HaP016LiHaQS
66<H0P0000=S66LiHaP00f<H00=l06<HHaP00T8@00H006<HHaQW>F<HIcT2
HaP00`00OomS6002HaP016LiHaQS66Li0f<H00IW>F<H000006<HIcT3HaP0
0fLiHaQS6002HaP1@Q010001Li`00006HaQoof<HIcUS66Li16<H00@007oo
HaQW>@AS6003IcUS66Li00AS6003IcUS66<H00AS6005IcUS66<HHaQW>@02
HaP2@Q001P00OomS66<HIcUS608000IS6003IcUS66Li00=S6005IcUS66<H
HaQW>@04HaP2@Q001P00OomS66LiHaQW>@=S60l000=S6005IcUS648@@Q00
0002HaP00fLiHaQW>@02HaP00`00OomS6004HaP00fLiHaQS6002HaP01d8@
HaQS66<HIcUS648@00=S6003IcUS66Li00AS60924004001oof<HHaP9@Q02
HaP00fLiHaQS6003HaP00fLiHaQW>@05HaP2@Q001000OomS66Li16<H00=W
>F<HHaP01T8@16<H00=W>F<HIcT00f<H00MW>F<H@Q124000HaQW>@05HaP0
0`00OomW>@05HaP00fLiHaP000040008HaP01VLiHaQW>F<HIcUS60924003
001oof<H00ES6003IcUS600000@000=S6003IcUS66<H009S6006IcUS66Li
HaQW>F<H0T8@00<007ooHaP00V<H00=W>F<HHaP00V<H1@0000=W>F<HHaP0
1f<H00AW>F<HHaQS60924005001oof<HHaQW>@05HaP50004HaP01fLiHaQS
66<HIcUS66Li00=S60924003001S66<H009S6007IcUS66<H001oofLiOol0
5P0000=oof<HHaP00T8@00@007ooHaQS60T000IS6003IcUS66<H009S6003
IcUS66<H009S60924004001oofLiOolF00000gooHaQS6002@Q000`00HaQS
6002HaP02FLiHaQS6000OomS6000HaQW>@05HaP00fLiHaQW>@03HaP00fLi
HaQS6002HaP01fLiHaQS66<H001W>F<H00924003001oof<H009S60Ql0003
@Q1S60;P00<2h003@Q1S60;P0082h005@Q1S66<HIcUS6002@Q001000OomS
66Li0f<H00UW>F<HIcUS66LiHaQW>F<HIcT00V<H0P0016<H00=W>F<HHaP0
0V<H0T8@00<006<HIcT01F<H00@007ooHaQW>@9S6003IcUS66<H00ES6080
00=S6003IcUS66<H009S6004IcUS648@0001Li`00003IcUoof<H00AS6005
IcUS66<H001oo`03HaP00fLiHaQS6003HaP00fLiHaQW>@0:HaP00fLiHaQS
6002HaP2@Q000`00OomS6003HaP20003HaP00fLiHaQW>@03HaP00fLiHaQS
6002HaP01FLiHaQS66<HIcT00V<H0T8@00<007ooHaP016<H00=W>F<HHaP0
3f<H00AW>F<HHaQS60924003001S66<H00ES6005001oof<HHaQW>@04HaP0
0fLiHaQW>@02HaP01fLiHaQS66<HIcUS66Li00AS6004IcUS66LiHaP2@Q00
0`00OomS600;HaP01fLiHaQW>F<HIcUS66Li00=S6003IcUS66Li009S6092
4003001oof<H009S6005IcUS66LiHaQW>@02HaP4@Q0016<HIcUS66Li16<H
00EW>F<HHaQS66Li00924005001S66<HHaQW>@03HaP01@00OomS66<HIcT0
2f<H00IW>F<HHaQW>F<HIcT6HaP01FLi@Q124000Ool00V<H00=W>F<HHaP0
3F<H00UW>F<HIcUS66LiHaQW>F<HIcT00T8@00@007ooHaQW>A=S6006IcUS
66<HHaQW>F<H0T8@00<007ooHaP016<H00=W>F<HHaP02f<H00=W>F<HHaP0
0V<H00=W>F<HHaP00T8@00@006<HHaQW>@AS6003001oof<H01Qoo`9S6092
4004001oof<HHaP90008HaP026LiHaQS66<HIcUS66LiHaP2@Q000`00OomS
600HOol2HaP2@Q001000HaQS66Li16<H00<007ooIcT060000V<H0T8@00<0
07ooHaP016<H17`000A246<HHaQW>@P2h003@Q1S66<H00=S60924003001o
of<H009S6003IcUS66<H00YS60800003HaQW>F<H00IS60924005001S66<H
HaQW>@03HaP00`00OomS6005HaP00fLiHaQW>@03HaP20005HaP00fLiHaQS
6002HaP1@Q010001Li`00007HaQoof<HHaQW>F<HIcT00f<H00@007ooHaQW
>@=S6003IcUS66Li00ES6005IcUS66<HHaQW>@07HaP01VLiHaQ2448@001o
o`QS6003IcUS66<H009S6007IcUS66<HHaQW>F<HIcT00f<H00AW>F<HHaQS
60924006001oof<HIcUS66Li1f<H00MW>F<HIcUS66LiHaQW>@07HaP01FLi
HaQ2448@00000V<H00=W>F<HIcT00V<H00<007ooIcT00f<H00=W>F<HIcT0
0f<H00EW>F<HHaQS66Li00ES6003IcUS66Li00AS60924006001oof<HIcUS
66Li0V<H00IW>F<HHaQW>F<HIcT7HaP00fLiHaQW>@05HaP2@Q001@00OomS
66<HIcT01V<H00=W>F<HHaP026<H00EW>F<HHaQS66Li009S60924003001S
66Li00ES6003001oof<H00=S6003IcUS66<H00ES600=IcUS66<HHaQW>F<H
IcUS66LiHaQW>F<HIcT00V<H0T8@00<007ooHaP00V<H00=W>F<HIcT01f<H
00EW>F<HIcUS66Li00=S6003IcUS66Li00=S60924005001oof<HHaQW>@02
HaP00fLiHaQS6009HaP00fLiHaQW>@03HaP016LiHaQS66<H0T8@00H007oo
HaQW>F<HIcT9HaP01VLiHaQS66LiHaQW>@=S6003IcUS66<H009S60924003
001S66<H009S600LIcUS66<H001oofLiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcT2HaP026LiHaQ2448@001oof<HIcT<
HaP01FLiHaQW>F<HIcT00V<H00=W>F<HHaP00f<H0T8@01X007ooHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li0f<H
0T8@00<006<HHaP00V<H00EW>F<HHaP007oo01]S60924005001oof<HHaQW
>@0FHaP01VLiHaQ2448@001oo`9S600>IcUS66<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>@US6007IcUS648@@Q0006<HIcT01F<H00<007ooHaP00V<H00=W
>F<HIcT036<H00QW>F<HIcUS66LiHaQ240000GNm00000fLiOomS6004HaP0
16LiHaQS60007Goo00=24000Ool077oo00=24000Ool077oo00=24000HaP0
16<H00=W>F<H00007Goo00=24000Ool077oo00=24000Ool077oo00=24000
HaP00V<H00EW>F<HIcUS600001eoo`03@Q0007oo01aoo`03@Q0007oo01ao
o`03@Q0007oo01aoo`05@Q0006<HHaQW>@04HaP00`00Oomoo`0KOol00d8@
001oo`0LOol00d8@001oo`0LOol01D8@001S66<HIcT016<H00<007ooOol0
6goo00=24000Ool077oo00=24000Ool077oo00=24000HaP00V<H00EW>F<H
IcUS600001Moo`9S60524040005cW00000IS67ooHaQW>F<HIcT5HaPN0000
0f<H0000000L00000f<H0000000L0002HaP00fLiHaQW>@04HaPN00000f<H
0000000L00000f<H0000000L0009HaPN00000f<H0000000L00000f<H0000
000L00000f<H0000000L0006HaP00fLiHaQS600N00000f<H0000000L0000
0f<H0000000L0002HaP01FLiHaQS66<HIcT00V<H7P0000=S600000007000
00=S6000000070002F<H5`000V<H0D8@0@000G>L00000fLiOomS6003HaP0
0fLiHaQW>@0PHaP00fLiHaQS600LHaP00fLiHaQS600QHaP00fLiHaQS600N
HaP00fLiHaQS600MHaP00fLiHaQS600NHaP00fLiHaQW>@0RHaP00fLiHaQS
600LHaP00fLiHaQS600LHaP00fLiHaQS600JHaP01VLiHaQS66LiHaQW>B=S
6003IcUS66<H01aS6003IcUS66<H021S6003IcUS66<H021S6003IcUS66<H
01aS6003IcUS66<H01iS6003IcUS66Li01YS6005IcUS66<H@Q000001Mkd0
0003HaQoof<H009S6003IcUS66<H00IS600GIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@08HaP05fLiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT026<H01MW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00MS
6005IcUS66<HHaQW>@05HaP05FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@07HaP06FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00QS600GIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@04HaP00fLiHaQS
6002HaP00fLiHaQW>@04HaP05fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcT026<H01MW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00QS600GIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@08HaP05FLiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@0;HaP00fLi
HaQW>@04HaP05fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT026<H01MW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66Li00QS600GIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@07HaP01FLiHaQS66<HIcT016<H
01MW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66Li00QS600GIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>@08HaP05fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcT016<H00=W>F<HHaP00V<H00=W>F<HIcT016<H
00mW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01f<H0D8@0@000G>L
000016LiOomS66Li0f<H00=W>F<HIcT0G6<H00=W>F<HIcT00f<H00EW>F<H
HaQS66Li05eS6003IcUS66Li00AS6003IcUS66<H07MS6005IcUS66LiHaQW
>@05HaP00fLiHaQS601HHaP00fLiHaQW>@03HaP01FLiHaQS66<HIcT0GF<H
00=W>F<HIcT016<H00=W>F<HHaP05F<H00=W>D8@00000G>L00000f<HOomS
6002HaP016LiHaQS61cW3R4800<@Q6<HHaP03F<H00EW>F<HIcUS66Li01US
6007IcUS66LiHaQW>F<HIcT06F<H00=W>F<HHaP00V<H00EW>F<HHaQS66Li
00=S6003IcUS66<H01IS6004IcUS66<HIcTLHaP01FLiHaQW>F<HIcT06F<H
00EW>F<HIcUS66Li00=S6003IcUS66Li01iS6005IcUS66LiHaQW>@0JHaP0
1FLiHaQW>F<HIcT06V<H00EW>F<HIcUS66Li01QS6003IcUS66<H00ES6003
IcUS66Li01iS6005IcUS66LiHaQW>@0JHaP01FLiHaQW>F<HIcT06F<H00=W
>F<HHaP00V<H00EW>F<HHaQS66Li01iS6005IcUS66LiHaQW>@0IHaP01FLi
HaQW>F<HIcT06F<H00EW>F<HIcUS66Li00=S6003IcUS66Li01ES6003IcUS
66Li009S60524040005g_@0000=W>GooHaP01F<H00<mkf<HHaP036<H00lQ
26<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01f<H01EW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT02f<H01MW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00=S6005
IcUS66<HHaQW>@03HaP00fLiHaQS6002HaP05fLiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00V<H01iW>F<HHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcT6HaP05fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT01V<H00=W>F<HIcT00f<H01eW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00MS
600IIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcT01V<H01UW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>@06HaP05fLiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00V<H00EW>F<HIcUS66Li00AS
600MIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@07HaP06FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00IS600GIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@03HaP01FLiHaQS
66<HIcT00f<H01eW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00MS600GIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@07HaP01fLiHaQW>F<H
IcUS66Li02000003HaQW>@0000l000AS60524040005cW00000US67ooHaQS
66LiHaQW>F<H?Nl00f<H00=JeVLiHaP00f<H00=JeV<HHaP00V<H00<Q26<H
HaP016<H1P0016<H00EW>F<HIcUS66Li00eS60L0000<HaQW>F<HIcUS66Li
HaQW>F<HIcUS66Li2f<H1`001f<H00AW>F<HHaQW>@=S6007IcUS66<HHaQW
>F<HIcT036<H1`005f<H1`002F<H00=W>F<HIcT05f<H1P000f<H00=W>F<H
IcT04f<H2`0000IS66LiHaQW>F<HIcTKHaP00fLiHaQW>@04HaP80009HaP0
0`00HaQS6005HaP00fLiHaQW>@0OHaP00fLiHaQW>@0OHaP01FLiHaQW>F<H
IcT076<H00=W>F<HIcT06F<H00UW>F<HIcUS66LiHaQW>F<HIcT07f<H00EW
>F<HIcUS66Li01US6005IcUS66LiHaQW>@07HaP00goo@Q12400<@Q000`00
Oom2400=@Q001000HaQS67oo3T8@00L006<HHaQW>F<H@Q000001Li`00003
IcUoof<H00AS6006IcTmkf<HIcUS65[F0V<H00eW>F<HIcUJeVLiHaQW>F<H
8@QS66LiHaQW>@09HaP00fLiHaQW>@05HaP02FLiHaQW>F<HIcUS66LiHaQW
>@0GHaP02FLiHaQW>F<HIcUS66LiHaQW>@0:HaP01FLiHaQW>F<HIcT00f<H
00MW>F<HIcUS66LiHaQW>@05HaP02FLiHaQW>F<HIcUS66LiHaQW>@0;HaP0
4fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00]S6007
IcUS66LiHaQW>F<HIcT016<H01=W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>@02HaP00fLiHaQS6006HaP00fLiHaQS6002HaP04FLi
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT04f<H01UW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@05
HaP00fLiHaQW>@0:HaP03fLiHaQW>F<HIcUS66LiHaP006<HIcUS66LiHaQW
>@04HaP07FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcT01F<H01mW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@05
HaP06fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>@04HaP06fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@03HaP08fLiHaQS66<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcT01F<H01UW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@05HaP00fLiHaQW>@04HaP00goo
HaQS600;HaP01T8@001oofLiHaQW>@IS6006IcUS66<HHaQ240000V<H00=o
of<HHaP02f<H00=24000HaP00f<H0D8@0@000G>L00001V<HOomS66LiHaQW
>@9S6007?NmS66<HHaQW>F<HIcT01V<H00A]S6<H8@QW>@=S6004IcUS66<H
0005HaP01@00HaP006LiHaP00`002F<H00=W>F<HIcT00V<H1@000f<H1000
00IS6000IcUS6000IcT:HaP01FLiHaQS66<H000016<H00@006<HHaQS60@0
009S60<000=S60<00003IcUS66<H00MS6005IcUS66LiHaP00006HaP00`00
HaQS60030003HaP00`00HaQS6007HaP00fLiHaQW>@03HaP00`00HaQS6002
HaP00`00HaQS6003000016<HIcUS60000f<H00<006<HHaP03V<H00<006<H
HaP00f<H0`0000=W>F<HHaP00`000V<H00<006<HHaP00P0036<H00EW>F<H
HaQS600000=S6003001S66<H009S6004001S6000IcT2HaP00`00HaQS6004
0002HaP30003HaP01@00HaQS66<H00001F<H00=W>F<HIcT01V<H00<006<H
HaP00V<H00@006<HHaQS60<0009S6003001S600000<000AS6003IcUS66Li
01MS600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@0OHaP01FLiHaQW>F<HIcT0
76<H00=W>F<HIcT06F<H00UW>F<HIcUS66LiHaQW>F<HIcT07f<H00EW>F<H
IcUS66Li01US6005IcUS66LiHaQW>@03HaP01FLiHaQW>F<HOol00f<H1P00
00MS66LiHaQS648@001oo`02HaP60005HaP01D8@001S66<HOol03F<H00Q2
4000HaQS66LiHaQ240000GNm00000fLiOomS6003HaP01FLiHaPmke[FIcT0
0U[F00AS65[FF]IW>@9JeP05IcUUBV<HKH`Q2002HaP01VLiHaQS66<HIcT0
009S6008IcUS66<H001S6000HaP000=S6009001S66LiHaQW>F<HIcUS66Li
00ES6005001S66<HHaQW>@02HaP02@00HaQS66<H001S6000HaP00003HaP0
1fLiHaQW>F<HIcUS66Li00AS6003IcUS6000009S6003IcUS6000009S6007
001S66<HHaP006<H00000f<H00<006<H00000f<H00T006<HIcUS66LiHaQW
>F<HIcT01F<H00@006<HHaQW>@=S6003001S600000=S6003001S6000009S
6007IcUS66LiHaQW>F<HIcT016<H00AW>F<HHaP0009S6005IcUS6000HaP0
0003HaP02000HaQS6000HaQW>F<H0002HaP02fLiHaQW>F<HIcUS66LiHaQW
>F<HIcT00f<H00H006<HIcUS66Li0003HaP00`00HaP00003HaP01@00HaP0
06<H00000V<H00/006<HIcUS66LiHaQW>F<HIcUS66Li00=S6003IcUS6000
00=S6008001S66<HIcUS6000HaP000=S6003001S600000=S6003001S6000
00=S600<001S66<H001S66LiHaP006<HIcUS66Li16<H00=W>F<HIcT00f<H
00<006<HHaP00V<H00@006<HIcT000=S600;001S6000HaP006<HIcUS6000
HaQW>@04HaP07FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H01mW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>@05HaP06fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@04HaP06fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@03HaP08fLiHaQS66<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcT01F<H01UW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@05HaP00fLiHaQW>@04HaP0
17ooHaQS66<H1P000f<H00UW>D8@001oofLiHaP006<HIcT00V<H00P006<H
HaQS66LiHaQ240000V<H00Aoof<HHaQW>@800004HaQW>F<HIcT20002HaP0
0d8@001S6003HaP1@Q010001Li`00005HaQoof<HHaQW>@03HaP01cg_HaQS
66<HF]IS66Li00=S609]S0=S60038@QS66<H009S6004IcUS66<H0005HaP0
1@00HaP006<H000036<H00=W>F<HIcT00V<H00<006<HHaP016<H00T006<H
HaQS6000HaP006<H00000V<H00]W>F<HIcUS66LiHaQW>F<HIcUS66Li00=S
6003001S66<H009S6004001S66<H0003HaP00`00HaP00005HaP00`00HaQS
6004HaP02FLiHaQW>F<HIcUS66LiHaQW>@02HaP00`00IcUS6002HaP01FLi
HaP006<H00000f<H00l006<H001S66LiHaQW>F<HIcUS66LiHaQW>F<HIcT0
0f<H00<006<H00000f<H00<006<H00001F<H00L006<H001S6000HaP0000=
HaP00fLiHaP00004HaP01`00HaQS66<H001S600000=S6003001S600000=S
6003001S66<H00YS600:IcUS66<H001S6000HaP006<H0003HaP00`00HaP0
0003HaP00`00HaP00003HaP00`00HaP00003HaP02@00HaP006<H001S6000
HaP00004HaP00fLiHaQW>@04HaP00fLiHaP00002HaP00fLiHaP00002HaP0
0`00HaQS6003HaP00`00HaP00003HaP01`00HaQS66<HIcUS66Li01MS600;
IcUS66LiHaQW>F<HIcUS66LiHaQW>@0OHaP01FLiHaQW>F<HIcT076<H00=W
>F<HIcT06F<H00UW>F<HIcUS66LiHaQW>F<HIcT07f<H00EW>F<HIcUS66Li
01US6005IcUS66LiHaQW>@04HaP016LiHaQS67oo0f<H00=W>F<HHaP01f<H
00=24000Ool00V<H00<006<HHaP00V<H00<006<HIcT00f<H00E24000HaQS
67oo00AS6080009S608000=S6008@Q0006<HHaQW>F<H@Q00005cW00000=W
>GooHaP00V<H00AW>F<HIcTmk`A]S0=S6003IcU]S6<H009S6005IcUS6248
HaQW>@05HaP02P00HaQW>F<HIcUS6000HaP006<H1@0000QS66LiHaQW>F<H
IcUS66Li0f<H00=W>F<H00001V<H00T006<HHaQS6000HaP006<H00001F<H
00EW>F<HIcUS66Li00AS6005IcUS6000HaQW>@02HaP01000HaQS66<H1000
00=S6000HaP00V<H00=W>F<H000010000f<H00EW>F<HIcUS66Li00=S6003
IcUS6000009S6007IcUS66<HHaP006<H00000f<H00<006<H000016<H00EW
>F<HIcUS66Li00=S6006IcUS66<H001S60000f<H00<006<H00001000019S
6000HaP006<H001S6000HaQW>F<HIcUS66LiHaQW>F<HIcT2HaP016LiHaQS
600016<H00L006<HHaQS6000HaP00003HaP00`00HaP00002HaP03000HaQS
66LiHaQW>F<HIcUS66LiHaQW>@ES6007001S6000HaP006<H00000f<H00T0
06<H001S66LiHaP006<H00000f<H00<006<H00000f<H00/006<H001S6000
HaP006<H001S66Li00ES6003IcUS66Li00=S6003001S66<H009S6003001S
66<H00D00004HaP006Li0003HaP00`00HaQS6004HaP07FLiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcT01F<H01mW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@05HaP06fLiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@04HaP0
6fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>@03HaP08fLiHaQS66<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H
01UW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>@05HaP00fLiHaQW>@02HaP00fLiHaQoo`0:HaP02FLiHaQS648@
001oofLiHaP00004HaP30003HaP01D8@001S66<HOol01F<H10000f<H00=W
>D8@000016<H0D8@0@000GNm000016<HOomS66Li16<H00Lmkf<HHaQS65h@
KHaW>@02HaP00ff<F]IW>@03HaP01R48IcUS66LiHaQW>@9S60@0009S6005
001S6000HaP00003HaP00`00HaQS6007HaP016LiHaQS66<H100000EW>F<H
HaP006Li009S6005001S6000HaP00002HaP02fLiHaQW>F<HIcUS66LiHaQW
>F<HIcT00f<H00<006<HHaP00V<H00<006<HHaP00V<H00EW>F<H001W>@00
00=S6003001S600000=S6008001S66<HIcUS66LiHaQW>@9S6004IcUS66<H
HaP50002HaP00`00HaP00003HaP02`00HaP006<HIcUS66LiHaQW>F<HIcT0
0V<H00EW>F<HHaQS600000=S600<001S66<H001S6000HaQW>F<H001S6000
0V<H00@006<HHaP000YS6003IcUS66<H009S6006001S66<HIcUS60000f<H
00<006<H00000f<H00D006<H001S6000009S600?001S66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS600000=S6005001S66<HHaP00002HaP01000HaP00000
0V<H00<006<H00000f<H00<006<H00000f<H00<006<H00000V<H00@006<H
HaP0009S6005IcUS66LiHaQW>@06HaP60002HaP02@00HaQW>F<H001S6000
HaP00003HaP01`00HaQW>F<HIcUS66Li01MS600;IcUS66LiHaQW>F<HIcUS
66LiHaQW>@0OHaP01FLiHaQW>F<HIcT076<H00=W>F<HIcT06F<H00UW>F<H
IcUS66LiHaQW>F<HIcT07f<H00EW>F<HIcUS66Li01US6009IcUS66LiHaQW
>F<HIcUS66Li00=S6004OomS66<HIcT3HaP00fLiHaQW>@02HaP01FLiHaQ2
4000Ool00V<H1P0000MS6000HaQW>F<H@Q000002HaP017ooHaQS66Li0f<H
0P001F<H00Q24000HaQS66LiHaQ240000G>L00000fLiOomS6002HaP01VLi
HaQS63g_HaQW>@9S609VDP03HaQW>Ff<00=S6003IcUS624800MS6003001S
66Li00=S6003001W>@00009S60<0009S6007IcUS66LiHaQW>F<HIcT01F<H
00<006<HIcT01F<H100000=S6000HaP00P001V<H00=W>F<HIcT016<H00=W
>F<H00000V<H00AW>F<H0000009S60<000=S60<000=S60<000AS6005IcUS
66LiHaQW>@05HaP00`00HaQW>@02HaP00`00HaP00002HaP30002HaP20005
HaP00fLiHaQW>@03HaP00fLiHaP00003HaP01P00HaQS6000IcUS60<00003
HaQW>@00009S6004001S66<H0002HaP01fLiHaQW>F<HIcUS66Li00=S6004
IcUS66<H0005HaP30003HaP30002HaP00`00HaQS60020005HaP01FLiHaQW
>F<HIcT016<H00D006<HHaQS600000=S6007001S66<H001S6000HaP00P00
0f<H10000V<H0`000V<H00@006<HHaP0009S6003001S66<H00ES6009IcUS
66LiHaQW>F<H001S66Li009S6004001S66<HHaP3000016<HIcT006<H1000
1f<H01eW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66Li00ES600OIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H
01]W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT016<H01]W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00f<H02=W>F<HHaQS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66Li00ES600IIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H00EW>F<HIcUS66Li009S6005
OomS66<HHaQW>@05HaP01fLiHaQS66<H@Q0007oo009S60H00003HaP006<H
009S6005@Q0006<HHaQoo`05HaP40002HaP016LiHaQ2400016<H0D8@0@00
0G>L000016<HOomS66Li0f<H00eW>Cg_HaQS66LiF]IS67C6HaQ]S6IBF]IW
>@03HaP01R48HaQS66LiHaQW>@9S6003001S66<H00ES6003001S66<H00IS
6009IcUS66LiHaQW>F<HIcUS66Li009S6003001S66<H00=S600:IcUS66<H
IcUS6000IcUS66Li0004HaP02FLiHaQW>F<HIcUS66LiHaQW>@03HaP00`00
HaQS6006HaP016LiHaQS66Li3V<H00EW>F<HIcUS66Li00=S6004IcUS66<H
0004HaP00`00HaP00007HaP01`00HaQS66<HIcUS66Li00AS6005IcUS66<H
HaP00003HaP00`00HaQS6003HaP00fLiHaQS600BHaP00fLiHaQW>@03HaP0
1000IcUS66Li3F<H00<006<HHaP016<H00eW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaP00003HaP01@00HaQS66<H000036<H00=W>F<H000046<H00EW>F<H
IcUS66Li00IS6003001S66<H009S6003001S66<H00IS6003001S66<H00MS
6003IcUS66Li01MS600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@0OHaP01FLi
HaQW>F<HIcT076<H00=W>F<HIcT06F<H00UW>F<HIcUS66LiHaQW>F<HIcT0
7f<H00EW>F<HIcUS66Li01US6007IcUS66LiHaQW>F<HIcT01F<H00=oof<H
IcT00f<H00=W>F<HIcT00f<H00EW>F<H@Q0007oo00AS6006001S66<HIcUS
60000f<H00E24000HaQS67oo009S6004IcUS60000002HaP20003HaP0248@
001S66<HIcUS648@0001Mkd00003IcUoof<H009S6006IcUS66<H?NmJeV<H
0U[F00AW>E[FIDYVDP9JeP0=HaQJeU[FHaPQ26<HIcUS66LiHaQW>F<H0000
0f<H00EW>F<HHaQS600000IS6003IcUS66<H009S6003IcUS66Li00ES6005
001S66<HHaQW>@06HaP01@00HaQS66<H00000V<H00=W>F<HHaP00V<H00=W
>F<HIcT016<H00EW>F<H001S66Li009S6003IcUS66<H015S6003IcUS66<H
009S6009IcUS66LiHaQW>F<HIcUS600000AS6003001S600000MS6003001S
66<H00AS6003IcUS66Li00=S6005IcT006<HHaQW>@02HaP00`00HaQS600;
HaP036LiHaQS66LiHaQW>F<HIcUS66LiHaQW>@=S6004IcUS66<H0004HaP0
0fLiHaQS6002HaP00fLiHaQS6004HaP00`00HaQS6002HaP00fLiHaQS6004
HaP00fLiHaQW>@03HaP00`00HaQS6004HaP016LiHaQS600026<H00=W>F<H
HaP00V<H00<006<HHaP00f<H00=W>F<HHaP00f<H00AW>F<HHaQW>@IS6003
IcUS66Li00=S6003001S66<H009S6003001S66<H00IS6003001S66<H00AS
6003IcUS66Li00=S600MIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@05HaP07fLiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66Li00ES600KIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66Li00AS600KIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00=S600SIcUS
66<HHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>@05HaP06FLiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00ES6005IcUS66Li
HaQW>@02HaP01GooHaQS66<HIcT016<H00=W>F<HHaP00V<H00A24000OomW
>@=S60H000=S6005@Q0006<HHaQoo`03HaP2000016<HIcUS66Li0P000V<H
00=24000HaP00f<H0D8@0@000G>L00001F<HOomS66<HIcT00f<H00@mkf<H
HaQW>@US6006IcUS6248IcUS66Li16<H1@0000AS6000HaP000AS600=IcUS
66<HHaQW>F<HIcUS66LiHaQW>F<HIcT00V<H1@000V<H00MW>F<HHaQS6000
HaP00006HaP01FLiHaQW>F<HIcT00V<H00=W>F<HHaP01@0000MW>F<HHaQS
66LiHaQW>@04HaP01fLiHaQW>F<HIcUS66Li009S6009IcUS66<HHaQW>F<H
IcUS66Li00IS60D0009S6006001S66<HIcUS66Li1V<H00=W>F<HIcT016<H
00AW>F<HHaP000ES6004001S6000IcT6HaP00fLiHaQW>@03HaP00fLiHaQS
6008HaP00fLiHaQS600500000fLiHaQS6002HaP02VLiHaQS66LiHaQW>F<H
IcUS60000V<H00=W>F<HHaP00f<H00EW>F<HIcUS66Li009S6003IcUS6000
009S6003IcUS66Li00AS6008001S6000IcUS66LiHaQW>@IS6005001S66Li
HaQW>@03HaP00fLiHaQW>@02HaP02FLiHaQS66<HIcUS66LiHaQW>@03HaP0
16LiHaQS600016<H00L006<HIcUS66LiHaQW>@02HaP00`00HaQS6003HaP0
1fLiHaQS66<HIcUS66Li01MS600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@0O
HaP01FLiHaQW>F<HIcT076<H00=W>F<HIcT06F<H00UW>F<HIcUS66LiHaQW
>F<HIcT07f<H00EW>F<HIcUS66Li01US6007IcUS66LiHaQW>F<HIcT01F<H
00=oof<HIcT00f<H00]W>F<HIcUS66LiHaQW>F<H@Q0007oo00AS60H000=S
6007@Q0006<HHaQoof<HIcT02f<H00Q24000HaQS66LiHaQ240000G>L0000
0fLiOomS6003HaP02FLiHaPmkf<HIcUS65[FHaQW>@02HaP00fLiF]IW>@03
HaP01B48HaQS66<HIcT03F<H00=W>F<HHaP00V<H00=W>F<HHaP00V<H00=W
>F<HIcT00f<H00=W>F<HHaP01F<H00=W>F<HHaP026<H00=W>F<HHaP00f<H
00=W>F<HIcT02f<H00=W>F<HHaP00f<H00=W>F<HHaP01f<H00EW>F<HHaQS
66Li00AS6005IcUS66LiHaQW>@0AHaP016LiHaQS66Li16<H00=W>F<HIcT0
1V<H00=W>F<HIcT01V<H00=W>F<HIcT01F<H00=W>F<HHaP00V<H00]W>F<H
IcUS66LiHaQW>F<HIcUS66Li00QS6003IcUS66<H00eS6005IcUS66LiHaQW
>@03HaP00fLiHaQW>@05HaP00fLiHaQS6002HaP00fLiHaQS6008HaP00fLi
HaQW>@08HaP00fLiHaQS6007HaP00fLiHaQS6004HaP01FLiHaQW>F<HIcT0
0f<H00=W>F<HHaP02f<H00=W>F<HIcT00f<H00=W>F<HHaP00V<H01eW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66Li00ES600OIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H01]W>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcT016<H01]W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcT00f<H02=W>F<HHaQS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66Li00ES600IIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcT01F<H00EW>F<HIcUS66Li009S6005OomS66<HHaQW
>@04HaP00fLiHaQS6002HaP00d8@001oo`0;HaP016LiHaQ240000V<H00=o
of<HHaP02V<H00=W>D8@000016<H0D8@0@000GNm00001F<HOomS66<HIcT0
0f<H00E246<HHaQS65[F009S6004IcUS66<HF]H2HaP00fLiHaPQ2002HaP0
1FLiHaQW>F<HIcT02f<H00=W>F<HIcT00f<H00EW>F<HIcUS66Li009S6003
IcUS66<H00]S6003IcUS66<H00=S6007IcUS66LiHaQW>F<HIcT016<H00=W
>F<HIcT02F<H00=W>F<HIcT00f<H00MW>F<HIcUS66LiHaQW>@03HaP02FLi
HaQS66<HIcUS66LiHaQW>@04HaP00fLiHaQS6007HaP01FLiHaQW>F<HIcT0
0V<H00MW>F<HHaQS66LiHaQW>@05HaP016LiHaQS66Li16<H00AW>F<HHaQW
>@ES6003IcUS66Li00=S6003IcUS66Li01ES6009IcUS66LiHaQW>F<HIcUS
66Li009S6003IcUS66Li00ES6003IcUS66Li00AS6003IcUS66Li00AS6007
IcUS66<HHaQW>F<HIcT00V<H00=W>F<HIcT016<H00=W>F<HIcT00f<H00]W
>F<HHaQS66LiHaQW>F<HIcUS66Li00=S6005IcUS66LiHaQW>@06HaP016Li
HaQS66Li0V<H00YW>F<HHaQW>F<HIcUS66LiHaQW>@ES6006IcUS66<HIcUS
66Li5f<H00]W>F<HIcUS66LiHaQW>F<HIcUS66Li01mS6005IcUS66LiHaQW
>@0LHaP00fLiHaQW>@0IHaP02FLiHaQW>F<HIcUS66LiHaQW>@0OHaP01FLi
HaQW>F<HIcT06F<H00MW>F<HIcUS66LiHaQW>@05HaP?Ool00`00Oomoo`0=
Ool00`00HaQS600?Ool01`00HaQS66LiHaQ24000005cW00000=W>GooHaP0
0V<H00MW>F<HHaPLicg_@Q0mk`02@Q02?Nl2@Q000cg_@Q0mk`02?Nl00a24
HaQS6006HaP026LiHaQS66LiHaQW>F<HIcT5HaP00fLiHaQS6003HaP00fLi
HaQW>@03HaP00fLiHaQW>@02HaP01fLiHaQW>F<HIcUS66Li009S6003IcUS
66Li00QS6003IcUS66Li00ES6006IcUS66<HIcUS66Li1F<H00=W>F<HHaP0
1f<H00EW>F<HHaQS66Li00ES6005IcUS66LiHaQW>@03HaP01VLiHaQS66Li
HaQW>@]S6003IcUS66<H009S6007IcUS66LiHaQW>F<HIcT00f<H00=W>F<H
HaP00V<H00AW>F<HHaQW>@9S6005IcUS66<HHaQW>@05HaP02fLiHaQW>F<H
IcUS66LiHaQW>F<HIcT00V<H00IW>F<HHaQW>F<HIcT;HaP00fLiHaQS6002
HaP01FLiHaQW>F<HIcT00f<H00=W>F<HIcT016<H00=W>F<HIcT00f<H00=W
>F<HHaP00f<H00=W>F<HHaP00V<H00=W>F<HHaP00f<H00EW>F<HIcUS66Li
00US6003IcUS66<H00ES6005IcUS66LiHaQW>@06HaP016LiHaQS66Li1f<H
00MW>F<HIcUS66LiHaQW>@04HaP07FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H01mW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>@05HaP06fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@04HaP06fLiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@03
HaP08fLiHaQS66<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H01UW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@05HaP0
1FLiHaQW>F<HIcT04f<H00UW>F<HIcUS66LiHaQW>F<HIcT076<H0D8@0@00
0G>L000016<HOomS66Li0f<H00=W>F<HHaP03V<H00MW>F<HIcUS66LiHaQW
>@03HaP00fLiHaQS6005HaP02fLiHaQW>F<HIcUS66LiHaQW>F<HIcT00f<H
00=W>F<HHaP00V<H00=W>F<HHaP02f<H00MW>F<HIcUS66LiHaQW>@04HaP0
0fLiHaQW>@02HaP00fLiHaQS6002HaP06fLiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@04HaP01FLiHaQS
66<HIcT016<H00UW>F<HIcUS66LiHaQW>F<HIcT00f<H00=W>F<HIcT02F<H
00EW>F<HHaQS66Li00IS600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@0;HaP0
0fLiHaQS6006HaP02FLiHaQW>F<HIcUS66LiHaQW>@03HaP00fLiHaQW>@05
HaP00fLiHaQW>@04HaP00fLiHaQW>@04HaP01fLiHaQS66<HIcUS66Li00=S
6003IcUS66Li00=S6003IcUS66Li00=S600CIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcT01f<H00=W>F<HIcT00f<H00UW>F<HIcUS
66LiHaQW>F<HIcT026<H00=W>F<HIcT05f<H00]W>F<HIcUS66LiHaQW>F<H
IcUS66Li01mS6005IcUS66LiHaQW>@0LHaP00fLiHaQW>@0IHaP02FLiHaQW
>F<HIcUS66LiHaQW>@0OHaP01FLiHaQW>F<HIcT06F<H00eW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@0QHaP00fLiHaQS600=HaP01VLiHaQW>F<H@Q00
005g_@0000=W>GooHaP00V<H00EW>F<HHaQS66Li00YS6003IcUS66<H00QS
6003IcUS66<H009S6005IcUS66LiHaQW>@04HaP00fLiHaQS6003HaP02FLi
HaQW>F<HIcUS66LiHaQW>@03HaP02fLiHaQW>F<HIcUS66LiHaQW>F<HIcT0
26<H00=W>F<HIcT026<H00=W>F<HIcT01F<H00=W>F<HHaP01f<H00EW>F<H
HaQS66Li00ES6005IcUS66LiHaQW>@03HaP01FLiHaQS66<HIcT02f<H00=W
>F<HHaP00f<H01=W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>@06HaP00fLiHaQS6003HaP04fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66Li00YS6003IcUS66<H00=S6005IcUS66LiHaQW>@03
HaP00fLiHaQW>@04HaP00fLiHaQW>@03HaP00fLiHaQS6002HaP00fLiHaQS
6003HaP00fLiHaQW>@03HaP01FLiHaQW>F<HIcT02F<H00=W>F<HHaP01F<H
00]W>F<HIcUS66LiHaQW>F<HIcUS66Li00]S6007IcUS66LiHaQW>F<HIcT0
16<H01eW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66Li00ES600OIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H
01]W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT016<H01]W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00f<H02=W>F<HHaQS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66Li00ES600IIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H00EW>F<HIcUS66Li00=S600=
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT03F<H00MW>F<HIcUS66LiHaQW
>@02HaP02fLiHaQW>F<HIcUS66LiHaQW>F<HIcT01f<H0D8@0@000G>L0000
16<HOomS66<Ho`0@o`0@>00@00AW>F<H@Q00005cW00000AW>GooHaQS6080
400348@Q224800XQ2003<H`0400@0?l04?l042H0409S60524040005g_@00
00AS67ooHaQW>@804003?NMokgo_00Yok`038@P0400@0?l04?4042000080
41000080409S60524040005cW00000AW>GooHaQS6080408mi`04Onlmigo_
?NL7Onl00b480100400`0103Oom40103Oooo011g01000goo@Q12400<@Q00
0`00Oom2400=@Q001000010047oo3T8@00L0000@011S66Li@Q000001Li`0
0004HaQoof<HHaP20106?NL00acP?NL]H004?NL00b480100400`0102Oom6
0102Oooo011g01000gooHaQW>@02HaP016LiHaQS66Li0V<H00IW>F<HHaQ2
4000Ool9HaP01VLiHaQW>F<H@Q0000804005OomW>F<HHaQW>@02HaP016Li
HaQS66Li0f<H00A240000100409S60524040005g_@0000AW>GooHaQS6080
400;7>1NicgPG^Lmh5kWOnmNkbU:<H1_K`02Onl00b48010040030102Ool6
0102Ool30104Ool20105Ool30104Ool>0102Ool30105Ool20102Ool40102
Ool20102Ool70102Ool40102Ool30102Ool20105Ool30102Ool40102Ool3
0102Ool50102Oooo011g010017ooIcUS66<H1P0016<H00E24000OomW>F<H
00T0009S6005@Q00000@011oo`0=HaP0248@0000400@HaQW>D8@0001Li`0
0004HaQoof<HHaP201001AcWOnm>IekW?NL00ekW00<YATYB<H000UkW00<0
048@@Q000`0@0Woo1P0@0Woo0P0@0Woo0P0@0Woo00<047ooOol00P0@0Woo
00<047ooOol00P0@0Woo3@0@0Woo0P0@0Woo0`0@0Woo00<047ooOol0100@
0Woo0P0@0Woo1`0@0Woo100@0Woo1`0@0Woo0P0@0Woo0P0@0Woo100@0Woo
0`0@0Woo1@0@0Wooo`0@M`0@00Aoof<HHaQS60H000AS6003@Q0007oo009S
6003001S66<H00ES6005001S66<H@Q000002010017ooHaQS66<H0P0000AS
66LiHaQS60800004IcUS648@00020102HaP1@Q010001Li`00004IcUoof<H
HaP201000cgWOnlLi`06?Nl00gNmE[Dmk`02?Nl00acW@Q0040020102Ool6
0102Ool20102Ool20102Ool00`0@Oomoo`020102Ool00`0@Oomoo`0A0102
Ool20102Ool30102Ool20106Ool30102Ool40106Ool30102Ool70102Ool3
0102Ool20106Ool40102Ool50102Oooo011g01000gooHaQS6009HaP01FLi
HaQ24000Ool00V<H00<006<HHaP01F<H00D006<HHaQ2400000804005OomS
66<HIcUS60020002HaP20003HaP0148@0000400@0V<H0D8@0@000G>L0000
16<HOomS66<H0P0@00Hmigo_?NlLicg_;F/2?Nl00be[?Nl]J`04?Nl0148@
0100400@0Woo1P0@0Woo0P0@0Woo0P0@0Woo00<047ooOol00P0@0Woo00<0
47ooOol017oo1@0@0goo1@0@0Woo0P0@0Woo0`0@0Woo0P0@0Woo0P0@0Woo
100@0Woo0`0@0Woo00<047ooOol0100@0Woo1`0@0Woo0`0@0Woo0P0@0Woo
0P0@0Woo100@0Woo1@0@0Wooo`0@M`0@00=oof<HHaP01f<H00MW>F<HHaQS
648@001oo`02HaP00`00HaQS6005HaP01@00HaQS648@00000P0@00=oof<H
HaP00f<H100016<H00Q24000010046LiHaQ240000GNm000016LiOomS66<H
0P0@00/migo_?Nlnk`804V@200007>L002480080008mk`04@Q00400@0106
Ool20102Ool20102Ool20102Ool00`0@Oomoo`020102Ool00`0@Oomoo`02
0102Ool=0102Ool20102Ool30102Ool20102Ool20102Ool40102Ool40104
Ool40102Ool70102Ool30102Ool20102Ool20102Ool40102Ool50102Oooo
011g01001GooHaQW>F<HIcT02F<H00I24000OomW>F<H0002HaP00fLiHaQW
>@02HaP01@00HaQS648@00000P0@00Aoof<HHaQW>@=S608000=S6004IcUS
648@00020102HaP1@Q010001Li`00004HaQoof<HHaP2010043gWOnlmkbe[
7>LaS1cW4V@aS1cW<H`Q21cWCW<mkd8@0`0@0Woo0`0@0Woo00@047ooOomo
o`8040Aoo`8040Eoo`<040Aoo`h0409oo`80409oo`<0409oo`<040Aoo`H0
409oo`<040Aoo`@0409oo`L0409oo`<0409oo`<040Aoo`D0409oo`D0409o
ool047L04003OomS66<H00ES6004IcUS66<HIcT2HaP00d8@001oo`02HaP0
0`00IcUS6005HaP01@00HaQS648@00000P0@00=oofLiHaP00f<H100016<H
00A240000100409S60524040005cW00000AW>GooHaQS6080400;?NMokcg_
?Nl002480000h15T000Li`020002?Nl0148@0100400@0Woo0`0@0Woo300@
0Woo600@0Woo0P0@0Woo0`0@0Woo0`0@17oo1P0@0Woo100@0goo100@0Woo
1`0@0Woo0`0@0Woo0`0@17oo1@0@0Woo1@0@0Wooo`0@M`0@00Qoof<HHaQW
>F<HIcUS66Li0V<H00MW>F<HHaQS648@001oo`02HaP00`00HaQS6004HaP0
1VLi001S66<H@Q0000804003OomS66<H009S6080009S608000=S6004@Q00
000@0102HaP1@Q010001Li`00004HaQoof<HHaP201001SgWOnlmkcg_000L
i`8000030N0002480080008mk`04@Q00400@0102Ool30102Ool<0102OolH
0102Ool20102Ool30102Ool40102Ool80102Ool30103Ool20104Ool70102
Ool20102Ool50102Ool60102Ool50102Oooo011g01000gooHaQS600:HaP0
16Li@Q0007oo0V<H2@000V<H00E24000010047oo00=S60800004HaQW>F<H
HaP2000016LiHaQ240000P0@00AW>F<H@Q00005cW00000AW>GooHaQS6080
400@?NMokcg_;F/Lic6<8@PLia9T7>LQj07P7>M>Lcg_@Q030106Ool=0102
OolH0103Ool00`0@Oomoo`030102Ool40102Ool40106Ool40102Ool40102
Ool70105Ool60102Ool40106Ool20103Oooo011g01002gooHaQW>F<HIcUS
66LiHaQW>F<HIcT00f<H00E24000OomW>F<H00T0009S6007@Q00000@011o
of<HIcT02f<H00A240000100409S60524040005cW00000AS67ooHaQS6080
4080008mk`0<000Q2000000Qj07P8NP00080?^lmkd8@o`0@l@0@00=oof<H
HaP02F<H00EW>F<H@Q0007oo00eS6005@Q00000@011oo`0=HaP0148@0000
400@0V<H0D8@0@000GNm000016LiOomS66<H100@00@mkacW000Li`800003
7>L001cW0080008mk`03@Q00400@0?l04>l040moo`03001oogoo00eoo`03
0000400@00moo`030000400@009S60524040005cW00000AS67ooHaQS60@0
40037>Lmkcg_00<mk`03@Q0mkcg_00<mk`037>L@Q00@0?l04?l042D04004
IcUS648@0001Li`00004IcUoof<HHaSo013o010h0102HaP1@Q010001Li`0
0003HaQoofLi0?mS6?mS63]S60524040005g_@0000=W>GooHaP016<H00=W
>F<HIcT00f<H00=W>F<HIcT0:6<H00=W>F<HHaP0of<Hof<H0F<H00AW>F<H
@Q00005cW00000=S67ooOol0ogooogoo>goo0D8@0@000G>L0000=fLiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66Li0?mS6?mS60QS6040005cW000\
\>"], "Picture",
  ImageSize->{575, 425},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Import Data from PSpice", "ExampleSection"],

Cell["Import Schematics", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DXFGraphics["\<op_741.dxf\>", 
      \[IndentingNewLine]TextStyle\  \[Rule] 
        \ {FontSize \[Rule] 10, FontColor\  \[Rule] \ RGBColor[1, 0, 0], 
          FontWeight \[Rule] "\<Bold\>"}, 
      \[IndentingNewLine]ColorList\  \[Rule] 
        \ {RGBColor[0, 0, 0]}\[IndentingNewLine]]; \)\)], "Input",
  CellTags->"IDH_DXFGRAPHICS"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .471 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 1 r
MFill
% Scaling calculations
-0.374221 0.117068 -0.489629 0.117068 [
[.08586 .31559 0 -2.6 ]
[.08586 .31559 45.125 10.4 ]
[.05308 .32144 0 -2.6 ]
[.05308 .32144 15.75 10.4 ]
[.18104 .31325 -45.125 -2.6 ]
[.18104 .31325 0 10.4 ]
[.23212 .32379 -15.75 -2.6 ]
[.23212 .32379 0 10.4 ]
[.02966 .25237 0 -2.6 ]
[.02966 .25237 45.125 10.4 ]
[.09756 .26057 0 -2.6 ]
[.09756 .26057 15.75 10.4 ]
[.23489 .25237 -45.125 -2.6 ]
[.23489 .25237 0 10.4 ]
[.18764 .26291 -15.75 -2.6 ]
[.18764 .26291 0 10.4 ]
[.04992 .11423 -45.125 -2.6 ]
[.04992 .11423 0 10.4 ]
[.10335 .12243 -15.75 -2.6 ]
[.10335 .12243 0 10.4 ]
[.21697 .1236 0 -2.6 ]
[.21697 .1236 45.125 10.4 ]
[.18185 .12243 0 -2.6 ]
[.18185 .12243 15.75 10.4 ]
[.11863 .1634 0 -2.6 ]
[.11863 .1634 45.125 10.4 ]
[.0882 .16691 0 -2.6 ]
[.0882 .16691 15.75 10.4 ]
[.17951 .36008 0 -2.6 ]
[.17951 .36008 45.125 10.4 ]
[.17951 .37764 0 -2.6 ]
[.17951 .37764 15.75 10.4 ]
[.05776 .04048 0 -2.6 ]
[.05776 .04048 15.75 10.4 ]
[.05893 .05219 0 -2.6 ]
[.05893 .05219 15.75 10.4 ]
[.18887 .04282 0 -2.6 ]
[.18887 .04282 15.75 10.4 ]
[.19005 .05453 0 -2.6 ]
[.19005 .05453 15.75 10.4 ]
[.14439 .04282 0 -2.6 ]
[.14439 .04282 21.625 10.4 ]
[.15258 .05453 0 -2.6 ]
[.15258 .05453 15.75 10.4 ]
[.27235 .36008 -45.125 -2.6 ]
[.27235 .36008 0 10.4 ]
[.293 .37764 -15.75 -2.6 ]
[.293 .37764 0 10.4 ]
[.2864 .11189 -45.125 -2.6 ]
[.2864 .11189 0 10.4 ]
[.32867 .13414 -21.625 -2.6 ]
[.32867 .13414 0 10.4 ]
[.38789 .11658 0 -2.6 ]
[.38789 .11658 45.125 10.4 ]
[.36214 .13414 0 -2.6 ]
[.36214 .13414 21.625 10.4 ]
[.29424 .04282 0 -2.6 ]
[.29424 .04282 15.75 10.4 ]
[.29541 .05453 0 -2.6 ]
[.29541 .05453 15.75 10.4 ]
[.40194 .36008 0 -2.6 ]
[.40194 .36008 45.125 10.4 ]
[.40194 .37764 0 -2.6 ]
[.40194 .37764 21.625 10.4 ]
[.51819 .36008 -45.125 -2.6 ]
[.51819 .36008 0 10.4 ]
[.53058 .37764 -27.5 -2.6 ]
[.53058 .37764 0 10.4 ]
[.62121 .36944 -45.125 -2.6 ]
[.62121 .36944 0 10.4 ]
[.57507 .387 -27.5 -2.6 ]
[.57507 .387 0 10.4 ]
[.35745 .29803 0 -2.6 ]
[.35745 .29803 21.625 10.4 ]
[.36565 .30974 0 -2.6 ]
[.36565 .30974 15.75 10.4 ]
[.8468 .339 0 -2.6 ]
[.8468 .339 45.125 10.4 ]
[.80699 .3472 0 -2.6 ]
[.80699 .3472 21.625 10.4 ]
[.77808 .30388 -45.125 -2.6 ]
[.77808 .30388 0 10.4 ]
[.82036 .3191 -21.625 -2.6 ]
[.82036 .3191 0 10.4 ]
[.53071 .1517 0 -2.6 ]
[.53071 .1517 45.125 10.4 ]
[.49091 .15755 0 -2.6 ]
[.49091 .15755 21.625 10.4 ]
[.56349 .11658 0 -2.6 ]
[.56349 .11658 45.125 10.4 ]
[.5354 .13414 0 -2.6 ]
[.5354 .13414 21.625 10.4 ]
[.8187 .27462 0 -2.6 ]
[.8187 .27462 15.75 10.4 ]
[.82221 .28632 0 -2.6 ]
[.82221 .28632 15.75 10.4 ]
[.82104 .21374 0 -2.6 ]
[.82104 .21374 15.75 10.4 ]
[.81987 .22779 0 -2.6 ]
[.81987 .22779 15.75 10.4 ]
[.53071 .04282 0 -2.6 ]
[.53071 .04282 21.625 10.4 ]
[.53891 .05453 0 -2.6 ]
[.53891 .05453 15.75 10.4 ]
[.49793 .04048 0 -2.6 ]
[.49793 .04048 21.625 10.4 ]
[.50613 .05219 0 -2.6 ]
[.50613 .05219 15.75 10.4 ]
[.69227 .21608 0 -2.6 ]
[.69227 .21608 21.625 10.4 ]
[.68992 .24301 0 -2.6 ]
[.68992 .24301 21.625 10.4 ]
[.77655 .03814 0 -2.6 ]
[.77655 .03814 21.625 10.4 ]
[.78007 .04985 0 -2.6 ]
[.78007 .04985 21.625 10.4 ]
[.24975 .13414 0 -2.6 ]
[.24975 .13414 21.625 10.4 ]
[.24741 .1634 0 -2.6 ]
[.24741 .1634 21.625 10.4 ]
[.67588 .29218 0 -2.6 ]
[.67588 .29218 45.125 10.4 ]
[.6431 .29803 0 -2.6 ]
[.6431 .29803 21.625 10.4 ]
[.72973 .26876 0 -2.6 ]
[.72973 .26876 45.125 10.4 ]
[.68992 .27696 0 -2.6 ]
[.68992 .27696 21.625 10.4 ]
[.86471 .15872 -45.125 -2.6 ]
[.86471 .15872 0 10.4 ]
[.82036 .16691 -21.625 -2.6 ]
[.82036 .16691 0 10.4 ]
[.75548 .19384 0 -2.6 ]
[.75548 .19384 45.125 10.4 ]
[.78358 .2114 0 -2.6 ]
[.78358 .2114 21.625 10.4 ]
[.60248 .04399 -45.125 -2.6 ]
[.60248 .04399 0 10.4 ]
[.65646 .05219 -21.625 -2.6 ]
[.65646 .05219 0 10.4 ]
[.45029 .08146 -45.125 -2.6 ]
[.45029 .08146 0 10.4 ]
[.50662 .08731 -21.625 -2.6 ]
[.50662 .08731 0 10.4 ]
[.4394 .2114 0 -2.6 ]
[.4394 .2114 21.6875 10.4 ]
[.44057 .22545 0 -2.6 ]
[.44057 .22545 15.75 10.4 ]
[.74999 .14935 -45.125 -2.6 ]
[.74999 .14935 0 10.4 ]
[.70618 .17628 -27.5 -2.6 ]
[.70618 .17628 0 10.4 ]
[.64697 .14935 -45.125 -2.6 ]
[.64697 .14935 0 10.4 ]
[.65936 .16691 -27.5 -2.6 ]
[.65936 .16691 0 10.4 ]
[.9619 .35808 -4.375 -2.2125 ]
[.9619 .35808 4.375 8.85 ]
[.9619 .34403 -4.375 -2.2125 ]
[.9619 .34403 4.375 8.85 ]
[.97619 .36476 -8.03125 -2.6 ]
[.97619 .36476 8.03125 10.4 ]
[.9619 .08882 -4.375 -2.2125 ]
[.9619 .08882 4.375 8.85 ]
[.9619 .07478 -4.375 -2.2125 ]
[.9619 .07478 4.375 8.85 ]
[.97619 .0955 -8.03125 -2.6 ]
[.97619 .0955 8.03125 10.4 ]
[.0319 .34355 -4.375 -2.2125 ]
[.0319 .34355 4.375 8.85 ]
[.0319 .3576 -4.375 -2.2125 ]
[.0319 .3576 4.375 8.85 ]
[.05576 .36476 -11.0313 -2.6 ]
[.05576 .36476 11.0313 10.4 ]
[.07429 .44653 -2.2125 -4.375 ]
[.07429 .44653 8.85 4.375 ]
[.06024 .44653 -2.2125 -4.375 ]
[.06024 .44653 8.85 4.375 ]
[.10025 .45022 -10.9688 -2.6 ]
[.10025 .45022 10.9688 10.4 ]
[.89362 .24418 0 -2.6 ]
[.89362 .24418 15.75 10.4 ]
[.88894 .26642 0 -2.6 ]
[.88894 .26642 21.625 10.4 ]
[.28942 .44963 -8.85 -4.375 ]
[.28942 .44963 2.2125 4.375 ]
[.30346 .44963 -8.85 -4.375 ]
[.30346 .44963 2.2125 4.375 ]
[.27585 .45256 -10.9688 -2.6 ]
[.27585 .45256 10.9688 10.4 ]
[.33287 .43968 0 -2.6 ]
[.33287 .43968 9.875 10.4 ]
[.94162 .23598 0 -2.6 ]
[.94162 .23598 9.875 10.4 ]
[.89948 .28081 0 -2.2125 ]
[.89948 .28081 9.0625 8.85 ]
[.32584 .21959 0 -2.6 ]
[.32584 .21959 9.875 10.4 ]
[.19707 .16457 0 -2.6 ]
[.19707 .16457 9.875 10.4 ]
[.10927 .10487 0 -2.6 ]
[.10927 .10487 15.75 10.4 ]
[.06595 .1634 0 -2.6 ]
[.06595 .1634 9.875 10.4 ]
[.08468 .28866 0 -2.6 ]
[.08468 .28866 9.875 10.4 ]
[.21346 .28866 0 -2.6 ]
[.21346 .28866 9.875 10.4 ]
[.16078 .339 0 -2.6 ]
[.16078 .339 9.875 10.4 ]
[.72036 .41393 0 -2.6 ]
[.72036 .41393 9.875 10.4 ]
[.33755 .14233 0 -2.6 ]
[.33755 .14233 15.75 10.4 ]
[.43823 .33549 0 -2.6 ]
[.43823 .33549 15.75 10.4 ]
[.69695 .34369 0 -2.6 ]
[.69695 .34369 15.75 10.4 ]
[.84562 .31208 0 -2.6 ]
[.84562 .31208 15.75 10.4 ]
[.56935 .24301 0 -2.6 ]
[.56935 .24301 15.75 10.4 ]
[.50379 .1154 0 -2.6 ]
[.50379 .1154 15.75 10.4 ]
[.47218 .15872 0 -2.6 ]
[.47218 .15872 15.75 10.4 ]
[.65598 .23481 0 -2.6 ]
[.65598 .23481 15.75 10.4 ]
[.75197 .17628 0 -2.6 ]
[.75197 .17628 15.75 10.4 ]
[.86084 .26174 0 -2.6 ]
[.86084 .26174 15.75 10.4 ]
[.84562 .19501 0 -2.6 ]
[.84562 .19501 15.75 10.4 ]
[.55413 .01121 0 -2.6 ]
[.55413 .01121 15.75 10.4 ]
[.08468 .0838 0 -2.6 ]
[.08468 .0838 15.75 10.4 ]
[.21346 .0838 0 -2.6 ]
[.21346 .0838 15.75 10.4 ]
[.29541 .07911 0 -2.6 ]
[.29541 .07911 15.75 10.4 ]
[.56466 .09316 0 -2.6 ]
[.56466 .09316 15.75 10.4 ]
[.94864 .26174 0 -2.6 ]
[.94864 .26174 9.875 10.4 ]
[.02849 .30623 0 -2.6 ]
[.02849 .30623 9.875 10.4 ]
[.24156 .45607 0 -2.6 ]
[.24156 .45607 9.875 10.4 ]
[.6232 .09082 0 -2.6 ]
[.6232 .09082 15.75 10.4 ]
[ 0 0 0 0 ]
[ 1 .471 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
%
% $ID: DXFGraphics.m,v 2.13 2000/06/06 16:00:52 thole Exp $
% $ID: DXFGraphics (C) 1998-1999 by M. Thole, ITWM e. V. $
%
% $ID: Created with: $
% $ID:   DXFGraphics[\"op_741.dxf\", TextStyle -> {FontSize -> 10, FontColor \
-> RGBColor[1, 0, 0], FontWeight -> \"Bold\"}, ColorList -> {RGBColor[0, 0, \
0]}] $
% $ID: User: halfmann@TENFORWARD.None $
% $ID: Date: 2000/11/6 14:15:48 $
%
% End of user PostScript
0 0 0 r
0 Mabswid
.08234 .33102 m
.07064 .31931 L
s
.07064 .31931 m
.08234 .3076 L
s
.08 .3158 m
.08 .30994 L
s
.08 .30994 m
.07415 .30994 L
s
.07064 .33102 m
.07064 .3076 L
s
.05893 .31931 m
.07064 .31931 L
s
.08234 .34272 m
.08234 .33102 L
s
.08234 .29589 m
.08234 .3076 L
s
gsave
.08586 .31559 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.05308 .32144 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q1) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.21112 .33102 m
.22282 .31931 L
s
.22282 .31931 m
.21112 .3076 L
s
.21346 .3158 m
.21346 .30994 L
s
.21346 .30994 m
.21931 .30994 L
s
.22282 .33102 m
.22282 .3076 L
s
.23453 .31931 m
.22282 .31931 L
s
.21112 .34272 m
.21112 .33102 L
s
.21112 .29589 m
.21112 .3076 L
s
gsave
.18104 .31325 -106.125 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.23212 .32379 -76.75 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q2) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.08234 .24907 m
.09405 .26077 L
s
.09405 .26077 m
.08234 .27248 L
s
.08468 .26429 m
.09054 .26429 L
s
.09054 .26429 m
.09054 .27014 L
s
.09405 .24907 m
.09405 .27248 L
s
.10576 .26077 m
.09405 .26077 L
s
.08234 .23736 m
.08234 .24907 L
s
.08234 .28419 m
.08234 .27248 L
s
gsave
.02966 .25237 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QPNP741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.09756 .26057 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q3) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.21112 .24907 m
.19941 .26077 L
s
.19941 .26077 m
.21112 .27248 L
s
.20878 .26429 m
.20292 .26429 L
s
.20292 .26429 m
.20292 .27014 L
s
.19941 .24907 m
.19941 .27248 L
s
.1877 .26077 m
.19941 .26077 L
s
.21112 .23736 m
.21112 .24907 L
s
.21112 .28419 m
.21112 .27248 L
s
gsave
.23489 .25237 -106.125 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QPNP741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.18764 .26291 -76.75 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q4) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.08234 .132 m
.09405 .12029 L
s
.09405 .12029 m
.08234 .10859 L
s
.08468 .11678 m
.08468 .11093 L
s
.08468 .11093 m
.09054 .11093 L
s
.09405 .132 m
.09405 .10859 L
s
.10576 .12029 m
.09405 .12029 L
s
.08234 .14371 m
.08234 .132 L
s
.08234 .09688 m
.08234 .10859 L
s
gsave
.04992 .11423 -106.125 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.10335 .12243 -76.75 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q5) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.21112 .132 m
.19941 .12029 L
s
.19941 .12029 m
.21112 .10859 L
s
.20878 .11678 m
.20878 .11093 L
s
.20878 .11093 m
.20292 .11093 L
s
.19941 .132 m
.19941 .10859 L
s
.1877 .12029 m
.19941 .12029 L
s
.21112 .14371 m
.21112 .132 L
s
.21112 .09688 m
.21112 .10859 L
s
gsave
.21697 .1236 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.18185 .12243 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q6) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.11746 .17883 m
.10576 .16712 L
s
.10576 .16712 m
.11746 .15541 L
s
.11512 .16361 m
.11512 .15776 L
s
.11512 .15776 m
.10927 .15776 L
s
.10576 .17883 m
.10576 .15541 L
s
.09405 .16712 m
.10576 .16712 L
s
.11746 .19053 m
.11746 .17883 L
s
.11746 .14371 m
.11746 .15541 L
s
gsave
.11863 .1634 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.0882 .16691 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q7) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.16429 .36614 m
.176 .37784 L
s
.176 .37784 m
.16429 .38955 L
s
.16663 .38135 m
.17249 .38135 L
s
.17249 .38135 m
.17249 .38721 L
s
.176 .36614 m
.176 .38955 L
s
.1877 .37784 m
.176 .37784 L
s
.16429 .35443 m
.16429 .36614 L
s
.16429 .40126 m
.16429 .38955 L
s
gsave
.17951 .36008 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QPNP741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.17951 .37764 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q8) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.08703 .05239 m
.07766 .05591 L
s
.07766 .04186 m
.08703 .04537 L
s
.08703 .04537 m
.07766 .04888 L
s
.07766 .04888 m
.08703 .05239 L
s
.07766 .05591 m
.08703 .05942 L
s
.08234 .03952 m
.07766 .04186 L
s
.08703 .05942 m
.08234 .06176 L
s
.08234 .03835 m
.08234 .03952 L
s
.08234 .07347 m
.08234 .06176 L
s
.08234 .02664 m
.08234 .03835 L
s
gsave
.05776 .04048 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(1) show
68.875000 13.000000 moveto
(k) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.05893 .05219 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(R1) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.2158 .05239 m
.20644 .05591 L
s
.20644 .04186 m
.2158 .04537 L
s
.2158 .04537 m
.20644 .04888 L
s
.20644 .04888 m
.2158 .05239 L
s
.20644 .05591 m
.2158 .05942 L
s
.21112 .03952 m
.20644 .04186 L
s
.2158 .05942 m
.21112 .06176 L
s
.21112 .03835 m
.21112 .03952 L
s
.21112 .07347 m
.21112 .06176 L
s
.21112 .02664 m
.21112 .03835 L
s
gsave
.18887 .04282 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(1) show
68.875000 13.000000 moveto
(k) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.19005 .05453 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(R2) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.18068 .05239 m
.17131 .05591 L
s
.17131 .04186 m
.18068 .04537 L
s
.18068 .04537 m
.17131 .04888 L
s
.17131 .04888 m
.18068 .05239 L
s
.17131 .05591 m
.18068 .05942 L
s
.176 .03952 m
.17131 .04186 L
s
.18068 .05942 m
.176 .06176 L
s
.176 .03835 m
.176 .03952 L
s
.176 .07347 m
.176 .06176 L
s
.176 .02664 m
.176 .03835 L
s
gsave
.14439 .04282 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(50) show
74.750000 13.000000 moveto
(k) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.15258 .05453 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(R3) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.31648 .36614 m
.30477 .37784 L
s
.30477 .37784 m
.31648 .38955 L
s
.31414 .38135 m
.30828 .38135 L
s
.30828 .38135 m
.30828 .38721 L
s
.30477 .36614 m
.30477 .38955 L
s
.29307 .37784 m
.30477 .37784 L
s
.31648 .35443 m
.31648 .36614 L
s
.31648 .40126 m
.31648 .38955 L
s
gsave
.27235 .36008 -106.125 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QPNP741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.293 .37764 -76.75 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q9) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.31648 .132 m
.32819 .12029 L
s
.32819 .12029 m
.31648 .10859 L
s
.31882 .11678 m
.31882 .11093 L
s
.31882 .11093 m
.32467 .11093 L
s
.32819 .132 m
.32819 .10859 L
s
.33989 .12029 m
.32819 .12029 L
s
.31648 .14371 m
.31648 .132 L
s
.31648 .09688 m
.31648 .10859 L
s
gsave
.2864 .11189 -106.125 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.32867 .13414 -82.625 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q10) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.38672 .132 m
.37501 .12029 L
s
.37501 .12029 m
.38672 .10859 L
s
.38438 .11678 m
.38438 .11093 L
s
.38438 .11093 m
.37852 .11093 L
s
.37501 .132 m
.37501 .10859 L
s
.36331 .12029 m
.37501 .12029 L
s
.38672 .14371 m
.38672 .132 L
s
.38672 .09688 m
.38672 .10859 L
s
gsave
.38789 .11658 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.36214 .13414 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q11) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.32116 .05239 m
.3118 .05591 L
s
.3118 .04186 m
.32116 .04537 L
s
.32116 .04537 m
.3118 .04888 L
s
.3118 .04888 m
.32116 .05239 L
s
.3118 .05591 m
.32116 .05942 L
s
.31648 .03952 m
.3118 .04186 L
s
.32116 .05942 m
.31648 .06176 L
s
.31648 .03835 m
.31648 .03952 L
s
.31648 .07347 m
.31648 .06176 L
s
.31648 .02664 m
.31648 .03835 L
s
gsave
.29424 .04282 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(5) show
68.875000 13.000000 moveto
(k) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.29541 .05453 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(R4) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.38672 .36614 m
.39843 .37784 L
s
.39843 .37784 m
.38672 .38955 L
s
.38906 .38135 m
.39491 .38135 L
s
.39491 .38135 m
.39491 .38721 L
s
.39843 .36614 m
.39843 .38955 L
s
.41013 .37784 m
.39843 .37784 L
s
.38672 .35443 m
.38672 .36614 L
s
.38672 .40126 m
.38672 .38955 L
s
gsave
.40194 .36008 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QPNP741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.40194 .37764 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q12) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.56232 .36614 m
.55061 .37784 L
s
.55061 .37784 m
.56232 .38955 L
s
.55998 .38135 m
.55413 .38135 L
s
.55413 .38135 m
.55413 .38721 L
s
.55061 .36614 m
.55061 .38955 L
s
.53891 .37784 m
.55061 .37784 L
s
.56232 .35443 m
.56232 .36614 L
s
.56232 .40126 m
.56232 .38955 L
s
gsave
.51819 .36008 -106.125 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QPNP741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.53058 .37764 -88.5 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q131) show
86.500000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.59744 .36614 m
.58573 .37784 L
s
.58573 .37784 m
.59744 .38955 L
s
.5951 .38135 m
.58925 .38135 L
s
.58925 .38135 m
.58925 .38721 L
s
.58573 .36614 m
.58573 .38955 L
s
.57403 .37784 m
.58573 .37784 L
s
.59744 .35443 m
.59744 .36614 L
s
.59744 .40126 m
.59744 .38955 L
s
gsave
.62121 .36944 -106.125 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QPNP741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.57507 .387 -88.5 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q132) show
86.500000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.3914 .30994 m
.38204 .31346 L
s
.38204 .29941 m
.3914 .30292 L
s
.3914 .30292 m
.38204 .30643 L
s
.38204 .30643 m
.3914 .30994 L
s
.38204 .31346 m
.3914 .31697 L
s
.38672 .29707 m
.38204 .29941 L
s
.3914 .31697 m
.38672 .31931 L
s
.38672 .29589 m
.38672 .29707 L
s
.38672 .33102 m
.38672 .31931 L
s
.38672 .28419 m
.38672 .29589 L
s
gsave
.35745 .29803 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(40) show
74.750000 13.000000 moveto
(k) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.36565 .30974 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(R5) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.84328 .35443 m
.83158 .34272 L
s
.83158 .34272 m
.84328 .33102 L
s
.84094 .33921 m
.84094 .33336 L
s
.84094 .33336 m
.83509 .33336 L
s
.83158 .35443 m
.83158 .33102 L
s
.81987 .34272 m
.83158 .34272 L
s
.84328 .36614 m
.84328 .35443 L
s
.84328 .31931 m
.84328 .33102 L
s
gsave
.8468 .339 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.80699 .3472 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q14) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.80816 .31931 m
.81987 .3076 L
s
.81987 .3076 m
.80816 .29589 L
s
.8105 .30409 m
.8105 .29824 L
s
.8105 .29824 m
.81636 .29824 L
s
.81987 .31931 m
.81987 .29589 L
s
.83158 .3076 m
.81987 .3076 L
s
.80816 .33102 m
.80816 .31931 L
s
.80816 .28419 m
.80816 .29589 L
s
gsave
.77808 .30388 -106.125 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.82036 .3191 -82.625 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q15) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.5272 .16712 m
.51549 .15541 L
s
.51549 .15541 m
.5272 .14371 L
s
.52486 .1519 m
.52486 .14605 L
s
.52486 .14605 m
.51901 .14605 L
s
.51549 .16712 m
.51549 .14371 L
s
.50379 .15541 m
.51549 .15541 L
s
.5272 .17883 m
.5272 .16712 L
s
.5272 .132 m
.5272 .14371 L
s
gsave
.53071 .1517 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.49091 .15755 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q16) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.56232 .132 m
.55061 .12029 L
s
.55061 .12029 m
.56232 .10859 L
s
.55998 .11678 m
.55998 .11093 L
s
.55998 .11093 m
.55413 .11093 L
s
.55061 .132 m
.55061 .10859 L
s
.53891 .12029 m
.55061 .12029 L
s
.56232 .14371 m
.56232 .132 L
s
.56232 .09688 m
.56232 .10859 L
s
gsave
.56349 .11658 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.5354 .13414 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q17) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.84797 .28653 m
.8386 .29004 L
s
.8386 .27599 m
.84797 .27951 L
s
.84797 .27951 m
.8386 .28302 L
s
.8386 .28302 m
.84797 .28653 L
s
.8386 .29004 m
.84797 .29355 L
s
.84328 .27365 m
.8386 .27599 L
s
.84797 .29355 m
.84328 .29589 L
s
.84328 .27248 m
.84328 .27365 L
s
.84328 .3076 m
.84328 .29589 L
s
.84328 .26077 m
.84328 .27248 L
s
gsave
.8187 .27462 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(27) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.82221 .28632 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(R6) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.84797 .228 m
.8386 .23151 L
s
.8386 .21746 m
.84797 .22097 L
s
.84797 .22097 m
.8386 .22448 L
s
.8386 .22448 m
.84797 .228 L
s
.8386 .23151 m
.84797 .23502 L
s
.84328 .21512 m
.8386 .21746 L
s
.84797 .23502 m
.84328 .23736 L
s
.84328 .21395 m
.84328 .21512 L
s
.84328 .24907 m
.84328 .23736 L
s
.84328 .20224 m
.84328 .21395 L
s
gsave
.82104 .21374 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(22) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.81987 .22779 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(R7) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.567 .05239 m
.55764 .05591 L
s
.55764 .04186 m
.567 .04537 L
s
.567 .04537 m
.55764 .04888 L
s
.55764 .04888 m
.567 .05239 L
s
.55764 .05591 m
.567 .05942 L
s
.56232 .03952 m
.55764 .04186 L
s
.567 .05942 m
.56232 .06176 L
s
.56232 .03835 m
.56232 .03952 L
s
.56232 .07347 m
.56232 .06176 L
s
.56232 .02664 m
.56232 .03835 L
s
gsave
.53071 .04282 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(100) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.53891 .05453 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(R8) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.53188 .05239 m
.52252 .05591 L
s
.52252 .04186 m
.53188 .04537 L
s
.53188 .04537 m
.52252 .04888 L
s
.52252 .04888 m
.53188 .05239 L
s
.52252 .05591 m
.53188 .05942 L
s
.5272 .03952 m
.52252 .04186 L
s
.53188 .05942 m
.5272 .06176 L
s
.5272 .03835 m
.5272 .03952 L
s
.5272 .07347 m
.5272 .06176 L
s
.5272 .02664 m
.5272 .03835 L
s
gsave
.49793 .04048 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(50) show
74.750000 13.000000 moveto
(k) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.50613 .05219 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(R9) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.70046 .24204 m
.69695 .23268 L
s
.711 .23268 m
.70748 .24204 L
s
.70748 .24204 m
.70397 .23268 L
s
.70397 .23268 m
.70046 .24204 L
s
.69695 .23268 m
.69344 .24204 L
s
.71334 .23736 m
.711 .23268 L
s
.69344 .24204 m
.6911 .23736 L
s
.71451 .23736 m
.71334 .23736 L
s
.67939 .23736 m
.6911 .23736 L
s
.72622 .23736 m
.71451 .23736 L
s
gsave
.69227 .21608 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(50) show
74.750000 13.000000 moveto
(k) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.68992 .24301 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(R10) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.81285 .05239 m
.80348 .05591 L
s
.80348 .04186 m
.81285 .04537 L
s
.81285 .04537 m
.80348 .04888 L
s
.80348 .04888 m
.81285 .05239 L
s
.80348 .05591 m
.81285 .05942 L
s
.80816 .03952 m
.80348 .04186 L
s
.81285 .05942 m
.80816 .06176 L
s
.80816 .03835 m
.80816 .03952 L
s
.80816 .07347 m
.80816 .06176 L
s
.80816 .02664 m
.80816 .03835 L
s
gsave
.77655 .03814 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(50) show
74.750000 13.000000 moveto
(k) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.78007 .04985 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(R11) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.2556 .1601 m
.25209 .15073 L
s
.26614 .15073 m
.26263 .1601 L
s
.26263 .1601 m
.25912 .15073 L
s
.25912 .15073 m
.2556 .1601 L
s
.25209 .15073 m
.24858 .1601 L
s
.26848 .15541 m
.26614 .15073 L
s
.24858 .1601 m
.24624 .15541 L
s
.26965 .15541 m
.26848 .15541 L
s
.23453 .15541 m
.24624 .15541 L
s
.28136 .15541 m
.26965 .15541 L
s
gsave
.24975 .13414 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(300) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.24741 .1634 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(R12) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.67939 .3076 m
.66768 .29589 L
s
.66768 .29589 m
.67939 .28419 L
s
.67705 .29238 m
.67705 .28653 L
s
.67705 .28653 m
.67119 .28653 L
s
.66768 .3076 m
.66768 .28419 L
s
.65598 .29589 m
.66768 .29589 L
s
.67939 .31931 m
.67939 .3076 L
s
.67939 .27248 m
.67939 .28419 L
s
gsave
.67588 .29218 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.6431 .29803 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q18) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.72622 .28419 m
.71451 .27248 L
s
.71451 .27248 m
.72622 .26077 L
s
.72387 .26897 m
.72387 .26312 L
s
.72387 .26312 m
.71802 .26312 L
s
.71451 .28419 m
.71451 .26077 L
s
.7028 .27248 m
.71451 .27248 L
s
.72622 .29589 m
.72622 .28419 L
s
.72622 .24907 m
.72622 .26077 L
s
gsave
.72973 .26876 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.68992 .27696 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q19) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.84328 .15541 m
.83158 .16712 L
s
.83158 .16712 m
.84328 .17883 L
s
.84094 .17063 m
.83509 .17063 L
s
.83509 .17063 m
.83509 .17649 L
s
.83158 .15541 m
.83158 .17883 L
s
.81987 .16712 m
.83158 .16712 L
s
.84328 .14371 m
.84328 .15541 L
s
.84328 .19053 m
.84328 .17883 L
s
gsave
.86471 .15872 -106.125 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QPNP741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.82036 .16691 -82.625 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q20) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.80816 .19053 m
.81987 .20224 L
s
.81987 .20224 m
.80816 .21395 L
s
.8105 .20575 m
.81636 .20575 L
s
.81636 .20575 m
.81636 .21161 L
s
.81987 .19053 m
.81987 .21395 L
s
.83158 .20224 m
.81987 .20224 L
s
.80816 .17883 m
.80816 .19053 L
s
.80816 .22565 m
.80816 .21395 L
s
gsave
.75548 .19384 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QPNP741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.78358 .2114 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q21) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.63256 .06176 m
.64427 .05005 L
s
.64427 .05005 m
.63256 .03835 L
s
.6349 .04654 m
.6349 .04069 L
s
.6349 .04069 m
.64076 .04069 L
s
.64427 .06176 m
.64427 .03835 L
s
.65598 .05005 m
.64427 .05005 L
s
.63256 .07347 m
.63256 .06176 L
s
.63256 .02664 m
.63256 .03835 L
s
gsave
.60248 .04399 -106.125 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.65646 .05219 -82.625 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q24) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.48037 .09688 m
.49208 .08517 L
s
.49208 .08517 m
.48037 .07347 L
s
.48271 .08166 m
.48271 .07581 L
s
.48271 .07581 m
.48857 .07581 L
s
.49208 .09688 m
.49208 .07347 L
s
.50379 .08517 m
.49208 .08517 L
s
.48037 .10859 m
.48037 .09688 L
s
.48037 .06176 m
.48037 .07347 L
s
gsave
.45029 .08146 -106.125 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QNPN741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.50662 .08731 -82.625 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q23) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.46281 .21746 m
.47452 .21746 L
s
.46281 .22214 m
.47452 .22214 L
s
.46867 .22214 m
.46867 .22565 L
s
.46867 .21395 m
.46867 .21746 L
s
.46867 .20224 m
.46867 .21395 L
s
.46867 .23736 m
.46867 .22565 L
s
gsave
.4394 .2114 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(30) show
74.812500 13.000000 moveto
(p) show
80.687500 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.44057 .22545 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(C1) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.72622 .15541 m
.71451 .16712 L
s
.71451 .16712 m
.72622 .17883 L
s
.72387 .17063 m
.71802 .17063 L
s
.71802 .17063 m
.71802 .17649 L
s
.71451 .15541 m
.71451 .17883 L
s
.7028 .16712 m
.71451 .16712 L
s
.72622 .14371 m
.72622 .15541 L
s
.72622 .19053 m
.72622 .17883 L
s
gsave
.74999 .14935 -106.125 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QPNP741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.70618 .17628 -88.5 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q222) show
86.500000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.6911 .15541 m
.67939 .16712 L
s
.67939 .16712 m
.6911 .17883 L
s
.68875 .17063 m
.6829 .17063 L
s
.6829 .17063 m
.6829 .17649 L
s
.67939 .15541 m
.67939 .17883 L
s
.66768 .16712 m
.67939 .16712 L
s
.6911 .14371 m
.6911 .15541 L
s
.6911 .19053 m
.6911 .17883 L
s
gsave
.64697 .14935 -106.125 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(QPNP741) show
104.125000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.65936 .16691 -88.5 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Q221) show
86.500000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
newpath
.96035 .35443 .01171 0 365.73 arc
s
.96035 .37784 m
.96035 .36614 L
s
gsave
.9619 .35808 -65.375 -6.2125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.062500 moveto
 460.000000 15.062500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.062500 lineto
closepath
clip newpath
63.000000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.687500 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(+) show
67.750000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
.96035 .33102 m
.96035 .34272 L
s
gsave
.9619 .34403 -65.375 -6.2125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.062500 moveto
 460.000000 15.062500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.062500 lineto
closepath
clip newpath
63.000000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.687500 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(-) show
67.750000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
gsave
.97619 .36476 -69.0313 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.312500 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(V1) show
75.062500 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
newpath
.96035 .08517 .01171 0 365.73 arc
s
.96035 .10859 m
.96035 .09688 L
s
gsave
.9619 .08882 -65.375 -6.2125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.062500 moveto
 460.000000 15.062500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.062500 lineto
closepath
clip newpath
63.000000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.687500 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(+) show
67.750000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
.96035 .06176 m
.96035 .07347 L
s
gsave
.9619 .07478 -65.375 -6.2125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.062500 moveto
 460.000000 15.062500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.062500 lineto
closepath
clip newpath
63.000000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.687500 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(-) show
67.750000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
gsave
.97619 .0955 -69.0313 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.312500 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(V2) show
75.062500 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
newpath
.03552 .35443 .01171 0 365.73 arc
s
.03552 .33102 m
.03552 .34272 L
s
gsave
.0319 .34355 -65.375 -6.2125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.062500 moveto
 460.000000 15.062500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.062500 lineto
closepath
clip newpath
63.000000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.687500 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(+) show
67.750000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
.03552 .37784 m
.03552 .36614 L
s
gsave
.0319 .3576 -65.375 -6.2125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.062500 moveto
 460.000000 15.062500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.062500 lineto
closepath
clip newpath
63.000000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.687500 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(-) show
67.750000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
gsave
.05576 .36476 -72.0313 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.312500 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Vid) show
81.062500 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
newpath
.07064 .44808 .01171 0 365.73 arc
s
.09405 .44808 m
.08234 .44808 L
s
gsave
.07429 .44653 -62.0563 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
65.375 9.53125 translate
270 rotate
-65.375 -9.53125 translate
0 19.0625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.062500 moveto
 460.000000 15.062500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.062500 lineto
closepath
clip newpath
63.000000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.687500 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(+) show
67.750000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
.04722 .44808 m
.05893 .44808 L
s
gsave
.06024 .44653 -62.0563 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
65.375 9.53125 translate
270 rotate
-65.375 -9.53125 translate
0 19.0625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.062500 moveto
 460.000000 15.062500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.062500 lineto
closepath
clip newpath
63.000000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.687500 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(-) show
67.750000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
gsave
.10025 .45022 -71.9688 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.312500 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Vos) show
80.937500 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.90416 .25609 m
.90767 .26546 L
s
.89362 .26546 m
.89713 .25609 L
s
.89713 .25609 m
.90065 .26546 L
s
.90065 .26546 m
.90416 .25609 L
s
.90767 .26546 m
.91118 .25609 L
s
.89128 .26077 m
.89362 .26546 L
s
.91118 .25609 m
.91352 .26077 L
s
.89011 .26077 m
.89128 .26077 L
s
.92523 .26077 m
.91352 .26077 L
s
.8784 .26077 m
.89011 .26077 L
s
gsave
.89362 .24418 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(1) show
68.875000 13.000000 moveto
(k) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.88894 .26642 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(R13) show
80.625000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
newpath
.29307 .44808 .01171 0 365.73 arc
s
.26965 .44808 m
.28136 .44808 L
s
gsave
.28942 .44963 -68.6938 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
65.375 9.53125 translate
90 rotate
-65.375 -9.53125 translate
0 19.0625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.062500 moveto
 460.000000 15.062500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.062500 lineto
closepath
clip newpath
63.000000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.687500 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(+) show
67.750000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
.31648 .44808 m
.30477 .44808 L
s
gsave
.30346 .44963 -68.6938 -9.53125 Mabsadd m
1 1 Mabs scale
currentpoint translate
65.375 9.53125 translate
90 rotate
-65.375 -9.53125 translate
0 19.0625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.062500 moveto
 460.000000 15.062500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.062500 lineto
closepath
clip newpath
63.000000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 11.687500 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(-) show
67.750000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono-Bold
%%+ font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono-Bold
%%+ Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono-Bold
%%+ font Courier-Bold
grestore
gsave
.27585 .45256 -71.9688 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.312500 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(Vic) show
80.937500 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
gsave
.33287 .43968 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(0) show
68.875000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.32819 .44223 m
.33404 .44808 L
s
.33404 .44808 m
.32819 .45394 L
s
.32819 .44223 m
.32819 .45394 L
s
.31648 .44808 m
.32819 .44808 L
s
gsave
.94162 .23598 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(0) show
68.875000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.93108 .24907 m
.93694 .24321 L
s
.93694 .24321 m
.94279 .24907 L
s
.93108 .24907 m
.94279 .24907 L
s
.93694 .26077 m
.93694 .24907 L
s
.88543 .2678 m
.89831 .28068 L
s
newpath
.90182 .28419 .00585 0 365.73 arc
s
.88777 .26546 m
.8784 .26077 L
s
.8784 .26077 m
.88309 .27014 L
s
.88309 .27014 m
.88777 .26546 L
s
gsave
.89948 .28081 -61 -6.2125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.0625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 15.062500 moveto
 460.000000 15.062500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 15.062500 lineto
closepath
clip newpath
63.000000 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.062500 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(V) show
68.062500 11.687500 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 7.625000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.176 .22565 m
.31648 .22565 L
s
gsave
.32584 .21959 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(3) show
68.875000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.31648 .22565 m
.31648 .35443 L
s
.10576 .26077 m
.176 .26077 L
s
.176 .26077 m
.1877 .26077 L
s
.176 .26077 m
.176 .22565 L
s
.31648 .14371 m
.31648 .22565 L
s
.21112 .23736 m
.21112 .15541 L
s
gsave
.19707 .16457 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(9) show
68.875000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.21112 .15541 m
.21112 .14371 L
s
.21112 .15541 m
.23453 .15541 L
s
.11746 .12029 m
.10576 .12029 L
s
gsave
.10927 .10487 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(10) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.11746 .14371 m
.11746 .12029 L
s
.1877 .12029 m
.176 .12029 L
s
.176 .12029 m
.11746 .12029 L
s
.176 .07347 m
.176 .12029 L
s
.08234 .14371 m
.08234 .16712 L
s
gsave
.06595 .1634 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(8) show
68.875000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.08234 .16712 m
.08234 .23736 L
s
.09405 .16712 m
.08234 .16712 L
s
.08234 .28419 m
.08234 .29589 L
s
gsave
.08468 .28866 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(6) show
68.875000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.21112 .28419 m
.21112 .29589 L
s
gsave
.21346 .28866 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(7) show
68.875000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.16429 .35443 m
.08234 .35443 L
s
gsave
.16078 .339 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(2) show
68.875000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.08234 .35443 m
.08234 .34272 L
s
.21112 .34272 m
.21112 .35443 L
s
.21112 .35443 m
.16429 .35443 L
s
.29307 .37784 m
.21112 .37784 L
s
.21112 .37784 m
.1877 .37784 L
s
.21112 .35443 m
.21112 .37784 L
s
.59744 .41296 m
.84328 .41296 L
s
gsave
.72036 .41393 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(1) show
68.875000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.59744 .40126 m
.59744 .41296 L
s
.56232 .41296 m
.59744 .41296 L
s
.56232 .40126 m
.56232 .41296 L
s
.11746 .19053 m
.11746 .41296 L
s
.11746 .41296 m
.16429 .41296 L
s
.16429 .41296 m
.16429 .40126 L
s
.38672 .40126 m
.38672 .41296 L
s
.16429 .41296 m
.31648 .41296 L
s
.31648 .41296 m
.38672 .41296 L
s
.31648 .40126 m
.31648 .41296 L
s
.38672 .41296 m
.5272 .41296 L
s
.5272 .41296 m
.56232 .41296 L
s
.5272 .17883 m
.5272 .41296 L
s
.84328 .41296 m
.84328 .36614 L
s
.84328 .41296 m
.96035 .41296 L
s
.96035 .41296 m
.96035 .37784 L
s
.3516 .12029 m
.3516 .14371 L
s
gsave
.33755 .14233 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(15) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.3516 .12029 m
.36331 .12029 L
s
.33989 .12029 m
.3516 .12029 L
s
.38672 .14371 m
.38672 .28419 L
s
.3516 .14371 m
.38672 .14371 L
s
.43355 .34272 m
.43355 .37784 L
s
gsave
.43823 .33549 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(16) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.43355 .37784 m
.53891 .37784 L
s
.38672 .33102 m
.38672 .34272 L
s
.38672 .34272 m
.38672 .35443 L
s
.38672 .34272 m
.43355 .34272 L
s
.41013 .37784 m
.43355 .37784 L
s
.57403 .37784 m
.53891 .37784 L
s
.59744 .34272 m
.72622 .34272 L
s
gsave
.69695 .34369 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(22) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.59744 .35443 m
.59744 .34272 L
s
.67939 .31931 m
.72622 .31931 L
s
.72622 .31931 m
.72622 .29589 L
s
.72622 .33102 m
.72622 .31931 L
s
.65598 .29589 m
.63256 .29589 L
s
.63256 .29589 m
.63256 .33102 L
s
.63256 .33102 m
.72622 .33102 L
s
.72622 .34272 m
.72622 .33102 L
s
.80816 .34272 m
.81987 .34272 L
s
.80816 .34272 m
.80816 .33102 L
s
.72622 .34272 m
.80816 .34272 L
s
.84328 .31931 m
.84328 .3076 L
s
gsave
.84562 .31208 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(25) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.84328 .3076 m
.83158 .3076 L
s
.46867 .24907 m
.56232 .24907 L
s
gsave
.56935 .24301 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(17) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.56232 .24907 m
.56232 .35443 L
s
.46867 .23736 m
.46867 .24907 L
s
.56232 .14371 m
.56232 .16712 L
s
.56232 .16712 m
.56232 .24907 L
s
.66768 .16712 m
.56232 .16712 L
s
.7028 .16712 m
.66768 .16712 L
s
.5272 .132 m
.5272 .12029 L
s
gsave
.50379 .1154 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(19) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.5272 .12029 m
.53891 .12029 L
s
.5272 .07347 m
.5272 .12029 L
s
.46867 .15541 m
.48037 .15541 L
s
gsave
.47218 .15872 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(18) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.28136 .15541 m
.46867 .15541 L
s
.46867 .20224 m
.46867 .15541 L
s
.48037 .10859 m
.48037 .15541 L
s
.48037 .15541 m
.49208 .15541 L
s
.49208 .15541 m
.50379 .15541 L
s
.49208 .15541 m
.49208 .19053 L
s
.49208 .19053 m
.6911 .19053 L
s
.67939 .23736 m
.67939 .27248 L
s
gsave
.65598 .23481 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(23) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.7028 .27248 m
.67939 .27248 L
s
.74963 .16712 m
.74963 .20224 L
s
gsave
.75197 .17628 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(24) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.72622 .23736 m
.72622 .24907 L
s
.72622 .19053 m
.72622 .20224 L
s
.72622 .20224 m
.72622 .23736 L
s
.74963 .20224 m
.72622 .20224 L
s
.81987 .16712 m
.74963 .16712 L
s
.84328 .26077 m
.8784 .26077 L
s
gsave
.86084 .26174 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(26) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.84328 .26077 m
.84328 .24907 L
s
.84328 .26077 m
.80816 .26077 L
s
.80816 .26077 m
.80816 .28419 L
s
.80816 .22565 m
.80816 .26077 L
s
.84328 .20224 m
.84328 .19053 L
s
gsave
.84562 .19501 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(27) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.83158 .20224 m
.84328 .20224 L
s
.56232 .02664 m
.5272 .02664 L
s
gsave
.55413 .01121 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(13) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.38672 .09688 m
.38672 .02664 L
s
.38672 .02664 m
.31648 .02664 L
s
.31648 .02664 m
.21112 .02664 L
s
.21112 .02664 m
.176 .02664 L
s
.176 .02664 m
.08234 .02664 L
s
.5272 .02664 m
.48037 .02664 L
s
.48037 .02664 m
.38672 .02664 L
s
.48037 .06176 m
.48037 .02664 L
s
.63256 .02664 m
.56232 .02664 L
s
.80816 .02664 m
.72622 .02664 L
s
.72622 .02664 m
.63256 .02664 L
s
.72622 .14371 m
.72622 .132 L
s
.6911 .14371 m
.6911 .132 L
s
.72622 .132 m
.72622 .02664 L
s
.6911 .132 m
.72622 .132 L
s
.96035 .06176 m
.96035 .02664 L
s
.96035 .02664 m
.84328 .02664 L
s
.84328 .02664 m
.80816 .02664 L
s
.84328 .14371 m
.84328 .02664 L
s
.08234 .07347 m
.08234 .09688 L
s
gsave
.08468 .0838 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(11) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.21112 .07347 m
.21112 .09688 L
s
gsave
.21346 .0838 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(12) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.31648 .07347 m
.31648 .09688 L
s
gsave
.29541 .07911 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(14) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.56232 .07347 m
.56232 .09688 L
s
gsave
.56466 .09316 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(20) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.93694 .26077 m
.96035 .26077 L
s
gsave
.94864 .26174 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(0) show
68.875000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.96035 .26077 m
.96035 .10859 L
s
.92523 .26077 m
.93694 .26077 L
s
.96035 .33102 m
.96035 .26077 L
s
.05893 .31931 m
.03552 .31931 L
s
gsave
.02849 .30623 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(4) show
68.875000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.03552 .31931 m
.03552 .33102 L
s
.03552 .37784 m
.03552 .44808 L
s
.03552 .44808 m
.04722 .44808 L
s
.26965 .44808 m
.24624 .44808 L
s
gsave
.24156 .45607 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(5) show
68.875000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.23453 .31931 m
.24624 .31931 L
s
.24624 .31931 m
.24624 .44808 L
s
.24624 .44808 m
.09405 .44808 L
s
.50379 .08517 m
.63256 .08517 L
s
gsave
.6232 .09082 -61 -6.6 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 17.000000 moveto
 460.000000 17.000000 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 17.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
(21) show
74.750000 13.000000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 10.187500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Bold
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Bold
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Bold
grestore
.63256 .07347 m
.63256 .08517 L
s
.80816 .07347 m
.80816 .08517 L
s
.63256 .08517 m
.67939 .08517 L
s
.67939 .08517 m
.80816 .08517 L
s
.67939 .05005 m
.67939 .08517 L
s
.65598 .05005 m
.67939 .05005 L
s
.80816 .17883 m
.80816 .08517 L
s
.02 Mabswid
newpath
.8784 .26077 .00117 180 360 arc
s
newpath
.8784 .26077 .00117 0 180 arc
s
newpath
.176 .26077 .00117 180 360 arc
s
newpath
.176 .26077 .00117 0 180 arc
s
newpath
.31648 .22565 .00117 180 360 arc
s
newpath
.31648 .22565 .00117 0 180 arc
s
newpath
.21112 .15541 .00117 180 360 arc
s
newpath
.21112 .15541 .00117 0 180 arc
s
newpath
.11746 .12029 .00117 180 360 arc
s
newpath
.11746 .12029 .00117 0 180 arc
s
newpath
.176 .12029 .00117 180 360 arc
s
newpath
.176 .12029 .00117 0 180 arc
s
newpath
.08234 .16712 .00117 180 360 arc
s
newpath
.08234 .16712 .00117 0 180 arc
s
newpath
.16429 .35443 .00117 180 360 arc
s
newpath
.16429 .35443 .00117 0 180 arc
s
newpath
.21112 .37784 .00117 180 360 arc
s
newpath
.21112 .37784 .00117 0 180 arc
s
newpath
.21112 .35443 .00117 180 360 arc
s
newpath
.21112 .35443 .00117 0 180 arc
s
newpath
.16429 .41296 .00117 180 360 arc
s
newpath
.16429 .41296 .00117 0 180 arc
s
newpath
.38672 .41296 .00117 180 360 arc
s
newpath
.38672 .41296 .00117 0 180 arc
s
newpath
.31648 .41296 .00117 180 360 arc
s
newpath
.31648 .41296 .00117 0 180 arc
s
newpath
.59744 .41296 .00117 180 360 arc
s
newpath
.59744 .41296 .00117 0 180 arc
s
newpath
.56232 .41296 .00117 180 360 arc
s
newpath
.56232 .41296 .00117 0 180 arc
s
newpath
.5272 .41296 .00117 180 360 arc
s
newpath
.5272 .41296 .00117 0 180 arc
s
newpath
.84328 .41296 .00117 180 360 arc
s
newpath
.84328 .41296 .00117 0 180 arc
s
newpath
.3516 .12029 .00117 180 360 arc
s
newpath
.3516 .12029 .00117 0 180 arc
s
newpath
.38672 .14371 .00117 180 360 arc
s
newpath
.38672 .14371 .00117 0 180 arc
s
newpath
.53891 .37784 .00117 180 360 arc
s
newpath
.53891 .37784 .00117 0 180 arc
s
newpath
.38672 .34272 .00117 180 360 arc
s
newpath
.38672 .34272 .00117 0 180 arc
s
newpath
.43355 .37784 .00117 180 360 arc
s
newpath
.43355 .37784 .00117 0 180 arc
s
newpath
.72622 .31931 .00117 180 360 arc
s
newpath
.72622 .31931 .00117 0 180 arc
s
newpath
.72622 .33102 .00117 180 360 arc
s
newpath
.72622 .33102 .00117 0 180 arc
s
newpath
.72622 .34272 .00117 180 360 arc
s
newpath
.72622 .34272 .00117 0 180 arc
s
newpath
.80816 .34272 .00117 180 360 arc
s
newpath
.80816 .34272 .00117 0 180 arc
s
newpath
.84328 .3076 .00117 180 360 arc
s
newpath
.84328 .3076 .00117 0 180 arc
s
newpath
.56232 .24907 .00117 180 360 arc
s
newpath
.56232 .24907 .00117 0 180 arc
s
newpath
.66768 .16712 .00117 180 360 arc
s
newpath
.66768 .16712 .00117 0 180 arc
s
newpath
.56232 .16712 .00117 180 360 arc
s
newpath
.56232 .16712 .00117 0 180 arc
s
newpath
.5272 .12029 .00117 180 360 arc
s
newpath
.5272 .12029 .00117 0 180 arc
s
newpath
.46867 .15541 .00117 180 360 arc
s
newpath
.46867 .15541 .00117 0 180 arc
s
newpath
.48037 .15541 .00117 180 360 arc
s
newpath
.48037 .15541 .00117 0 180 arc
s
newpath
.49208 .15541 .00117 180 360 arc
s
newpath
.49208 .15541 .00117 0 180 arc
s
newpath
.67939 .27248 .00117 180 360 arc
s
newpath
.67939 .27248 .00117 0 180 arc
s
newpath
.72622 .23736 .00117 180 360 arc
s
newpath
.72622 .23736 .00117 0 180 arc
s
newpath
.72622 .20224 .00117 180 360 arc
s
newpath
.72622 .20224 .00117 0 180 arc
s
newpath
.84328 .26077 .00117 180 360 arc
s
newpath
.84328 .26077 .00117 0 180 arc
s
newpath
.8784 .26077 .00117 180 360 arc
s
newpath
.8784 .26077 .00117 0 180 arc
s
newpath
.8784 .26077 .00117 180 360 arc
s
newpath
.8784 .26077 .00117 0 180 arc
s
newpath
.80816 .26077 .00117 180 360 arc
s
newpath
.80816 .26077 .00117 0 180 arc
s
newpath
.84328 .20224 .00117 180 360 arc
s
newpath
.84328 .20224 .00117 0 180 arc
s
newpath
.56232 .02664 .00117 180 360 arc
s
newpath
.56232 .02664 .00117 0 180 arc
s
newpath
.5272 .02664 .00117 180 360 arc
s
newpath
.5272 .02664 .00117 0 180 arc
s
newpath
.38672 .02664 .00117 180 360 arc
s
newpath
.38672 .02664 .00117 0 180 arc
s
newpath
.31648 .02664 .00117 180 360 arc
s
newpath
.31648 .02664 .00117 0 180 arc
s
newpath
.21112 .02664 .00117 180 360 arc
s
newpath
.21112 .02664 .00117 0 180 arc
s
newpath
.176 .02664 .00117 180 360 arc
s
newpath
.176 .02664 .00117 0 180 arc
s
newpath
.48037 .02664 .00117 180 360 arc
s
newpath
.48037 .02664 .00117 0 180 arc
s
newpath
.63256 .02664 .00117 180 360 arc
s
newpath
.63256 .02664 .00117 0 180 arc
s
newpath
.80816 .02664 .00117 180 360 arc
s
newpath
.80816 .02664 .00117 0 180 arc
s
newpath
.72622 .02664 .00117 180 360 arc
s
newpath
.72622 .02664 .00117 0 180 arc
s
newpath
.72622 .132 .00117 180 360 arc
s
newpath
.72622 .132 .00117 0 180 arc
s
newpath
.84328 .02664 .00117 180 360 arc
s
newpath
.84328 .02664 .00117 0 180 arc
s
newpath
.93694 .26077 .00117 180 360 arc
s
newpath
.93694 .26077 .00117 0 180 arc
s
newpath
.96035 .26077 .00117 180 360 arc
s
newpath
.96035 .26077 .00117 0 180 arc
s
newpath
.24624 .44808 .00117 180 360 arc
s
newpath
.24624 .44808 .00117 0 180 arc
s
newpath
.63256 .08517 .00117 180 360 arc
s
newpath
.63256 .08517 .00117 0 180 arc
s
newpath
.67939 .08517 .00117 180 360 arc
s
newpath
.67939 .08517 .00117 0 180 arc
s
newpath
.80816 .08517 .00117 180 360 arc
s
newpath
.80816 .08517 .00117 0 180 arc
s
0 0 m
1 0 L
1 .471 L
0 .471 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{770.938, 363.125},
  ImageMargins->{{20, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Import Simulation Data", "Subsection"],

Cell["\<\
Analog Insydes' data reader is used to import the PSpice simulation data.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(op741data\  = \ 
      ReadSimulationData["\<op_741.csd\>", Simulator \[Rule] "\<PSpice\>"]
        \)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"\<\"V(26)\"\>", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.1`, 1.`*^6}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Vout741PSpice\  = \ "\<V(26)\>" /. First\ @\ op741data; \)\)], "Input",\

  CellTags->"IDH_CSDFREAD"],

Cell["Plot PSpice simulation data as Bode plot:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BodePlot[Vout741PSpice[f], \ {f, \ 0.1, \ 1.*^6}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0178571 0.714286 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.392857 0.97619 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 1 r
MFill
% Scaling calculations
0.159864 0.136054 0.0140458 0.00246554 [
[.02381 -0.0125 -20 -12.5625 ]
[.02381 -0.0125 20 0 ]
[.29592 -0.0125 -17 -12.5625 ]
[.29592 -0.0125 17 0 ]
[.56803 -0.0125 -17 -12.5625 ]
[.56803 -0.0125 17 0 ]
[.84014 -0.0125 -17 -12.5625 ]
[.84014 -0.0125 17 0 ]
[.5 -0.0125 -29 -25.125 ]
[.5 -0.0125 29 -12.5625 ]
[-0.0125 .01405 -6 -4.5 ]
[-0.0125 .01405 0 4.5 ]
[-0.0125 .06336 -12 -4.5 ]
[-0.0125 .06336 0 4.5 ]
[-0.0125 .11267 -12 -4.5 ]
[-0.0125 .11267 0 4.5 ]
[-0.0125 .16198 -12 -4.5 ]
[-0.0125 .16198 0 4.5 ]
[-0.0125 .21129 -12 -4.5 ]
[-0.0125 .21129 0 4.5 ]
[-0.0125 .2606 -18 -4.5 ]
[-0.0125 .2606 0 4.5 ]
[-0.01875 .1425 -30.5625 -44 ]
[-0.01875 .1425 -18 44 ]
[.02381 .2975 -20 0 ]
[.02381 .2975 20 12.5625 ]
[.29592 .2975 -17 0 ]
[.29592 .2975 17 12.5625 ]
[.56803 .2975 -17 0 ]
[.56803 .2975 17 12.5625 ]
[.84014 .2975 -17 0 ]
[.84014 .2975 17 12.5625 ]
[ -0.0025 -0.0025 0 0 ]
[ 1.0025 .2875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .285 L
s
.29592 0 m
.29592 .285 L
s
.56803 0 m
.56803 .285 L
s
.84014 0 m
.84014 .285 L
s
.17064 0 m
.17064 .285 L
s
.20908 0 m
.20908 .285 L
s
.23217 0 m
.23217 .285 L
s
.24874 0 m
.24874 .285 L
s
.26166 0 m
.26166 .285 L
s
.27226 0 m
.27226 .285 L
s
.28124 0 m
.28124 .285 L
s
.28903 0 m
.28903 .285 L
s
.44275 0 m
.44275 .285 L
s
.48119 0 m
.48119 .285 L
s
.50428 0 m
.50428 .285 L
s
.52085 0 m
.52085 .285 L
s
.53377 0 m
.53377 .285 L
s
.54436 0 m
.54436 .285 L
s
.55335 0 m
.55335 .285 L
s
.56114 0 m
.56114 .285 L
s
.71485 0 m
.71485 .285 L
s
.7533 0 m
.7533 .285 L
s
.77639 0 m
.77639 .285 L
s
.79295 0 m
.79295 .285 L
s
.80588 0 m
.80588 .285 L
s
.81647 0 m
.81647 .285 L
s
.82546 0 m
.82546 .285 L
s
.83325 0 m
.83325 .285 L
s
0 .01405 m
1 .01405 L
s
0 .06336 m
1 .06336 L
s
0 .11267 m
1 .11267 L
s
0 .16198 m
1 .16198 L
s
0 .21129 m
1 .21129 L
s
0 .2606 m
1 .2606 L
s
0 0 0 r
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -81 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E) show
87.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.29592 0 m
.29592 .00625 L
s
gsave
.29592 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.56803 0 m
.56803 .00625 L
s
gsave
.56803 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.84014 0 m
.84014 .00625 L
s
gsave
.84014 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.17064 0 m
.17064 .00375 L
s
.20908 0 m
.20908 .00375 L
s
.23217 0 m
.23217 .00375 L
s
.24874 0 m
.24874 .00375 L
s
.26166 0 m
.26166 .00375 L
s
.27226 0 m
.27226 .00375 L
s
.28124 0 m
.28124 .00375 L
s
.28903 0 m
.28903 .00375 L
s
.44275 0 m
.44275 .00375 L
s
.48119 0 m
.48119 .00375 L
s
.50428 0 m
.50428 .00375 L
s
.52085 0 m
.52085 .00375 L
s
.53377 0 m
.53377 .00375 L
s
.54436 0 m
.54436 .00375 L
s
.55335 0 m
.55335 .00375 L
s
.56114 0 m
.56114 .00375 L
s
.71485 0 m
.71485 .00375 L
s
.7533 0 m
.7533 .00375 L
s
.77639 0 m
.77639 .00375 L
s
.79295 0 m
.79295 .00375 L
s
.80588 0 m
.80588 .00375 L
s
.81647 0 m
.81647 .00375 L
s
.82546 0 m
.82546 .00375 L
s
.83325 0 m
.83325 .00375 L
s
.005 w
0 0 m
1 0 L
s
gsave
.5 -0.0125 -90 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
0 .01405 m
.00625 .01405 L
s
[(0)] -0.0125 .01405 1 0 Mshowa
0 .06336 m
.00625 .06336 L
s
[(20)] -0.0125 .06336 1 0 Mshowa
0 .11267 m
.00625 .11267 L
s
[(40)] -0.0125 .11267 1 0 Mshowa
0 .16198 m
.00625 .16198 L
s
[(60)] -0.0125 .16198 1 0 Mshowa
0 .21129 m
.00625 .21129 L
s
[(80)] -0.0125 .21129 1 0 Mshowa
0 .2606 m
.00625 .2606 L
s
[(100)] -0.0125 .2606 1 0 Mshowa
.125 Mabswid
0 .02637 m
.00375 .02637 L
s
0 .0387 m
.00375 .0387 L
s
0 .05103 m
.00375 .05103 L
s
0 .07568 m
.00375 .07568 L
s
0 .08801 m
.00375 .08801 L
s
0 .10034 m
.00375 .10034 L
s
0 .125 m
.00375 .125 L
s
0 .13732 m
.00375 .13732 L
s
0 .14965 m
.00375 .14965 L
s
0 .17431 m
.00375 .17431 L
s
0 .18663 m
.00375 .18663 L
s
0 .19896 m
.00375 .19896 L
s
0 .22362 m
.00375 .22362 L
s
0 .23594 m
.00375 .23594 L
s
0 .24827 m
.00375 .24827 L
s
0 .00172 m
.00375 .00172 L
s
0 .27293 m
.00375 .27293 L
s
.005 w
0 0 m
0 .285 L
s
gsave
-0.01875 .1425 -129.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10.2813 translate
90 rotate
-105 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnitude) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
.25 Mabswid
.02381 .27875 m
.02381 .285 L
s
gsave
.02381 .2975 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E) show
87.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.29592 .27875 m
.29592 .285 L
s
gsave
.29592 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.56803 .27875 m
.56803 .285 L
s
gsave
.56803 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.84014 .27875 m
.84014 .285 L
s
gsave
.84014 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.17064 .28125 m
.17064 .285 L
s
.20908 .28125 m
.20908 .285 L
s
.23217 .28125 m
.23217 .285 L
s
.24874 .28125 m
.24874 .285 L
s
.26166 .28125 m
.26166 .285 L
s
.27226 .28125 m
.27226 .285 L
s
.28124 .28125 m
.28124 .285 L
s
.28903 .28125 m
.28903 .285 L
s
.44275 .28125 m
.44275 .285 L
s
.48119 .28125 m
.48119 .285 L
s
.50428 .28125 m
.50428 .285 L
s
.52085 .28125 m
.52085 .285 L
s
.53377 .28125 m
.53377 .285 L
s
.54436 .28125 m
.54436 .285 L
s
.55335 .28125 m
.55335 .285 L
s
.56114 .28125 m
.56114 .285 L
s
.71485 .28125 m
.71485 .285 L
s
.7533 .28125 m
.7533 .285 L
s
.77639 .28125 m
.77639 .285 L
s
.79295 .28125 m
.79295 .285 L
s
.80588 .28125 m
.80588 .285 L
s
.81647 .28125 m
.81647 .285 L
s
.82546 .28125 m
.82546 .285 L
s
.83325 .28125 m
.83325 .285 L
s
.005 w
0 .285 m
1 .285 L
s
.25 Mabswid
.99375 .01405 m
1 .01405 L
s
.99375 .06336 m
1 .06336 L
s
.99375 .11267 m
1 .11267 L
s
.99375 .16198 m
1 .16198 L
s
.99375 .21129 m
1 .21129 L
s
.99375 .2606 m
1 .2606 L
s
.125 Mabswid
.99625 .02637 m
1 .02637 L
s
.99625 .0387 m
1 .0387 L
s
.99625 .05103 m
1 .05103 L
s
.99625 .07568 m
1 .07568 L
s
.99625 .08801 m
1 .08801 L
s
.99625 .10034 m
1 .10034 L
s
.99625 .125 m
1 .125 L
s
.99625 .13732 m
1 .13732 L
s
.99625 .14965 m
1 .14965 L
s
.99625 .17431 m
1 .17431 L
s
.99625 .18663 m
1 .18663 L
s
.99625 .19896 m
1 .19896 L
s
.99625 .22362 m
1 .22362 L
s
.99625 .23594 m
1 .23594 L
s
.99625 .24827 m
1 .24827 L
s
.99625 .00172 m
1 .00172 L
s
.99625 .27293 m
1 .27293 L
s
.005 w
1 0 m
1 .285 L
s
0 0 m
1 0 L
1 .285 L
0 .285 L
closepath
clip
newpath
1 0 0 r
.02381 .27821 m
.06349 .27818 L
.10317 .27806 L
.14286 .27762 L
.18254 .27605 L
.22222 .27164 L
.2619 .26286 L
.30159 .25062 L
.34127 .23686 L
.38095 .2226 L
.42063 .20822 L
.46032 .19378 L
.5 .17932 L
.53968 .16503 L
.57937 .15073 L
.61905 .1364 L
.65873 .12205 L
.69841 .10769 L
.7381 .09331 L
.77778 .07892 L
.81746 .06451 L
.85714 .05008 L
.89683 .03564 L
.93651 .02121 L
.97619 .00679 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.0178571 0.97619 0.357143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 1 r
MFill
% Scaling calculations
0.159864 0.136054 0.278214 0.00288623 [
[.02381 -0.0125 -20 -12.5625 ]
[.02381 -0.0125 20 0 ]
[.29592 -0.0125 -17 -12.5625 ]
[.29592 -0.0125 17 0 ]
[.56803 -0.0125 -17 -12.5625 ]
[.56803 -0.0125 17 0 ]
[.84014 -0.0125 -17 -12.5625 ]
[.84014 -0.0125 17 0 ]
[.5 -0.0125 -29 -25.125 ]
[.5 -0.0125 29 -12.5625 ]
[-0.0125 .04732 -18 -4.5 ]
[-0.0125 .04732 0 4.5 ]
[-0.0125 .10504 -18 -4.5 ]
[-0.0125 .10504 0 4.5 ]
[-0.0125 .16277 -18 -4.5 ]
[-0.0125 .16277 0 4.5 ]
[-0.0125 .22049 -18 -4.5 ]
[-0.0125 .22049 0 4.5 ]
[-0.0125 .27821 -6 -4.5 ]
[-0.0125 .27821 0 4.5 ]
[-0.01875 .1425 -30.5625 -35 ]
[-0.01875 .1425 -18 35 ]
[.02381 .2975 -20 0 ]
[.02381 .2975 20 12.5625 ]
[.29592 .2975 -17 0 ]
[.29592 .2975 17 12.5625 ]
[.56803 .2975 -17 0 ]
[.56803 .2975 17 12.5625 ]
[.84014 .2975 -17 0 ]
[.84014 .2975 17 12.5625 ]
[ -0.0025 -0.0025 0 0 ]
[ 1.0025 .2875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .285 L
s
.29592 0 m
.29592 .285 L
s
.56803 0 m
.56803 .285 L
s
.84014 0 m
.84014 .285 L
s
.17064 0 m
.17064 .285 L
s
.20908 0 m
.20908 .285 L
s
.23217 0 m
.23217 .285 L
s
.24874 0 m
.24874 .285 L
s
.26166 0 m
.26166 .285 L
s
.27226 0 m
.27226 .285 L
s
.28124 0 m
.28124 .285 L
s
.28903 0 m
.28903 .285 L
s
.44275 0 m
.44275 .285 L
s
.48119 0 m
.48119 .285 L
s
.50428 0 m
.50428 .285 L
s
.52085 0 m
.52085 .285 L
s
.53377 0 m
.53377 .285 L
s
.54436 0 m
.54436 .285 L
s
.55335 0 m
.55335 .285 L
s
.56114 0 m
.56114 .285 L
s
.71485 0 m
.71485 .285 L
s
.7533 0 m
.7533 .285 L
s
.77639 0 m
.77639 .285 L
s
.79295 0 m
.79295 .285 L
s
.80588 0 m
.80588 .285 L
s
.81647 0 m
.81647 .285 L
s
.82546 0 m
.82546 .285 L
s
.83325 0 m
.83325 .285 L
s
0 .04732 m
1 .04732 L
s
0 .10504 m
1 .10504 L
s
0 .16277 m
1 .16277 L
s
0 .22049 m
1 .22049 L
s
0 0 0 r
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -81 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E) show
87.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.29592 0 m
.29592 .00625 L
s
gsave
.29592 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.56803 0 m
.56803 .00625 L
s
gsave
.56803 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.84014 0 m
.84014 .00625 L
s
gsave
.84014 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.17064 0 m
.17064 .00375 L
s
.20908 0 m
.20908 .00375 L
s
.23217 0 m
.23217 .00375 L
s
.24874 0 m
.24874 .00375 L
s
.26166 0 m
.26166 .00375 L
s
.27226 0 m
.27226 .00375 L
s
.28124 0 m
.28124 .00375 L
s
.28903 0 m
.28903 .00375 L
s
.44275 0 m
.44275 .00375 L
s
.48119 0 m
.48119 .00375 L
s
.50428 0 m
.50428 .00375 L
s
.52085 0 m
.52085 .00375 L
s
.53377 0 m
.53377 .00375 L
s
.54436 0 m
.54436 .00375 L
s
.55335 0 m
.55335 .00375 L
s
.56114 0 m
.56114 .00375 L
s
.71485 0 m
.71485 .00375 L
s
.7533 0 m
.7533 .00375 L
s
.77639 0 m
.77639 .00375 L
s
.79295 0 m
.79295 .00375 L
s
.80588 0 m
.80588 .00375 L
s
.81647 0 m
.81647 .00375 L
s
.82546 0 m
.82546 .00375 L
s
.83325 0 m
.83325 .00375 L
s
.005 w
0 0 m
1 0 L
s
gsave
.5 -0.0125 -90 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
0 .04732 m
.00625 .04732 L
s
[(-80)] -0.0125 .04732 1 0 Mshowa
0 .10504 m
.00625 .10504 L
s
[(-60)] -0.0125 .10504 1 0 Mshowa
0 .16277 m
.00625 .16277 L
s
[(-40)] -0.0125 .16277 1 0 Mshowa
0 .22049 m
.00625 .22049 L
s
[(-20)] -0.0125 .22049 1 0 Mshowa
0 .27821 m
.00625 .27821 L
s
[(0)] -0.0125 .27821 1 0 Mshowa
.125 Mabswid
0 .06175 m
.00375 .06175 L
s
0 .07618 m
.00375 .07618 L
s
0 .09061 m
.00375 .09061 L
s
0 .11947 m
.00375 .11947 L
s
0 .1339 m
.00375 .1339 L
s
0 .14833 m
.00375 .14833 L
s
0 .1772 m
.00375 .1772 L
s
0 .19163 m
.00375 .19163 L
s
0 .20606 m
.00375 .20606 L
s
0 .23492 m
.00375 .23492 L
s
0 .24935 m
.00375 .24935 L
s
0 .26378 m
.00375 .26378 L
s
0 .03289 m
.00375 .03289 L
s
0 .01845 m
.00375 .01845 L
s
0 .00402 m
.00375 .00402 L
s
.005 w
0 0 m
0 .285 L
s
gsave
-0.01875 .1425 -120.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
96 10.2813 translate
90 rotate
-96 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(deg) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(L) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
.25 Mabswid
.02381 .27875 m
.02381 .285 L
s
gsave
.02381 .2975 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E) show
87.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.29592 .27875 m
.29592 .285 L
s
gsave
.29592 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.56803 .27875 m
.56803 .285 L
s
gsave
.56803 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.84014 .27875 m
.84014 .285 L
s
gsave
.84014 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.17064 .28125 m
.17064 .285 L
s
.20908 .28125 m
.20908 .285 L
s
.23217 .28125 m
.23217 .285 L
s
.24874 .28125 m
.24874 .285 L
s
.26166 .28125 m
.26166 .285 L
s
.27226 .28125 m
.27226 .285 L
s
.28124 .28125 m
.28124 .285 L
s
.28903 .28125 m
.28903 .285 L
s
.44275 .28125 m
.44275 .285 L
s
.48119 .28125 m
.48119 .285 L
s
.50428 .28125 m
.50428 .285 L
s
.52085 .28125 m
.52085 .285 L
s
.53377 .28125 m
.53377 .285 L
s
.54436 .28125 m
.54436 .285 L
s
.55335 .28125 m
.55335 .285 L
s
.56114 .28125 m
.56114 .285 L
s
.71485 .28125 m
.71485 .285 L
s
.7533 .28125 m
.7533 .285 L
s
.77639 .28125 m
.77639 .285 L
s
.79295 .28125 m
.79295 .285 L
s
.80588 .28125 m
.80588 .285 L
s
.81647 .28125 m
.81647 .285 L
s
.82546 .28125 m
.82546 .285 L
s
.83325 .28125 m
.83325 .285 L
s
.005 w
0 .285 m
1 .285 L
s
.25 Mabswid
.99375 .04732 m
1 .04732 L
s
.99375 .10504 m
1 .10504 L
s
.99375 .16277 m
1 .16277 L
s
.99375 .22049 m
1 .22049 L
s
.99375 .27821 m
1 .27821 L
s
.125 Mabswid
.99625 .06175 m
1 .06175 L
s
.99625 .07618 m
1 .07618 L
s
.99625 .09061 m
1 .09061 L
s
.99625 .11947 m
1 .11947 L
s
.99625 .1339 m
1 .1339 L
s
.99625 .14833 m
1 .14833 L
s
.99625 .1772 m
1 .1772 L
s
.99625 .19163 m
1 .19163 L
s
.99625 .20606 m
1 .20606 L
s
.99625 .23492 m
1 .23492 L
s
.99625 .24935 m
1 .24935 L
s
.99625 .26378 m
1 .26378 L
s
.99625 .03289 m
1 .03289 L
s
.99625 .01845 m
1 .01845 L
s
.99625 .00402 m
1 .00402 L
s
.005 w
1 0 m
1 .285 L
s
0 0 m
1 0 L
1 .285 L
0 .285 L
closepath
clip
newpath
1 0 0 r
.02381 .27292 m
.06349 .26786 L
.10317 .25802 L
.14286 .23927 L
.18254 .20577 L
.22222 .15618 L
.2619 .10366 L
.30159 .06515 L
.34127 .04275 L
.38095 .03089 L
.42063 .02478 L
.46032 .02167 L
.5 .02008 L
.53968 .01929 L
.57937 .01887 L
.61905 .01865 L
.65873 .01851 L
.69841 .01841 L
.7381 .01828 L
.77778 .01806 L
.81746 .01766 L
.85714 .01689 L
.89683 .01538 L
.93651 .01245 L
.97619 .00679 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{516, 387},
  ImageMargins->{{31, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Import Netlist", "Subsection"],

Cell[TextData[{
  StyleBox[
  "For the application of symbolic analysis, especially symbolic \
approximation, the next step is to generate a symbolic netlist including the \
numerical reference information. While the SPICE simulator input file (*.cir) \
only contains the numerical values of the elements the operating point \
information and the values for the small-signal parameters of the transistors \
have to be extracted from the simulator output file (*.out). This task is \
performed by the netlist translator ",
    FontSize->12],
  StyleBox["ReadNetlist", "MR"],
  StyleBox[
  ". The output is a netlist containing symbolic values for each network \
element as well as the corresponding numerical reference information. ",
    FontSize->12]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(op741\  = 
      ReadNetlist["\<op_741.cir\>", "\<op_741.out\>", 
        KeepPrefix \[Rule] False, Simulator \[Rule] "\<PSpice\>"]; \n
    DisplayForm\ @\ op741\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"\<\"Circuit:\"\>"},
          {
            TagBox[GridBox[{
                  {"\<\"  \"\>", 
                    InterpretationBox[GridBox[{
                          {GridBox[{
                                {
                                  \("Netlist ("\[InvisibleSpace]Checked
                                    \[InvisibleSpace]", "\[InvisibleSpace]45
                                    \[InvisibleSpace]" Entries):"\)},
                                {
                                  TagBox[GridBox[{
                                        {"\<\" \"\>", 
                                        InterpretationBox[GridBox[{
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q1\"\>", ",", 
                                        \({"2" \[Rule] "C", "4" \[Rule] "B", 
                                        "6" \[Rule] "E"}\), ",", 
                                        \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q1"]\), ",", 
                                        \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q1"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q1"]\), 
                                        ",", \(IB$ac \[Rule] 
                                        3.42000000000000037`*^-8\), ",", 
                                        \(IC$ac \[Rule] 7.5`*^-6\), ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["0.567999999999999971`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["14.5000000000000017`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["15.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["219.000000000000039`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.00029`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["756000.000000000049`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 
                                        2.19000000000000083`*^7\), ",", 
                                        \(CBE$ac \[Rule] 
                                        1.47000000000000019`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        3.70000000000000062`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["219.000000000000039`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        2.50999999999999978`*^7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q2\"\>", ",", 
                                        \({"2" \[Rule] "C", "5" \[Rule] "B", 
                                        "7" \[Rule] "E"}\), ",", 
                                        \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q2"]\), ",", 
                                        \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q2"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q2"]\), 
                                        ",", \(IB$ac \[Rule] 
                                        3.43999999999999905`*^-8\), ",", 
                                        \(IC$ac \[Rule] 
                                        7.54000000000000003`*^-6\), ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["0.567999999999999971`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["14.5000000000000017`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["15.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["219.000000000000039`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.000291000000000000014`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["753000.000000000024`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 2.1800000000000006`*^7
                                        \), ",", \(CBE$ac \[Rule] 
                                        1.47000000000000019`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        3.70000000000000062`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["219.000000000000039`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        2.52000000000000046`*^7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q3\"\>", ",", 
                                        \({"8" \[Rule] "C", "3" \[Rule] "B", 
                                        "6" \[Rule] "E"}\), ",", 
                                        \(Model \[Rule] 
                                        Model["BJT", "QPNP741", "Q3"]\), ",", 
                                        \(Selector \[Rule] 
                                        Selector["BJT", "QPNP741", "Q3"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QPNP741", "Q3"]\), 
                                        ",", \(IB$ac \[Rule] 
                                        \(-1.17999999999999904`*^-7\)\), ",", 
                                        \(IC$ac \[Rule] 
                                        \(-7.41999999999999904`*^-6\)\), 
                                        ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.522000000000000063`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        StyleBox["12.8000000000000024`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["13.3000000000000007`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["62.8000000000000113`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.000286999999999999957`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["219000.000000000039`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["100.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 
                                        8.46000000000000085`*^6\), ",", 
                                        \(CBE$ac \[Rule] 
                                        1.4200000000000001`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 3.85`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["62.6999999999999957`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        2.52999999999999936`*^7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q4\"\>", ",", 
                                        \({"9" \[Rule] "C", "3" \[Rule] "B", 
                                        "7" \[Rule] "E"}\), ",", 
                                        \(Model \[Rule] 
                                        Model["BJT", "QPNP741", "Q4"]\), ",", 
                                        \(Selector \[Rule] 
                                        Selector["BJT", "QPNP741", "Q4"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QPNP741", "Q4"]\), 
                                        ",", \(IB$ac \[Rule] 
                                        \(-1.18999999999999905`*^-7\)\), ",", 
                                        \(IC$ac \[Rule] 
                                        \(-7.45000000000000017`*^-6\)\), 
                                        ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.523000000000000042`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        StyleBox["12.6`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["13.1000000000000005`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["62.5999999999999889`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.000288000000000000042`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["217000.000000000037`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["100.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 
                                        8.40000000000000035`*^6\), ",", 
                                        \(CBE$ac \[Rule] 
                                        1.4200000000000001`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        3.8700000000000001`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["62.5`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        2.54000000000000092`*^7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q5\"\>", ",", 
                                        \({"8" \[Rule] "C", "10" \[Rule] "B", 
                                        "11" \[Rule] "E"}\), ",", 
                                        \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q5"]\), ",", 
                                        \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q5"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q5"]\), 
                                        ",", \(IB$ac \[Rule] 
                                        3.66999999999999904`*^-8\), ",", 
                                        \(IC$ac \[Rule] 
                                        7.3700000000000001`*^-6\), ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["0.570000000000000106`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.576999999999999868`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["1.14999999999999902`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["200.999999999999934`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.000285000000000000053`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["705000.000000000071`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 
                                        2.04000000000000047`*^7\), ",", 
                                        \(CBE$ac \[Rule] 
                                        1.47000000000000019`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        8.27999999999999758`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["200.999999999999934`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        1.97000000000000046`*^7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q6\"\>", ",", 
                                        \({"9" \[Rule] "C", "10" \[Rule] "B", 
                                        "12" \[Rule] "E"}\), ",", 
                                        \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q6"]\), ",", 
                                        \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q6"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q6"]\), 
                                        ",", \(IB$ac \[Rule] 
                                        3.66999999999999904`*^-8\), ",", 
                                        \(IC$ac \[Rule] 
                                        7.3700000000000001`*^-6\), ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["0.570000000000000106`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.765000000000000035`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["1.33000000000000007`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["200.999999999999934`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.000285000000000000053`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["705000.000000000071`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 
                                        2.04000000000000047`*^7\), ",", 
                                        \(CBE$ac \[Rule] 
                                        1.47000000000000019`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        7.92999999999999971`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["200.999999999999934`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        2.00000000000000044`*^7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q7\"\>", ",", 
                                        \({"1" \[Rule] "C", "8" \[Rule] "B", 
                                        "10" \[Rule] "E"}\), ",", 
                                        \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q7"]\), ",", 
                                        \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q7"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q7"]\), 
                                        ",", \(IB$ac \[Rule] 
                                        4.84999999999999875`*^-8\), ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        StyleBox["0.0000115999999999999925`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["0.576999999999999868`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["28.79999999999999`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["29.399999999999995`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["239.000000000000012`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.000447000000000000063`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["533000.000000000007`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 1.55`*^7\), ",", 
                                        \(CBE$ac \[Rule] 
                                        1.48000000000000024`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        2.96999999999999886`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["238.000000000000033`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        4.00000000000000088`*^7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q8\"\>", ",", 
                                        \({"2" \[Rule] "C", "2" \[Rule] "B", 
                                        "1" \[Rule] "E"}\), ",", 
                                        \(Model \[Rule] 
                                        Model["BJT", "QPNP741", "Q8"]\), ",", 
                                        \(Selector \[Rule] 
                                        Selector["BJT", "QPNP741", "Q8"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QPNP741", "Q8"]\), 
                                        ",", \(IB$ac \[Rule] 
                                        \(-2.89000000000000056`*^-7\)\), 
                                        ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.0000145`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.546000000000000085`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        \(VBC$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.546000000000000085`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["50.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.000559000000000000074`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["89500.0000000000284`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["100.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 3.4600000000000004`*^6
                                        \), ",", \(CBE$ac \[Rule] 1.45`*^-12
                                        \), ",", \(CBC$ac \[Rule] 1.`*^-12\), 
                                        ",", \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["50.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        3.64000000000000056`*^7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"R1\"\>", ",", \({"13", "11"}\), 
                                        ",", \(Type \[Rule] Resistor\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        StyleBox["1000.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->4]}], ",", 
                                        \(Symbolic \[Rule] R1\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"R2\"\>", ",", \({"13", "12"}\), 
                                        ",", \(Type \[Rule] Resistor\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        StyleBox["1000.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->4]}], ",", 
                                        \(Symbolic \[Rule] R2\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"R3\"\>", ",", \({"13", "10"}\), 
                                        ",", \(Type \[Rule] Resistor\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        StyleBox["50000.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->5]}], ",", 
                                        \(Symbolic \[Rule] R3\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q9\"\>", ",", 
                                        \({"3" \[Rule] "C", "2" \[Rule] "B", 
                                        "1" \[Rule] "E"}\), ",", 
                                        \(Model \[Rule] 
                                        Model["BJT", "QPNP741", "Q9"]\), ",", 
                                        \(Selector \[Rule] 
                                        Selector["BJT", "QPNP741", "Q9"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QPNP741", "Q9"]\), 
                                        ",", \(IB$ac \[Rule] 
                                        \(-2.89000000000000056`*^-7\)\), 
                                        ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.0000189999999999999893`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.546000000000000085`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        StyleBox["15.5`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["16.1000000000000031`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["65.5000000000000071`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.000732000000000000028`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["89500.0000000000284`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["100.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 3.4600000000000004`*^6
                                        \), ",", \(CBE$ac \[Rule] 1.45`*^-12
                                        \), ",", \(CBC$ac \[Rule] 
                                        3.6200000000000001`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["65.5000000000000071`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        6.45000000000000017`*^7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q10\"\>", ",", 
                                        \({"3" \[Rule] "C", "15" \[Rule] "B", 
                                        "14" \[Rule] "E"}\), ",", 
                                        \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q10"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q10"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q10"]
                                        \), ",", \(IB$ac \[Rule] 
                                        8.82000000000000028`*^-8\), ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        StyleBox["0.0000191999999999999904`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["0.591999999999999815`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["13.2000000000000006`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["13.79999999999999`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["218.000000000000015`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.000741999999999999904`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["293000.000000000007`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 
                                        8.51000000000000333`*^6\), ",", 
                                        \(CBE$ac \[Rule] 
                                        1.50000000000000017`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        3.8099999999999996`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["218.000000000000015`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        6.29000000000000092`*^7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q11\"\>", ",", 
                                        \({"15" \[Rule] "C", 
                                        "15" \[Rule] "B", "13" \[Rule] "E"}
                                        \), ",", \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q11"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q11"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q11"]
                                        \), ",", \(IB$ac \[Rule] 
                                        3.56000000000000049`*^-6\), ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        StyleBox["0.000713000000000000078`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["0.688999999999999968`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        \(VBC$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["0.688999999999999968`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.0276000000000000023`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["7260.00000000000156`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RO$ac", "\[Rule]", 
                                        StyleBox["210000.000000000008`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        \(CBE$ac \[Rule] 
                                        1.60000000000000008`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 1.`*^-12\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        1.69000000000000039`*^9\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"R4\"\>", ",", \({"13", "14"}\), 
                                        ",", \(Type \[Rule] Resistor\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        StyleBox["5000.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->4]}], ",", 
                                        \(Symbolic \[Rule] R4\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q12\"\>", ",", 
                                        \({"16" \[Rule] "C", 
                                        "16" \[Rule] "B", "1" \[Rule] "E"}\), 
                                        ",", \(Model \[Rule] 
                                        Model["BJT", "QPNP741", "Q12"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QPNP741", "Q12"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QPNP741", "Q12"]
                                        \), ",", 
                                        RowBox[{"IB$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.000013800000000000001`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.000688999999999999879`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.647000000000000063`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        \(VBC$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.647000000000000063`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["50.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.0266000000000000014`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["1880.00000000000007`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->4]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["100.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RO$ac", "\[Rule]", 
                                        StyleBox["72600.0000000000245`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        \(CBE$ac \[Rule] 
                                        1.56000000000000005`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        9.99000000000000021`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["50.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        1.66000000000000014`*^9\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q131\"\>", ",", 
                                        \({"17" \[Rule] "C", 
                                        "16" \[Rule] "B", "1" \[Rule] "E"}\), 
                                        ",", \(Model \[Rule] 
                                        Model["BJT", "QPNP741", "Q131"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QPNP741", "Q131"]\), 
                                        ",", 
                                        RowBox[{"AREA", "\[Rule]", 
                                        StyleBox["0.75`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        \(Parameters \[Rule] 
                                        Parameters["BJT", "QPNP741", "Q131"]
                                        \), ",", 
                                        RowBox[{"IB$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.0000102999999999999891`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.000676999999999999779`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.647000000000000063`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        StyleBox["15.5`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["16.200000000000001`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["65.5000000000000071`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.026200000000000001`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["2500.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->4]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["133.000000000000007`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RO$ac", "\[Rule]", 
                                        StyleBox["96800.0000000000326`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        \(CBE$ac \[Rule] 
                                        1.16999999999999904`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        2.71999999999999886`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["65.5000000000000071`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        2.89000000000000056`*^9\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q132\"\>", ",", 
                                        \({"22" \[Rule] "C", 
                                        "16" \[Rule] "B", "1" \[Rule] "E"}\), 
                                        ",", \(Model \[Rule] 
                                        Model["BJT", "QPNP741", "Q132"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QPNP741", "Q132"]\), 
                                        ",", 
                                        RowBox[{"AREA", "\[Rule]", 
                                        StyleBox["0.25`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        \(Parameters \[Rule] 
                                        Parameters["BJT", "QPNP741", "Q132"]
                                        \), ",", \(IB$ac \[Rule] 
                                        \(-3.4499999999999984`*^-6\)\), ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.000218999999999999905`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.647000000000000063`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        StyleBox["13.700000000000001`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["14.29999999999999`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["63.7000000000000099`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.00848000000000000042`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["7510.00000000000156`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["400.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RO$ac", "\[Rule]", 
                                        StyleBox["290000.000000000035`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        \(CBE$ac \[Rule] 
                                        3.88999999999999843`*^-13\), ",", 
                                        \(CBC$ac \[Rule] 
                                        9.42999999999999971`*^-14\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["63.6000000000000031`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        2.79000000000000092`*^9\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"R5\"\>", ",", \({"15", "16"}\), 
                                        ",", \(Type \[Rule] Resistor\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        StyleBox["40000.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->5]}], ",", 
                                        \(Symbolic \[Rule] R5\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q14\"\>", ",", 
                                        \({"1" \[Rule] "C", "22" \[Rule] "B", 
                                        "25" \[Rule] "E"}\), ",", 
                                        \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q14"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q14"]\), 
                                        ",", 
                                        RowBox[{"AREA", "\[Rule]", 
                                        StyleBox["3.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->1]}], ",", 
                                        \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q14"]
                                        \), ",", \(IB$ac \[Rule] 
                                        1.5700000000000001`*^-6\), ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        StyleBox["0.000342999999999999927`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["0.6379999999999999`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["14.29999999999999`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["14.9000000000000021`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["219.000000000000039`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.0133000000000000007`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["16500.0000000000017`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->5]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["66.7000000000000081`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RO$ac", "\[Rule]", 
                                        StyleBox["478000.000000000024`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        \(CBE$ac \[Rule] 
                                        4.63999999999999879`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        1.1200000000000001`*^-12\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["219.000000000000039`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        3.67000000000000126`*^8\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q15\"\>", ",", 
                                        \({"22" \[Rule] "C", 
                                        "25" \[Rule] "B", "26" \[Rule] "E"}
                                        \), ",", \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q15"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q15"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q15"]
                                        \), ",", \(IB$ac \[Rule] 
                                        \(-3.20000000000000017`*^-13\)\), 
                                        ",", \(IC$ac \[Rule] 
                                        9.74000000000000021`*^-13\), ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["0.00931000000000000049`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.6379999999999999`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["0.648000000000000042`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["3.04000000000000003`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        \(GM$ac \[Rule] 
                                        1.07000000000000006`*^-13\), ",", 
                                        \(RPI$ac \[Rule] 
                                        1.80000000000000071`*^14\), ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 
                                        9.91000000000000191`*^11\), ",", 
                                        \(CBE$ac \[Rule] 1.`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        8.16000000000000014`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["19.3000000000000007`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"FT$ac", "\[Rule]", 
                                        StyleBox["0.00934999999999999786`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{"\<\"Q16\"\>", ",", 
                                        \({"1" \[Rule] "C", "18" \[Rule] "B", 
                                        "19" \[Rule] "E"}\), ",", 
                                        \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q16"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q16"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q16"]
                                        \), ",", \(IB$ac \[Rule] 
                                        7.61000000000000031`*^-8\), ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        StyleBox["0.0000181000000000000014`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["0.5879999999999999`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["28.700000000000001`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["29.1999999999999904`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["238.000000000000033`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.000701000000000000067`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["340000.000000000035`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 
                                        9.86000000000000298`*^6\), ",", 
                                        \(CBE$ac \[Rule] 
                                        1.49000000000000003`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        2.98000000000000007`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["238.000000000000033`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        6.23000000000000309`*^7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q17\"\>", ",", 
                                        \({"17" \[Rule] "C", 
                                        "19" \[Rule] "B", "20" \[Rule] "E"}
                                        \), ",", \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q17"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q17"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q17"]
                                        \), ",", \(IB$ac \[Rule] 
                                        3.129999999999999`*^-6\), ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        StyleBox["0.000679999999999999893`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["0.684999999999999964`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["13.1000000000000005`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["13.79999999999999`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["217.000000000000037`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.02629999999999999`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["8270.00000000000312`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RO$ac", "\[Rule]", 
                                        StyleBox["240000.000000000035`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        \(CBE$ac \[Rule] 
                                        1.60000000000000008`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        3.82000000000000028`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["217.000000000000037`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        2.11000000000000031`*^9\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"R6\"\>", ",", \({"26", "25"}\), 
                                        ",", \(Type \[Rule] Resistor\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        StyleBox["27.0000000000000017`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        \(Symbolic \[Rule] R6\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"R7\"\>", ",", \({"27", "26"}\), 
                                        ",", \(Type \[Rule] Resistor\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        StyleBox["22.0000000000000017`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        \(Symbolic \[Rule] R7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"R8\"\>", ",", \({"13", "20"}\), 
                                        ",", \(Type \[Rule] Resistor\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        StyleBox["100.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(Symbolic \[Rule] R8\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"R9\"\>", ",", \({"13", "19"}\), 
                                        ",", \(Type \[Rule] Resistor\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        StyleBox["50000.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->5]}], ",", 
                                        \(Symbolic \[Rule] R9\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"R10\"\>", ",", \({"24", "23"}\), 
                                        ",", \(Type \[Rule] Resistor\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        StyleBox["50000.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->5]}], ",", 
                                        \(Symbolic \[Rule] R10\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{"\<\"R11\"\>", ",", 
                                        \({"13", "21"}\), ",", 
                                        \(Type \[Rule] Resistor\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        StyleBox["50000.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->5]}], ",", 
                                        \(Symbolic \[Rule] R11\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"R12\"\>", ",", \({"18", "9"}\), 
                                        ",", \(Type \[Rule] Resistor\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        StyleBox["300.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(Symbolic \[Rule] R12\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q18\"\>", ",", 
                                        \({"22" \[Rule] "C", 
                                        "22" \[Rule] "B", "23" \[Rule] "E"}
                                        \), ",", \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q18"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q18"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q18"]
                                        \), ",", \(IB$ac \[Rule] 
                                        7.03000000000000202`*^-8\), ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        StyleBox["0.0000140999999999999907`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["0.58600000000000012`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        \(VBC$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["0.58600000000000012`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.00054300000000000006`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["368000.000000000015`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 
                                        1.07000000000000028`*^7\), ",", 
                                        \(CBE$ac \[Rule] 
                                        1.49000000000000003`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 1.`*^-12\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        3.47000000000000063`*^7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q19\"\>", ",", 
                                        \({"22" \[Rule] "C", 
                                        "23" \[Rule] "B", "24" \[Rule] "E"}
                                        \), ",", \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q19"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q19"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q19"]
                                        \), ",", \(IB$ac \[Rule] 1.01`*^-6\), 
                                        ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        StyleBox["0.000204000000000000003`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["0.655999999999999783`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.58600000000000012`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["1.2399999999999991`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["200.999999999999934`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.0078700000000000001`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["25500.0000000000026`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->5]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RO$ac", "\[Rule]", 
                                        StyleBox["740000.000000000035`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        \(CBE$ac \[Rule] 
                                        1.56999999999999895`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        8.26000000000000156`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["200.999999999999934`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        5.23000000000000309`*^8\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q20\"\>", ",", 
                                        \({"13" \[Rule] "C", 
                                        "24" \[Rule] "B", "27" \[Rule] "E"}
                                        \), ",", \(Model \[Rule] 
                                        Model["BJT", "QPNP741", "Q20"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QPNP741", "Q20"]\), 
                                        ",", 
                                        RowBox[{"AREA", "\[Rule]", 
                                        StyleBox["3.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->1]}], ",", 
                                        \(Parameters \[Rule] 
                                        Parameters["BJT", "QPNP741", "Q20"]
                                        \), ",", \(IB$ac \[Rule] 
                                        \(-4.45000000000000106`*^-6\)\), 
                                        ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.000286999999999999957`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.5879999999999999`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        StyleBox["14.5000000000000017`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["15.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["64.5000000000000017`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.0111000000000000009`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["5810.00000000000049`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->4]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["33.3000000000000007`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RO$ac", "\[Rule]", 
                                        StyleBox["225000.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        \(CBE$ac \[Rule] 
                                        4.48000000000000042`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        1.11000000000000009`*^-12\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["64.4000000000000127`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        3.16000000000000191`*^8\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q21\"\>", ",", 
                                        \({"21" \[Rule] "C", 
                                        "27" \[Rule] "B", "26" \[Rule] "E"}
                                        \), ",", \(Model \[Rule] 
                                        Model["BJT", "QPNP741", "Q21"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QPNP741", "Q21"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QPNP741", "Q21"]
                                        \), ",", \(IB$ac \[Rule] 
                                        5.01999999999999779`*^-12\), ",", 
                                        \(IC$ac \[Rule] 
                                        \(-2.4600000000000004`*^-11\)\), 
                                        ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.00641000000000000014`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        StyleBox["15.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["15.0999999999999907`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["4.91000000000000014`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        \(GM$ac \[Rule] 
                                        3.43000000000000015`*^-13\), ",", 
                                        \(RPI$ac \[Rule] 
                                        3.34000000000000074`*^13\), ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["100.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 
                                        6.24000000000000287`*^11\), ",", 
                                        \(CBE$ac \[Rule] 1.`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        3.66000000000000103`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["11.5000000000000013`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"FT$ac", "\[Rule]", 
                                        StyleBox["0.0398999999999999985`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q24\"\>", ",", 
                                        \({"21" \[Rule] "C", 
                                        "21" \[Rule] "B", "13" \[Rule] "E"}
                                        \), ",", \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q24"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q24"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q24"]
                                        \), ",", \(IB$ac \[Rule] 
                                        6.8099999999999996`*^-21\), ",", 
                                        \(IC$ac \[Rule] 
                                        1.35999999999999898`*^-18\), ",", 
                                        \(VBE$ac \[Rule] 1.26`*^-6\), ",", 
                                        \(VBC$ac \[Rule] 0.`\), ",", 
                                        \(VCE$ac \[Rule] 1.26`*^-6\), ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["136.000000000000031`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(GM$ac \[Rule] 
                                        3.77000000000000001`*^-18\), ",", 
                                        \(RPI$ac \[Rule] 
                                        1.86000000000000049`*^14\), ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 
                                        9.28000000000000291`*^11\), ",", 
                                        \(CBE$ac \[Rule] 1.`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 1.`*^-12\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["0.000700000000000000088`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->1]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 3.`*^-7\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q23\"\>", ",", 
                                        \({"18" \[Rule] "C", 
                                        "21" \[Rule] "B", "13" \[Rule] "E"}
                                        \), ",", \(Model \[Rule] 
                                        Model["BJT", "QNPN741", "Q23"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QNPN741", "Q23"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QNPN741", "Q23"]
                                        \), ",", \(IB$ac \[Rule] 
                                        \(-6.71999999999999797`*^-13\)\), 
                                        ",", \(IC$ac \[Rule] 
                                        2.02999999999999891`*^-12\), ",", 
                                        \(VBE$ac \[Rule] 1.26`*^-6\), ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["1.34000000000000007`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        StyleBox["1.34000000000000007`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["3.02000000000000001`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        \(GM$ac \[Rule] 
                                        6.90999999999999836`*^-14\), ",", 
                                        \(RPI$ac \[Rule] 
                                        1.86000000000000049`*^14\), ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["200.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 
                                        9.82000000000000028`*^11\), ",", 
                                        \(CBE$ac \[Rule] 1.`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        7.13000000000000078`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["12.8000000000000024`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"FT$ac", "\[Rule]", 
                                        StyleBox["0.0064200000000000017`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], "}"}]},
                                        {
                                        \({"C1", {"18", "17"}, 
                                        Type \[Rule] Capacitor, 
                                        Value \[Rule] 3.`*^-11, 
                                        Symbolic \[Rule] C1}\)},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{"\<\"Q222\"\>", ",", 
                                        \({"13" \[Rule] "C", 
                                        "17" \[Rule] "B", "24" \[Rule] "E"}
                                        \), ",", \(Model \[Rule] 
                                        Model["BJT", "QPNP741", "Q222"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QPNP741", "Q222"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QPNP741", "Q222"]
                                        \), ",", \(IB$ac \[Rule] 
                                        \(-3.43000000000000015`*^-6\)\), 
                                        ",", 
                                        RowBox[{"IC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.000218999999999999905`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.609999999999999875`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        StyleBox["13.89999999999999`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["14.5000000000000017`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        StyleBox["63.9000000000000056`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"GM$ac", "\[Rule]", 
                                        StyleBox["0.00844999999999999928`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"RPI$ac", "\[Rule]", 
                                        StyleBox["7550.00000000000071`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->4]}], ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["100.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"RO$ac", "\[Rule]", 
                                        StyleBox["292000.000000000028`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->6]}], ",", 
                                        \(CBE$ac \[Rule] 
                                        1.52000000000000028`*^-12\), ",", 
                                        \(CBC$ac \[Rule] 
                                        3.75000000000000044`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        StyleBox["63.79999999999999`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        \(FT$ac \[Rule] 
                                        7.11000000000000298`*^8\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"Q221\"\>", ",", 
                                        \({"13" \[Rule] "C", 
                                        "17" \[Rule] "B", "18" \[Rule] "E"}
                                        \), ",", \(Model \[Rule] 
                                        Model["BJT", "QPNP741", "Q221"]\), 
                                        ",", \(Selector \[Rule] 
                                        Selector["BJT", "QPNP741", "Q221"]\), 
                                        ",", \(Parameters \[Rule] 
                                        Parameters["BJT", "QPNP741", "Q221"]
                                        \), ",", \(IB$ac \[Rule] 
                                        4.86999999999999921`*^-12\), ",", 
                                        \(IC$ac \[Rule] 
                                        \(-6.33000000000000007`*^-12\)\), 
                                        ",", 
                                        RowBox[{"VBE$ac", "\[Rule]", 
                                        StyleBox["12.5`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"VBC$ac", "\[Rule]", 
                                        StyleBox["13.89999999999999`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->16]}], ",", 
                                        RowBox[{"VCE$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["1.34000000000000007`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        RowBox[{"BETADC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["1.30000000000000004`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}]}], ",", 
                                        \(GM$ac \[Rule] 
                                        \(-2.68000000000000015`*^-14\)\), 
                                        ",", \(RPI$ac \[Rule] 
                                        5.00000000000000355`*^13\), ",", 
                                        RowBox[{"RX$ac", "\[Rule]", 
                                        StyleBox["100.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        \(RO$ac \[Rule] 
                                        7.67000000000000348`*^11\), ",", 
                                        \(CBE$ac \[Rule] 
                                        3.879999999999999`*^-13\), ",", 
                                        \(CBC$ac \[Rule] 
                                        3.75000000000000044`*^-13\), ",", 
                                        \(CJS$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"BETAAC$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["1.34000000000000007`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], ",", 
                                        \(CBX$ac \[Rule] 0.`\), ",", 
                                        RowBox[{"FT$ac", "\[Rule]", 
                                        RowBox[{"-", 
                                        StyleBox["0.00560000000000000053`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}]}]}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"V1\"\>", ",", \({"1", "0"}\), 
                                        ",", \(Type \[Rule] VoltageSource\), 
                                        ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{"DC", "\[Rule]", 
                                        StyleBox["15.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        RowBox[{"Transient", "\[Rule]", 
                                        StyleBox["15.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}]}], "}"}]}], ",", 
                                        \(Symbolic \[Rule] {DC \[Rule] V1, 
                                        Transient \[Rule] V1}\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"V2\"\>", ",", \({"0", "13"}\), 
                                        ",", \(Type \[Rule] VoltageSource\), 
                                        ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{"DC", "\[Rule]", 
                                        StyleBox["15.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}], ",", 
                                        RowBox[{"Transient", "\[Rule]", 
                                        StyleBox["15.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->2]}]}], "}"}]}], ",", 
                                        \(Symbolic \[Rule] {DC \[Rule] V2, 
                                        Transient \[Rule] V2}\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"VOS\"\>", ",", 
                                        \({"5", "$N$0001"}\), ",", 
                                        \(Type \[Rule] VoltageSource\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{"DC", "\[Rule]", 
                                        StyleBox["0.000321000000000000085`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}], ",", 
                                        RowBox[{"Transient", "\[Rule]", 
                                        StyleBox["0.000321000000000000085`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->3]}]}], "}"}]}], ",", 
                                        \(Symbolic \[Rule] {DC \[Rule] VOS, 
                                        Transient \[Rule] VOS}\)}], "}"}]},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"R13\"\>", ",", \({"26", "0"}\), 
                                        ",", \(Type \[Rule] Resistor\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        StyleBox["1000.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->4]}], ",", 
                                        \(Symbolic \[Rule] R13\)}], "}"}]},
                                        {
                                        \({"VIC", {"5", "0"}, 
                                        Type \[Rule] VoltageSource, 
                                        Value \[Rule] {DC \[Rule] 0.`, 
                                        Transient \[Rule] 0.`}, 
                                        Symbolic \[Rule] {DC \[Rule] VIC, 
                                        Transient \[Rule] VIC}}\)},
                                        {
                                        RowBox[{"{", 
                                        RowBox[{
                                        "\<\"VID\"\>", ",", 
                                        \({"4", "$N$0001"}\), ",", 
                                        \(Type \[Rule] VoltageSource\), ",", 
                                        RowBox[{"Value", "\[Rule]", 
                                        RowBox[{"{", 
                                        RowBox[{
                                        RowBox[{"AC", "\[Rule]", 
                                        StyleBox["1.`",
                                        StyleBoxAutoDelete->True,
                                        PrintPrecision->1]}], ",", 
                                        \(DC \[Rule] CheckedSinWave[Time, 
                                        0.`, 0.8`, 1000.`, 0.`, 0.`, 0.`]\), 
                                        ",", \(Transient \[Rule] 
                                        CheckedSinWave[Time, 0.`, 0.8`, 
                                        1000.`, 0.`, 0.`, 0.`]\)}], "}"}]}], 
                                        ",", \(Symbolic \[Rule] VID\)}], 
                                        "}"}]}
                                        },
                                        RowSpacings->1,
                                        ColumnSpacings->3,
                                        RowAlignments->Baseline,
                                        ColumnAlignments->{Left}],
                                        TableForm[ {
                                        
                                        SequenceForm[ {"Q1", {"2" -> "C", 
                                        "4" -> "B", "6" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q1"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q1"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q1"], 
                                        IB$ac -> .34200000000000002*^-7, 
                                        IC$ac -> .75000000000000002*^-5, 
                                        VBE$ac -> .56799999999999995, 
                                        VBC$ac -> -14.5, VCE$ac -> 15.0, 
                                        BETADC$ac -> 219.0, GM$ac -> .00029, 
                                        RPI$ac -> .756*^6, RX$ac -> .2*^3, 
                                        RO$ac -> .219*^8, 
                                        CBE$ac -> .147*^-11, 
                                        CBC$ac -> .37000000000000004*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 219.0, 
                                        CBX$ac -> 0.0, FT$ac -> 
                                        25099999.999999989}], 
                                        
                                        SequenceForm[ {"Q2", {"2" -> "C", 
                                        "5" -> "B", "7" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q2"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q2"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q2"], 
                                        IB$ac -> .3439999999999999*^-7, 
                                        IC$ac -> .75399999999999998*^-5, 
                                        VBE$ac -> .56799999999999995, 
                                        VBC$ac -> -14.5, VCE$ac -> 15.0, 
                                        BETADC$ac -> 219.0, 
                                        GM$ac -> .00029100000000000003, 
                                        RPI$ac -> .753*^6, RX$ac -> .2*^3, 
                                        RO$ac -> .218*^8, 
                                        CBE$ac -> .147*^-11, 
                                        CBC$ac -> .37000000000000004*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 219.0, 
                                        CBX$ac -> 0.0, FT$ac -> .252*^8}], 
                                        
                                        SequenceForm[ {"Q3", {"8" -> "C", 
                                        "3" -> "B", "6" -> "E"}, Model -> 
                                        Model[ "BJT", "QPNP741", "Q3"], 
                                        Selector -> Selector[ 
                                        "BJT", "QPNP741", "Q3"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QPNP741", "Q3"], 
                                        IB$ac -> -.11799999999999991*^-6, 
                                        IC$ac -> -.74199999999999993*^-5, 
                                        VBE$ac -> -.52200000000000002, 
                                        VBC$ac -> 12.800000000000001, 
                                        VCE$ac -> -13.300000000000001, 
                                        BETADC$ac -> 62.800000000000011, 
                                        GM$ac -> .00028699999999999998, 
                                        RPI$ac -> .219*^6, RX$ac -> .1*^3, 
                                        RO$ac -> .846*^7, 
                                        CBE$ac -> .142*^-11, 
                                        CBC$ac -> .38500000000000003*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 
                                        62.699999999999989, CBX$ac -> 0.0, 
                                        FT$ac -> 25299999.999999989}], 
                                        
                                        SequenceForm[ {"Q4", {"9" -> "C", 
                                        "3" -> "B", "7" -> "E"}, Model -> 
                                        Model[ "BJT", "QPNP741", "Q4"], 
                                        Selector -> Selector[ 
                                        "BJT", "QPNP741", "Q4"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QPNP741", "Q4"], 
                                        IB$ac -> -.1189999999999999*^-6, 
                                        IC$ac -> -.74499999999999998*^-5, 
                                        VBE$ac -> -.52300000000000002, 
                                        VBC$ac -> 12.6, VCE$ac -> -13.1, 
                                        BETADC$ac -> 62.599999999999987, 
                                        GM$ac -> .00028800000000000001, 
                                        RPI$ac -> .217*^6, RX$ac -> .1*^3, 
                                        RO$ac -> .84*^7, CBE$ac -> .142*^-11, 
                                        CBC$ac -> .38700000000000002*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 62.5, 
                                        CBX$ac -> 0.0, FT$ac -> .254*^8}], 
                                        
                                        SequenceForm[ {"Q5", {"8" -> "C", 
                                        "10" -> "B", "11" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q5"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q5"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q5"], 
                                        IB$ac -> .36699999999999991*^-7, 
                                        IC$ac -> .73699999999999997*^-5, 
                                        VBE$ac -> .57000000000000006, 
                                        VBC$ac -> -.57699999999999985, 
                                        VCE$ac -> 1.149999999999999, 
                                        BETADC$ac -> 200.99999999999989, 
                                        GM$ac -> .00028499999999999999, 
                                        RPI$ac -> .705*^6, RX$ac -> .2*^3, 
                                        RO$ac -> .204*^8, 
                                        CBE$ac -> .147*^-11, 
                                        CBC$ac -> .8279999999999998*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 
                                        200.99999999999989, CBX$ac -> 0.0, 
                                        FT$ac -> .197*^8}], 
                                        
                                        SequenceForm[ {"Q6", {"9" -> "C", 
                                        "10" -> "B", "12" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q6"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q6"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q6"], 
                                        IB$ac -> .36699999999999991*^-7, 
                                        IC$ac -> .73699999999999997*^-5, 
                                        VBE$ac -> .57000000000000006, 
                                        VBC$ac -> -.76500000000000001, 
                                        VCE$ac -> 1.3300000000000001, 
                                        BETADC$ac -> 200.99999999999989, 
                                        GM$ac -> .00028499999999999999, 
                                        RPI$ac -> .705*^6, RX$ac -> .2*^3, 
                                        RO$ac -> .204*^8, 
                                        CBE$ac -> .147*^-11, 
                                        CBC$ac -> .79299999999999985*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 
                                        200.99999999999989, CBX$ac -> 0.0, 
                                        FT$ac -> .2*^8}], 
                                        
                                        SequenceForm[ {"Q7", {"1" -> "C", 
                                        "8" -> "B", "10" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q7"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q7"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q7"], 
                                        IB$ac -> .48499999999999984*^-7, 
                                        IC$ac -> .000011599999999999991, 
                                        VBE$ac -> .57699999999999985, 
                                        VBC$ac -> -28.79999999999999, 
                                        VCE$ac -> 29.399999999999991, 
                                        BETADC$ac -> 239.0, 
                                        GM$ac -> .00044700000000000002, 
                                        RPI$ac -> .533*^6, RX$ac -> .2*^3, 
                                        RO$ac -> .155*^8, 
                                        CBE$ac -> .148*^-11, 
                                        CBC$ac -> .2969999999999999*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 238.0, 
                                        CBX$ac -> 0.0, FT$ac -> .4*^8}], 
                                        
                                        SequenceForm[ {"Q8", {"2" -> "C", 
                                        "2" -> "B", "1" -> "E"}, Model -> 
                                        Model[ "BJT", "QPNP741", "Q8"], 
                                        Selector -> Selector[ 
                                        "BJT", "QPNP741", "Q8"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QPNP741", "Q8"], 
                                        IB$ac -> -.28900000000000001*^-6, 
                                        IC$ac -> -.0000145, 
                                        VBE$ac -> -.54600000000000004, 
                                        VBC$ac -> 0.0, 
                                        VCE$ac -> -.54600000000000004, 
                                        BETADC$ac -> .5*^2, 
                                        GM$ac -> .00055900000000000004, 
                                        RPI$ac -> 89500.000000000015, 
                                        RX$ac -> .1*^3, RO$ac -> .346*^7, 
                                        CBE$ac -> .14499999999999999*^-11, 
                                        CBC$ac -> .99999999999999998*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> .5*^2, 
                                        CBX$ac -> 0.0, FT$ac -> .364*^8}], 
                                        
                                        SequenceForm[ {"R1", {"13", "11"}, 
                                        Type -> Resistor, Value -> .1*^4, 
                                        Symbolic -> R1}], 
                                        
                                        SequenceForm[ {"R2", {"13", "12"}, 
                                        Type -> Resistor, Value -> .1*^4, 
                                        Symbolic -> R2}], 
                                        SequenceForm[ {"R3", {"13", "10"}, 
                                        Type -> Resistor, Value -> .5*^5, 
                                        Symbolic -> R3}], 
                                        
                                        SequenceForm[ {"Q9", {"3" -> "C", 
                                        "2" -> "B", "1" -> "E"}, Model -> 
                                        Model[ "BJT", "QPNP741", "Q9"], 
                                        Selector -> Selector[ 
                                        "BJT", "QPNP741", "Q9"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QPNP741", "Q9"], 
                                        IB$ac -> -.28900000000000001*^-6, 
                                        IC$ac -> -.000018999999999999991, 
                                        VBE$ac -> -.54600000000000004, 
                                        VBC$ac -> 15.5, 
                                        VCE$ac -> -16.100000000000001, 
                                        BETADC$ac -> 65.5, 
                                        GM$ac -> .00073200000000000001, 
                                        RPI$ac -> 89500.000000000015, 
                                        RX$ac -> .1*^3, RO$ac -> .346*^7, 
                                        CBE$ac -> .14499999999999999*^-11, 
                                        CBC$ac -> .36200000000000002*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 65.5, 
                                        CBX$ac -> 0.0, FT$ac -> .645*^8}], 
                                        
                                        SequenceForm[ {"Q10", {"3" -> "C", 
                                        "15" -> "B", "14" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q10"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q10"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q10"], 
                                        IB$ac -> .88200000000000009*^-7, 
                                        IC$ac -> .000019199999999999989, 
                                        VBE$ac -> .59199999999999986, 
                                        VBC$ac -> -13.199999999999999, 
                                        VCE$ac -> 13.79999999999999, 
                                        BETADC$ac -> 218.0, 
                                        GM$ac -> .00074199999999999993, 
                                        RPI$ac -> .293*^6, RX$ac -> .2*^3, 
                                        RO$ac -> 8510000.0000000019, 
                                        CBE$ac -> .15000000000000001*^-11, 
                                        CBC$ac -> .38099999999999994*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 218.0, 
                                        CBX$ac -> 0.0, FT$ac -> .629*^8}], 
                                        
                                        SequenceForm[ {"Q11", {"15" -> "C", 
                                        "15" -> "B", "13" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q11"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q11"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q11"], 
                                        IB$ac -> .35600000000000002*^-5, 
                                        IC$ac -> .00071299999999999998, 
                                        VBE$ac -> .68899999999999995, 
                                        VBC$ac -> 0.0, 
                                        VCE$ac -> .68899999999999995, 
                                        BETADC$ac -> .2*^3, GM$ac -> .0276, 
                                        RPI$ac -> 7260.0000000000009, 
                                        RX$ac -> .2*^3, RO$ac -> .21*^6, 
                                        CBE$ac -> .16*^-11, 
                                        CBC$ac -> .99999999999999998*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> .2*^3, 
                                        CBX$ac -> 0.0, FT$ac -> .169*^10}], 
                                        
                                        SequenceForm[ {"R4", {"13", "14"}, 
                                        Type -> Resistor, Value -> .5*^4, 
                                        Symbolic -> R4}], 
                                        
                                        SequenceForm[ {"Q12", {"16" -> "C", 
                                        "16" -> "B", "1" -> "E"}, Model -> 
                                        Model[ "BJT", "QPNP741", "Q12"], 
                                        Selector -> Selector[ 
                                        "BJT", "QPNP741", "Q12"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QPNP741", "Q12"], 
                                        IB$ac -> -.0000138, 
                                        IC$ac -> -.00068899999999999983, 
                                        VBE$ac -> -.64700000000000002, 
                                        VBC$ac -> 0.0, 
                                        VCE$ac -> -.64700000000000002, 
                                        BETADC$ac -> .5*^2, 
                                        GM$ac -> .026599999999999999, 
                                        RPI$ac -> .188*^4, RX$ac -> .1*^3, 
                                        RO$ac -> 72600.000000000015, 
                                        CBE$ac -> .156*^-11, 
                                        CBC$ac -> .99900000000000009*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> .5*^2, 
                                        CBX$ac -> 0.0, FT$ac -> .166*^10}], 
                                        
                                        SequenceForm[ {"Q131", {"17" -> "C", 
                                        "16" -> "B", "1" -> "E"}, Model -> 
                                        Model[ "BJT", "QPNP741", "Q131"], 
                                        Selector -> Selector[ 
                                        "BJT", "QPNP741", "Q131"], 
                                        AREA -> .75, Parameters -> 
                                        Parameters[ 
                                        "BJT", "QPNP741", "Q131"], 
                                        IB$ac -> -.000010299999999999989, 
                                        IC$ac -> -.00067699999999999987, 
                                        VBE$ac -> -.64700000000000002, 
                                        VBC$ac -> 15.5, 
                                        VCE$ac -> -16.199999999999999, 
                                        BETADC$ac -> 65.5, 
                                        GM$ac -> .026200000000000001, 
                                        RPI$ac -> .25*^4, RX$ac -> 133.0, 
                                        RO$ac -> 96800.000000000015, 
                                        CBE$ac -> .11699999999999991*^-11, 
                                        CBC$ac -> .2719999999999999*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 65.5, 
                                        CBX$ac -> 0.0, FT$ac -> .289*^10}], 
                                        
                                        SequenceForm[ {"Q132", {"22" -> "C", 
                                        "16" -> "B", "1" -> "E"}, Model -> 
                                        Model[ "BJT", "QPNP741", "Q132"], 
                                        Selector -> Selector[ 
                                        "BJT", "QPNP741", "Q132"], 
                                        AREA -> .25, Parameters -> 
                                        Parameters[ 
                                        "BJT", "QPNP741", "Q132"], 
                                        IB$ac -> -.34499999999999987*^-5, 
                                        IC$ac -> -.0002189999999999999, 
                                        VBE$ac -> -.64700000000000002, 
                                        VBC$ac -> 13.699999999999999, 
                                        VCE$ac -> -14.29999999999999, 
                                        BETADC$ac -> 63.700000000000003, 
                                        GM$ac -> .0084799999999999997, 
                                        RPI$ac -> 7510.0000000000009, 
                                        RX$ac -> .4*^3, RO$ac -> .29*^6, 
                                        CBE$ac -> .38899999999999986*^-12, 
                                        CBC$ac -> .943*^-13, CJS$ac -> 0.0, 
                                        BETAAC$ac -> 63.600000000000001, 
                                        CBX$ac -> 0.0, FT$ac -> .279*^10}], 
                                        
                                        SequenceForm[ {"R5", {"15", "16"}, 
                                        Type -> Resistor, Value -> .4*^5, 
                                        Symbolic -> R5}], 
                                        
                                        SequenceForm[ {"Q14", {"1" -> "C", 
                                        "22" -> "B", "25" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q14"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q14"], AREA -> 
                                        3.0, Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q14"], 
                                        IB$ac -> .157*^-5, 
                                        IC$ac -> .00034299999999999988, 
                                        VBE$ac -> .6379999999999999, 
                                        VBC$ac -> -14.29999999999999, 
                                        VCE$ac -> 14.9, BETADC$ac -> 219.0, 
                                        GM$ac -> .013299999999999999, 
                                        RPI$ac -> .165*^5, RX$ac -> 
                                        66.700000000000003, RO$ac -> .478*^6, 
                                        CBE$ac -> .46399999999999988*^-11, 
                                        CBC$ac -> .11200000000000001*^-11, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 219.0, 
                                        CBX$ac -> 0.0, FT$ac -> 
                                        367000000.00000006}], 
                                        
                                        SequenceForm[ {"Q15", {"22" -> "C", 
                                        "25" -> "B", "26" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q15"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q15"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q15"], 
                                        IB$ac -> -.32*^-12, 
                                        IC$ac -> .97400000000000009*^-12, 
                                        VBE$ac -> .0093100000000000006, 
                                        VBC$ac -> -.6379999999999999, 
                                        VCE$ac -> .64800000000000002, 
                                        BETADC$ac -> -3.04, 
                                        GM$ac -> .10700000000000001*^-12, 
                                        RPI$ac -> .18*^15, RX$ac -> .2*^3, 
                                        RO$ac -> .991*^12, 
                                        CBE$ac -> .99999999999999998*^-12, 
                                        CBC$ac -> .81600000000000006*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 
                                        19.300000000000001, CBX$ac -> 0.0, 
                                        FT$ac -> .0093499999999999972}], 
                                        SequenceForm[ {"Q16", {"1" -> "C", 
                                        "18" -> "B", "19" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q16"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q16"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q16"], 
                                        IB$ac -> .761*^-7, 
                                        IC$ac -> .000018099999999999999, 
                                        VBE$ac -> .58799999999999986, 
                                        VBC$ac -> -28.699999999999999, 
                                        VCE$ac -> 29.199999999999989, 
                                        BETADC$ac -> 238.0, 
                                        GM$ac -> .00070100000000000002, 
                                        RPI$ac -> .34*^6, RX$ac -> .2*^3, 
                                        RO$ac -> 9860000.0000000019, 
                                        CBE$ac -> .14899999999999999*^-11, 
                                        CBC$ac -> .29799999999999999*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 238.0, 
                                        CBX$ac -> 0.0, FT$ac -> 
                                        62300000.000000015}], 
                                        
                                        SequenceForm[ {"Q17", {"17" -> "C", 
                                        "19" -> "B", "20" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q17"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q17"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q17"], 
                                        IB$ac -> .31299999999999988*^-5, 
                                        IC$ac -> .00067999999999999983, 
                                        VBE$ac -> .68499999999999994, 
                                        VBC$ac -> -13.1, VCE$ac -> 
                                        13.79999999999999, BETADC$ac -> 
                                        217.0, GM$ac -> .02629999999999999, 
                                        RPI$ac -> 8270.0000000000018, 
                                        RX$ac -> .2*^3, RO$ac -> .24*^6, 
                                        CBE$ac -> .16*^-11, 
                                        CBC$ac -> .38199999999999999*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 217.0, 
                                        CBX$ac -> 0.0, FT$ac -> 
                                        2109999999.9999998}], 
                                        
                                        SequenceForm[ {"R6", {"26", "25"}, 
                                        Type -> Resistor, Value -> 27.0, 
                                        Symbolic -> R6}], 
                                        
                                        SequenceForm[ {"R7", {"27", "26"}, 
                                        Type -> Resistor, Value -> 22.0, 
                                        Symbolic -> R7}], 
                                        
                                        SequenceForm[ {"R8", {"13", "20"}, 
                                        Type -> Resistor, Value -> .1*^3, 
                                        Symbolic -> R8}], 
                                        
                                        SequenceForm[ {"R9", {"13", "19"}, 
                                        Type -> Resistor, Value -> .5*^5, 
                                        Symbolic -> R9}], 
                                        
                                        SequenceForm[ {"R10", {"24", "23"}, 
                                        Type -> Resistor, Value -> .5*^5, 
                                        Symbolic -> R10}], 
                                        
                                        SequenceForm[ {"R11", {"13", "21"}, 
                                        Type -> Resistor, Value -> .5*^5, 
                                        Symbolic -> R11}], 
                                        
                                        SequenceForm[ {"R12", {"18", "9"}, 
                                        Type -> Resistor, Value -> .3*^3, 
                                        Symbolic -> R12}], 
                                        
                                        SequenceForm[ {"Q18", {"22" -> "C", 
                                        "22" -> "B", "23" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q18"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q18"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q18"], 
                                        IB$ac -> .70300000000000014*^-7, 
                                        IC$ac -> .00001409999999999999, 
                                        VBE$ac -> .58600000000000008, 
                                        VBC$ac -> 0.0, 
                                        VCE$ac -> .58600000000000008, 
                                        BETADC$ac -> .2*^3, 
                                        GM$ac -> .00054299999999999997, 
                                        RPI$ac -> .368*^6, RX$ac -> .2*^3, 
                                        RO$ac -> .107*^8, 
                                        CBE$ac -> .14899999999999999*^-11, 
                                        CBC$ac -> .99999999999999998*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> .2*^3, 
                                        CBX$ac -> 0.0, FT$ac -> .347*^8}], 
                                        
                                        SequenceForm[ {"Q19", {"22" -> "C", 
                                        "23" -> "B", "24" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q19"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q19"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q19"], 
                                        IB$ac -> .10100000000000001*^-5, 
                                        IC$ac -> .000204, 
                                        VBE$ac -> .65599999999999981, 
                                        VBC$ac -> -.58600000000000008, 
                                        VCE$ac -> 1.2399999999999991, 
                                        BETADC$ac -> 200.99999999999989, 
                                        GM$ac -> .0078700000000000003, 
                                        RPI$ac -> .255*^5, RX$ac -> .2*^3, 
                                        RO$ac -> .74*^6, 
                                        CBE$ac -> .1569999999999999*^-11, 
                                        CBC$ac -> .82600000000000012*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 
                                        200.99999999999989, CBX$ac -> 0.0, 
                                        FT$ac -> 523000000.00000012}], 
                                        
                                        SequenceForm[ {"Q20", {"13" -> "C", 
                                        "24" -> "B", "27" -> "E"}, Model -> 
                                        Model[ "BJT", "QPNP741", "Q20"], 
                                        Selector -> Selector[ 
                                        "BJT", "QPNP741", "Q20"], AREA -> 
                                        3.0, Parameters -> Parameters[ 
                                        "BJT", "QPNP741", "Q20"], 
                                        IB$ac -> -.44500000000000014*^-5, 
                                        IC$ac -> -.00028699999999999998, 
                                        VBE$ac -> -.58799999999999986, 
                                        VBC$ac -> 14.5, VCE$ac -> -15.0, 
                                        BETADC$ac -> 64.5, GM$ac -> .0111, 
                                        RPI$ac -> .581*^4, RX$ac -> 
                                        33.299999999999997, RO$ac -> .225*^6, 
                                        CBE$ac -> .44800000000000003*^-11, 
                                        CBC$ac -> .11100000000000001*^-11, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 
                                        64.400000000000006, CBX$ac -> 0.0, 
                                        FT$ac -> 316000000.00000012}], 
                                        
                                        SequenceForm[ {"Q21", {"21" -> "C", 
                                        "27" -> "B", "26" -> "E"}, Model -> 
                                        Model[ "BJT", "QPNP741", "Q21"], 
                                        Selector -> Selector[ 
                                        "BJT", "QPNP741", "Q21"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QPNP741", "Q21"], 
                                        IB$ac -> .50199999999999984*^-11, 
                                        IC$ac -> -.24600000000000001*^-10, 
                                        VBE$ac -> -.0064099999999999999, 
                                        VBC$ac -> 15.0, 
                                        VCE$ac -> -15.099999999999991, 
                                        BETADC$ac -> -4.9100000000000001, 
                                        GM$ac -> .343*^-12, 
                                        RPI$ac -> .334*^14, RX$ac -> .1*^3, 
                                        RO$ac -> 624000000000.00012, 
                                        CBE$ac -> .99999999999999998*^-12, 
                                        CBC$ac -> .36600000000000011*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 11.5, 
                                        CBX$ac -> 0.0, 
                                        FT$ac -> .039899999999999998}], 
                                        
                                        SequenceForm[ {"Q24", {"21" -> "C", 
                                        "21" -> "B", "13" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q24"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q24"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q24"], 
                                        IB$ac -> .68099999999999992*^-20, 
                                        IC$ac -> .13599999999999989*^-17, 
                                        VBE$ac -> .126*^-5, VBC$ac -> 0.0, 
                                        VCE$ac -> .126*^-5, BETADC$ac -> 
                                        136.0, GM$ac -> .377*^-17, 
                                        RPI$ac -> .186*^15, RX$ac -> .2*^3, 
                                        RO$ac -> 928000000000.00012, 
                                        CBE$ac -> .99999999999999998*^-12, 
                                        CBC$ac -> .99999999999999998*^-12, 
                                        CJS$ac -> 0.0, 
                                        BETAAC$ac -> .00069999999999999999, 
                                        CBX$ac -> 0.0, 
                                        FT$ac -> .29999999999999999*^-6}], 
                                        
                                        SequenceForm[ {"Q23", {"18" -> "C", 
                                        "21" -> "B", "13" -> "E"}, Model -> 
                                        Model[ "BJT", "QNPN741", "Q23"], 
                                        Selector -> Selector[ 
                                        "BJT", "QNPN741", "Q23"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QNPN741", "Q23"], 
                                        IB$ac -> -.67199999999999976*^-12, 
                                        IC$ac -> .20299999999999988*^-11, 
                                        VBE$ac -> .126*^-5, 
                                        VBC$ac -> -1.3400000000000001, 
                                        VCE$ac -> 1.3400000000000001, 
                                        BETADC$ac -> -3.02, 
                                        GM$ac -> .69099999999999991*^-13, 
                                        RPI$ac -> .186*^15, RX$ac -> .2*^3, 
                                        RO$ac -> .982*^12, 
                                        CBE$ac -> .99999999999999998*^-12, 
                                        CBC$ac -> .71299999999999999*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 
                                        12.800000000000001, CBX$ac -> 0.0, 
                                        FT$ac -> .0064200000000000012}], 
                                        
                                        SequenceForm[ {"C1", {"18", "17"}, 
                                        Type -> Capacitor, Value -> .3*^-10, 
                                        Symbolic -> C1}], 
                                        
                                        SequenceForm[ {"Q222", {"13" -> "C", 
                                        "17" -> "B", "24" -> "E"}, Model -> 
                                        Model[ "BJT", "QPNP741", "Q222"], 
                                        Selector -> Selector[ 
                                        "BJT", "QPNP741", "Q222"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QPNP741", "Q222"], 
                                        IB$ac -> -.34300000000000002*^-5, 
                                        IC$ac -> -.0002189999999999999, 
                                        VBE$ac -> -.60999999999999988, 
                                        VBC$ac -> 13.89999999999999, 
                                        VCE$ac -> -14.5, BETADC$ac -> 
                                        63.899999999999999, 
                                        GM$ac -> .0084499999999999992, 
                                        RPI$ac -> .755*^4, RX$ac -> .1*^3, 
                                        RO$ac -> .292*^6, 
                                        CBE$ac -> .152*^-11, 
                                        CBC$ac -> .37500000000000002*^-12, 
                                        CJS$ac -> 0.0, BETAAC$ac -> 
                                        63.79999999999999, CBX$ac -> 0.0, 
                                        FT$ac -> 711000000.00000012}], 
                                        
                                        SequenceForm[ {"Q221", {"13" -> "C", 
                                        "17" -> "B", "18" -> "E"}, Model -> 
                                        Model[ "BJT", "QPNP741", "Q221"], 
                                        Selector -> Selector[ 
                                        "BJT", "QPNP741", "Q221"], 
                                        Parameters -> Parameters[ 
                                        "BJT", "QPNP741", "Q221"], 
                                        IB$ac -> .48699999999999992*^-11, 
                                        IC$ac -> -.63299999999999999*^-11, 
                                        VBE$ac -> 12.5, VBC$ac -> 
                                        13.89999999999999, 
                                        VCE$ac -> -1.3400000000000001, 
                                        BETADC$ac -> -1.3, 
                                        GM$ac -> -.268*^-13, RPI$ac -> 
                                        50000000000000.008, RX$ac -> .1*^3, 
                                        RO$ac -> 767000000000.00012, 
                                        CBE$ac -> .38799999999999991*^-12, 
                                        CBC$ac -> .37500000000000002*^-12, 
                                        CJS$ac -> 0.0, 
                                        BETAAC$ac -> -1.3400000000000001, 
                                        CBX$ac -> 0.0, 
                                        FT$ac -> -.0055999999999999999}], 
                                        
                                        SequenceForm[ {"V1", {"1", "0"}, 
                                        Type -> VoltageSource, Value -> {
                                        DC -> 15.0, Transient -> 15.0}, 
                                        Symbolic -> {DC -> V1, Transient -> 
                                        V1}}], 
                                        
                                        SequenceForm[ {"V2", {"0", "13"}, 
                                        Type -> VoltageSource, Value -> {
                                        DC -> 15.0, Transient -> 15.0}, 
                                        Symbolic -> {DC -> V2, Transient -> 
                                        V2}}], 
                                        
                                        SequenceForm[ {"VOS", {"5", 
                                        "$N$0001"}, Type -> VoltageSource, 
                                        Value -> {DC -> .000321, 
                                        Transient -> .000321}, Symbolic -> {
                                        DC -> VOS, Transient -> VOS}}], 
                                        
                                        SequenceForm[ {"R13", {"26", "0"}, 
                                        Type -> Resistor, Value -> .1*^4, 
                                        Symbolic -> R13}], 
                                        
                                        SequenceForm[ {"VIC", {"5", "0"}, 
                                        Type -> VoltageSource, Value -> {
                                        DC -> 0.0, Transient -> 0.0}, 
                                        Symbolic -> {DC -> VIC, Transient -> 
                                        VIC}}], 
                                        
                                        SequenceForm[ {"VID", {"4", 
                                        "$N$0001"}, Type -> VoltageSource, 
                                        Value -> {AC -> 1.0, DC -> 
                                        CheckedSinWave[ 
                                        Time, 0.0, .80000000000000004, .1*^4, 
                                        0.0, 0.0, 0.0], Transient -> 
                                        CheckedSinWave[ 
                                        Time, 0.0, .80000000000000004, .1*^4, 
                                        0.0, 0.0, 0.0]}, Symbolic -> 
                                        VID}]}]]}
                                        },
                                      RowSpacings->1,
                                      ColumnSpacings->0,
                                      RowAlignments->Baseline,
                                      ColumnAlignments->{Left}],
                                    (
                                    TableForm[ #, TableSpacing -> {1, 0}]&)]}
                                },
                              GridBaseline->{Baseline, {1, 1}},
                              ColumnAlignments->{Left}]},
                          {
                            RowBox[{
                            "\<\"LocalModelParameters[\"\>", 
                              "\[InvisibleSpace]", "\<\"QNPN741\"\>", 
                              "\[InvisibleSpace]", "\<\", \"\>", 
                              "\[InvisibleSpace]", \(Type \[Rule] "NPN"\), 
                              "\[InvisibleSpace]", "\<\", \"\>", 
                              "\[InvisibleSpace]", 
                              RowBox[{"BF", "\[Rule]", 
                                StyleBox["200.`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->3]}], "\[InvisibleSpace]", 
                              "\<\", \"\>", "\[InvisibleSpace]", 
                              \(IS \[Rule] 2.`*^-15\), "\[InvisibleSpace]", 
                              "\<\", \"\>", "\[InvisibleSpace]", 
                              RowBox[{"VAF", "\[Rule]", 
                                StyleBox["150.`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->3]}], "\[InvisibleSpace]", 
                              "\<\", \"\>", "\[InvisibleSpace]", 
                              RowBox[{"RB", "\[Rule]", 
                                StyleBox["200.`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->3]}], "\[InvisibleSpace]", 
                              "\<\", \"\>", "\[InvisibleSpace]", 
                              RowBox[{"BR", "\[Rule]", 
                                StyleBox["2.`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->1]}], "\[InvisibleSpace]", 
                              "\<\", \"\>", "\[InvisibleSpace]", 
                              \(CJE \[Rule] 1.`*^-12\), "\[InvisibleSpace]", 
                              "\<\", \"\>", "\[InvisibleSpace]", 
                              \(CJC \[Rule] 1.`*^-12\), "\[InvisibleSpace]", 
                              "\<\"]\"\>"}]},
                          {
                            RowBox[{
                            "\<\"LocalModelParameters[\"\>", 
                              "\[InvisibleSpace]", "\<\"QPNP741\"\>", 
                              "\[InvisibleSpace]", "\<\", \"\>", 
                              "\[InvisibleSpace]", \(Type \[Rule] "PNP"\), 
                              "\[InvisibleSpace]", "\<\", \"\>", 
                              "\[InvisibleSpace]", 
                              RowBox[{"BF", "\[Rule]", 
                                StyleBox["50.`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->2]}], "\[InvisibleSpace]", 
                              "\<\", \"\>", "\[InvisibleSpace]", 
                              \(IS \[Rule] 1.`*^-14\), "\[InvisibleSpace]", 
                              "\<\", \"\>", "\[InvisibleSpace]", 
                              RowBox[{"VAF", "\[Rule]", 
                                StyleBox["50.`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->2]}], "\[InvisibleSpace]", 
                              "\<\", \"\>", "\[InvisibleSpace]", 
                              RowBox[{"RB", "\[Rule]", 
                                StyleBox["100.`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->3]}], "\[InvisibleSpace]", 
                              "\<\", \"\>", "\[InvisibleSpace]", 
                              RowBox[{"BR", "\[Rule]", 
                                StyleBox["3.`",
                                  StyleBoxAutoDelete->True,
                                  PrintPrecision->1]}], "\[InvisibleSpace]", 
                              "\<\", \"\>", "\[InvisibleSpace]", 
                              \(CJE \[Rule] 1.`*^-12\), "\[InvisibleSpace]", 
                              "\<\", \"\>", "\[InvisibleSpace]", 
                              \(CJC \[Rule] 1.`*^-12\), "\[InvisibleSpace]", 
                              "\<\"]\"\>"}]},
                          {
                            \("GlobalParameters["\[InvisibleSpace]\(Simulator 
                                \[Rule] "PSpice"\)\[InvisibleSpace]"]"\)}
                          },
                        RowSpacings->1,
                        ColumnSpacings->3,
                        RowAlignments->Baseline,
                        ColumnAlignments->{Left}],
                      TableForm[ {
                        SequenceForm[ 
                          DisplayForm[ 
                            NetlistObject[ 
                            Checked][ {"Q1", {"2" -> "C", "4" -> "B", "6" -> 
                              "E"}, Model -> Model[ "BJT", "QNPN741", "Q1"], 
                              Selector -> Selector[ "BJT", "QNPN741", "Q1"], 
                              Parameters -> Parameters[ 
                              "BJT", "QNPN741", "Q1"], 
                              IB$ac -> .34200000000000002*^-7, 
                              IC$ac -> .75000000000000002*^-5, 
                              VBE$ac -> .56799999999999995, VBC$ac -> -14.5, 
                              VCE$ac -> 15.0, BETADC$ac -> 219.0, 
                              GM$ac -> .00029, RPI$ac -> .756*^6, 
                              RX$ac -> .2*^3, RO$ac -> .219*^8, 
                              CBE$ac -> .147*^-11, 
                              CBC$ac -> .37000000000000004*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 219.0, CBX$ac -> 0.0, 
                              FT$ac -> 25099999.999999989}, {"Q2", {"2" -> 
                              "C", "5" -> "B", "7" -> "E"}, Model -> Model[ 
                              "BJT", "QNPN741", "Q2"], Selector -> Selector[ 
                              "BJT", "QNPN741", "Q2"], Parameters -> 
                              Parameters[ "BJT", "QNPN741", "Q2"], 
                              IB$ac -> .3439999999999999*^-7, 
                              IC$ac -> .75399999999999998*^-5, 
                              VBE$ac -> .56799999999999995, VBC$ac -> -14.5, 
                              VCE$ac -> 15.0, BETADC$ac -> 219.0, 
                              GM$ac -> .00029100000000000003, 
                              RPI$ac -> .753*^6, RX$ac -> .2*^3, 
                              RO$ac -> .218*^8, CBE$ac -> .147*^-11, 
                              CBC$ac -> .37000000000000004*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 219.0, CBX$ac -> 0.0, 
                              FT$ac -> .252*^8}, {"Q3", {"8" -> "C", "3" -> 
                              "B", "6" -> "E"}, Model -> Model[ 
                              "BJT", "QPNP741", "Q3"], Selector -> Selector[ 
                              "BJT", "QPNP741", "Q3"], Parameters -> 
                              Parameters[ "BJT", "QPNP741", "Q3"], 
                              IB$ac -> -.11799999999999991*^-6, 
                              IC$ac -> -.74199999999999993*^-5, 
                              VBE$ac -> -.52200000000000002, VBC$ac -> 
                              12.800000000000001, 
                              VCE$ac -> -13.300000000000001, BETADC$ac -> 
                              62.800000000000011, 
                              GM$ac -> .00028699999999999998, 
                              RPI$ac -> .219*^6, RX$ac -> .1*^3, 
                              RO$ac -> .846*^7, CBE$ac -> .142*^-11, 
                              CBC$ac -> .38500000000000003*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 62.699999999999989, CBX$ac -> 
                              0.0, FT$ac -> 25299999.999999989}, {"Q4", {
                              "9" -> "C", "3" -> "B", "7" -> "E"}, Model -> 
                              Model[ "BJT", "QPNP741", "Q4"], Selector -> 
                              Selector[ "BJT", "QPNP741", "Q4"], 
                              Parameters -> Parameters[ 
                              "BJT", "QPNP741", "Q4"], 
                              IB$ac -> -.1189999999999999*^-6, 
                              IC$ac -> -.74499999999999998*^-5, 
                              VBE$ac -> -.52300000000000002, VBC$ac -> 12.6, 
                              VCE$ac -> -13.1, BETADC$ac -> 
                              62.599999999999987, 
                              GM$ac -> .00028800000000000001, 
                              RPI$ac -> .217*^6, RX$ac -> .1*^3, 
                              RO$ac -> .84*^7, CBE$ac -> .142*^-11, 
                              CBC$ac -> .38700000000000002*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 62.5, CBX$ac -> 0.0, 
                              FT$ac -> .254*^8}, {"Q5", {"8" -> "C", "10" -> 
                              "B", "11" -> "E"}, Model -> Model[ 
                              "BJT", "QNPN741", "Q5"], Selector -> Selector[ 
                              "BJT", "QNPN741", "Q5"], Parameters -> 
                              Parameters[ "BJT", "QNPN741", "Q5"], 
                              IB$ac -> .36699999999999991*^-7, 
                              IC$ac -> .73699999999999997*^-5, 
                              VBE$ac -> .57000000000000006, 
                              VBC$ac -> -.57699999999999985, VCE$ac -> 
                              1.149999999999999, BETADC$ac -> 
                              200.99999999999989, 
                              GM$ac -> .00028499999999999999, 
                              RPI$ac -> .705*^6, RX$ac -> .2*^3, 
                              RO$ac -> .204*^8, CBE$ac -> .147*^-11, 
                              CBC$ac -> .8279999999999998*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 200.99999999999989, CBX$ac -> 
                              0.0, FT$ac -> .197*^8}, {"Q6", {"9" -> "C", 
                              "10" -> "B", "12" -> "E"}, Model -> Model[ 
                              "BJT", "QNPN741", "Q6"], Selector -> Selector[ 
                              "BJT", "QNPN741", "Q6"], Parameters -> 
                              Parameters[ "BJT", "QNPN741", "Q6"], 
                              IB$ac -> .36699999999999991*^-7, 
                              IC$ac -> .73699999999999997*^-5, 
                              VBE$ac -> .57000000000000006, 
                              VBC$ac -> -.76500000000000001, VCE$ac -> 
                              1.3300000000000001, BETADC$ac -> 
                              200.99999999999989, 
                              GM$ac -> .00028499999999999999, 
                              RPI$ac -> .705*^6, RX$ac -> .2*^3, 
                              RO$ac -> .204*^8, CBE$ac -> .147*^-11, 
                              CBC$ac -> .79299999999999985*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 200.99999999999989, CBX$ac -> 
                              0.0, FT$ac -> .2*^8}, {"Q7", {"1" -> "C", 
                              "8" -> "B", "10" -> "E"}, Model -> Model[ 
                              "BJT", "QNPN741", "Q7"], Selector -> Selector[ 
                              "BJT", "QNPN741", "Q7"], Parameters -> 
                              Parameters[ "BJT", "QNPN741", "Q7"], 
                              IB$ac -> .48499999999999984*^-7, 
                              IC$ac -> .000011599999999999991, 
                              VBE$ac -> .57699999999999985, 
                              VBC$ac -> -28.79999999999999, VCE$ac -> 
                              29.399999999999991, BETADC$ac -> 239.0, 
                              GM$ac -> .00044700000000000002, 
                              RPI$ac -> .533*^6, RX$ac -> .2*^3, 
                              RO$ac -> .155*^8, CBE$ac -> .148*^-11, 
                              CBC$ac -> .2969999999999999*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 238.0, CBX$ac -> 0.0, 
                              FT$ac -> .4*^8}, {"Q8", {"2" -> "C", "2" -> 
                              "B", "1" -> "E"}, Model -> Model[ 
                              "BJT", "QPNP741", "Q8"], Selector -> Selector[ 
                              "BJT", "QPNP741", "Q8"], Parameters -> 
                              Parameters[ "BJT", "QPNP741", "Q8"], 
                              IB$ac -> -.28900000000000001*^-6, 
                              IC$ac -> -.0000145, 
                              VBE$ac -> -.54600000000000004, VBC$ac -> 0.0, 
                              VCE$ac -> -.54600000000000004, 
                              BETADC$ac -> .5*^2, 
                              GM$ac -> .00055900000000000004, RPI$ac -> 
                              89500.000000000015, RX$ac -> .1*^3, 
                              RO$ac -> .346*^7, 
                              CBE$ac -> .14499999999999999*^-11, 
                              CBC$ac -> .99999999999999998*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> .5*^2, CBX$ac -> 0.0, 
                              FT$ac -> .364*^8}, {"R1", {"13", "11"}, Type -> 
                              Resistor, Value -> .1*^4, Symbolic -> R1}, {
                              "R2", {"13", "12"}, Type -> Resistor, 
                              Value -> .1*^4, Symbolic -> R2}, {"R3", {"13", 
                              "10"}, Type -> Resistor, Value -> .5*^5, 
                              Symbolic -> R3}, {"Q9", {"3" -> "C", "2" -> 
                              "B", "1" -> "E"}, Model -> Model[ 
                              "BJT", "QPNP741", "Q9"], Selector -> Selector[ 
                              "BJT", "QPNP741", "Q9"], Parameters -> 
                              Parameters[ "BJT", "QPNP741", "Q9"], 
                              IB$ac -> -.28900000000000001*^-6, 
                              IC$ac -> -.000018999999999999991, 
                              VBE$ac -> -.54600000000000004, VBC$ac -> 15.5, 
                              VCE$ac -> -16.100000000000001, BETADC$ac -> 
                              65.5, GM$ac -> .00073200000000000001, RPI$ac -> 
                              89500.000000000015, RX$ac -> .1*^3, 
                              RO$ac -> .346*^7, 
                              CBE$ac -> .14499999999999999*^-11, 
                              CBC$ac -> .36200000000000002*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 65.5, CBX$ac -> 0.0, 
                              FT$ac -> .645*^8}, {"Q10", {"3" -> "C", "15" -> 
                              "B", "14" -> "E"}, Model -> Model[ 
                              "BJT", "QNPN741", "Q10"], Selector -> Selector[ 
                              "BJT", "QNPN741", "Q10"], Parameters -> 
                              Parameters[ "BJT", "QNPN741", "Q10"], 
                              IB$ac -> .88200000000000009*^-7, 
                              IC$ac -> .000019199999999999989, 
                              VBE$ac -> .59199999999999986, 
                              VBC$ac -> -13.199999999999999, VCE$ac -> 
                              13.79999999999999, BETADC$ac -> 218.0, 
                              GM$ac -> .00074199999999999993, 
                              RPI$ac -> .293*^6, RX$ac -> .2*^3, RO$ac -> 
                              8510000.0000000019, 
                              CBE$ac -> .15000000000000001*^-11, 
                              CBC$ac -> .38099999999999994*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 218.0, CBX$ac -> 0.0, 
                              FT$ac -> .629*^8}, {"Q11", {"15" -> "C", 
                              "15" -> "B", "13" -> "E"}, Model -> Model[ 
                              "BJT", "QNPN741", "Q11"], Selector -> Selector[ 
                              "BJT", "QNPN741", "Q11"], Parameters -> 
                              Parameters[ "BJT", "QNPN741", "Q11"], 
                              IB$ac -> .35600000000000002*^-5, 
                              IC$ac -> .00071299999999999998, 
                              VBE$ac -> .68899999999999995, VBC$ac -> 0.0, 
                              VCE$ac -> .68899999999999995, 
                              BETADC$ac -> .2*^3, GM$ac -> .0276, RPI$ac -> 
                              7260.0000000000009, RX$ac -> .2*^3, 
                              RO$ac -> .21*^6, CBE$ac -> .16*^-11, 
                              CBC$ac -> .99999999999999998*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> .2*^3, CBX$ac -> 0.0, 
                              FT$ac -> .169*^10}, {"R4", {"13", "14"}, 
                              Type -> Resistor, Value -> .5*^4, Symbolic -> 
                              R4}, {"Q12", {"16" -> "C", "16" -> "B", "1" -> 
                              "E"}, Model -> Model[ "BJT", "QPNP741", "Q12"], 
                              Selector -> Selector[ "BJT", "QPNP741", "Q12"], 
                              Parameters -> Parameters[ 
                              "BJT", "QPNP741", "Q12"], IB$ac -> -.0000138, 
                              IC$ac -> -.00068899999999999983, 
                              VBE$ac -> -.64700000000000002, VBC$ac -> 0.0, 
                              VCE$ac -> -.64700000000000002, 
                              BETADC$ac -> .5*^2, 
                              GM$ac -> .026599999999999999, 
                              RPI$ac -> .188*^4, RX$ac -> .1*^3, RO$ac -> 
                              72600.000000000015, CBE$ac -> .156*^-11, 
                              CBC$ac -> .99900000000000009*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> .5*^2, CBX$ac -> 0.0, 
                              FT$ac -> .166*^10}, {"Q131", {"17" -> "C", 
                              "16" -> "B", "1" -> "E"}, Model -> Model[ 
                              "BJT", "QPNP741", "Q131"], Selector -> 
                              Selector[ "BJT", "QPNP741", "Q131"], 
                              AREA -> .75, Parameters -> Parameters[ 
                              "BJT", "QPNP741", "Q131"], 
                              IB$ac -> -.000010299999999999989, 
                              IC$ac -> -.00067699999999999987, 
                              VBE$ac -> -.64700000000000002, VBC$ac -> 15.5, 
                              VCE$ac -> -16.199999999999999, BETADC$ac -> 
                              65.5, GM$ac -> .026200000000000001, 
                              RPI$ac -> .25*^4, RX$ac -> 133.0, RO$ac -> 
                              96800.000000000015, 
                              CBE$ac -> .11699999999999991*^-11, 
                              CBC$ac -> .2719999999999999*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 65.5, CBX$ac -> 0.0, 
                              FT$ac -> .289*^10}, {"Q132", {"22" -> "C", 
                              "16" -> "B", "1" -> "E"}, Model -> Model[ 
                              "BJT", "QPNP741", "Q132"], Selector -> 
                              Selector[ "BJT", "QPNP741", "Q132"], 
                              AREA -> .25, Parameters -> Parameters[ 
                              "BJT", "QPNP741", "Q132"], 
                              IB$ac -> -.34499999999999987*^-5, 
                              IC$ac -> -.0002189999999999999, 
                              VBE$ac -> -.64700000000000002, VBC$ac -> 
                              13.699999999999999, 
                              VCE$ac -> -14.29999999999999, BETADC$ac -> 
                              63.700000000000003, 
                              GM$ac -> .0084799999999999997, RPI$ac -> 
                              7510.0000000000009, RX$ac -> .4*^3, 
                              RO$ac -> .29*^6, 
                              CBE$ac -> .38899999999999986*^-12, 
                              CBC$ac -> .943*^-13, CJS$ac -> 0.0, 
                              BETAAC$ac -> 63.600000000000001, CBX$ac -> 0.0, 
                              FT$ac -> .279*^10}, {"R5", {"15", "16"}, 
                              Type -> Resistor, Value -> .4*^5, Symbolic -> 
                              R5}, {"Q14", {"1" -> "C", "22" -> "B", "25" -> 
                              "E"}, Model -> Model[ "BJT", "QNPN741", "Q14"], 
                              Selector -> Selector[ "BJT", "QNPN741", "Q14"], 
                              AREA -> 3.0, Parameters -> Parameters[ 
                              "BJT", "QNPN741", "Q14"], IB$ac -> .157*^-5, 
                              IC$ac -> .00034299999999999988, 
                              VBE$ac -> .6379999999999999, 
                              VBC$ac -> -14.29999999999999, VCE$ac -> 14.9, 
                              BETADC$ac -> 219.0, 
                              GM$ac -> .013299999999999999, 
                              RPI$ac -> .165*^5, RX$ac -> 66.700000000000003, 
                              RO$ac -> .478*^6, 
                              CBE$ac -> .46399999999999988*^-11, 
                              CBC$ac -> .11200000000000001*^-11, CJS$ac -> 
                              0.0, BETAAC$ac -> 219.0, CBX$ac -> 0.0, 
                              FT$ac -> 367000000.00000006}, {"Q15", {"22" -> 
                              "C", "25" -> "B", "26" -> "E"}, Model -> Model[ 
                              "BJT", "QNPN741", "Q15"], Selector -> Selector[ 
                              "BJT", "QNPN741", "Q15"], Parameters -> 
                              Parameters[ "BJT", "QNPN741", "Q15"], 
                              IB$ac -> -.32*^-12, 
                              IC$ac -> .97400000000000009*^-12, 
                              VBE$ac -> .0093100000000000006, 
                              VBC$ac -> -.6379999999999999, 
                              VCE$ac -> .64800000000000002, 
                              BETADC$ac -> -3.04, 
                              GM$ac -> .10700000000000001*^-12, 
                              RPI$ac -> .18*^15, RX$ac -> .2*^3, 
                              RO$ac -> .991*^12, 
                              CBE$ac -> .99999999999999998*^-12, 
                              CBC$ac -> .81600000000000006*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 19.300000000000001, CBX$ac -> 
                              0.0, FT$ac -> .0093499999999999972}, {"Q16", {
                              "1" -> "C", "18" -> "B", "19" -> "E"}, Model -> 
                              Model[ "BJT", "QNPN741", "Q16"], Selector -> 
                              Selector[ "BJT", "QNPN741", "Q16"], 
                              Parameters -> Parameters[ 
                              "BJT", "QNPN741", "Q16"], IB$ac -> .761*^-7, 
                              IC$ac -> .000018099999999999999, 
                              VBE$ac -> .58799999999999986, 
                              VBC$ac -> -28.699999999999999, VCE$ac -> 
                              29.199999999999989, BETADC$ac -> 238.0, 
                              GM$ac -> .00070100000000000002, 
                              RPI$ac -> .34*^6, RX$ac -> .2*^3, RO$ac -> 
                              9860000.0000000019, 
                              CBE$ac -> .14899999999999999*^-11, 
                              CBC$ac -> .29799999999999999*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 238.0, CBX$ac -> 0.0, 
                              FT$ac -> 62300000.000000015}, {"Q17", {"17" -> 
                              "C", "19" -> "B", "20" -> "E"}, Model -> Model[ 
                              "BJT", "QNPN741", "Q17"], Selector -> Selector[ 
                              "BJT", "QNPN741", "Q17"], Parameters -> 
                              Parameters[ "BJT", "QNPN741", "Q17"], 
                              IB$ac -> .31299999999999988*^-5, 
                              IC$ac -> .00067999999999999983, 
                              VBE$ac -> .68499999999999994, VBC$ac -> -13.1, 
                              VCE$ac -> 13.79999999999999, BETADC$ac -> 
                              217.0, GM$ac -> .02629999999999999, RPI$ac -> 
                              8270.0000000000018, RX$ac -> .2*^3, 
                              RO$ac -> .24*^6, CBE$ac -> .16*^-11, 
                              CBC$ac -> .38199999999999999*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 217.0, CBX$ac -> 0.0, 
                              FT$ac -> 2109999999.9999998}, {"R6", {"26", 
                              "25"}, Type -> Resistor, Value -> 27.0, 
                              Symbolic -> R6}, {"R7", {"27", "26"}, Type -> 
                              Resistor, Value -> 22.0, Symbolic -> R7}, {
                              "R8", {"13", "20"}, Type -> Resistor, 
                              Value -> .1*^3, Symbolic -> R8}, {"R9", {"13", 
                              "19"}, Type -> Resistor, Value -> .5*^5, 
                              Symbolic -> R9}, {"R10", {"24", "23"}, Type -> 
                              Resistor, Value -> .5*^5, Symbolic -> R10}, {
                              "R11", {"13", "21"}, Type -> Resistor, 
                              Value -> .5*^5, Symbolic -> R11}, {"R12", {
                              "18", "9"}, Type -> Resistor, Value -> .3*^3, 
                              Symbolic -> R12}, {"Q18", {"22" -> "C", "22" -> 
                              "B", "23" -> "E"}, Model -> Model[ 
                              "BJT", "QNPN741", "Q18"], Selector -> Selector[ 
                              "BJT", "QNPN741", "Q18"], Parameters -> 
                              Parameters[ "BJT", "QNPN741", "Q18"], 
                              IB$ac -> .70300000000000014*^-7, 
                              IC$ac -> .00001409999999999999, 
                              VBE$ac -> .58600000000000008, VBC$ac -> 0.0, 
                              VCE$ac -> .58600000000000008, 
                              BETADC$ac -> .2*^3, 
                              GM$ac -> .00054299999999999997, 
                              RPI$ac -> .368*^6, RX$ac -> .2*^3, 
                              RO$ac -> .107*^8, 
                              CBE$ac -> .14899999999999999*^-11, 
                              CBC$ac -> .99999999999999998*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> .2*^3, CBX$ac -> 0.0, 
                              FT$ac -> .347*^8}, {"Q19", {"22" -> "C", 
                              "23" -> "B", "24" -> "E"}, Model -> Model[ 
                              "BJT", "QNPN741", "Q19"], Selector -> Selector[ 
                              "BJT", "QNPN741", "Q19"], Parameters -> 
                              Parameters[ "BJT", "QNPN741", "Q19"], 
                              IB$ac -> .10100000000000001*^-5, 
                              IC$ac -> .000204, VBE$ac -> .65599999999999981, 
                              VBC$ac -> -.58600000000000008, VCE$ac -> 
                              1.2399999999999991, BETADC$ac -> 
                              200.99999999999989, 
                              GM$ac -> .0078700000000000003, 
                              RPI$ac -> .255*^5, RX$ac -> .2*^3, 
                              RO$ac -> .74*^6, 
                              CBE$ac -> .1569999999999999*^-11, 
                              CBC$ac -> .82600000000000012*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 200.99999999999989, CBX$ac -> 
                              0.0, FT$ac -> 523000000.00000012}, {"Q20", {
                              "13" -> "C", "24" -> "B", "27" -> "E"}, 
                              Model -> Model[ "BJT", "QPNP741", "Q20"], 
                              Selector -> Selector[ "BJT", "QPNP741", "Q20"], 
                              AREA -> 3.0, Parameters -> Parameters[ 
                              "BJT", "QPNP741", "Q20"], 
                              IB$ac -> -.44500000000000014*^-5, 
                              IC$ac -> -.00028699999999999998, 
                              VBE$ac -> -.58799999999999986, VBC$ac -> 14.5, 
                              VCE$ac -> -15.0, BETADC$ac -> 64.5, 
                              GM$ac -> .0111, RPI$ac -> .581*^4, RX$ac -> 
                              33.299999999999997, RO$ac -> .225*^6, 
                              CBE$ac -> .44800000000000003*^-11, 
                              CBC$ac -> .11100000000000001*^-11, CJS$ac -> 
                              0.0, BETAAC$ac -> 64.400000000000006, CBX$ac -> 
                              0.0, FT$ac -> 316000000.00000012}, {"Q21", {
                              "21" -> "C", "27" -> "B", "26" -> "E"}, 
                              Model -> Model[ "BJT", "QPNP741", "Q21"], 
                              Selector -> Selector[ "BJT", "QPNP741", "Q21"], 
                              Parameters -> Parameters[ 
                              "BJT", "QPNP741", "Q21"], 
                              IB$ac -> .50199999999999984*^-11, 
                              IC$ac -> -.24600000000000001*^-10, 
                              VBE$ac -> -.0064099999999999999, VBC$ac -> 
                              15.0, VCE$ac -> -15.099999999999991, 
                              BETADC$ac -> -4.9100000000000001, 
                              GM$ac -> .343*^-12, RPI$ac -> .334*^14, 
                              RX$ac -> .1*^3, RO$ac -> 624000000000.00012, 
                              CBE$ac -> .99999999999999998*^-12, 
                              CBC$ac -> .36600000000000011*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 11.5, CBX$ac -> 0.0, 
                              FT$ac -> .039899999999999998}, {"Q24", {"21" -> 
                              "C", "21" -> "B", "13" -> "E"}, Model -> Model[ 
                              "BJT", "QNPN741", "Q24"], Selector -> Selector[ 
                              "BJT", "QNPN741", "Q24"], Parameters -> 
                              Parameters[ "BJT", "QNPN741", "Q24"], 
                              IB$ac -> .68099999999999992*^-20, 
                              IC$ac -> .13599999999999989*^-17, 
                              VBE$ac -> .126*^-5, VBC$ac -> 0.0, 
                              VCE$ac -> .126*^-5, BETADC$ac -> 136.0, 
                              GM$ac -> .377*^-17, RPI$ac -> .186*^15, 
                              RX$ac -> .2*^3, RO$ac -> 928000000000.00012, 
                              CBE$ac -> .99999999999999998*^-12, 
                              CBC$ac -> .99999999999999998*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> .00069999999999999999, 
                              CBX$ac -> 0.0, 
                              FT$ac -> .29999999999999999*^-6}, {"Q23", {
                              "18" -> "C", "21" -> "B", "13" -> "E"}, 
                              Model -> Model[ "BJT", "QNPN741", "Q23"], 
                              Selector -> Selector[ "BJT", "QNPN741", "Q23"], 
                              Parameters -> Parameters[ 
                              "BJT", "QNPN741", "Q23"], 
                              IB$ac -> -.67199999999999976*^-12, 
                              IC$ac -> .20299999999999988*^-11, 
                              VBE$ac -> .126*^-5, 
                              VBC$ac -> -1.3400000000000001, VCE$ac -> 
                              1.3400000000000001, BETADC$ac -> -3.02, 
                              GM$ac -> .69099999999999991*^-13, 
                              RPI$ac -> .186*^15, RX$ac -> .2*^3, 
                              RO$ac -> .982*^12, 
                              CBE$ac -> .99999999999999998*^-12, 
                              CBC$ac -> .71299999999999999*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 12.800000000000001, CBX$ac -> 
                              0.0, FT$ac -> .0064200000000000012}, {"C1", {
                              "18", "17"}, Type -> Capacitor, 
                              Value -> .3*^-10, Symbolic -> C1}, {"Q222", {
                              "13" -> "C", "17" -> "B", "24" -> "E"}, 
                              Model -> Model[ "BJT", "QPNP741", "Q222"], 
                              Selector -> Selector[ 
                              "BJT", "QPNP741", "Q222"], Parameters -> 
                              Parameters[ "BJT", "QPNP741", "Q222"], 
                              IB$ac -> -.34300000000000002*^-5, 
                              IC$ac -> -.0002189999999999999, 
                              VBE$ac -> -.60999999999999988, VBC$ac -> 
                              13.89999999999999, VCE$ac -> -14.5, 
                              BETADC$ac -> 63.899999999999999, 
                              GM$ac -> .0084499999999999992, 
                              RPI$ac -> .755*^4, RX$ac -> .1*^3, 
                              RO$ac -> .292*^6, CBE$ac -> .152*^-11, 
                              CBC$ac -> .37500000000000002*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> 63.79999999999999, CBX$ac -> 
                              0.0, FT$ac -> 711000000.00000012}, {"Q221", {
                              "13" -> "C", "17" -> "B", "18" -> "E"}, 
                              Model -> Model[ "BJT", "QPNP741", "Q221"], 
                              Selector -> Selector[ 
                              "BJT", "QPNP741", "Q221"], Parameters -> 
                              Parameters[ "BJT", "QPNP741", "Q221"], 
                              IB$ac -> .48699999999999992*^-11, 
                              IC$ac -> -.63299999999999999*^-11, VBE$ac -> 
                              12.5, VBC$ac -> 13.89999999999999, 
                              VCE$ac -> -1.3400000000000001, 
                              BETADC$ac -> -1.3, GM$ac -> -.268*^-13, 
                              RPI$ac -> 50000000000000.008, RX$ac -> .1*^3, 
                              RO$ac -> 767000000000.00012, 
                              CBE$ac -> .38799999999999991*^-12, 
                              CBC$ac -> .37500000000000002*^-12, CJS$ac -> 
                              0.0, BETAAC$ac -> -1.3400000000000001, 
                              CBX$ac -> 0.0, 
                              FT$ac -> -.0055999999999999999}, {"V1", {"1", 
                              "0"}, Type -> VoltageSource, Value -> {DC -> 
                              15.0, Transient -> 15.0}, Symbolic -> {DC -> 
                              V1, Transient -> V1}}, {"V2", {"0", "13"}, 
                              Type -> VoltageSource, Value -> {DC -> 15.0, 
                              Transient -> 15.0}, Symbolic -> {DC -> V2, 
                              Transient -> V2}}, {"VOS", {"5", "$N$0001"}, 
                              Type -> VoltageSource, Value -> {DC -> .000321, 
                              Transient -> .000321}, Symbolic -> {DC -> VOS, 
                              Transient -> VOS}}, {"R13", {"26", "0"}, 
                              Type -> Resistor, Value -> .1*^4, Symbolic -> 
                              R13}, {"VIC", {"5", "0"}, Type -> 
                              VoltageSource, Value -> {DC -> 0.0, 
                              Transient -> 0.0}, Symbolic -> {DC -> VIC, 
                              Transient -> VIC}}, {"VID", {"4", "$N$0001"}, 
                              Type -> VoltageSource, Value -> {AC -> 1.0, 
                              DC -> CheckedSinWave[ 
                              Time, 0.0, .80000000000000004, .1*^4, 0.0, 0.0, 
                                0.0], Transient -> CheckedSinWave[ 
                              Time, 0.0, .80000000000000004, .1*^4, 0.0, 0.0, 
                                0.0]}, Symbolic -> VID}]]], 
                        SequenceForm[ 
                          DisplayForm[ 
                            LocalModelParameters[ "QNPN741"][ 
                            Type -> "NPN", BF -> .2*^3, 
                              IS -> .20000000000000002*^-14, VAF -> .15*^3, 
                              RB -> .2*^3, BR -> 2.0, 
                              CJE -> .99999999999999998*^-12, 
                              CJC -> .99999999999999998*^-12]]], 
                        SequenceForm[ 
                          DisplayForm[ 
                            LocalModelParameters[ "QPNP741"][ 
                            Type -> "PNP", BF -> .5*^2, IS -> .1*^-13, 
                              VAF -> .5*^2, RB -> .1*^3, BR -> 3.0, 
                              CJE -> .99999999999999998*^-12, 
                              CJC -> .99999999999999998*^-12]]], 
                        SequenceForm[ 
                          DisplayForm[ 
                            GlobalParameters[ Simulator -> "PSpice"]]]}]]}
                  },
                RowSpacings->1,
                ColumnSpacings->0,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #, TableSpacing -> {1, 0}]&)]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {"Circuit:", 
        TableForm[ {{"  ", 
          TableForm[ {
            SequenceForm[ 
              DisplayForm[ 
                NetlistObject[ 
                Checked][ {"Q1", {"2" -> "C", "4" -> "B", "6" -> "E"}, 
                  Model -> Model[ "BJT", "QNPN741", "Q1"], Selector -> 
                  Selector[ "BJT", "QNPN741", "Q1"], Parameters -> 
                  Parameters[ "BJT", "QNPN741", "Q1"], 
                  IB$ac -> .34200000000000002*^-7, 
                  IC$ac -> .75000000000000002*^-5, 
                  VBE$ac -> .56799999999999995, VBC$ac -> -14.5, VCE$ac -> 
                  15.0, BETADC$ac -> 219.0, GM$ac -> .00029, 
                  RPI$ac -> .756*^6, RX$ac -> .2*^3, RO$ac -> .219*^8, 
                  CBE$ac -> .147*^-11, CBC$ac -> .37000000000000004*^-12, 
                  CJS$ac -> 0.0, BETAAC$ac -> 219.0, CBX$ac -> 0.0, FT$ac -> 
                  25099999.999999989}, {"Q2", {"2" -> "C", "5" -> "B", "7" -> 
                  "E"}, Model -> Model[ "BJT", "QNPN741", "Q2"], Selector -> 
                  Selector[ "BJT", "QNPN741", "Q2"], Parameters -> 
                  Parameters[ "BJT", "QNPN741", "Q2"], 
                  IB$ac -> .3439999999999999*^-7, 
                  IC$ac -> .75399999999999998*^-5, 
                  VBE$ac -> .56799999999999995, VBC$ac -> -14.5, VCE$ac -> 
                  15.0, BETADC$ac -> 219.0, GM$ac -> .00029100000000000003, 
                  RPI$ac -> .753*^6, RX$ac -> .2*^3, RO$ac -> .218*^8, 
                  CBE$ac -> .147*^-11, CBC$ac -> .37000000000000004*^-12, 
                  CJS$ac -> 0.0, BETAAC$ac -> 219.0, CBX$ac -> 0.0, 
                  FT$ac -> .252*^8}, {"Q3", {"8" -> "C", "3" -> "B", "6" -> 
                  "E"}, Model -> Model[ "BJT", "QPNP741", "Q3"], Selector -> 
                  Selector[ "BJT", "QPNP741", "Q3"], Parameters -> 
                  Parameters[ "BJT", "QPNP741", "Q3"], 
                  IB$ac -> -.11799999999999991*^-6, 
                  IC$ac -> -.74199999999999993*^-5, 
                  VBE$ac -> -.52200000000000002, VBC$ac -> 
                  12.800000000000001, VCE$ac -> -13.300000000000001, 
                  BETADC$ac -> 62.800000000000011, 
                  GM$ac -> .00028699999999999998, RPI$ac -> .219*^6, 
                  RX$ac -> .1*^3, RO$ac -> .846*^7, CBE$ac -> .142*^-11, 
                  CBC$ac -> .38500000000000003*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 62.699999999999989, CBX$ac -> 0.0, FT$ac -> 
                  25299999.999999989}, {"Q4", {"9" -> "C", "3" -> "B", "7" -> 
                  "E"}, Model -> Model[ "BJT", "QPNP741", "Q4"], Selector -> 
                  Selector[ "BJT", "QPNP741", "Q4"], Parameters -> 
                  Parameters[ "BJT", "QPNP741", "Q4"], 
                  IB$ac -> -.1189999999999999*^-6, 
                  IC$ac -> -.74499999999999998*^-5, 
                  VBE$ac -> -.52300000000000002, VBC$ac -> 12.6, 
                  VCE$ac -> -13.1, BETADC$ac -> 62.599999999999987, 
                  GM$ac -> .00028800000000000001, RPI$ac -> .217*^6, 
                  RX$ac -> .1*^3, RO$ac -> .84*^7, CBE$ac -> .142*^-11, 
                  CBC$ac -> .38700000000000002*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 62.5, CBX$ac -> 0.0, FT$ac -> .254*^8}, {
                  "Q5", {"8" -> "C", "10" -> "B", "11" -> "E"}, Model -> 
                  Model[ "BJT", "QNPN741", "Q5"], Selector -> Selector[ 
                  "BJT", "QNPN741", "Q5"], Parameters -> Parameters[ 
                  "BJT", "QNPN741", "Q5"], IB$ac -> .36699999999999991*^-7, 
                  IC$ac -> .73699999999999997*^-5, 
                  VBE$ac -> .57000000000000006, 
                  VBC$ac -> -.57699999999999985, VCE$ac -> 1.149999999999999, 
                  BETADC$ac -> 200.99999999999989, 
                  GM$ac -> .00028499999999999999, RPI$ac -> .705*^6, 
                  RX$ac -> .2*^3, RO$ac -> .204*^8, CBE$ac -> .147*^-11, 
                  CBC$ac -> .8279999999999998*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 200.99999999999989, CBX$ac -> 0.0, 
                  FT$ac -> .197*^8}, {"Q6", {"9" -> "C", "10" -> "B", "12" -> 
                  "E"}, Model -> Model[ "BJT", "QNPN741", "Q6"], Selector -> 
                  Selector[ "BJT", "QNPN741", "Q6"], Parameters -> 
                  Parameters[ "BJT", "QNPN741", "Q6"], 
                  IB$ac -> .36699999999999991*^-7, 
                  IC$ac -> .73699999999999997*^-5, 
                  VBE$ac -> .57000000000000006, 
                  VBC$ac -> -.76500000000000001, VCE$ac -> 
                  1.3300000000000001, BETADC$ac -> 200.99999999999989, 
                  GM$ac -> .00028499999999999999, RPI$ac -> .705*^6, 
                  RX$ac -> .2*^3, RO$ac -> .204*^8, CBE$ac -> .147*^-11, 
                  CBC$ac -> .79299999999999985*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 200.99999999999989, CBX$ac -> 0.0, 
                  FT$ac -> .2*^8}, {"Q7", {"1" -> "C", "8" -> "B", "10" -> 
                  "E"}, Model -> Model[ "BJT", "QNPN741", "Q7"], Selector -> 
                  Selector[ "BJT", "QNPN741", "Q7"], Parameters -> 
                  Parameters[ "BJT", "QNPN741", "Q7"], 
                  IB$ac -> .48499999999999984*^-7, 
                  IC$ac -> .000011599999999999991, 
                  VBE$ac -> .57699999999999985, VBC$ac -> -28.79999999999999, 
                  VCE$ac -> 29.399999999999991, BETADC$ac -> 239.0, 
                  GM$ac -> .00044700000000000002, RPI$ac -> .533*^6, 
                  RX$ac -> .2*^3, RO$ac -> .155*^8, CBE$ac -> .148*^-11, 
                  CBC$ac -> .2969999999999999*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 238.0, CBX$ac -> 0.0, FT$ac -> .4*^8}, {"Q8", {
                  "2" -> "C", "2" -> "B", "1" -> "E"}, Model -> Model[ 
                  "BJT", "QPNP741", "Q8"], Selector -> Selector[ 
                  "BJT", "QPNP741", "Q8"], Parameters -> Parameters[ 
                  "BJT", "QPNP741", "Q8"], IB$ac -> -.28900000000000001*^-6, 
                  IC$ac -> -.0000145, VBE$ac -> -.54600000000000004, 
                  VBC$ac -> 0.0, VCE$ac -> -.54600000000000004, 
                  BETADC$ac -> .5*^2, GM$ac -> .00055900000000000004, 
                  RPI$ac -> 89500.000000000015, RX$ac -> .1*^3, 
                  RO$ac -> .346*^7, CBE$ac -> .14499999999999999*^-11, 
                  CBC$ac -> .99999999999999998*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> .5*^2, CBX$ac -> 0.0, FT$ac -> .364*^8}, {
                  "R1", {"13", "11"}, Type -> Resistor, Value -> .1*^4, 
                  Symbolic -> R1}, {"R2", {"13", "12"}, Type -> Resistor, 
                  Value -> .1*^4, Symbolic -> R2}, {"R3", {"13", "10"}, 
                  Type -> Resistor, Value -> .5*^5, Symbolic -> R3}, {"Q9", {
                  "3" -> "C", "2" -> "B", "1" -> "E"}, Model -> Model[ 
                  "BJT", "QPNP741", "Q9"], Selector -> Selector[ 
                  "BJT", "QPNP741", "Q9"], Parameters -> Parameters[ 
                  "BJT", "QPNP741", "Q9"], IB$ac -> -.28900000000000001*^-6, 
                  IC$ac -> -.000018999999999999991, 
                  VBE$ac -> -.54600000000000004, VBC$ac -> 15.5, 
                  VCE$ac -> -16.100000000000001, BETADC$ac -> 65.5, 
                  GM$ac -> .00073200000000000001, RPI$ac -> 
                  89500.000000000015, RX$ac -> .1*^3, RO$ac -> .346*^7, 
                  CBE$ac -> .14499999999999999*^-11, 
                  CBC$ac -> .36200000000000002*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 65.5, CBX$ac -> 0.0, FT$ac -> .645*^8}, {
                  "Q10", {"3" -> "C", "15" -> "B", "14" -> "E"}, Model -> 
                  Model[ "BJT", "QNPN741", "Q10"], Selector -> Selector[ 
                  "BJT", "QNPN741", "Q10"], Parameters -> Parameters[ 
                  "BJT", "QNPN741", "Q10"], IB$ac -> .88200000000000009*^-7, 
                  IC$ac -> .000019199999999999989, 
                  VBE$ac -> .59199999999999986, 
                  VBC$ac -> -13.199999999999999, VCE$ac -> 13.79999999999999, 
                  BETADC$ac -> 218.0, GM$ac -> .00074199999999999993, 
                  RPI$ac -> .293*^6, RX$ac -> .2*^3, RO$ac -> 
                  8510000.0000000019, CBE$ac -> .15000000000000001*^-11, 
                  CBC$ac -> .38099999999999994*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 218.0, CBX$ac -> 0.0, FT$ac -> .629*^8}, {
                  "Q11", {"15" -> "C", "15" -> "B", "13" -> "E"}, Model -> 
                  Model[ "BJT", "QNPN741", "Q11"], Selector -> Selector[ 
                  "BJT", "QNPN741", "Q11"], Parameters -> Parameters[ 
                  "BJT", "QNPN741", "Q11"], IB$ac -> .35600000000000002*^-5, 
                  IC$ac -> .00071299999999999998, 
                  VBE$ac -> .68899999999999995, VBC$ac -> 0.0, 
                  VCE$ac -> .68899999999999995, BETADC$ac -> .2*^3, 
                  GM$ac -> .0276, RPI$ac -> 7260.0000000000009, 
                  RX$ac -> .2*^3, RO$ac -> .21*^6, CBE$ac -> .16*^-11, 
                  CBC$ac -> .99999999999999998*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> .2*^3, CBX$ac -> 0.0, FT$ac -> .169*^10}, {
                  "R4", {"13", "14"}, Type -> Resistor, Value -> .5*^4, 
                  Symbolic -> R4}, {"Q12", {"16" -> "C", "16" -> "B", "1" -> 
                  "E"}, Model -> Model[ "BJT", "QPNP741", "Q12"], Selector -> 
                  Selector[ "BJT", "QPNP741", "Q12"], Parameters -> 
                  Parameters[ "BJT", "QPNP741", "Q12"], IB$ac -> -.0000138, 
                  IC$ac -> -.00068899999999999983, 
                  VBE$ac -> -.64700000000000002, VBC$ac -> 0.0, 
                  VCE$ac -> -.64700000000000002, BETADC$ac -> .5*^2, 
                  GM$ac -> .026599999999999999, RPI$ac -> .188*^4, 
                  RX$ac -> .1*^3, RO$ac -> 72600.000000000015, 
                  CBE$ac -> .156*^-11, CBC$ac -> .99900000000000009*^-12, 
                  CJS$ac -> 0.0, BETAAC$ac -> .5*^2, CBX$ac -> 0.0, 
                  FT$ac -> .166*^10}, {"Q131", {"17" -> "C", "16" -> "B", 
                  "1" -> "E"}, Model -> Model[ "BJT", "QPNP741", "Q131"], 
                  Selector -> Selector[ "BJT", "QPNP741", "Q131"], 
                  AREA -> .75, Parameters -> Parameters[ 
                  "BJT", "QPNP741", "Q131"], 
                  IB$ac -> -.000010299999999999989, 
                  IC$ac -> -.00067699999999999987, 
                  VBE$ac -> -.64700000000000002, VBC$ac -> 15.5, 
                  VCE$ac -> -16.199999999999999, BETADC$ac -> 65.5, 
                  GM$ac -> .026200000000000001, RPI$ac -> .25*^4, RX$ac -> 
                  133.0, RO$ac -> 96800.000000000015, 
                  CBE$ac -> .11699999999999991*^-11, 
                  CBC$ac -> .2719999999999999*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 65.5, CBX$ac -> 0.0, FT$ac -> .289*^10}, {
                  "Q132", {"22" -> "C", "16" -> "B", "1" -> "E"}, Model -> 
                  Model[ "BJT", "QPNP741", "Q132"], Selector -> Selector[ 
                  "BJT", "QPNP741", "Q132"], AREA -> .25, Parameters -> 
                  Parameters[ "BJT", "QPNP741", "Q132"], 
                  IB$ac -> -.34499999999999987*^-5, 
                  IC$ac -> -.0002189999999999999, 
                  VBE$ac -> -.64700000000000002, VBC$ac -> 
                  13.699999999999999, VCE$ac -> -14.29999999999999, 
                  BETADC$ac -> 63.700000000000003, 
                  GM$ac -> .0084799999999999997, RPI$ac -> 
                  7510.0000000000009, RX$ac -> .4*^3, RO$ac -> .29*^6, 
                  CBE$ac -> .38899999999999986*^-12, CBC$ac -> .943*^-13, 
                  CJS$ac -> 0.0, BETAAC$ac -> 63.600000000000001, CBX$ac -> 
                  0.0, FT$ac -> .279*^10}, {"R5", {"15", "16"}, Type -> 
                  Resistor, Value -> .4*^5, Symbolic -> R5}, {"Q14", {"1" -> 
                  "C", "22" -> "B", "25" -> "E"}, Model -> Model[ 
                  "BJT", "QNPN741", "Q14"], Selector -> Selector[ 
                  "BJT", "QNPN741", "Q14"], AREA -> 3.0, Parameters -> 
                  Parameters[ "BJT", "QNPN741", "Q14"], IB$ac -> .157*^-5, 
                  IC$ac -> .00034299999999999988, 
                  VBE$ac -> .6379999999999999, VBC$ac -> -14.29999999999999, 
                  VCE$ac -> 14.9, BETADC$ac -> 219.0, 
                  GM$ac -> .013299999999999999, RPI$ac -> .165*^5, RX$ac -> 
                  66.700000000000003, RO$ac -> .478*^6, 
                  CBE$ac -> .46399999999999988*^-11, 
                  CBC$ac -> .11200000000000001*^-11, CJS$ac -> 0.0, 
                  BETAAC$ac -> 219.0, CBX$ac -> 0.0, FT$ac -> 
                  367000000.00000006}, {"Q15", {"22" -> "C", "25" -> "B", 
                  "26" -> "E"}, Model -> Model[ "BJT", "QNPN741", "Q15"], 
                  Selector -> Selector[ "BJT", "QNPN741", "Q15"], 
                  Parameters -> Parameters[ "BJT", "QNPN741", "Q15"], 
                  IB$ac -> -.32*^-12, IC$ac -> .97400000000000009*^-12, 
                  VBE$ac -> .0093100000000000006, 
                  VBC$ac -> -.6379999999999999, VCE$ac -> .64800000000000002, 
                  BETADC$ac -> -3.04, GM$ac -> .10700000000000001*^-12, 
                  RPI$ac -> .18*^15, RX$ac -> .2*^3, RO$ac -> .991*^12, 
                  CBE$ac -> .99999999999999998*^-12, 
                  CBC$ac -> .81600000000000006*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 19.300000000000001, CBX$ac -> 0.0, 
                  FT$ac -> .0093499999999999972}, {"Q16", {"1" -> "C", 
                  "18" -> "B", "19" -> "E"}, Model -> Model[ 
                  "BJT", "QNPN741", "Q16"], Selector -> Selector[ 
                  "BJT", "QNPN741", "Q16"], Parameters -> Parameters[ 
                  "BJT", "QNPN741", "Q16"], IB$ac -> .761*^-7, 
                  IC$ac -> .000018099999999999999, 
                  VBE$ac -> .58799999999999986, 
                  VBC$ac -> -28.699999999999999, VCE$ac -> 
                  29.199999999999989, BETADC$ac -> 238.0, 
                  GM$ac -> .00070100000000000002, RPI$ac -> .34*^6, 
                  RX$ac -> .2*^3, RO$ac -> 9860000.0000000019, 
                  CBE$ac -> .14899999999999999*^-11, 
                  CBC$ac -> .29799999999999999*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 238.0, CBX$ac -> 0.0, FT$ac -> 
                  62300000.000000015}, {"Q17", {"17" -> "C", "19" -> "B", 
                  "20" -> "E"}, Model -> Model[ "BJT", "QNPN741", "Q17"], 
                  Selector -> Selector[ "BJT", "QNPN741", "Q17"], 
                  Parameters -> Parameters[ "BJT", "QNPN741", "Q17"], 
                  IB$ac -> .31299999999999988*^-5, 
                  IC$ac -> .00067999999999999983, 
                  VBE$ac -> .68499999999999994, VBC$ac -> -13.1, VCE$ac -> 
                  13.79999999999999, BETADC$ac -> 217.0, 
                  GM$ac -> .02629999999999999, RPI$ac -> 8270.0000000000018, 
                  RX$ac -> .2*^3, RO$ac -> .24*^6, CBE$ac -> .16*^-11, 
                  CBC$ac -> .38199999999999999*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 217.0, CBX$ac -> 0.0, FT$ac -> 
                  2109999999.9999998}, {"R6", {"26", "25"}, Type -> Resistor, 
                  Value -> 27.0, Symbolic -> R6}, {"R7", {"27", "26"}, 
                  Type -> Resistor, Value -> 22.0, Symbolic -> R7}, {"R8", {
                  "13", "20"}, Type -> Resistor, Value -> .1*^3, Symbolic -> 
                  R8}, {"R9", {"13", "19"}, Type -> Resistor, Value -> .5*^5, 
                  Symbolic -> R9}, {"R10", {"24", "23"}, Type -> Resistor, 
                  Value -> .5*^5, Symbolic -> R10}, {"R11", {"13", "21"}, 
                  Type -> Resistor, Value -> .5*^5, Symbolic -> R11}, {
                  "R12", {"18", "9"}, Type -> Resistor, Value -> .3*^3, 
                  Symbolic -> R12}, {"Q18", {"22" -> "C", "22" -> "B", 
                  "23" -> "E"}, Model -> Model[ "BJT", "QNPN741", "Q18"], 
                  Selector -> Selector[ "BJT", "QNPN741", "Q18"], 
                  Parameters -> Parameters[ "BJT", "QNPN741", "Q18"], 
                  IB$ac -> .70300000000000014*^-7, 
                  IC$ac -> .00001409999999999999, 
                  VBE$ac -> .58600000000000008, VBC$ac -> 0.0, 
                  VCE$ac -> .58600000000000008, BETADC$ac -> .2*^3, 
                  GM$ac -> .00054299999999999997, RPI$ac -> .368*^6, 
                  RX$ac -> .2*^3, RO$ac -> .107*^8, 
                  CBE$ac -> .14899999999999999*^-11, 
                  CBC$ac -> .99999999999999998*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> .2*^3, CBX$ac -> 0.0, FT$ac -> .347*^8}, {
                  "Q19", {"22" -> "C", "23" -> "B", "24" -> "E"}, Model -> 
                  Model[ "BJT", "QNPN741", "Q19"], Selector -> Selector[ 
                  "BJT", "QNPN741", "Q19"], Parameters -> Parameters[ 
                  "BJT", "QNPN741", "Q19"], IB$ac -> .10100000000000001*^-5, 
                  IC$ac -> .000204, VBE$ac -> .65599999999999981, 
                  VBC$ac -> -.58600000000000008, VCE$ac -> 
                  1.2399999999999991, BETADC$ac -> 200.99999999999989, 
                  GM$ac -> .0078700000000000003, RPI$ac -> .255*^5, 
                  RX$ac -> .2*^3, RO$ac -> .74*^6, 
                  CBE$ac -> .1569999999999999*^-11, 
                  CBC$ac -> .82600000000000012*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 200.99999999999989, CBX$ac -> 0.0, FT$ac -> 
                  523000000.00000012}, {"Q20", {"13" -> "C", "24" -> "B", 
                  "27" -> "E"}, Model -> Model[ "BJT", "QPNP741", "Q20"], 
                  Selector -> Selector[ "BJT", "QPNP741", "Q20"], AREA -> 
                  3.0, Parameters -> Parameters[ "BJT", "QPNP741", "Q20"], 
                  IB$ac -> -.44500000000000014*^-5, 
                  IC$ac -> -.00028699999999999998, 
                  VBE$ac -> -.58799999999999986, VBC$ac -> 14.5, 
                  VCE$ac -> -15.0, BETADC$ac -> 64.5, GM$ac -> .0111, 
                  RPI$ac -> .581*^4, RX$ac -> 33.299999999999997, 
                  RO$ac -> .225*^6, CBE$ac -> .44800000000000003*^-11, 
                  CBC$ac -> .11100000000000001*^-11, CJS$ac -> 0.0, 
                  BETAAC$ac -> 64.400000000000006, CBX$ac -> 0.0, FT$ac -> 
                  316000000.00000012}, {"Q21", {"21" -> "C", "27" -> "B", 
                  "26" -> "E"}, Model -> Model[ "BJT", "QPNP741", "Q21"], 
                  Selector -> Selector[ "BJT", "QPNP741", "Q21"], 
                  Parameters -> Parameters[ "BJT", "QPNP741", "Q21"], 
                  IB$ac -> .50199999999999984*^-11, 
                  IC$ac -> -.24600000000000001*^-10, 
                  VBE$ac -> -.0064099999999999999, VBC$ac -> 15.0, 
                  VCE$ac -> -15.099999999999991, 
                  BETADC$ac -> -4.9100000000000001, GM$ac -> .343*^-12, 
                  RPI$ac -> .334*^14, RX$ac -> .1*^3, RO$ac -> 
                  624000000000.00012, CBE$ac -> .99999999999999998*^-12, 
                  CBC$ac -> .36600000000000011*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 11.5, CBX$ac -> 0.0, 
                  FT$ac -> .039899999999999998}, {"Q24", {"21" -> "C", 
                  "21" -> "B", "13" -> "E"}, Model -> Model[ 
                  "BJT", "QNPN741", "Q24"], Selector -> Selector[ 
                  "BJT", "QNPN741", "Q24"], Parameters -> Parameters[ 
                  "BJT", "QNPN741", "Q24"], IB$ac -> .68099999999999992*^-20, 
                  IC$ac -> .13599999999999989*^-17, VBE$ac -> .126*^-5, 
                  VBC$ac -> 0.0, VCE$ac -> .126*^-5, BETADC$ac -> 136.0, 
                  GM$ac -> .377*^-17, RPI$ac -> .186*^15, RX$ac -> .2*^3, 
                  RO$ac -> 928000000000.00012, 
                  CBE$ac -> .99999999999999998*^-12, 
                  CBC$ac -> .99999999999999998*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> .00069999999999999999, CBX$ac -> 0.0, 
                  FT$ac -> .29999999999999999*^-6}, {"Q23", {"18" -> "C", 
                  "21" -> "B", "13" -> "E"}, Model -> Model[ 
                  "BJT", "QNPN741", "Q23"], Selector -> Selector[ 
                  "BJT", "QNPN741", "Q23"], Parameters -> Parameters[ 
                  "BJT", "QNPN741", "Q23"], 
                  IB$ac -> -.67199999999999976*^-12, 
                  IC$ac -> .20299999999999988*^-11, VBE$ac -> .126*^-5, 
                  VBC$ac -> -1.3400000000000001, VCE$ac -> 
                  1.3400000000000001, BETADC$ac -> -3.02, 
                  GM$ac -> .69099999999999991*^-13, RPI$ac -> .186*^15, 
                  RX$ac -> .2*^3, RO$ac -> .982*^12, 
                  CBE$ac -> .99999999999999998*^-12, 
                  CBC$ac -> .71299999999999999*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 12.800000000000001, CBX$ac -> 0.0, 
                  FT$ac -> .0064200000000000012}, {"C1", {"18", "17"}, 
                  Type -> Capacitor, Value -> .3*^-10, Symbolic -> C1}, {
                  "Q222", {"13" -> "C", "17" -> "B", "24" -> "E"}, Model -> 
                  Model[ "BJT", "QPNP741", "Q222"], Selector -> Selector[ 
                  "BJT", "QPNP741", "Q222"], Parameters -> Parameters[ 
                  "BJT", "QPNP741", "Q222"], 
                  IB$ac -> -.34300000000000002*^-5, 
                  IC$ac -> -.0002189999999999999, 
                  VBE$ac -> -.60999999999999988, VBC$ac -> 13.89999999999999, 
                  VCE$ac -> -14.5, BETADC$ac -> 63.899999999999999, 
                  GM$ac -> .0084499999999999992, RPI$ac -> .755*^4, 
                  RX$ac -> .1*^3, RO$ac -> .292*^6, CBE$ac -> .152*^-11, 
                  CBC$ac -> .37500000000000002*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> 63.79999999999999, CBX$ac -> 0.0, FT$ac -> 
                  711000000.00000012}, {"Q221", {"13" -> "C", "17" -> "B", 
                  "18" -> "E"}, Model -> Model[ "BJT", "QPNP741", "Q221"], 
                  Selector -> Selector[ "BJT", "QPNP741", "Q221"], 
                  Parameters -> Parameters[ "BJT", "QPNP741", "Q221"], 
                  IB$ac -> .48699999999999992*^-11, 
                  IC$ac -> -.63299999999999999*^-11, VBE$ac -> 12.5, 
                  VBC$ac -> 13.89999999999999, VCE$ac -> -1.3400000000000001, 
                  BETADC$ac -> -1.3, GM$ac -> -.268*^-13, RPI$ac -> 
                  50000000000000.008, RX$ac -> .1*^3, RO$ac -> 
                  767000000000.00012, CBE$ac -> .38799999999999991*^-12, 
                  CBC$ac -> .37500000000000002*^-12, CJS$ac -> 0.0, 
                  BETAAC$ac -> -1.3400000000000001, CBX$ac -> 0.0, 
                  FT$ac -> -.0055999999999999999}, {"V1", {"1", "0"}, Type -> 
                  VoltageSource, Value -> {DC -> 15.0, Transient -> 15.0}, 
                  Symbolic -> {DC -> V1, Transient -> V1}}, {"V2", {"0", 
                  "13"}, Type -> VoltageSource, Value -> {DC -> 15.0, 
                  Transient -> 15.0}, Symbolic -> {DC -> V2, Transient -> 
                  V2}}, {"VOS", {"5", "$N$0001"}, Type -> VoltageSource, 
                  Value -> {DC -> .000321, Transient -> .000321}, 
                  Symbolic -> {DC -> VOS, Transient -> VOS}}, {"R13", {"26", 
                  "0"}, Type -> Resistor, Value -> .1*^4, Symbolic -> R13}, {
                  "VIC", {"5", "0"}, Type -> VoltageSource, Value -> {DC -> 
                  0.0, Transient -> 0.0}, Symbolic -> {DC -> VIC, 
                  Transient -> VIC}}, {"VID", {"4", "$N$0001"}, Type -> 
                  VoltageSource, Value -> {AC -> 1.0, DC -> CheckedSinWave[ 
                  Time, 0.0, .80000000000000004, .1*^4, 0.0, 0.0, 0.0], 
                  Transient -> CheckedSinWave[ 
                  Time, 0.0, .80000000000000004, .1*^4, 0.0, 0.0, 0.0]}, 
                  Symbolic -> VID}]]], 
            SequenceForm[ 
              DisplayForm[ 
                LocalModelParameters[ "QNPN741"][ 
                Type -> "NPN", BF -> .2*^3, IS -> .20000000000000002*^-14, 
                  VAF -> .15*^3, RB -> .2*^3, BR -> 2.0, 
                  CJE -> .99999999999999998*^-12, 
                  CJC -> .99999999999999998*^-12]]], 
            SequenceForm[ 
              DisplayForm[ 
                LocalModelParameters[ "QPNP741"][ 
                Type -> "PNP", BF -> .5*^2, IS -> .1*^-13, VAF -> .5*^2, 
                  RB -> .1*^3, BR -> 3.0, CJE -> .99999999999999998*^-12, 
                  CJC -> .99999999999999998*^-12]]], 
            SequenceForm[ 
              DisplayForm[ 
                GlobalParameters[ Simulator -> "PSpice"]]]}]}}, 
          TableSpacing -> {1, 0}]}],
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ensure Validity of Models", "ExampleSection"],

Cell[TextData[{
  "Since the generated Analog Insydes netlist contains only generic model \
references for each transistor the corresponding device model definitions \
must be selected. Following we choose a simplified BJT small-signal model \
from the Analog Insydes model library by setting the option ",
  StyleBox["ModelLibrary \[Rule] \"BasicModels`\". ", "MR"]
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .40965 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 1 r
MFill
% Scaling calculations
-0.356524 0.0975224 -1.72677 0.0975224 [
[.97619 .339 -5.59375 -7.8125 ]
[.97619 .339 5.59375 7.8125 ]
[.72048 .16767 -23.9063 -7.8125 ]
[.72048 .16767 23.9063 7.8125 ]
[.2163 .20431 -12.7813 -7.8125 ]
[.2163 .20431 12.7813 7.8125 ]
[.89543 .25333 -9.1875 -7.8125 ]
[.89543 .25333 9.1875 7.8125 ]
[.43304 .39989 -12.7813 -7.8125 ]
[.43304 .39989 12.7813 7.8125 ]
[.3466 .20482 -12.7813 -7.8125 ]
[.3466 .20482 12.7813 7.8125 ]
[.04368 .25333 -12.9375 -7.8125 ]
[.04368 .25333 12.9375 7.8125 ]
[.02381 .33951 -5.59375 -7.8125 ]
[.02381 .33951 5.59375 7.8125 ]
[.6214 .00975 -5.59375 -7.8125 ]
[.6214 .00975 5.59375 7.8125 ]
[.92588 .03401 -5.59375 -7.8125 ]
[.92588 .03401 5.59375 7.8125 ]
[ 0 0 0 0 ]
[ 1 .40965 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of user PostScript
%
% $ID: DXFGraphics.m,v 2.12 2000/01/11 12:18:57 thole Exp $
% $ID: DXFGraphics (C) 1998-1999 by M. Thole, ITWM e. V. $
%
% $ID: Created with: $
% $ID:   DXFGraphics[\"p:\\\\AnalogInsydes\\\\Mathematica\\\\Graphics\\\\DXF\\\
\\bjtacsp.dxf\", TextStyle -> {FontColor -> RGBColor[1, 0, 0], FontWeight -> \
\"Bold\"}, FillColors -> {5, RGBColor[0, 0, 0]}, ColorList -> {RGBColor[0., \
0., 0.]}, Background -> RGBColor[1, 1, 1]] $
% $ID: User: halfmann@TENFORWARD.None $
% $ID: Date: 2000/5/19 17:1:18 $
%
% End of user PostScript
0 g
gsave
.97619 .339 -66.5938 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.625 translate 1 -1 scale
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(C) show
70.188 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 0 r
0 Mabswid
[ ] 0 setdash
.61882 .1816 m
.61882 .14496 L
s
.62811 .17592 m
.61882 .14496 L
.60953 .17592 L
.61882 .16044 L
.62811 .17592 L
F
.62811 .17592 m
.61882 .14496 L
.60953 .17592 L
.61882 .16044 L
.62811 .17592 L
s
0 g
gsave
.72048 .16767 -84.9063 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.625 translate 1 -1 scale
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(GM) show
77.750 15.063 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(*) show
85.250 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(VPI) show
106.813 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.61882 .27913 m
.66785 .23063 L
.61882 .1816 L
.57031 .23063 L
.61882 .27913 L
s
.57031 .23063 m
.66785 .23063 L
s
0 0 0 r
.61882 .32816 m
.61882 .27913 L
s
.61882 .32816 m
.61882 .32816 .00774 0 365.73 arc
F
newpath
.61882 .32816 .00774 0 365.73 arc
s
0 g
.61882 .1816 m
.61882 .12071 L
s
.11928 .29152 m
.16779 .29152 L
.16779 .19399 L
.11928 .19399 L
.11928 .29152 L
s
gsave
.2163 .20431 -73.7813 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.625 translate 1 -1 scale
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(RPI) show
84.563 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.80151 .29152 m
.85053 .29152 L
.85053 .19399 L
.80151 .19399 L
.80151 .29152 L
s
gsave
.89543 .25333 -70.1875 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.625 translate 1 -1 scale
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(RO) show
77.375 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.43304 .39989 -73.7813 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.625 translate 1 -1 scale
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(CBC) show
84.563 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.04233 Mabswid
.41137 .36377 m
.41137 .291 L
s
.43614 .36377 m
.43614 .291 L
s
gsave
.3466 .20482 -73.7813 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.625 translate 1 -1 scale
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(CBE) show
84.563 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.31383 .25436 m
.24107 .25436 L
s
.31383 .23011 m
.24107 .23011 L
s
0 0 0 r
0 Mabswid
.14353 .32816 m
.14353 .29152 L
s
.14353 .32816 m
.14353 .32816 .00774 0 365.73 arc
F
newpath
.14353 .32816 .00774 0 365.73 arc
s
.27771 .25488 m
.27771 .32816 L
s
.27771 .32816 m
.27771 .32816 .00774 0 365.73 arc
F
newpath
.27771 .32816 .00774 0 365.73 arc
s
0 g
.61882 .12071 m
.14353 .12071 L
.14353 .19399 L
s
.61882 .12071 m
.82628 .12071 L
.82628 .19399 L
s
0 0 0 r
.82628 .29152 m
.82628 .32816 L
s
.82628 .32816 m
.82628 .32816 .00774 0 365.73 arc
F
newpath
.82628 .32816 .00774 0 365.73 arc
s
.61882 .12071 m
.61882 .03556 L
s
.61882 .12071 m
.61882 .12071 .00774 0 365.73 arc
F
newpath
.61882 .12071 .00774 0 365.73 arc
s
.61882 .03556 m
.61882 .03556 .00774 0 365.73 arc
F
newpath
.61882 .03556 .00774 0 365.73 arc
s
.41137 .32764 m
.05787 .32764 L
s
.05787 .32764 m
.05787 .32764 .00774 0 365.73 arc
F
newpath
.05787 .32764 .00774 0 365.73 arc
s
.43562 .32764 m
.92329 .32764 L
s
.92329 .32764 m
.92329 .32764 .00774 0 365.73 arc
F
newpath
.92329 .32764 .00774 0 365.73 arc
s
.27771 .23063 m
.27771 .12071 L
s
.27771 .12071 m
.27771 .12071 .00774 0 365.73 arc
F
newpath
.27771 .12071 .00774 0 365.73 arc
s
0 g
gsave
.04368 .25333 -73.9375 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.625 translate 1 -1 scale
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.313 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(VPI) show
84.875 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 0 r
.09451 .29152 m
.09451 .19399 L
s
.1038 .22495 m
.09451 .19399 L
.08522 .22495 L
.09451 .20947 L
.1038 .22495 L
F
.1038 .22495 m
.09451 .19399 L
.08522 .22495 L
.09451 .20947 L
.1038 .22495 L
s
0 g
gsave
.02381 .33951 -66.5938 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.625 translate 1 -1 scale
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(B) show
70.188 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.6214 .00975 -66.5938 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.625 translate 1 -1 scale
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(E) show
70.188 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.92588 .03401 -66.5938 -11.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 23.625 translate 1 -1 scale
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(S) show
70.188 15.063 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 0 r
.92329 .05929 m
.92329 .05929 .00774 0 365.73 arc
F
newpath
.92329 .05929 .00774 0 365.73 arc
s
0 0 m
1 0 L
1 .40965 L
0 .40965 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{420, 171.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["BJT simplified small-signal model", "Caption",
  CellTags->{"IDH_MODELS", "IDH_MODELSBJTS"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(equationsAC741 = 
      CircuitEquations[op741, ModelLibrary \[Rule] "\<BasicModels`\>"]\)], 
  "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]  DAE[AC, \[LeftSkeleton]33\[Times]33
        \[RightSkeleton]] \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "A numerical reference simulation is performed applying the Analog Insydes \
function ",
  StyleBox["ACAnalysis", "MR"],
  " in the frequency range of interest. "
}], "Text"],

Cell[BoxData[
    \(\(reference = ACAnalysis[equationsAC741, \ {f, \ 0.1, \ 1.*^6}]; \)\)], 
  "Input"],

Cell["\<\
Next, a Bode plot of the transfer function generated by Analog Insydes and \
the simulation data read from PSpice is generated. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BodePlot[Evaluate[reference], {Vout741PSpice[f], V$26[f]}, 
      \ {f, \ 0.1, \ 1.*^6}, 
      TraceNames \[Rule] {"\<PSpice\>", "\<AnalogInsydes\>"}]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.521429 0.47619 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.164286 0.97619 0.878571 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0178571 0.714286 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.392857 0.97619 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 1 r
MFill
% Scaling calculations
0.159864 0.136054 0.0140396 0.00246445 [
[.02381 -0.0125 -20 -12.5625 ]
[.02381 -0.0125 20 0 ]
[.29592 -0.0125 -17 -12.5625 ]
[.29592 -0.0125 17 0 ]
[.56803 -0.0125 -17 -12.5625 ]
[.56803 -0.0125 17 0 ]
[.84014 -0.0125 -17 -12.5625 ]
[.84014 -0.0125 17 0 ]
[.5 -0.0125 -29 -25.125 ]
[.5 -0.0125 29 -12.5625 ]
[-0.0125 .01404 -6 -4.5 ]
[-0.0125 .01404 0 4.5 ]
[-0.0125 .06333 -12 -4.5 ]
[-0.0125 .06333 0 4.5 ]
[-0.0125 .11262 -12 -4.5 ]
[-0.0125 .11262 0 4.5 ]
[-0.0125 .16191 -12 -4.5 ]
[-0.0125 .16191 0 4.5 ]
[-0.0125 .2112 -12 -4.5 ]
[-0.0125 .2112 0 4.5 ]
[-0.0125 .26049 -18 -4.5 ]
[-0.0125 .26049 0 4.5 ]
[-0.01875 .1425 -30.5625 -44 ]
[-0.01875 .1425 -18 44 ]
[.02381 .2975 -20 0 ]
[.02381 .2975 20 12.5625 ]
[.29592 .2975 -17 0 ]
[.29592 .2975 17 12.5625 ]
[.56803 .2975 -17 0 ]
[.56803 .2975 17 12.5625 ]
[.84014 .2975 -17 0 ]
[.84014 .2975 17 12.5625 ]
[ -0.0025 -0.0025 0 0 ]
[ 1.0025 .2875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .285 L
s
.29592 0 m
.29592 .285 L
s
.56803 0 m
.56803 .285 L
s
.84014 0 m
.84014 .285 L
s
.17064 0 m
.17064 .285 L
s
.20908 0 m
.20908 .285 L
s
.23217 0 m
.23217 .285 L
s
.24874 0 m
.24874 .285 L
s
.26166 0 m
.26166 .285 L
s
.27226 0 m
.27226 .285 L
s
.28124 0 m
.28124 .285 L
s
.28903 0 m
.28903 .285 L
s
.44275 0 m
.44275 .285 L
s
.48119 0 m
.48119 .285 L
s
.50428 0 m
.50428 .285 L
s
.52085 0 m
.52085 .285 L
s
.53377 0 m
.53377 .285 L
s
.54436 0 m
.54436 .285 L
s
.55335 0 m
.55335 .285 L
s
.56114 0 m
.56114 .285 L
s
.71485 0 m
.71485 .285 L
s
.7533 0 m
.7533 .285 L
s
.77639 0 m
.77639 .285 L
s
.79295 0 m
.79295 .285 L
s
.80588 0 m
.80588 .285 L
s
.81647 0 m
.81647 .285 L
s
.82546 0 m
.82546 .285 L
s
.83325 0 m
.83325 .285 L
s
0 .01404 m
1 .01404 L
s
0 .06333 m
1 .06333 L
s
0 .11262 m
1 .11262 L
s
0 .16191 m
1 .16191 L
s
0 .2112 m
1 .2112 L
s
0 .26049 m
1 .26049 L
s
0 0 0 r
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -81 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E) show
87.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.29592 0 m
.29592 .00625 L
s
gsave
.29592 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.56803 0 m
.56803 .00625 L
s
gsave
.56803 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.84014 0 m
.84014 .00625 L
s
gsave
.84014 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.17064 0 m
.17064 .00375 L
s
.20908 0 m
.20908 .00375 L
s
.23217 0 m
.23217 .00375 L
s
.24874 0 m
.24874 .00375 L
s
.26166 0 m
.26166 .00375 L
s
.27226 0 m
.27226 .00375 L
s
.28124 0 m
.28124 .00375 L
s
.28903 0 m
.28903 .00375 L
s
.44275 0 m
.44275 .00375 L
s
.48119 0 m
.48119 .00375 L
s
.50428 0 m
.50428 .00375 L
s
.52085 0 m
.52085 .00375 L
s
.53377 0 m
.53377 .00375 L
s
.54436 0 m
.54436 .00375 L
s
.55335 0 m
.55335 .00375 L
s
.56114 0 m
.56114 .00375 L
s
.71485 0 m
.71485 .00375 L
s
.7533 0 m
.7533 .00375 L
s
.77639 0 m
.77639 .00375 L
s
.79295 0 m
.79295 .00375 L
s
.80588 0 m
.80588 .00375 L
s
.81647 0 m
.81647 .00375 L
s
.82546 0 m
.82546 .00375 L
s
.83325 0 m
.83325 .00375 L
s
.005 w
0 0 m
1 0 L
s
gsave
.5 -0.0125 -90 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
0 .01404 m
.00625 .01404 L
s
[(0)] -0.0125 .01404 1 0 Mshowa
0 .06333 m
.00625 .06333 L
s
[(20)] -0.0125 .06333 1 0 Mshowa
0 .11262 m
.00625 .11262 L
s
[(40)] -0.0125 .11262 1 0 Mshowa
0 .16191 m
.00625 .16191 L
s
[(60)] -0.0125 .16191 1 0 Mshowa
0 .2112 m
.00625 .2112 L
s
[(80)] -0.0125 .2112 1 0 Mshowa
0 .26049 m
.00625 .26049 L
s
[(100)] -0.0125 .26049 1 0 Mshowa
.125 Mabswid
0 .02636 m
.00375 .02636 L
s
0 .03868 m
.00375 .03868 L
s
0 .05101 m
.00375 .05101 L
s
0 .07565 m
.00375 .07565 L
s
0 .08797 m
.00375 .08797 L
s
0 .1003 m
.00375 .1003 L
s
0 .12494 m
.00375 .12494 L
s
0 .13726 m
.00375 .13726 L
s
0 .14958 m
.00375 .14958 L
s
0 .17423 m
.00375 .17423 L
s
0 .18655 m
.00375 .18655 L
s
0 .19887 m
.00375 .19887 L
s
0 .22352 m
.00375 .22352 L
s
0 .23584 m
.00375 .23584 L
s
0 .24816 m
.00375 .24816 L
s
0 .00172 m
.00375 .00172 L
s
0 .27281 m
.00375 .27281 L
s
.005 w
0 0 m
0 .285 L
s
gsave
-0.01875 .1425 -129.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10.2813 translate
90 rotate
-105 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnitude) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
.25 Mabswid
.02381 .27875 m
.02381 .285 L
s
gsave
.02381 .2975 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E) show
87.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.29592 .27875 m
.29592 .285 L
s
gsave
.29592 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.56803 .27875 m
.56803 .285 L
s
gsave
.56803 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.84014 .27875 m
.84014 .285 L
s
gsave
.84014 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.17064 .28125 m
.17064 .285 L
s
.20908 .28125 m
.20908 .285 L
s
.23217 .28125 m
.23217 .285 L
s
.24874 .28125 m
.24874 .285 L
s
.26166 .28125 m
.26166 .285 L
s
.27226 .28125 m
.27226 .285 L
s
.28124 .28125 m
.28124 .285 L
s
.28903 .28125 m
.28903 .285 L
s
.44275 .28125 m
.44275 .285 L
s
.48119 .28125 m
.48119 .285 L
s
.50428 .28125 m
.50428 .285 L
s
.52085 .28125 m
.52085 .285 L
s
.53377 .28125 m
.53377 .285 L
s
.54436 .28125 m
.54436 .285 L
s
.55335 .28125 m
.55335 .285 L
s
.56114 .28125 m
.56114 .285 L
s
.71485 .28125 m
.71485 .285 L
s
.7533 .28125 m
.7533 .285 L
s
.77639 .28125 m
.77639 .285 L
s
.79295 .28125 m
.79295 .285 L
s
.80588 .28125 m
.80588 .285 L
s
.81647 .28125 m
.81647 .285 L
s
.82546 .28125 m
.82546 .285 L
s
.83325 .28125 m
.83325 .285 L
s
.005 w
0 .285 m
1 .285 L
s
.25 Mabswid
.99375 .01404 m
1 .01404 L
s
.99375 .06333 m
1 .06333 L
s
.99375 .11262 m
1 .11262 L
s
.99375 .16191 m
1 .16191 L
s
.99375 .2112 m
1 .2112 L
s
.99375 .26049 m
1 .26049 L
s
.125 Mabswid
.99625 .02636 m
1 .02636 L
s
.99625 .03868 m
1 .03868 L
s
.99625 .05101 m
1 .05101 L
s
.99625 .07565 m
1 .07565 L
s
.99625 .08797 m
1 .08797 L
s
.99625 .1003 m
1 .1003 L
s
.99625 .12494 m
1 .12494 L
s
.99625 .13726 m
1 .13726 L
s
.99625 .14958 m
1 .14958 L
s
.99625 .17423 m
1 .17423 L
s
.99625 .18655 m
1 .18655 L
s
.99625 .19887 m
1 .19887 L
s
.99625 .22352 m
1 .22352 L
s
.99625 .23584 m
1 .23584 L
s
.99625 .24816 m
1 .24816 L
s
.99625 .00172 m
1 .00172 L
s
.99625 .27281 m
1 .27281 L
s
.005 w
1 0 m
1 .285 L
s
0 0 m
1 0 L
1 .285 L
0 .285 L
closepath
clip
newpath
1 0 0 r
.02381 .27809 m
.06349 .27806 L
.10317 .27794 L
.14286 .27749 L
.18254 .27593 L
.22222 .27152 L
.2619 .26274 L
.30159 .25051 L
.34127 .23675 L
.38095 .22251 L
.42063 .20812 L
.46032 .19369 L
.5 .17924 L
.53968 .16495 L
.57937 .15066 L
.61905 .13634 L
.65873 .122 L
.69841 .10764 L
.7381 .09327 L
.77778 .07888 L
.81746 .06448 L
.85714 .05006 L
.89683 .03563 L
.93651 .0212 L
.97619 .00678 L
s
0 .8 0 r
[ .03 .02 ] 0 setdash
.02381 .27821 m
.06349 .27818 L
.10317 .27806 L
.14286 .27761 L
.18254 .27604 L
.22222 .27159 L
.2619 .26278 L
.30159 .25053 L
.34127 .23677 L
.38095 .22252 L
.42063 .20814 L
.46032 .19371 L
.5 .17925 L
.53968 .16497 L
.57937 .15067 L
.61905 .13635 L
.65873 .12201 L
.69841 .10765 L
.7381 .09328 L
.77778 .07889 L
.81746 .06449 L
.85714 .05007 L
.89683 .03564 L
.93651 .02121 L
.97619 .00679 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.0178571 0.97619 0.357143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 1 r
MFill
% Scaling calculations
0.159864 0.136054 0.278214 0.00288623 [
[.02381 -0.0125 -20 -12.5625 ]
[.02381 -0.0125 20 0 ]
[.29592 -0.0125 -17 -12.5625 ]
[.29592 -0.0125 17 0 ]
[.56803 -0.0125 -17 -12.5625 ]
[.56803 -0.0125 17 0 ]
[.84014 -0.0125 -17 -12.5625 ]
[.84014 -0.0125 17 0 ]
[.5 -0.0125 -29 -25.125 ]
[.5 -0.0125 29 -12.5625 ]
[-0.0125 .04732 -18 -4.5 ]
[-0.0125 .04732 0 4.5 ]
[-0.0125 .10504 -18 -4.5 ]
[-0.0125 .10504 0 4.5 ]
[-0.0125 .16277 -18 -4.5 ]
[-0.0125 .16277 0 4.5 ]
[-0.0125 .22049 -18 -4.5 ]
[-0.0125 .22049 0 4.5 ]
[-0.0125 .27821 -6 -4.5 ]
[-0.0125 .27821 0 4.5 ]
[-0.01875 .1425 -30.5625 -35 ]
[-0.01875 .1425 -18 35 ]
[.02381 .2975 -20 0 ]
[.02381 .2975 20 12.5625 ]
[.29592 .2975 -17 0 ]
[.29592 .2975 17 12.5625 ]
[.56803 .2975 -17 0 ]
[.56803 .2975 17 12.5625 ]
[.84014 .2975 -17 0 ]
[.84014 .2975 17 12.5625 ]
[ -0.0025 -0.0025 0 0 ]
[ 1.0025 .2875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .285 L
s
.29592 0 m
.29592 .285 L
s
.56803 0 m
.56803 .285 L
s
.84014 0 m
.84014 .285 L
s
.17064 0 m
.17064 .285 L
s
.20908 0 m
.20908 .285 L
s
.23217 0 m
.23217 .285 L
s
.24874 0 m
.24874 .285 L
s
.26166 0 m
.26166 .285 L
s
.27226 0 m
.27226 .285 L
s
.28124 0 m
.28124 .285 L
s
.28903 0 m
.28903 .285 L
s
.44275 0 m
.44275 .285 L
s
.48119 0 m
.48119 .285 L
s
.50428 0 m
.50428 .285 L
s
.52085 0 m
.52085 .285 L
s
.53377 0 m
.53377 .285 L
s
.54436 0 m
.54436 .285 L
s
.55335 0 m
.55335 .285 L
s
.56114 0 m
.56114 .285 L
s
.71485 0 m
.71485 .285 L
s
.7533 0 m
.7533 .285 L
s
.77639 0 m
.77639 .285 L
s
.79295 0 m
.79295 .285 L
s
.80588 0 m
.80588 .285 L
s
.81647 0 m
.81647 .285 L
s
.82546 0 m
.82546 .285 L
s
.83325 0 m
.83325 .285 L
s
0 .04732 m
1 .04732 L
s
0 .10504 m
1 .10504 L
s
0 .16277 m
1 .16277 L
s
0 .22049 m
1 .22049 L
s
0 0 0 r
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -81 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E) show
87.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.29592 0 m
.29592 .00625 L
s
gsave
.29592 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.56803 0 m
.56803 .00625 L
s
gsave
.56803 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.84014 0 m
.84014 .00625 L
s
gsave
.84014 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.17064 0 m
.17064 .00375 L
s
.20908 0 m
.20908 .00375 L
s
.23217 0 m
.23217 .00375 L
s
.24874 0 m
.24874 .00375 L
s
.26166 0 m
.26166 .00375 L
s
.27226 0 m
.27226 .00375 L
s
.28124 0 m
.28124 .00375 L
s
.28903 0 m
.28903 .00375 L
s
.44275 0 m
.44275 .00375 L
s
.48119 0 m
.48119 .00375 L
s
.50428 0 m
.50428 .00375 L
s
.52085 0 m
.52085 .00375 L
s
.53377 0 m
.53377 .00375 L
s
.54436 0 m
.54436 .00375 L
s
.55335 0 m
.55335 .00375 L
s
.56114 0 m
.56114 .00375 L
s
.71485 0 m
.71485 .00375 L
s
.7533 0 m
.7533 .00375 L
s
.77639 0 m
.77639 .00375 L
s
.79295 0 m
.79295 .00375 L
s
.80588 0 m
.80588 .00375 L
s
.81647 0 m
.81647 .00375 L
s
.82546 0 m
.82546 .00375 L
s
.83325 0 m
.83325 .00375 L
s
.005 w
0 0 m
1 0 L
s
gsave
.5 -0.0125 -90 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
0 .04732 m
.00625 .04732 L
s
[(-80)] -0.0125 .04732 1 0 Mshowa
0 .10504 m
.00625 .10504 L
s
[(-60)] -0.0125 .10504 1 0 Mshowa
0 .16277 m
.00625 .16277 L
s
[(-40)] -0.0125 .16277 1 0 Mshowa
0 .22049 m
.00625 .22049 L
s
[(-20)] -0.0125 .22049 1 0 Mshowa
0 .27821 m
.00625 .27821 L
s
[(0)] -0.0125 .27821 1 0 Mshowa
.125 Mabswid
0 .06175 m
.00375 .06175 L
s
0 .07618 m
.00375 .07618 L
s
0 .09061 m
.00375 .09061 L
s
0 .11947 m
.00375 .11947 L
s
0 .1339 m
.00375 .1339 L
s
0 .14833 m
.00375 .14833 L
s
0 .1772 m
.00375 .1772 L
s
0 .19163 m
.00375 .19163 L
s
0 .20606 m
.00375 .20606 L
s
0 .23492 m
.00375 .23492 L
s
0 .24935 m
.00375 .24935 L
s
0 .26378 m
.00375 .26378 L
s
0 .03289 m
.00375 .03289 L
s
0 .01845 m
.00375 .01845 L
s
0 .00402 m
.00375 .00402 L
s
.005 w
0 0 m
0 .285 L
s
gsave
-0.01875 .1425 -120.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
96 10.2813 translate
90 rotate
-96 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(deg) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(L) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
.25 Mabswid
.02381 .27875 m
.02381 .285 L
s
gsave
.02381 .2975 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E) show
87.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.29592 .27875 m
.29592 .285 L
s
gsave
.29592 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.56803 .27875 m
.56803 .285 L
s
gsave
.56803 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.84014 .27875 m
.84014 .285 L
s
gsave
.84014 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.17064 .28125 m
.17064 .285 L
s
.20908 .28125 m
.20908 .285 L
s
.23217 .28125 m
.23217 .285 L
s
.24874 .28125 m
.24874 .285 L
s
.26166 .28125 m
.26166 .285 L
s
.27226 .28125 m
.27226 .285 L
s
.28124 .28125 m
.28124 .285 L
s
.28903 .28125 m
.28903 .285 L
s
.44275 .28125 m
.44275 .285 L
s
.48119 .28125 m
.48119 .285 L
s
.50428 .28125 m
.50428 .285 L
s
.52085 .28125 m
.52085 .285 L
s
.53377 .28125 m
.53377 .285 L
s
.54436 .28125 m
.54436 .285 L
s
.55335 .28125 m
.55335 .285 L
s
.56114 .28125 m
.56114 .285 L
s
.71485 .28125 m
.71485 .285 L
s
.7533 .28125 m
.7533 .285 L
s
.77639 .28125 m
.77639 .285 L
s
.79295 .28125 m
.79295 .285 L
s
.80588 .28125 m
.80588 .285 L
s
.81647 .28125 m
.81647 .285 L
s
.82546 .28125 m
.82546 .285 L
s
.83325 .28125 m
.83325 .285 L
s
.005 w
0 .285 m
1 .285 L
s
.25 Mabswid
.99375 .04732 m
1 .04732 L
s
.99375 .10504 m
1 .10504 L
s
.99375 .16277 m
1 .16277 L
s
.99375 .22049 m
1 .22049 L
s
.99375 .27821 m
1 .27821 L
s
.125 Mabswid
.99625 .06175 m
1 .06175 L
s
.99625 .07618 m
1 .07618 L
s
.99625 .09061 m
1 .09061 L
s
.99625 .11947 m
1 .11947 L
s
.99625 .1339 m
1 .1339 L
s
.99625 .14833 m
1 .14833 L
s
.99625 .1772 m
1 .1772 L
s
.99625 .19163 m
1 .19163 L
s
.99625 .20606 m
1 .20606 L
s
.99625 .23492 m
1 .23492 L
s
.99625 .24935 m
1 .24935 L
s
.99625 .26378 m
1 .26378 L
s
.99625 .03289 m
1 .03289 L
s
.99625 .01845 m
1 .01845 L
s
.99625 .00402 m
1 .00402 L
s
.005 w
1 0 m
1 .285 L
s
0 0 m
1 0 L
1 .285 L
0 .285 L
closepath
clip
newpath
1 0 0 r
.02381 .27292 m
.06349 .26786 L
.10317 .25802 L
.14286 .23927 L
.18254 .20577 L
.22222 .15618 L
.2619 .10366 L
.30159 .06515 L
.34127 .04275 L
.38095 .03089 L
.42063 .02478 L
.46032 .02167 L
.5 .02008 L
.53968 .01929 L
.57937 .01887 L
.61905 .01865 L
.65873 .01851 L
.69841 .01841 L
.7381 .01828 L
.77778 .01806 L
.81746 .01766 L
.85714 .01689 L
.89683 .01538 L
.93651 .01245 L
.97619 .00679 L
s
0 .8 0 r
[ .03 .02 ] 0 setdash
.02381 .27289 m
.06349 .2678 L
.10317 .25791 L
.14286 .23906 L
.18254 .20545 L
.22222 .15571 L
.2619 .10329 L
.30159 .06491 L
.34127 .04262 L
.38095 .03082 L
.42063 .02475 L
.46032 .02165 L
.5 .02007 L
.53968 .01928 L
.57937 .01887 L
.61905 .01865 L
.65873 .01852 L
.69841 .01841 L
.7381 .01829 L
.77778 .01809 L
.81746 .01772 L
.85714 .017 L
.89683 .01561 L
.93651 .01289 L
.97619 .00766 L
s
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
0 g
.14286 .02143 m
.14286 .11667 L
.95238 .11667 L
.95238 .02143 L
F
1 g
.11905 .04524 m
.11905 .14048 L
.92857 .14048 L
.92857 .04524 L
F
0 g
.001 w
.11905 .04524 m
.92857 .04524 L
.92857 .14048 L
.11905 .14048 L
.11905 .04524 L
s
% Start of sub-graphic
p
0.119048 0.0452381 0.928571 0.140476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0396825 0.396825 0.00498504 0.0498504 [
[ 0 0 0 0 ]
[ 1 .11765 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11765 L
0 .11765 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0714286 0.00897308 0.468254 0.0588235 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.005 w
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.26984 .06281 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(PSpice) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% Start of sub-graphic
p
0.531746 0.00897308 0.928571 0.0588235 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 .8 0 r
.005 w
[ .03 .02 ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.73016 .06281 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(AnalogInsydes) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{530, 476.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
The curves fit perfectly in the frequency range of interest. Hence, the \
simplified PSpice model is sufficient for being used in the next step of the \
symbolic analysis flow.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbolic Approximation", "ExampleSection"],

Cell["\<\
Set up symbolic circuit equations of OP\[Micro]A741 in sparse tableau \
formulation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(op741sta\  = \ 
      CircuitEquations[op741, \ ElementValues \[Rule] Symbolic, \ 
        Formulation\  \[Rule] \ SparseTableau, 
        ModelLibrary \[Rule] "\<BasicModels`\>"]\)], "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]  DAE[AC, \[LeftSkeleton]402\[Times]402
        \[RightSkeleton]] \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Estimate the number of symbolic terms in the transfer function ",
  StyleBox["without",
    FontWeight->"Bold"],
  " approximation."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ComplexityEstimate[op741sta] // N\)], "Input"],

Cell[BoxData[
    \(1.6186803248911481`*^21\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Call equation-based approximation routine on the symbolic circuit \
equations of the OP\[Micro]A741 circuit. To capture the first corner \
frequency appropriate design points are chosen at ",
  Cell[BoxData[
      \(TraditionalForm\`1  Hz\)]],
  " and at ",
  Cell[BoxData[
      \(TraditionalForm\`10  Hz\)]],
  " with a maximum error of 40% and 30% respectively."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(op741approx\ \  = \ 
      ApproximateMatrixEquation[op741sta, \ V$R13, 
        \ {{s\ \  \[Rule] \ 2. \ \[Pi]\ I\ 1. , \ MaxError\  \[Rule] \ 0.4}, {
            s\ \  \[Rule] \ 2. \ \[Pi]\ I\ 10. , \ 
            MaxError\  \[Rule] \ 0.3}}, CompressEquations \[Rule] True]\)], 
  "Input"],

Cell[BoxData[
    \(\[SkeletonIndicator]  DAE[AC, \[LeftSkeleton]44\[Times]44
        \[RightSkeleton]] \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell["Solve for the output voltage (V$R13):", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Vout741\  = \ 
      V$R13\  /. \ First[Solve[op741approx, \ V$R13]] // Simplify\)], "Input"],

Cell[BoxData[
    \(\((gm$Q16\ gm$Q17\ gm$Q2\ gm$Q4\ R9\ Ro$Q131\ Ro$Q17\ Ro$Q4\ Rpi$Q16\ 
          Rpi$Q17\ VID)\)/
      \((\((gm$Q2 + gm$Q4)\)\ 
          \((gm$Q17\ R8\ \((Ro$Q131 + Ro$Q17)\)\ Ro$Q4\ Rpi$Q17 + 
              R9\ \((Ro$Q17\ 
                      \((Ro$Q4 + gm$Q16\ gm$Q17\ R8\ Rpi$Q16\ Rpi$Q17)\) + 
                    Ro$Q131\ 
                      \((Ro$Q4 + gm$Q16\ gm$Q17\ R8\ Rpi$Q16\ Rpi$Q17 + 
                          C1\ gm$Q16\ gm$Q17\ Ro$Q17\ Ro$Q4\ Rpi$Q16\ Rpi$Q17
                            \ s)\))\))\))\)\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Verification of the Result", "ExampleSection"],

Cell["Evaluate approximated result with numerical values:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Vout741N[s_]\  = \ 
      Vout741\  /. \ GetDAEOptions[op741sta, DesignPoint]\  // \ Simplify\)], 
  "Input"],

Cell[BoxData[
    \(7.32151565764917577`*^22
      \/\(2.90286836076560064`*^17 + 1.51745330962874902`*^16\ s\)\)], 
  "Output"]
}, Open  ]],

Cell["\<\
Plot approximated function together with unsimplified transfer function as \
Bode plot:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BodePlot[{Vout741PSpice[f], \ Vout741N[2. \ \[Pi]\ I\ f]}, 
      \ {f, \ 0.1, \ 1.*^6}, 
      TraceNames \[Rule] {"\<Reference\>", "\<Approximation\>"}]; \)\)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.521429 0.47619 [
[ 0 0 0 0 ]
[ 1 .9 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.164286 0.97619 0.878571 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0178571 0.714286 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.392857 0.97619 0.732143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 1 r
MFill
% Scaling calculations
0.159864 0.136054 0.0139382 0.00244665 [
[.02381 -0.0125 -20 -12.5625 ]
[.02381 -0.0125 20 0 ]
[.29592 -0.0125 -17 -12.5625 ]
[.29592 -0.0125 17 0 ]
[.56803 -0.0125 -17 -12.5625 ]
[.56803 -0.0125 17 0 ]
[.84014 -0.0125 -17 -12.5625 ]
[.84014 -0.0125 17 0 ]
[.5 -0.0125 -29 -25.125 ]
[.5 -0.0125 29 -12.5625 ]
[-0.0125 .01394 -6 -4.5 ]
[-0.0125 .01394 0 4.5 ]
[-0.0125 .06287 -12 -4.5 ]
[-0.0125 .06287 0 4.5 ]
[-0.0125 .1118 -12 -4.5 ]
[-0.0125 .1118 0 4.5 ]
[-0.0125 .16074 -12 -4.5 ]
[-0.0125 .16074 0 4.5 ]
[-0.0125 .20967 -12 -4.5 ]
[-0.0125 .20967 0 4.5 ]
[-0.0125 .2586 -18 -4.5 ]
[-0.0125 .2586 0 4.5 ]
[-0.01875 .1425 -30.5625 -44 ]
[-0.01875 .1425 -18 44 ]
[.02381 .2975 -20 0 ]
[.02381 .2975 20 12.5625 ]
[.29592 .2975 -17 0 ]
[.29592 .2975 17 12.5625 ]
[.56803 .2975 -17 0 ]
[.56803 .2975 17 12.5625 ]
[.84014 .2975 -17 0 ]
[.84014 .2975 17 12.5625 ]
[ -0.0025 -0.0025 0 0 ]
[ 1.0025 .2875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .285 L
s
.29592 0 m
.29592 .285 L
s
.56803 0 m
.56803 .285 L
s
.84014 0 m
.84014 .285 L
s
.17064 0 m
.17064 .285 L
s
.20908 0 m
.20908 .285 L
s
.23217 0 m
.23217 .285 L
s
.24874 0 m
.24874 .285 L
s
.26166 0 m
.26166 .285 L
s
.27226 0 m
.27226 .285 L
s
.28124 0 m
.28124 .285 L
s
.28903 0 m
.28903 .285 L
s
.44275 0 m
.44275 .285 L
s
.48119 0 m
.48119 .285 L
s
.50428 0 m
.50428 .285 L
s
.52085 0 m
.52085 .285 L
s
.53377 0 m
.53377 .285 L
s
.54436 0 m
.54436 .285 L
s
.55335 0 m
.55335 .285 L
s
.56114 0 m
.56114 .285 L
s
.71485 0 m
.71485 .285 L
s
.7533 0 m
.7533 .285 L
s
.77639 0 m
.77639 .285 L
s
.79295 0 m
.79295 .285 L
s
.80588 0 m
.80588 .285 L
s
.81647 0 m
.81647 .285 L
s
.82546 0 m
.82546 .285 L
s
.83325 0 m
.83325 .285 L
s
0 .01394 m
1 .01394 L
s
0 .06287 m
1 .06287 L
s
0 .1118 m
1 .1118 L
s
0 .16074 m
1 .16074 L
s
0 .20967 m
1 .20967 L
s
0 .2586 m
1 .2586 L
s
0 0 0 r
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -81 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E) show
87.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.29592 0 m
.29592 .00625 L
s
gsave
.29592 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.56803 0 m
.56803 .00625 L
s
gsave
.56803 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.84014 0 m
.84014 .00625 L
s
gsave
.84014 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.17064 0 m
.17064 .00375 L
s
.20908 0 m
.20908 .00375 L
s
.23217 0 m
.23217 .00375 L
s
.24874 0 m
.24874 .00375 L
s
.26166 0 m
.26166 .00375 L
s
.27226 0 m
.27226 .00375 L
s
.28124 0 m
.28124 .00375 L
s
.28903 0 m
.28903 .00375 L
s
.44275 0 m
.44275 .00375 L
s
.48119 0 m
.48119 .00375 L
s
.50428 0 m
.50428 .00375 L
s
.52085 0 m
.52085 .00375 L
s
.53377 0 m
.53377 .00375 L
s
.54436 0 m
.54436 .00375 L
s
.55335 0 m
.55335 .00375 L
s
.56114 0 m
.56114 .00375 L
s
.71485 0 m
.71485 .00375 L
s
.7533 0 m
.7533 .00375 L
s
.77639 0 m
.77639 .00375 L
s
.79295 0 m
.79295 .00375 L
s
.80588 0 m
.80588 .00375 L
s
.81647 0 m
.81647 .00375 L
s
.82546 0 m
.82546 .00375 L
s
.83325 0 m
.83325 .00375 L
s
.005 w
0 0 m
1 0 L
s
gsave
.5 -0.0125 -90 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
0 .01394 m
.00625 .01394 L
s
[(0)] -0.0125 .01394 1 0 Mshowa
0 .06287 m
.00625 .06287 L
s
[(20)] -0.0125 .06287 1 0 Mshowa
0 .1118 m
.00625 .1118 L
s
[(40)] -0.0125 .1118 1 0 Mshowa
0 .16074 m
.00625 .16074 L
s
[(60)] -0.0125 .16074 1 0 Mshowa
0 .20967 m
.00625 .20967 L
s
[(80)] -0.0125 .20967 1 0 Mshowa
0 .2586 m
.00625 .2586 L
s
[(100)] -0.0125 .2586 1 0 Mshowa
.125 Mabswid
0 .02617 m
.00375 .02617 L
s
0 .0384 m
.00375 .0384 L
s
0 .05064 m
.00375 .05064 L
s
0 .0751 m
.00375 .0751 L
s
0 .08734 m
.00375 .08734 L
s
0 .09957 m
.00375 .09957 L
s
0 .12404 m
.00375 .12404 L
s
0 .13627 m
.00375 .13627 L
s
0 .1485 m
.00375 .1485 L
s
0 .17297 m
.00375 .17297 L
s
0 .1852 m
.00375 .1852 L
s
0 .19744 m
.00375 .19744 L
s
0 .2219 m
.00375 .2219 L
s
0 .23414 m
.00375 .23414 L
s
0 .24637 m
.00375 .24637 L
s
0 .0017 m
.00375 .0017 L
s
0 .27084 m
.00375 .27084 L
s
0 .28307 m
.00375 .28307 L
s
.005 w
0 0 m
0 .285 L
s
gsave
-0.01875 .1425 -129.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10.2813 translate
90 rotate
-105 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnitude) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
.25 Mabswid
.02381 .27875 m
.02381 .285 L
s
gsave
.02381 .2975 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E) show
87.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.29592 .27875 m
.29592 .285 L
s
gsave
.29592 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.56803 .27875 m
.56803 .285 L
s
gsave
.56803 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.84014 .27875 m
.84014 .285 L
s
gsave
.84014 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.17064 .28125 m
.17064 .285 L
s
.20908 .28125 m
.20908 .285 L
s
.23217 .28125 m
.23217 .285 L
s
.24874 .28125 m
.24874 .285 L
s
.26166 .28125 m
.26166 .285 L
s
.27226 .28125 m
.27226 .285 L
s
.28124 .28125 m
.28124 .285 L
s
.28903 .28125 m
.28903 .285 L
s
.44275 .28125 m
.44275 .285 L
s
.48119 .28125 m
.48119 .285 L
s
.50428 .28125 m
.50428 .285 L
s
.52085 .28125 m
.52085 .285 L
s
.53377 .28125 m
.53377 .285 L
s
.54436 .28125 m
.54436 .285 L
s
.55335 .28125 m
.55335 .285 L
s
.56114 .28125 m
.56114 .285 L
s
.71485 .28125 m
.71485 .285 L
s
.7533 .28125 m
.7533 .285 L
s
.77639 .28125 m
.77639 .285 L
s
.79295 .28125 m
.79295 .285 L
s
.80588 .28125 m
.80588 .285 L
s
.81647 .28125 m
.81647 .285 L
s
.82546 .28125 m
.82546 .285 L
s
.83325 .28125 m
.83325 .285 L
s
.005 w
0 .285 m
1 .285 L
s
.25 Mabswid
.99375 .01394 m
1 .01394 L
s
.99375 .06287 m
1 .06287 L
s
.99375 .1118 m
1 .1118 L
s
.99375 .16074 m
1 .16074 L
s
.99375 .20967 m
1 .20967 L
s
.99375 .2586 m
1 .2586 L
s
.125 Mabswid
.99625 .02617 m
1 .02617 L
s
.99625 .0384 m
1 .0384 L
s
.99625 .05064 m
1 .05064 L
s
.99625 .0751 m
1 .0751 L
s
.99625 .08734 m
1 .08734 L
s
.99625 .09957 m
1 .09957 L
s
.99625 .12404 m
1 .12404 L
s
.99625 .13627 m
1 .13627 L
s
.99625 .1485 m
1 .1485 L
s
.99625 .17297 m
1 .17297 L
s
.99625 .1852 m
1 .1852 L
s
.99625 .19744 m
1 .19744 L
s
.99625 .2219 m
1 .2219 L
s
.99625 .23414 m
1 .23414 L
s
.99625 .24637 m
1 .24637 L
s
.99625 .0017 m
1 .0017 L
s
.99625 .27084 m
1 .27084 L
s
.99625 .28307 m
1 .28307 L
s
.005 w
1 0 m
1 .285 L
s
0 0 m
1 0 L
1 .285 L
0 .285 L
closepath
clip
newpath
1 0 0 r
.02381 .27608 m
.06349 .27605 L
.10317 .27593 L
.14286 .27549 L
.18254 .27394 L
.22222 .26956 L
.2619 .26084 L
.30159 .2487 L
.34127 .23504 L
.38095 .2209 L
.42063 .20662 L
.46032 .19229 L
.5 .17794 L
.53968 .16376 L
.57937 .14957 L
.61905 .13536 L
.65873 .12112 L
.69841 .10687 L
.7381 .0926 L
.77778 .07831 L
.81746 .06402 L
.85714 .0497 L
.89683 .03537 L
.93651 .02104 L
.97619 .00673 L
s
0 .8 0 r
[ .03 .02 ] 0 setdash
.02381 .27825 m
.06349 .27822 L
.10317 .2781 L
.14286 .27764 L
.18254 .27604 L
.22222 .2715 L
.2619 .26249 L
.30159 .25017 L
.34127 .23647 L
.38095 .22235 L
.42063 .20812 L
.46032 .19386 L
.5 .17959 L
.53968 .16532 L
.57937 .15105 L
.61905 .13678 L
.65873 .1225 L
.69841 .10823 L
.7381 .09396 L
.77778 .07969 L
.81746 .06541 L
.85714 .05114 L
.89683 .03687 L
.93651 .0226 L
.97619 .00833 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.0178571 0.97619 0.357143 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
1 1 1 r
MFill
% Scaling calculations
0.159864 0.136054 0.278214 0.00288623 [
[.02381 -0.0125 -20 -12.5625 ]
[.02381 -0.0125 20 0 ]
[.29592 -0.0125 -17 -12.5625 ]
[.29592 -0.0125 17 0 ]
[.56803 -0.0125 -17 -12.5625 ]
[.56803 -0.0125 17 0 ]
[.84014 -0.0125 -17 -12.5625 ]
[.84014 -0.0125 17 0 ]
[.5 -0.0125 -29 -25.125 ]
[.5 -0.0125 29 -12.5625 ]
[-0.0125 .04732 -18 -4.5 ]
[-0.0125 .04732 0 4.5 ]
[-0.0125 .10504 -18 -4.5 ]
[-0.0125 .10504 0 4.5 ]
[-0.0125 .16277 -18 -4.5 ]
[-0.0125 .16277 0 4.5 ]
[-0.0125 .22049 -18 -4.5 ]
[-0.0125 .22049 0 4.5 ]
[-0.0125 .27821 -6 -4.5 ]
[-0.0125 .27821 0 4.5 ]
[-0.01875 .1425 -30.5625 -35 ]
[-0.01875 .1425 -18 35 ]
[.02381 .2975 -20 0 ]
[.02381 .2975 20 12.5625 ]
[.29592 .2975 -17 0 ]
[.29592 .2975 17 12.5625 ]
[.56803 .2975 -17 0 ]
[.56803 .2975 17 12.5625 ]
[.84014 .2975 -17 0 ]
[.84014 .2975 17 12.5625 ]
[ -0.0025 -0.0025 0 0 ]
[ 1.0025 .2875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .285 L
s
.29592 0 m
.29592 .285 L
s
.56803 0 m
.56803 .285 L
s
.84014 0 m
.84014 .285 L
s
.17064 0 m
.17064 .285 L
s
.20908 0 m
.20908 .285 L
s
.23217 0 m
.23217 .285 L
s
.24874 0 m
.24874 .285 L
s
.26166 0 m
.26166 .285 L
s
.27226 0 m
.27226 .285 L
s
.28124 0 m
.28124 .285 L
s
.28903 0 m
.28903 .285 L
s
.44275 0 m
.44275 .285 L
s
.48119 0 m
.48119 .285 L
s
.50428 0 m
.50428 .285 L
s
.52085 0 m
.52085 .285 L
s
.53377 0 m
.53377 .285 L
s
.54436 0 m
.54436 .285 L
s
.55335 0 m
.55335 .285 L
s
.56114 0 m
.56114 .285 L
s
.71485 0 m
.71485 .285 L
s
.7533 0 m
.7533 .285 L
s
.77639 0 m
.77639 .285 L
s
.79295 0 m
.79295 .285 L
s
.80588 0 m
.80588 .285 L
s
.81647 0 m
.81647 .285 L
s
.82546 0 m
.82546 .285 L
s
.83325 0 m
.83325 .285 L
s
0 .04732 m
1 .04732 L
s
0 .10504 m
1 .10504 L
s
0 .16277 m
1 .16277 L
s
0 .22049 m
1 .22049 L
s
0 0 0 r
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -81 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E) show
87.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.29592 0 m
.29592 .00625 L
s
gsave
.29592 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.56803 0 m
.56803 .00625 L
s
gsave
.56803 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.84014 0 m
.84014 .00625 L
s
gsave
.84014 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.17064 0 m
.17064 .00375 L
s
.20908 0 m
.20908 .00375 L
s
.23217 0 m
.23217 .00375 L
s
.24874 0 m
.24874 .00375 L
s
.26166 0 m
.26166 .00375 L
s
.27226 0 m
.27226 .00375 L
s
.28124 0 m
.28124 .00375 L
s
.28903 0 m
.28903 .00375 L
s
.44275 0 m
.44275 .00375 L
s
.48119 0 m
.48119 .00375 L
s
.50428 0 m
.50428 .00375 L
s
.52085 0 m
.52085 .00375 L
s
.53377 0 m
.53377 .00375 L
s
.54436 0 m
.54436 .00375 L
s
.55335 0 m
.55335 .00375 L
s
.56114 0 m
.56114 .00375 L
s
.71485 0 m
.71485 .00375 L
s
.7533 0 m
.7533 .00375 L
s
.77639 0 m
.77639 .00375 L
s
.79295 0 m
.79295 .00375 L
s
.80588 0 m
.80588 .00375 L
s
.81647 0 m
.81647 .00375 L
s
.82546 0 m
.82546 .00375 L
s
.83325 0 m
.83325 .00375 L
s
.005 w
0 0 m
1 0 L
s
gsave
.5 -0.0125 -90 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.25 Mabswid
0 .04732 m
.00625 .04732 L
s
[(-80)] -0.0125 .04732 1 0 Mshowa
0 .10504 m
.00625 .10504 L
s
[(-60)] -0.0125 .10504 1 0 Mshowa
0 .16277 m
.00625 .16277 L
s
[(-40)] -0.0125 .16277 1 0 Mshowa
0 .22049 m
.00625 .22049 L
s
[(-20)] -0.0125 .22049 1 0 Mshowa
0 .27821 m
.00625 .27821 L
s
[(0)] -0.0125 .27821 1 0 Mshowa
.125 Mabswid
0 .06175 m
.00375 .06175 L
s
0 .07618 m
.00375 .07618 L
s
0 .09061 m
.00375 .09061 L
s
0 .11947 m
.00375 .11947 L
s
0 .1339 m
.00375 .1339 L
s
0 .14833 m
.00375 .14833 L
s
0 .1772 m
.00375 .1772 L
s
0 .19163 m
.00375 .19163 L
s
0 .20606 m
.00375 .20606 L
s
0 .23492 m
.00375 .23492 L
s
0 .24935 m
.00375 .24935 L
s
0 .26378 m
.00375 .26378 L
s
0 .03289 m
.00375 .03289 L
s
0 .01845 m
.00375 .01845 L
s
0 .00402 m
.00375 .00402 L
s
.005 w
0 0 m
0 .285 L
s
gsave
-0.01875 .1425 -120.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
96 10.2813 translate
90 rotate
-96 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(deg) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(L) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
.25 Mabswid
.02381 .27875 m
.02381 .285 L
s
gsave
.02381 .2975 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E) show
87.000000 12.812500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.29592 .27875 m
.29592 .285 L
s
gsave
.29592 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E1) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.56803 .27875 m
.56803 .285 L
s
gsave
.56803 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E3) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.84014 .27875 m
.84014 .285 L
s
gsave
.84014 .2975 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.0) show
81.000000 12.812500 moveto
(E5) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.001 w
.17064 .28125 m
.17064 .285 L
s
.20908 .28125 m
.20908 .285 L
s
.23217 .28125 m
.23217 .285 L
s
.24874 .28125 m
.24874 .285 L
s
.26166 .28125 m
.26166 .285 L
s
.27226 .28125 m
.27226 .285 L
s
.28124 .28125 m
.28124 .285 L
s
.28903 .28125 m
.28903 .285 L
s
.44275 .28125 m
.44275 .285 L
s
.48119 .28125 m
.48119 .285 L
s
.50428 .28125 m
.50428 .285 L
s
.52085 .28125 m
.52085 .285 L
s
.53377 .28125 m
.53377 .285 L
s
.54436 .28125 m
.54436 .285 L
s
.55335 .28125 m
.55335 .285 L
s
.56114 .28125 m
.56114 .285 L
s
.71485 .28125 m
.71485 .285 L
s
.7533 .28125 m
.7533 .285 L
s
.77639 .28125 m
.77639 .285 L
s
.79295 .28125 m
.79295 .285 L
s
.80588 .28125 m
.80588 .285 L
s
.81647 .28125 m
.81647 .285 L
s
.82546 .28125 m
.82546 .285 L
s
.83325 .28125 m
.83325 .285 L
s
.005 w
0 .285 m
1 .285 L
s
.25 Mabswid
.99375 .04732 m
1 .04732 L
s
.99375 .10504 m
1 .10504 L
s
.99375 .16277 m
1 .16277 L
s
.99375 .22049 m
1 .22049 L
s
.99375 .27821 m
1 .27821 L
s
.125 Mabswid
.99625 .06175 m
1 .06175 L
s
.99625 .07618 m
1 .07618 L
s
.99625 .09061 m
1 .09061 L
s
.99625 .11947 m
1 .11947 L
s
.99625 .1339 m
1 .1339 L
s
.99625 .14833 m
1 .14833 L
s
.99625 .1772 m
1 .1772 L
s
.99625 .19163 m
1 .19163 L
s
.99625 .20606 m
1 .20606 L
s
.99625 .23492 m
1 .23492 L
s
.99625 .24935 m
1 .24935 L
s
.99625 .26378 m
1 .26378 L
s
.99625 .03289 m
1 .03289 L
s
.99625 .01845 m
1 .01845 L
s
.99625 .00402 m
1 .00402 L
s
.005 w
1 0 m
1 .285 L
s
0 0 m
1 0 L
1 .285 L
0 .285 L
closepath
clip
newpath
1 0 0 r
.02381 .27292 m
.06349 .26786 L
.10317 .25802 L
.14286 .23927 L
.18254 .20577 L
.22222 .15618 L
.2619 .10366 L
.30159 .06515 L
.34127 .04275 L
.38095 .03089 L
.42063 .02478 L
.46032 .02167 L
.5 .02008 L
.53968 .01929 L
.57937 .01887 L
.61905 .01865 L
.65873 .01851 L
.69841 .01841 L
.7381 .01828 L
.77778 .01806 L
.81746 .01766 L
.85714 .01689 L
.89683 .01538 L
.93651 .01245 L
.97619 .00679 L
s
0 .8 0 r
[ .03 .02 ] 0 setdash
.02381 .27278 m
.06349 .2676 L
.10317 .25751 L
.14286 .23828 L
.18254 .20393 L
.22222 .15313 L
.2619 .10051 L
.30159 .06308 L
.34127 .04167 L
.38095 .03037 L
.42063 .02455 L
.46032 .02157 L
.5 .02005 L
.53968 .01927 L
.57937 .01887 L
.61905 .01867 L
.65873 .01856 L
.69841 .01851 L
.7381 .01848 L
.77778 .01847 L
.81746 .01846 L
.85714 .01846 L
.89683 .01846 L
.93651 .01846 L
.97619 .01845 L
s
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
0 g
.14286 .02143 m
.14286 .11667 L
.95238 .11667 L
.95238 .02143 L
F
1 g
.11905 .04524 m
.11905 .14048 L
.92857 .14048 L
.92857 .04524 L
F
0 g
.001 w
.11905 .04524 m
.92857 .04524 L
.92857 .14048 L
.11905 .14048 L
.11905 .04524 L
s
% Start of sub-graphic
p
0.119048 0.0452381 0.928571 0.140476 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0396825 0.396825 0.00498504 0.0498504 [
[ 0 0 0 0 ]
[ 1 .11765 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .11765 L
0 .11765 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0714286 0.00897308 0.468254 0.0588235 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.005 w
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.26984 .06281 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Reference) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
% Start of sub-graphic
p
0.531746 0.00897308 0.928571 0.0588235 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 .8 0 r
.005 w
[ .03 .02 ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.73016 .06281 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Approximation) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .9 L
0 .9 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{524, 471.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Extraction of Dominant Pole", "ExampleSection"],

Cell["\<\
Since the approximated transfer function fits fine with the unsimplified \
transfer function (see Bode plot) extract symbolic formula for dominant pole:\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[Denominator[Vout741] == 0, s] // Simplify\)], "Input"],

Cell[BoxData[
    \({{s \[Rule] 
          \(-\(\((\((Ro$Q131 + Ro$Q17)\)\ 
                  \((gm$Q17\ R8\ Ro$Q4\ Rpi$Q17 + 
                      R9\ \((Ro$Q4 + gm$Q16\ gm$Q17\ R8\ Rpi$Q16\ Rpi$Q17)\))
                    \))\)/\((
                C1\ gm$Q16\ gm$Q17\ R9\ Ro$Q131\ Ro$Q17\ Ro$Q4\ Rpi$Q16\ 
                  Rpi$Q17)\)\)\)}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Interpretation of the Result", "ExampleSection"],

Cell[TextData[{
  "An interpretation of this formula shows that the intermediate stage with \
the BJTs Q16 and Q17 together with their resistors ",
  StyleBox["R8", "MR"],
  ", ",
  StyleBox["Ro$Q131", "MR"],
  " (output resistance of Q131) and the compensation capacitor ",
  StyleBox["C1", "MR"],
  " dominate this first pole. The pole is also influenced by the output \
resistance of the first differential stage (",
  StyleBox["Ro$Q4", "MR"],
  "). Note, that this formula contains more information than formulas which \
can usually be found in text books, and also note that for the derivation of \
these text-books formulas tedious hand-calculations and a lot of circuit \
knowledge is necessary."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000930001ka000`40O003
h00Oog>Log>LAG>L003o003o00140001Li`00003HaQ2448@0?m24?m24412
4040005cW00000AW>GooHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li
0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW
>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW
>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004
IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<H
IcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP0
16LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS
66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H
00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<H
HaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S
6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS
66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2
HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016Li
HaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li
0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW
>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW
>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004
IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<H
IcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP0
16LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS
66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H
00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<H
HaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S
6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS
66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2
HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016Li
HaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li
0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP026LiHaQS66LiHaQW>D8@
0001Li`00003HaQoof<H0?mS6?mS63mS60524040005cW00000EW>GooHaQS
67oo0?mS6?mS63eS60524040005cW00000aS67ooHaQS67ooHaQW>F<HIcUS
66LiHaR0000026<HIcUS66LiHaQW>F<HIcWo0009000026<HIcUS66LiHaQW
>F<HIcVB000026<HIcUS66LiHaQW>F<HIcT2HaP1@Q010001Li`00005IcUo
of<HHaQoo`07HaP00`00HaQS601lHaP00`00HaQS6006HaP00`00HaQS603o
HaP5HaP00`00HaQS6006HaP00`00HaQS602>HaP00`00HaQS6008HaP1@Q01
0001Li`00005HaQoof<HHaQoo`02HaP00fLiHaQW>@02HaP00`00HaQS601l
HaP01`00HaQW>F<HIcUS66Li009S6003001S66<H0?mS60ES6007001S66Li
HaQW>F<HIcT00V<H00<006<HHaP09f<H2000Gf<H00d006<HIcUS66LiHaQW
>F<HIcUS66Li@Q000001Li`00007IcUoof<HHaQoof<HIcT01F<H02d006<H
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaP00P00
04iS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcT2HaP00`00HaQS6006HaP0o`00HaQS
66<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>@001P00HaQS66<HIcUS609S6003001S66<H00IS600Y001S
66<HHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@0;HaP0FfLiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li009S
6003001S66<H00QS60524040005cW00000ES67ooHaQS67oo00=S6005IcUS
66LiHaP0000=HaP20003HaP40003HaP20002HaP60003HaP40003HaP20008
HaP20006HaP20005HaP40003HaP20003HaP40004HaP4000OHaP03FLi001S
66<HIcUS66LiHaQW>F<H001S66Li0?mS60AS600=IcT006<HHaQW>F<HIcUS
66LiHaP006<HIcT01F<H10000f<H0P000V<H0P000V<H0P000f<H1@000V<H
0P001F<H0P0016<H0P0000=S6000000016<H100016<H1@00BV<H00iW>@00
HaQS66LiHaQW>F<HIcUS66LiHaQ240000G>L00001FLiOomS66<HOol00V<H
00=W>F<HHaP00V<H00`006<HHaQW>F<HIcUS66LiHaQW>F<HIcT2HaP20002
HaP2000016LiHaP000000V<H0P000V<H0P001V<H0P0000AW>F<H0000009S
608000=S6003IcUS66Li009S608000=S6003IcUS66<H008000AS60800004
IcUS60000002HaP20002HaP2000016LiHaP000000V<H0P0000IW>F<H0000
06<HIcT2HaP06FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66Li009S6003001S66Li00IS6004001S66<HIcT2HaP0
ofLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@02HaP00`00HaQW>@06HaP01@00HaQS66<HIcT0
0V<H0P0000AW>F<H0000009S6080009S6080009S6080009S60800004IcUS
60000002HaP20005HaP20004HaP200000f<H00000003HaP2000016LiHaP0
00000V<H0P0000AW>F<H000000AS6015IcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li009S6003001S66Li00QS6052
4040005cW00000ES67ooHaQS67oo00AS6004IcUS66<H0009HaP60002HaP2
0002HaP20006HaP2000:HaP20005HaP00fLiHaQS6004HaP20002HaP016Li
HaQS66<H0P000V<H00=W>F<HHaP00f<H0P001V<H0P000V<H0P000V<H0P00
0V<H0P000f<H00=W>F<HHaP06F<H00L006<HHaQS66LiHaQW>@02HaP00`00
HaQS6002HaP00fLiHaQS603oHaP01`00HaQS66<HIcUS66Li009S6003001S
66<H00=S608000AS6003001S66<H0080009S6080009S6080009S6080009S
608000ES6003IcUS66Li009S60H00004HaQW>@000003HaP20006HaP20002
HaP20002HaP00fLiHaQS6016HaP02@00HaQS66<HIcUS66LiHaQW>@02HaP1
@Q010001Li`00005IcUoof<HHaQoo`02HaP00fLiHaQS6002HaP02000IcUS
66LiHaQW>F<HIcT2HaP2000016LiHaP000000V<H0P0000AW>F<H000000MS
608000=S6003IcUS66<H00=S608000IS6004IcUS66<HIcT2HaP20006HaP2
0008HaP20006HaP2000016LiHaP000000V<H0P0000AW>F<H0000009S600K
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66Li009S6003001S66Li00IS603o001S66<HHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li0006
001S66<HHaQW>F<H0V<H00<006<HIcT01V<H00@006<HHaQW>@9S608000MS
60800006IcUS6000001W>F<H0P000V<H0P0000AW>F<H000000YS60800004
IcUS60000002HaP20003HaP20007HaP200000f<H00000003HaP0AVLiHaQS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
0V<H00<006<HIcT01V<H00AW>F<H@Q00005cW00000ES67ooHaQS67oo00=S
6005IcUS66LiHaP0000:HaP200000f<H00000002HaP20002HaP20003HaP0
0fLiHaQS6002HaP20004HaP20002HaP20002HaP00fLiHaQS6003HaP016Li
HaQS66<H0P000V<H00AW>F<HHaQS6080009S6003IcUS66<H00D000=S6003
IcUS66<H0080009S60800004HaQW>@000002HaP2000OHaP01`00HaQS66<H
IcUS66Li009S6003001S66Li0?mS60ES6007001S66<HHaQW>F<HIcT00V<H
00H006<HHaQS66LiHaP20007HaP20002HaP20002HaP20002HaP20002HaP2
0002HaP01FLiHaQW>F<HIcT00f<H0P000V<H0P0000AS66Li000000=S60H0
00AS60@0009S6003IcUS66Li04IS6009001S66<HHaQW>F<HIcUS66Li009S
60524040005cW00000MW>GooHaQS67ooHaQW>@05HaP02@00HaQS66<HIcUS
66LiHaQW>@02HaP200001F<H000006LiHaP01@000V<H00=W>F<HHaP00f<H
00EW>F<H000006Li009S60D000ES6003IcUS66Li009S6003IcUS66<H0080
00=S6003IcUS66<H008000AS60800006IcUS6000001S66Li16<H0P0000AW
>F<H0000009S60800004IcUS60000003HaP07fLiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H001S66Li
00IS6003001S66<H009S603oIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li0006IcUS66LiHaQW
>F<H1V<H00<006<HIcT00f<H0P000V<H00=W>F<HIcT00V<H0P0000IW>F<H
000006LiHaP200001VLiHaP00000IcUS608000MS6008IcUS66<HHaP006Li
HaP000=S60<0009S6080009S6080009S6080009S608000=S601;IcUS66<H
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<H001S66Li00QS60524040005cW00000ES67ooHaQS67oo00=S6005IcUS
66<HHaP00002HaP00fLiHaQS6006HaP40002HaP20007HaP00fLiHaQS6004
HaP20002HaP20006HaP00fLiHaQS6007HaP20006HaP20004HaP20002HaP2
0003HaP00fLiHaQS60020002HaP2000016<HIcT000000V<H0P000V<H00=W
>F<HHaP06V<H00L006<HHaQS66LiHaQW>@02HaP01000HaQS66Liof<H16<H
00X006<HHaQS66LiHaQW>F<HIcT000=S6004IcUS60000007HaP90004HaP5
0002HaP200000f<HIcUS6002HaP00fLiHaP000030003HaP40002HaP40004
HaP40002HaP01VLiHaQS66LiHaQW>DAS600=001S66<HHaQW>F<HIcUS66Li
HaQW>D8@00000G>L00001FLiOomS66<HOol00V<H00=W>F<HIcT00V<H00<0
06<HHaP00V<H00EW>F<HIcUS66Li009S60@00004IcUS60000006HaP016Li
HaQS66<H0P000V<H0P000V<H0P0016<H00=W>F<HHaP00V<H00EW>F<HIcUS
66Li009S60800004HaQW>F<HIcT2HaP2000016<HIcUS66<H0P0000IW>F<H
000006<HIcT4HaP2000016LiHaP000000V<H0P0000AW>F<H000000AS600I
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcT00V<H00<006<HIcT01V<H0?l006<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT000H006<H
IcUS66LiHaP2HaP00`00HaQW>@06HaP00`00HaQW>@03HaP20002HaP00fLi
HaP00002HaP00fLiHaQS6009HaP016LiHaQS66<H0P000V<H0P000f<H00AW
>F<HHaQS60@000=S6003IcUS66<H009S6003IcUS66<H00=S6003IcUS66<H
00QS6003IcUS66<H009S6011IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>@02HaP00`00HaQW>@08HaP1@Q010001Li`00005HaQo
of<HHaQoo`05HaP01fLiHaP006<HIcUS66Li00QS60<0009S6080009S6080
0006HaQW>F<HHaQW>F<H0P000V<H0P000V<H0P001V<H00QW>F<HIcUS66Li
HaQW>F<H100016<H100016<H0P000V<H0P000f<H00=W>F<HHaP00P000V<H
0P0000AS66Li0000009S6080009S6003IcUS66<H01QS6003IcUS600000=S
6003IcUS66Li009S6003001S66<H0?mS60=S6003IcUS600000=S6003IcUS
66<H009S6003001S66<H00AS6080009S608000MS6003IcUS66<H00QS6080
00ES6005IcUS66<HHaQW>@02HaP200000f<HIcUS600>HaP00fLiHaQS6003
HaP00fLiHaQS6002HaP00fLiHaQW>@11HaP00fLiHaP00003HaP01FLiHaQW
>F<HIcT00V<H0D8@0@000G>L00002FLiOomS66<HOomS66LiHaQW>@03HaP0
0`00HaQS6003HaP01FLiHaQW>F<HIcT00f<H0P0000=S66LiHaP0100026<H
100000=S66LiHaP01P0000=S66LiHaP00V<H00=W>F<HHaP00V<H00IW>F<H
000006<HIcT4HaP200000f<HIcUS6002HaP40002HaP00fLiHaQS6003HaP4
0004HaP40006HaP05fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcT00f<H00<006<HIcT01V<H0?l006<HHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaP000D006<HHaQW>F<H00=S6003001S66Li009S6005IcUS66LiHaP00003
HaP016LiHaQS66<H10004f<H0P000f<H00EW>F<HHaQS66Li00AS608000aS
6004IcUS66<HIcT5HaP01fLiHaQS66<HIcUS66Li00AS600oIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00=S6003001S66Li00QS6052
4040005cW00000ES67ooHaQS67oo00AS6004IcUS66<H0002HaP01fLiHaQW
>F<HIcUS66Li00]S6008IcUS66<HIcUS66LiHaQW>@ES6003IcUS66<H00=S
6003IcUS66<H00AS6006IcUS66<HIcUS66Li26<H00=W>F<HHaP03f<H00=W
>F<HHaP01F<H00=W>F<HHaP01f<H00=W>F<HIcT06F<H00=W>F<H00000f<H
00IW>F<HIcUS66Li003oHaP5HaP00fLiHaP00003HaP00fLiHaQS6002HaP0
1000HaQS66Li2F<H00=W>F<HIcT00V<H00UW>F<HHaQS66LiHaQW>F<HIcT0
2f<H00EW>F<HHaQS66Li00MS6007IcUS66LiHaQW>F<HIcT016<H00IW>F<H
HaQW>F<HIcT3HaP00fLiHaQS6002HaP00fLiHaQW>@11HaP00fLiHaP00003
HaP02FLiHaQW>F<HIcUS66Li@Q000001Li`00005IcUoof<HHaQoo`02HaP0
0fLiHaQS6002HaP00`00HaQW>@03HaP00fLiHaQS6002HaP00fLiHaQS600M
HaP00fLiHaQW>@03HaP00fLiHaQS6007HaP00fLiHaQS6007HaP00fLiHaQS
6005HaP01FLiHaQS66<HIcT04f<H01MW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00=S6003001S66<H00IS603o001S
66<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<H0005001S66<HIcUS6003HaP00`00HaQS6003HaP01FLi
HaQS6000IcT016<H00=W>F<HHaP01f<H00=W>F<HHaP00V<H00=W>F<HHaP0
0f<H00=W>F<HIcT016<H00=W>F<HIcT00f<H00=W>F<HHaP01F<H00=W>F<H
HaP01V<H00=W>F<HIcT026<H00MW>F<HHaQS66LiHaQW>@04HaP0?fLiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@03HaP00`00HaQS6008
HaP1@Q010001Li`00005HaQoof<HHaQoo`03HaP01FLiHaQW>F<H00000f<H
00IW>F<HHaQW>F<HIcT3HaP00fLiHaQW>@02HaP03FLiHaQS66<HIcUS66Li
HaQW>F<HIcUS66Li00ES6003IcUS66<H00MS6003IcUS66<H009S6003IcUS
66Li009S6003IcUS66<H009S6003IcUS66Li009S6003IcUS66Li009S6005
IcUS66<HHaQW>@03HaP01FLiHaQS66<HIcT01F<H00]W>F<HHaQS66LiHaQW
>F<HIcUS66Li01US6003IcUS6000009S6003IcUS66Li00=S6003001S66<H
0?mS60=S6003IcUS6000009S6007IcUS66LiHaQW>F<H00000V<H00=W>F<H
HaP00V<H00IW>F<HHaQW>F<HIcT4HaP00fLiHaQW>@02HaP00fLiHaQW>@04
HaP016LiHaQS66Li16<H00UW>F<HHaQS66LiHaQW>F<HIcT00f<H00EW>F<H
IcUS66Li00ES6005IcUS66LiHaQW>@05HaP00fLiHaQS6002HaP00fLiHaQW
>@11HaP00fLiHaP00002HaP02VLiHaQW>F<HIcUS66LiHaQ240000G>L0000
1fLiOomS66<HOomS66Li00ES68000006HaQW>F<HIcUS66Li0V<Ho`002@00
00=S66LiHaP01F<HTP0000=S66LiHaP01f<H0D8@0@000G>L00001F<HOomS
66<HOol00f<H00=W>F<HHaP0AV<H00=W>F<HHaP0?6<H00=W>F<HIcT0of<H
3F<H00=W>F<HIcT0Uf<H00EW>F<HIcUS66Li009S60524040005cW00000EW
>GooHaQS67oo009S6004IcUS66<HIcV2HaP00fLiHaQW>@3oHaP?HaP00fLi
HaQS602GHaP00fLiHaQS6003HaP016LiHaQ240000G>L000016<HOomS66<H
ogooogoo?7oo0V<H0D8@0@000G>L000016LiOomS66<Ho`00o`00?0000V<H
0D8@0@000G>L000016<HOomW>F<H400004aS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQooa00
003oHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<H002_HaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaP040003f<H00EW>F<HHaQ24000005cW00000=W>GooHaP0
0V<H3T8@04`007ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoo`9S60i2403o001oofLiOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<H002_001oofLiOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaP00V<H
3T8@00`006LiHaQW>F<HIcUS66LiHaQW>F<HIcT7HaP1@Q010001Li`00003
HaQoof<H009S603oOomW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQ24000HaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomW>GooIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H@Q00
06<HOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67oo003oOomW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQ24000HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomW>GooIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<H@Q0006<HOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
000[OomW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQ24000HaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOol0
46<H00AW>F<H@Q00005cW00000=W>GooHaP00V<H00=oof<HHaP02F<H04iW
>D8@001oof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOol2HaP00gooHaQS6009HaP0ofLi@Q0007oo
IcUoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS6000/FLi@Q0007ooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS6002HaP00gooHaQS6009HaP00fLi@Q00000<HaP00fLiHaQW>@03HaP1
@Q010001Li`00003HaQoof<H009S6003OomS66<H00YS601@@Q0006<HOomW
>GooHaQoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooHaQoo`aS603o@Q0006<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H002c@Q0006<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS600<HaP00d8@
001S6002HaP01fLiHaQW>F<HIcUS66Li00ES6005IcUS66Li@Q000001Li`0
0003IcUoof<H009S6003OomS66<H009S6006IcUS6000IcUS66Li0V<H0512
4000OomS67ooHaQoofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQW>Goo0f<H00MW>F<HIcUS66LiHaQW>@02
HaP0od8@001oof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoo`00/d8@001oof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOol016<H00H006LiHaQW>F<HIcT2HaP0148@
001S66Li2F<H00=W>F<HIcT016<H0D8@0@000G>L00000f<HOomW>@02HaP0
1WooHaQW>F<HIcUS608000AS601AIcU24000HaQoofLiOomS67ooHaQoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67oo009S6003IcUS66<H00IS603oIcU24000HaQoofLiOomS67ooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo002fIcU24000
HaQoofLiOomS67ooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS609S
608000ES6003IcU2400000=S6005IcUS66LiHaQW>@02HaP02VLiHaQS66<H
IcUS66LiHaQ240000G>L00000f<HOomS6002HaP00gooHaQS6002HaP30002
HaP0D6LiHaQS648@001oof<HOomS67ooHaQoofLiOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOol2HaP00gooIcUS6002HaP0
1VLiHaQS66LiHaQW>@9S603o@Q0007ooHaQoof<HOomW>GooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo002`@Q0007ooHaQo
of<HOomW>GooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS609S6003OomS66<H009S60<0
009S6005IcUS66<H@Q000009HaP01FLiHaQW>F<HIcT016<H0D8@0@000G>L
00000f<HOomS6002HaP017ooHaQS66<H10001F<H05124000HaQoofLiOomS
67ooHaQoof<HOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomS67oo1V<H00=W>F<HHaP00f<H0?m24000HaQoofLiOomS67oo
HaQoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaP0
06M24000HaQoofLiOomS67ooHaQoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS6008O000A6<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoof<HOol2HaP00fLiHaP0
00030004HaP02D8@001S66<HIcUS66LiHaQW>@03HaP02VLiHaQS66<HIcUS
66LiHaQ240000G>L00000fLiOomS6002HaP00gooHaQW>@02HaP30003HaP0
CfLiHaQ24000OomS67ooHaQoofLiOomS67ooIcUoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67oo009S6006OomS66<HIcUS66Li0f<H
0?mW>F<HIcUS648@001oof<HOomS67ooHaQoofLiOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOol006QW>F<HIcUS648@001oof<HOomS67ooHaQo
ofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<H0g`000Qoof<HOomS67ooHaQoof<H0g`003iS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67oo0V<H00=oof<HHaP00V<H0`000f<H00IW>F<H
@Q0006<HIcT5HaP01fLiHaQW>F<HIcUS66Li00AS60524040005cW00000IS
67ooHaQW>F<HOol5HaP20002HaP0DfLiHaQS648@001S67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
HaQoof<HOol01F<H00=W>F<HIcT016<H0?m24000HaQoofLiOomS67ooHaQo
of<HOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcT00692
4000HaQoofLiOomS67ooHaQoof<HOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67oo0W`000ioof<HOomW>GooHaQoofLiOomS67ooIcUo
of<H0W`003moof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOol0
0V<H00AW>F<H000000IS6003@Q0006<H009S6003IcUS66Li00AS600:IcUS
66<HHaQW>F<HIcUS648@0001Li`00003IcUoof<H009S6003OomS66<H00AS
6003001S66<H00=S601=@Q0007ooIcUoofLiOomS67ooIcUoof<HOomW>Goo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooIcUoo`02HaP01WooHaQS
66LiHaQW>@=S603oIcUS66LiHaQ24000OomS67ooHaQoofLiOomS67ooIcUo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67oo002dIcUS66LiHaQ24000OomS
67ooHaQoofLiOomS67ooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H0V<H00=oof<HHaP00V<H
00`006<HHaQS66LiHaQW>F<H@Q0006<HIcT5HaP01fLiHaQW>F<HIcUS66Li
00AS60524040005cW00000=S67ooHaP00V<H00Eoof<HIcUS66Li00ES601C
IcUS66<H@Q0006<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoof<HOomS67ooHaQoo`05HaP00fLiHaQW>@04
HaP0od8@001S67ooHaQoof<HOomS67ooHaQoof<HOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS6000Gd8@001S67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaP00W`001AW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo0W`003aS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoof<HOol2HaP00fLiHaQS6007HaP00d8@001S
6002HaP00fLiHaQW>@04HaP02VLiHaQS66<HIcUS66LiHaQ240000G>L0000
0fLiOomS6002HaP00gooHaQS6008HaP0CfLiHaQ24000OomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoofLiOomS
67oo009S6006OomS66<HIcUS66Li0f<H0?mW>F<HIcUS648@001oofLiOomW
>GooHaQoofLiOomS67ooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOol00;AW
>F<HIcUS648@001oofLiOomW>GooHaQoofLiOomS67ooIcUoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaP2
HaP00gooIcUS6006HaP026LiHaQW>F<H@Q0006<HIcT5HaP01fLiHaQW>F<H
IcUS66Li00AS60524040005cW00000ES67ooHaQW>F<H00eoo`1?@Q0006<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooHaQoof<HOomW>GooHaP03Goo0?m24000HaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUo
of<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67oo
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcT005a24000
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
0W`001YoofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H
OomW>GooHaQoofLi0W`003QoofLiOomS67ooIcUoof<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<H3Goo00=2
4000HaP00V<H00=W>F<HIcT016<H00YW>F<HHaQS66LiHaQW>F<H@Q00005c
W00000=W>GooHaP046<H04`007ooIcUoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoofLiOomS67ooHaQooa1S603o001oofLi
OomS67ooIcUoof<HOomW>GooHaQoofLiOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<H002_001oofLiOomS67ooIcUoof<HOomW>GooHaQoofLiOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaP046<H00<006<HHaP01F<H00MW>F<HIcUS66LiHaQW>@04HaP1@Q010001
Li`00004HaQoof<HHaSoOoo4Ool00g`0Oomoo`0NOol00g`0Oomoo`13Ool@
0002HaP1@Q010001Li`00004IcUoof<HHaSoOoo3Ool00g`0Oomoo`0POol0
0g`0Oomoo`12Ool00f<H@Q12400<@Q001@00HaQS648@00000G>L000016<H
OomS66<Hogoo`Woo00=l07ooOol08Woo00=l07ooOol0@Goo00=W>GooHaP0
1V<H00MW>F<HHaQS66Li@Q000002HaP1@Q010001Li`00004IcUoof<HIcWo
Ooo2Ool00g`0Oomoo`0ROol00g`001l07`0201loOol00f<HOomS6003HaP0
0fLiHaQS6005HaP01T8@001S66<H@Q00005cW00000AS67ooHaQS6?mool5o
o`03O01oogoo01moo`0301moogoo009oo`05O01oogooOol07`0nOol01FLi
OomS66<HIcT00f<H00=W>F<HIcT00f<H00I24000HaQS648@0001Li`00004
IcUoof<HIcWoOoo0Ool00g`0Oomoo`0POol00`0OOomoo`03Ool017`0Oomo
o`0O?Woo00=S67ooIcT016<H00=W>F<HHaP00V<H00AW>F<H@Q00009S6052
4040005cW00000AS67ooHaQS6?mookmoo`03O01oogoo025oo`0301moogoo
00Aoo`03O01oo`0O03ioo`05IcUoof<HHaQW>@02HaP00`00HaQW>@04HaP0
1T8@001S66<H@Q00005cW00000AW>GooHaQW>Omookmoo`03O01oogoo025o
o`0301moogoo00Aoo`03O0007goo03ioo`03HaQoof<H00=S60<0000;HaQW
>F<HIcUS648@001W>F<H@Q000001Li`00004HaQoof<HHaSoOonnOol00g`0
Oomoo`0ROol00`0OOomoo`04Ool00`0OO01oo`0nOol01FLiOomS66<HIcT0
1@0016<H00I24000HaQS648@0001Li`00004IcUoof<HIcWoOonmOol00g`0
Oomoo`0QOol301l7Ool00`0OO01oo`0mOol016<HOomS66<H1`0000ES66Li
HaQ24000009S60524040005cW00000AS67ooHaQS6?mookaoo`03O01oogoo
02Aoo`0301moogoo009oo`@07`03Ooml07oo03aoo`03IcUoof<H00]S6006
@Q0006<HHaQ240000G>L000016LiOomS66Liogoo_7oo00=l07ooOol0;Woo
00=l07ooOol0>goo00=S67ooHaP00f<H00=W>F<HHaP01F<H00I24000HaQS
648@0001Li`00004HaQoof<HHaSoOonkOol00g`0Oomoo`0`Ool00g`0Oomo
o`0jOol00fLiOomS6007HaP01VLiHaQW>F<H@Q00009S60524040005cW000
00AW>GooHaQW>Omook]oo`03O01oogoo031oo`03O01oogoo03Yoo`06HaQo
of<HIcUS66Li0V<H00=W>F<HHaP00f<H00I24000HaQS648@0001Li`00004
HaQoof<HHaSoOonjOol00g`0Oomoo`0bOol00g`0Oomoo`0iOol00fLiOomo
o`0;Ool01T8@001S66<H@Q00005cW00000AW>GooHaQW>H=oo`807aioo`80
7eioo`807cmoo`807e=oo`807aioo`03O01oogoo00Qoo`807aioo`807`Qo
o`03O01oogoo03Aoo`807`=oo`mS6005001S66<H@Q000001Li`00004HaQo
of<HHaP^Ool00`0O0P02001A0P0401lL0P0401mL0P0401lm0P0401mA0P04
01lL0P000g`00P0200080P0401lL0P0401l80P000g`00P02000b0P0401l2
0P0046<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@0@00
0G>L000016LiOomS66Li;Woo00<07gooOol0DGoo100O77oo100OG7oo100O
?Goo100ODGoo100O77oo00=l07ooOol027oo100O77oo100O27oo00=l07oo
Ool0<Woo100O0goo00iS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo0f<H
0D8@0@000G>L000016<HOomS66<H;Woo00<07gooOol0DWoo0P0O7Woo0P0O
GWoo0P0O?goo0P0ODgoo0P0O77oo00=l07ooOol02Woo0P0O7Woo0P0O2Woo
00=l07ooOol0<Woo0P0O0goo01AW>GooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HIcU240000G>L000016LiOomS66Li;Woo00<07gooOol0Dgoo
00<07gooOol07Goo00<07gooOol0GGoo00<07gooOol0?Woo00<207ooOol0
DWoo00<207ooOol06Woo00=l07ooOol02goo00<07gooOol07Goo00<07goo
Ool027oo00=l07ooOol0<goo00<07gooOol00Woo00iW>GooHaQoof<HOomS
67ooHaQoof<HOomS67oo0f<H0D8@0@000G>L000016<HOomS66<H;Woo00<0
7gooOol0Dgoo00<07gooOol07Goo00<07gooOol0GGoo00<07gooOol0?Woo
00<207ooOol0DWoo00<207ooOol06Goo00=l07ooOol037oo00<07gooOol0
7Goo00<07gooOol02Goo00=l07ooOol0<Woo01@07gooOomoofLiOomS67oo
IcUoof<HOomS67ooHaQoofLiOomS67oo0V<H0D8@0@000G>L000016LiOomS
66Li;Woo00<07gooOol0Dgoo00<07gooOol07Goo00<07gooOol0GGoo00<0
7gooOol0?Woo00<207ooOol0DWoo00<207ooOol06Goo00=l07ooOol037oo
00<07gooOol07Goo00<07gooOol02Goo00=l07ooOol0<Woo00<07gooOol0
0Woo00iW>GooHaQoof<HOomS67ooIcUoof<HOomS67oo0f<H0D8@0@000G>L
000016<HOomS66<H;Woo00<07gooOol0Dgoo00<07gooOol07Goo00<07goo
Ool0GGoo00<07gooOol0?Woo00<207ooOol0DWoo00<207ooOol067oo00=l
07ooOol03Goo00<07gooOol07Goo00<07gooOol02Woo00=l07ooOol0<Goo
01P07gooOomoofLiOomS67ooIcUoof<HOomW>GooHaQoof<HOomW>GooHaQW
>D8@0001Li`00004IcUoof<HIcT^Ool00`0OOomoo`1COol00`0OOomoo`0M
Ool00`0OOomoo`1MOol00`0OOomoo`0nOol00`80Oomoo`1BOol00`80Oomo
o`0HOol00g`0Oomoo`0=Ool00`0OOomoo`0MOol00`0OOomoo`0:Ool00g`0
Oomoo`0aOol00`0OOomoo`02Ool03V<HOomW>GooHaQoof<HOomS67ooIcUo
of<HOol3HaP1@Q010001Li`00004HaQoof<HHaP^Ool00`0OOomoo`1COol0
0`0OOomoo`0MOol00`0OOomoo`1MOol00`0OOomoo`0nOol00`80Oomoo`1B
Ool00`80Oomoo`0HOol00g`0Oomoo`0=Ool00`0OOomoo`0MOol00`0OOomo
o`0:Ool00g`0Oomoo`0aOol0500OOomoogooIcUoof<HOomS67ooIcUoof<H
OomS67ooHaQoof<HOol2HaP1@Q010001Li`00004IcUoof<HIcT^Ool00`0O
Oomoo`1COol00`0OOomoo`0MOol00`0OOomoo`1MOol00`0OOomoo`0nOol0
0`80Oomoo`1BOol00`80Oomoo`0GOol00g`0Oomoo`0>Ool00`0OOomoo`0M
Ool00`0OOomoo`0;Ool00g`0Oomoo`0`Ool00`0OOomoo`02Ool03VLiOomS
67ooHaQoof<HOomW>GooHaQoof<HOol3HaP1@Q010001Li`00004HaQoof<H
HaP^Ool00`0OOomoo`1COol00`0OOomoo`0MOol00`0OOomoo`1MOol00`0O
Oomoo`0nOol00`80Oomoo`1BOol00`80Oomoo`0GOol00g`0Oomoo`0>Ool0
0`0OOomoo`0MOol00`0OOomoo`0;Ool00g`0Oomoo`0`Ool0600OOomoogoo
IcUoof<HOomW>GooHaQoof<HOomS67ooIcUoof<HOomS66Li@Q00005cW000
00AW>GooHaQW>Bioo`030P1oogoo05=oo`030P1oogoo01eoo`030P1oogoo
05eoo`030P1oogoo03ioo`030P1oogoo059oo`030P1oogoo01Moo`03O01o
ogoo00ioo`030P1oogoo01eoo`030P1oogoo00]oo`03O01oogoo03Eoo`0>
IcUoof<HOomS67ooIcUoof<HOomS67ooHaQoo`=S60524040005cW00000AS
67ooHaQS62ioo`030P1oogoo05=oo`030P1oogoo01eoo`030P1oogoo05eo
o`030P1oogoo03ioo`030P1oogoo059oo`030P1oogoo01Ioo`03O01oogoo
00moo`030P1oogoo01eoo`030P1oogoo00aoo`03O01oogoo031oo`0C0P1o
ogooIcUoof<HOomW>GooHaQoof<HOomW>GooHaQoofLiOol00V<H0D8@0@00
0G>L000016LiOomS66Li;7oo0P80E7oo0P807Woo0P80GWoo0P80@Goo00<2
07ooOol0DWoo00<207ooOol05Woo00=l07ooOol03Goo0P807Woo0P803goo
00=l07ooOol0<Goo0P8000moofLiOomS67ooHaQoof<HOomS67ooHaQoof<H
Ool00f<H0D8@0@000G>L000016<HOomS66<H:Woo0P80E7oo0P807Woo0P80
GWoo0P80@goo00<207ooOol0DWoo00<207ooOol03Woo100O0goo00@07g`0
01l07`]oo`8201ioo`82015oo`03O01oogoo035oo`82000DHaQoofLiOomS
67ooIcUoof<HOomS67ooIcUoof<HOomS66Li@Q00005cW00000AW>GooHaQW
>Aaoo`0501moogooOol07`02Ool00`0OOomoo`06Ool20P1DOol20P0NOol2
0P1NOol30P10Ool00`80Oomoo`1BOol00`80Oomoo`0BOol0100OOomoog`0
0Woo00@07gooOol07`9oo`0301moogoo00Eoo`<201eoo`<200moo`03O01o
ogoo031oo`0A0P1oogooHaQoof<HOomS67ooHaQoofLiOomS67ooHaQoo`03
HaP1@Q010001Li`00004HaQoof<HHaPLOol0100OOomoogoo0`0O2goo0`80
=goo100O0goo100O4Goo0`807Goo0`80Bgoo100O3goo0`80?Goo00<207oo
Ool0DWoo00<207ooOol04Woo00@07goo01ml00=oo`0301moo`0O00807`]o
o`<200Ioo`@07`=oo`@07`aoo`<200aoo`03O01oogoo031oo`0B0P1oofLi
OomS67ooIcUoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@0@000G>L0000
16LiOomS66Li77oo00L07gooOomoo`0OOol07`0>Ool20P0iOol0100OOomo
o`0O0Woo00@07gooOol07`9oo`0301moogoo00aoo`8200]oo`0501moogoo
Ool07`02Ool00`0OOomoo`09Ool20P1=Ool00`0OOol07`02Ool00`0OOomo
o`0:Ool20P0kOol00`80Oomoo`1BOol00`80Oomoo`0BOol0100OOol07g`0
0goo00D07goo01moo`0O00ioo`8200Aoo`0401moogoo01l3Ool0100OOomo
o`0O3goo0P802Goo00@07g`001l07c1oo`0A0P1oogooIcUoof<HOomS67oo
IcUoof<HOomW>GooHaQoo`03HaP1@Q010001Li`00004HaQoof<HHaPLOol0
1@0OOomoogoo01l00Woo00<07gooOol02Goo0P80>goo00<07goo01l017oo
00<07goo01l00P0O3Goo0P803Goo00@07gooOomoo`<07`Yoo`8204moo`03
01moo`0O00807`Yoo`<203eoo`030P1oogoo059oo`030P1oogoo015oo`04
01moogooO004Ool00`0OOol07`02Ool00`0OOomoo`08Ool30P000goo01mo
o`02Ool00`0OOomoo`02Ool00`0OOol07`04Ool00`0OOomoo`09Ool30P0:
Ool01@0OOomoog`001l00Woo00<07gooOol00Woo00@07gooOol07`Ioo`03
01moogoo009oo`0301moogoo009oo`0301moogoo00Ioo`0301moogoo00=o
o`0301moogoo00=oo`0F0P1oofLiOomS67ooHaQoof<HOomS67ooHaQoof<H
OomW>GooHaQW>D8@0001Li`00004IcUoof<HIcTLOol01@0OOomoogoo01l0
0goo00<07gooOol01Goo0`80?Goo00<07goo01l017oo00D07goo01moo`0O
00Yoo`<200moo`0701moogooOol07goo01l01goo0`80DGoo00D07goo01mo
o`0O00Moo`<2041oo`030P1oogoo059oo`030P1oogoo00ioo`<07`=oo`03
O01oogoo009oo`0301moo`0O00=oo`0301moogoo00Aoo`<200Aoo`0501mo
ogooOol07`04Ool00`0OOol07`04Ool00`0OOomoo`06Ool30P0<Ool01P0O
OomoogooO0007`9oo`0401moogooOol201l2Ool00`0OOomoo`04Ool0100O
Oomoogoo0P0O17oo00<07gooOol00Woo1@0O1Goo00<07gooOol01Woo00iS
67ooIcUoofLiOomS67ooHaQoofLiOomS67oo0f<H0D8@0@000G>L000016<H
OomS66<H6Woo0`0O0goo00<07gooOol01goo0P80?goo00@07gooOol07`Ao
o`0301moo`0O009oo`0301moogoo00Eoo`82019oo`0501moogooOol07`02
Ool00`0OOomoo`02Ool20P1COol0100OOomoo`0O0Woo00<07gooOol00Woo
0P80@goo00<207ooOol0DWoo00<207ooOol03Woo00<07gooOol00goo00=l
000OOol00Woo00<07goo01l027oo0P801goo00D07gooOomoo`0O00Aoo`03
01moo`0O00Aoo`0301moogoo00Aoo`8200moo`0901moogooOoml07oo01mo
o`0O009oo`0301moo`0O009oo`@07`=oo`0601moogoo01moo`0O1Goo00<0
7gooOol00Woo00@07gooOol07`Eoo`0301moogoo00Eoo`0@IcUoof<HOomS
67ooHaQoofLiOomS67ooHaQoof<HOol2HaP1@Q010001Li`00004IcUoof<H
IcTLOol01@0OOomoogoo01l02goo0P80>Woo0`0O0goo00<07gooOol00Woo
00<07goo01l00goo00<07gooOol01Woo0P8047oo00D07gooOomoo`0O00=o
o`0301moogoo00=oo`8204ioo`<07`=oo`0501moogooOol07`05Ool30P10
Ool00`80Oomoo`1BOol00`80Oomoo`0>Ool401l00gooO01oo`0401l2Ool0
0`0OOomoo`08Ool30P04Ool01@0OOomoogoo01l017oo00<07goo01l017oo
00<07gooOol01Woo0`8037oo00<07gooOol00Woo00Al000OOol07`9oo`03
01moo`0O009oo`0401moogooOol201l01goo01moogoo01moo`0O00Eoo`03
01moogoo009oo`0401moogoo01l5Ool00`0OOomoo`06Ool03V<HOomS67oo
HaQoof<HOomS67ooHaQoof<HOol3HaP1@Q010001Li`00004HaQoof<HHaP^
Ool30P0gOol00`0OOomoo`04Ool01`0OOomoogoo01moo`0O00ioo`<200]o
o`<07`=oo`0301moogoo00Uoo`<204]oo`0301moogoo00=oo`0301moogoo
00Yoo`<203eoo`030P1oogoo059oo`030P1oogoo01=oo`03O01oogoo01=o
o`<200807`Aoo`0501moogooOol07`02Ool01@0OOomoogoo01l02goo0`80
2Goo00<07gooOol00Woo00Il000OOol07goo01l2Ool0100OOomoo`0O17oo
00D07goo01moo`0O009oo`0301moogoo00Aoo`0301moogoo009oo`0301mo
o`0O00Eoo`0301moogoo00Eoo`0DIcUoofLiOomS67ooIcUoof<HOomW>Goo
HaQoofLiOomS66Li@Q00005cW00000AW>GooHaQW>C5oo`8203Eoo`@07`=o
o`@07`9oo`0301moogoo00moo`8200]oo`0501moogooOol07`0>Ool20P19
Ool401l2Ool00`0OOomoo`0=Ool20P0kOol00`80Oomoo`1BOol00`80Oomo
o`0COol00g`0Oomoo`0FOol20P04Ool401l3Ool401l?Ool20P08Ool01@0O
OomoogooO0000Woo0P0O0goo00@07gooOol07`Aoo`0401moo`0O01l3Ool0
0`0OOomoo`04Ool00`0OOomoo`03Ool201l3Ool301l8Ool03V<HOomW>Goo
HaQoof<HOomS67ooHaQoof<HOol3HaP1@Q010001Li`00004HaQoof<HHaP`
Ool20P1DOol20P0NOol20P1NOol20P0mOol00`80Oomoo`1BOol00`80Oomo
o`0COol00g`0Oomoo`0DOol20P0NOol20P0;Ool301l00g`0Oomoo`0201l3
Ool00`0OOomoo`0601l00goo01l07`03Ool00`0OOomoo`0601l4Ool201l5
Ool00`0OOomoo`05Ool046LiOomS67ooHaQoofLiOomS67ooHaQoofLiOomS
67oo0V<H0D8@0@000G>L000016LiOomS66Li;Woo0P80E7oo0P807Woo0P80
GWoo0P80?goo00<207ooOol0DWoo00<207ooOol04Woo00=l07ooOol027oo
0`0O27oo0P807Woo0P804Goo00=l07ooOol0<7oo00iW>GooHaQoof<HOomS
67ooIcUoof<HOomS67oo0f<H0D8@0@000G>L000016<HOomS66<H6Goo00D0
7gooOomoo`0O00Eoo`0301moogoo00Ioo`8205Aoo`8201ioo`8205ioo`82
045oo`030P1oogoo059oo`030P1oogoo019oo`04O01oogoo01l3Ool00`0O
Oomoo`04Ool00`0OOomoo`03Ool20P0NOol20P0COol00g`0Oomoo`0_Ool0
56LiOomS67ooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQW>D8@0001Li`0
0004IcUoof<HIcTIOol01@0OOomoogoo01l01Goo00<07gooOol017oo0P80
BWoo100O1Woo0P805Woo1@0O0goo0P80GWoo0P80@goo00<207ooOol0DWoo
00<207ooOol04Woo00Al07ooOol07`=oo`0301moogoo00Aoo`0401moogoo
Ool20P0EOol401l5Ool20P0EOol00g`0Oomoo`0`Ool03VLiOomS67ooHaQo
ofLiOomS67ooIcUoof<HOol3HaP1@Q010001Li`00004HaQoof<HHaPIOol0
100OOomoo`0O1Woo00<07gooOol01Woo0P80@7oo00D07gooOomoo`0O00Mo
o`0301moogoo00Eoo`8200eoo`0501moogooOol07`03Ool00`0OOomoo`06
Ool20P1=Ool01@0OOomoogoo01l01Woo00<07gooOol00goo0`80@7oo00<2
07ooOol0DWoo00<207ooOol04Woo00Al07ooOol07`9oo`0301moogoo009o
o`D07`Aoo`<200Yoo`0501moogooOol07`02Ool00`0OOomoo`02Ool00`0O
Oomoo`04Ool30P0BOol00g`0Oomoo`0_Ool046LiOomS67ooIcUoof<HOomS
67ooHaQoof<HOomS67oo0V<H0D8@0@000G>L000016LiOomS66Li6Goo1P0O
17oo00<07gooOol027oo0`80?Goo00D07gooOomoo`0O00Moo`0301moogoo
00Moo`<200Yoo`0501moogooOol07`04Ool00`0OOomoo`07Ool30P1:Ool0
1@0OOomoogoo01l00Woo1@0O27oo0`80?Goo00<207ooOol0DWoo00<207oo
Ool04Goo00Al07ooOomoo`H07`03Ool07goo009oo`807`Moo`<200Moo`05
01moogooOol07`02Ool00`0OOomoo`02Ool00`0OOomoo`07Ool30P0@Ool0
0g`0Oomoo`0]Ool04080OomW>GooHaQoof<HOomS67ooIcUoof<HOomW>Goo
0f<H0D8@0@000G>L000016<HOomS66<H6Goo00<07gooOol00Woo00<07goo
Ool00Woo00<07gooOol02goo0P80>goo00@07gooOol07`Qoo`0301moogoo
00Yoo`8200Qoo`0401moogoo01l6Ool00`0OOomoo`09Ool20P18Ool0100O
Oomoo`0O17oo00@07gooOol07`]oo`8203]oo`030P1oogoo059oo`030P1o
ogoo015oo`05O01oogooOol07`04Ool00`0OOol07`04Ool00`0OOomoo`08
Ool20P05Ool0100OOomoo`0O0goo00<07gooOol00Woo00<07gooOol02Woo
0P803Woo00=l07ooOol0;7oo01H207ooIcUoof<HOomW>GooHaQoof<HOomS
67ooHaQoof<HOomS66Li@Q00005cW00000AW>GooHaQW>AUoo`0301moogoo
009oo`0301moogoo00<07`aoo`8203aoo`H07`Aoo`807`aoo`8200Uoo`H0
7`Eoo`0301moogoo00Moo`8204Uoo`H07`9oo`0401moogoo01l9Ool20P0m
Ool00`80Oomoo`1BOol00`80Oomoo`0AOol01G`0Oomoogoo01l017oo00<0
7goo01l00goo00<07gooOol01goo0P801goo1P0O0Woo100O2goo0P8047oo
00=l07ooOol0:goo018207ooOomoofLiOomS67ooHaQoofLiOomS67ooIcUo
of<HOol3HaP1@Q010001Li`00004HaQoof<HHaPIOol601l4Ool00`0OOomo
o`09Ool00`80Oomoo`0lOol00`0OOomoo`02Ool00`0OOomoo`02Ool00`0O
Oomoo`0:Ool00`80Oomoo`09Ool00`0OOomoo`02Ool00`0OOomoo`04Ool0
0`0OOomoo`05Ool00`80Oomoo`19Ool00`0OOomoo`02Ool01`0OOomoogoo
01moo`0O00Qoo`030P1oogoo03eoo`030P1oogoo059oo`030P1oogoo015o
o`04O01oogooOol601l2Ool301l9Ool00`80Oomoo`07Ool00`0OOomoo`02
Ool0100OOomoo`0O0Woo00<07gooOol027oo00<207ooOol047oo00=l07oo
Ool0:Woo01@207ooOomoofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67oo0V<H0D8@0@000G>L000016LiOomS66Li;Woo00<07gooOol0?Goo00<0
7gooOol00Woo00<07gooOol00goo00<07gooOol027oo00<07gooOol02Woo
00<07gooOol00Woo00@07gooOol07`=oo`0301moogoo00Aoo`0301moogoo
04Yoo`0301moogoo009oo`0301moogoo009oo`807`Moo`0301moogoo03io
o`030P1oogoo059oo`0301moogoo011oo`03O01oogoo01Eoo`0301moogoo
00Qoo`0301moogoo009oo`0301moo`0O00Aoo`0301moogoo00Ioo`0301mo
ogoo019oo`03O01oogoo02Uoo`0301moogoo009oo`0>HaQoofLiOomW>Goo
HaQoofLiOomS67ooIcUoo`=S60524040005cW00000AS67ooHaQS62ioo`03
01moogoo03eoo`H07`9oo`@07`Yoo`0301moogoo00Yoo`H07`9oo`@07`Mo
o`0301moogoo04Yoo`H07`Aoo`807`Moo`0301moogoo03ioo`030P1oogoo
059oo`0301moogoo011oo`03O01oogoo01Eoo`0301moogoo00Qoo`H07`9o
o`@07`Uoo`0301moogoo019oo`03O01oogoo02Uoo`0H01moogooOomW>Goo
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HIcU240000G>L000016Li
OomS66Li;Woo00<07gooOol0Dgoo00<07gooOol07Goo00<07gooOol0GGoo
00<07gooOol0?Woo00<207ooOol0DWoo00<07gooOol047oo00=l07ooOol0
5Goo00<07gooOol07Goo00<07gooOol04Woo00=l07ooOol0:Goo00<07goo
Ool00Woo00iS67ooHaQoof<HOomW>GooHaQoofLiOomS67oo0f<H0D8@0@00
0G>L000016<HOomS66<H;Woo00<07gooOol0Dgoo00<07gooOol07Goo00<0
7gooOol0GGoo00<07gooOol0?Woo00<207ooOol0DWoo00<07gooOol047oo
00=l07ooOol05Goo00<07gooOol07Goo00<07gooOol04Woo00=l07ooOol0
:Goo01@07gooOomoofLiOomW>GooHaQoof<HOomS67ooHaQoof<HOomS67oo
0V<H0D8@0@000G>L000016LiOomS66Li;Woo00<07gooOol0Dgoo00<07goo
Ool07Goo00<07gooOol0GGoo00<07gooOol0?Woo00<207ooOol0DWoo00<0
7gooOol047oo00=l07ooOol05Goo00<07gooOol07Goo00<07gooOol04Woo
00=l07ooOol0:Goo00<07gooOol00Woo00iS67ooHaQoofLiOomS67ooIcUo
of<HOomW>Goo0f<H0D8@0@000G>L000016<HOomS66<H;Woo00<07gooOol0
Dgoo00<07gooOol07Goo00<07gooOol0GGoo00<07gooOol0?Woo00<207oo
Ool0DWoo00<07gooOol03goo00=l07ooOol05Woo00<07gooOol07Goo00<0
7gooOol04goo00=l07ooOol0:7oo01P07gooOomoofLiOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQW>D8@0001Li`00004IcUoof<HIcT^Ool0
0`0OOomoo`1COol00`0OOomoo`0MOol00`0OOomoo`1MOol00`0OOomoo`0n
Ool00`80Oomoo`1BOol00`0OOomoo`0?Ool00g`0Oomoo`0FOol00`0OOomo
o`0MOol00`0OOomoo`0COol00g`0Oomoo`0XOol00`0OOomoo`02Ool03V<H
OomW>GooHaQoofLiOomS67ooIcUoof<HOol3HaP1@Q010001Li`00004HaQo
of<HHaP^Ool00`0OOomoo`1COol00`0OOomoo`0MOol00`0OOomoo`1MOol0
0`0OOomoo`0nOol00`80Oomoo`1BOol00`0OOomoo`0?Ool00g`0Oomoo`0F
Ool00`0OOomoo`0MOol00`0OOomoo`0COol00g`0Oomoo`0XOol0500OOomo
ogooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOol2HaP1@Q010001
Li`00004IcUoof<HIcT^Ool00`0OOomoo`1COol00`0OOomoo`0MOol00`0O
Oomoo`1MOol00`0OOomoo`0nOol00`80Oomoo`1BOol00`0OOomoo`0?Ool0
0g`0Oomoo`0FOol00`0OOomoo`0MOol00`0OOomoo`0COol00g`0Oomoo`0X
Ool00`0OOomoo`02Ool03VLiOomS67ooIcUoof<HOomW>GooHaQoofLiOol3
HaP1@Q01000100000004HaQoof<HHaP^Ool00`0OOomoo`1COol00`0OOomo
o`0MOol00`0OOomoo`1MOol00`0OOomoo`0nOol00`80Oomoo`1BOol00`0O
Oomoo`0?Ool00g`0Oomoo`0FOol00`0OOomoo`0MOol00`0OOomoo`0COol0
0g`0Oomoo`0XOol0600OOomoogooIcUoof<HOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS66Li@Q00005cW00000AW>GooHaQW>Bioo`030P1oogoo05=o
o`030P1oogoo01eoo`030P1oogoo05eoo`030P1oogoo03ioo`030P1oogoo
06Aoo`03O01oogoo01Ioo`030P1oogoo01eoo`030P1oogoo01=oo`03O01o
ogoo02Qoo`030P1oogoo009oo`0>HaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoo`=S60524040005cW00000AS67ooHaQS62ioo`030P1oogoo05=oo`03
0P1oogoo01eoo`030P1oogoo05eoo`030P1oogoo03ioo`030P1oogoo05=o
o`030P1oogoo00Moo`030P1oogoo00Aoo`03O01oogoo01Ioo`030P1oogoo
01eoo`030P1oogoo01=oo`03O01oogoo02Qoo`0D0P1oogooOomW>GooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQoo`9S60524040005cW00000AW>Goo
HaQW>Bioo`030P1oogoo05=oo`030P1oogoo01eoo`030P1oogoo05eoo`03
0P1oogoo03ioo`030P1oogoo05Aoo`H200=oo`030P1oogoo00=oo`03O01o
ogoo01Moo`030P1oogoo01eoo`030P1oogoo01Aoo`03O01oogoo02Moo`03
0P1oogoo009oo`0>IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoo`=S6052
4040005cW00000AS67ooHaQS62ioo`030P1oogoo05=oo`030P1oogoo01eo
o`030P1oogoo05eoo`030P1oogoo03ioo`030P1oogoo05Eoo`030P1oogoo
00Eoo`030P1oogoo00=oo`03O01oogoo01Moo`030P1oogoo01eoo`030P1o
ogoo01Aoo`03O01oogoo02Moo`0H0P1oogooOomW>GooHaQoofLiOomS67oo
HaQoof<HOomS67ooHaQoof<HIcU240000G>L000016LiOomS66Li;Woo00<2
07ooOol0Dgoo00<207ooOol07Goo00<207ooOol0GGoo00<207ooOol0?Woo
00<207ooOol0EGoo0P801Woo00<207ooOol00goo00=l07ooOol05goo00<2
07ooOol07Goo00<207ooOol057oo00=l07ooOol09goo00<207ooOol00Woo
00iW>GooHaQoof<HOomW>GooHaQoofLiOomS67oo0f<H0D8@0@000G>L0000
16<HOomS66<H;Woo00<207ooOol0Dgoo00<207ooOol07Goo00<207ooOol0
GGoo00<207ooOol0?Woo00<207ooOol0EGoo00@207oo0P0200Aoo`030P1o
ogoo00=oo`03O01oogoo01Moo`030P1oogoo01eoo`030P1oogoo01Aoo`03
O01oogoo02Moo`0D0P1oogooOomW>GooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQoo`9S60524040005cW00000AW>GooHaQW>Bioo`030P1oogoo05=o
o`030P1oogoo01eoo`030P1oogoo05eoo`030P1oogoo03ioo`030P1oogoo
05Eoo`050P1oogooOol20003Ool00`80Oomoo`03Ool00g`0Oomoo`0GOol0
0`80Oomoo`0MOol00`80Oomoo`0DOol00g`0Oomoo`0WOol00`80Oomoo`02
Ool03V<HOomW>GooIcUoof<HOomW>GooHaQoofLiOol3HaP1@Q010001Li`0
0004HaQoof<HHaP^Ool00`80Oomoo`1COol00`80Oomoo`0MOol00`80Oomo
o`1>Ool00`0OOomoo`05Ool00`0OOomoo`04Ool00`80Oomoo`0nOol00`80
Oomoo`1EOol00`80Oomoo`02Ool01080Oomoo`801Goo00=l07ooOol05goo
00<207ooOol07Goo00<207ooOol057oo00=l07ooOol09goo01P207ooOomo
ofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQW>D8@0001Li`0
0004IcUoof<HIcT^Ool00`80Oomoo`1COol00`80Oomoo`0MOol00`80Oomo
o`1>Ool0100OOomoogoo1@0O1Woo00<207ooOol0?Woo00<207ooOol087oo
100O=goo00<207oo0P001Goo00=l07ooOol05goo00<207ooOol07Goo00<2
07ooOol057oo00=l07ooOol09goo00<207ooOol00Woo00iS67ooHaQoof<H
OomW>GooHaQoofLiOomS67oo0f<H0D8@0@000G>L000016<HOomS66<H;Woo
00<207ooOol0Dgoo00<207ooOol07Goo00<207ooOol0CWoo00<07gooOol0
0Woo00@07gooOol07`Ioo`030P1oogoo03ioo`030P1oogoo01moo`0301mo
ogoo00807`9oo`0301moogoo009oo`0401moogoo01l6Ool00`0OOomoo`02
Ool00`0OOomoo`02Ool00`0OOomoo`06Ool00`0OOomoo`03Ool00`0OOomo
o`0;Ool20P05Ool00g`0Oomoo`0GOol00`80Oomoo`0MOol00`80Oomoo`0D
Ool00g`0Oomoo`0VOol201l3Ool046LiOomW>GooHaQoof<HOomS67ooHaQo
of<HOomS67oo0V<H0D8@0@000G>L000016LiOomS66Li;Woo00<207ooOol0
Dgoo00<207ooOol07Goo00<207ooOol01goo1@0O@Woo00<07gooOol00Woo
00@07gooOol07`Ioo`030P1oogoo03ioo`030P1oogoo01ioo`0301moogoo
009oo`0401moogoo01l3Ool201l2Ool00`0OOomoo`04Ool0100OOomoogoo
0P0O17oo00<07gooOol00Woo1@0O1Goo00<07gooOol037oo00<2000O01l0
0P0O00=l000O01l00`0OC@8000=l00800P009080100O0P8000moof<HOomS
67ooIcUoof<HOomW>GooHaQoofLiOol00f<H0D8@0@000G>L000016<HOomS
66<H;Woo00<207ooOol00goo00<07gooOol017oo00<07gooOol0AWoo00<2
07ooOol07Goo00<207ooOol00goo00<07gooOol00Woo00<07gooOol0@goo
00<07gooOol00goo00<07goo01l01Woo00<207ooOol0?Woo00<207ooOol0
7Woo00<07gooOol00goo00<07goo01l00Woo00<07goo01l00Woo100O0goo
00H07gooOol07goo01l5Ool00`0OOomoo`02Ool0100OOomoo`0O1Goo00<0
7gooOol02goo0P8017oo00=l07ooOol067oo00<207ooOol07Goo00<207oo
Ool05Goo00=l07ooOol097oo100O0Woo01AW>GooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoof<HIcU240000G>L000016LiOomS66Li;Woo00<207oo
Ool00goo00<07gooOol017oo00<07gooOol0AWoo00<207ooOol07Goo00<2
07ooOol00goo00<07gooOol00goo00<07gooOol0@7oo0`0O1Woo0P0O1Woo
00<207ooOol0?Woo00<207ooOol07Woo00<07gooOol00goo00<07goo01l0
0Woo00<07goo01l00Woo00@07gooOomoo`807`07Ool07gooOol07goo01l0
1Goo00<07gooOol00Woo00@07gooOol07`Eoo`0301moogoo00Yoo`030P1o
o`8000Aoo`03O01oogoo01Qoo`030P1oogoo01eoo`030P1oogoo01Eoo`03
O01oogoo02Eoo`807`Aoo`0>HaQoofLiOomS67ooIcUoof<HOomW>GooHaQo
o`=S60524040005cW00000AS67ooHaQS62ioo`030P1oogoo00=oo`0301mo
ogoo00Aoo`0301moogoo04Ioo`030P1oogoo01eoo`030P1oogoo00=oo`03
01moogoo00Aoo`0301moogoo045oo`0301moogoo00Aoo`807`Ioo`030P1o
ogoo03ioo`030P1oogoo01ioo`0301moogoo00=oo`0501moo`0OOol07`02
Ool0100OOomoo`0O17oo00D07goo01moo`0O009oo`0301moogoo00Aoo`03
01moogoo009oo`0301moo`0O00Eoo`0301moogoo00Uoo`040P1oogoo0P04
Ool00g`0Oomoo`0HOol00`80Oomoo`0MOol00`80Oomoo`0EOol00g`0Oomo
o`0ZOol046LiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@
0@000G>L000016LiOomS66Li;Woo00<207ooOol00goo00<07gooOol017oo
00<07gooOol0AWoo00<207ooOol07Goo00<207ooOol00goo00<07gooOol0
1Goo00<07gooOol0Cgoo00<207ooOol0?Woo00<207ooOol07goo00D07goo
Oomoo`0O009oo`807`=oo`0401moogoo01l4Ool0100OOol07`0O0goo00<0
7gooOol017oo00<07gooOol00goo0P0O0goo0`0O2Woo00D207ooOomoo`80
00Aoo`03O0007`0O00807`9oo`D07`=oo`@07`Qoo`030P1oogoo01eoo`03
0P1oogoo01Eoo`03O01oogoo02]oo`0>HaQoof<HOomW>GooHaQoofLiOomS
67ooIcUoo`=S60524040005cW00000AS67ooHaQS62ioo`030P1oogoo00=o
o`0301moogoo00Aoo`0301moogoo04Ioo`030P1oogoo01eoo`030P1oogoo
00=oo`0301moogoo00Ioo`0301moogoo04ioo`030P1oogoo03ioo`030P1o
ogoo021oo`<07`=oo`807`=oo`0301moogoo00H07`03Ool07`0O00=oo`03
01moogoo00H07`Aoo`807`Eoo`0301moogoo00Moo`030P1oogoo009oo`03
0P1oogoo009oo`03O01oogoo00807`=oo`0301moogoo00Qoo`0301moogoo
00Eoo`030P1oogoo01eoo`030P1oogoo01Eoo`03O01oogoo02Yoo`0DIcUo
ofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS66Li@Q00005cW00000AW
>GooHaQW>Bioo`040P1oogooOol301l4Ool301m8Ool00`80Oomoo`0MOol0
1080Oomoogoo0`0O17oo00D07gooOomoo`0O051oo`030P1oogoo03ioo`03
0P1oogoo05Moo`030P1oogoo00=oo`060P1oogooOol07g`00goo00<07goo
Ool00Woo00<07gooOol01goo00<07gooOol01Goo00<207ooOol07Goo00<2
07ooOol05Goo00=l07ooOol0:goo00iS67ooHaQoof<HOomW>GooHaQoofLi
OomS67oo0f<H0D8@0@000G>L000016<HOomS66<H;Woo00<207ooOol00goo
00<07gooOol017oo00<07gooOol0AWoo00<207ooOol07Goo00<207ooOol0
0goo00<07gooOol00Woo100ODGoo00<207ooOol0?Woo00<207ooOol0EWoo
00<207ooOol017oo00H207ooOomoo`0OO004Ool00`0OOomoo`02Ool00`0O
Oomoo`06Ool00`0OOomoo`05Ool00`80Oomoo`0MOol00`80Oomoo`0EOol0
0g`0Oomoo`0NOol501l7Ool046LiOomS67ooIcUoof<HOomS67ooHaQoof<H
OomS67oo0V<H0D8@0@000G>L000016LiOomS66Li;Woo00<207ooOol0Dgoo
00<207ooOol07Goo00<207ooOol0GGoo00<207ooOol0?Woo00<207ooOol0
EGoo00<207ooOol01Goo00H207ooOomoo`0OO004Ool00`0OOomoo`03Ool0
0`0OOomoo`03Ool201l8Ool00`80Oomoo`0MOol00`80Oomoo`0EOol00g`0
Oomoo`0OOol00`0OOomoo`06Ool04@0OOomoof<HOomS67ooHaQoof<HOomW
>GooHaQoofLiOol00f<H0D8@0@000G>L000016<HOomS66<H;Woo00<207oo
Ool0Dgoo00<207ooOol07Goo00<207ooOol0GGoo00<207ooOol0?Woo00<2
07ooOol0E7oo00<207ooOol01Woo00H207ooOomoo`0OO004Ool00`0OOomo
o`04Ool00`0OOomoo`02Ool00`0OOomoo`07Ool00`80Oomoo`0MOol01080
Oomoogoo1@0O0goo100O27oo00=l07ooOol087oo00<07gooOol01Goo01H0
7gooIcUoof<HOomS67ooIcUoof<HOomS67ooHaQoof<HOomS66Li@Q00005c
W00000AW>GooHaQW>Bioo`030P1oogoo05=oo`030P1oogoo01eoo`030P1o
ogoo05eoo`030P1oogoo03ioo`030P1oogoo05=oo`030P1oogoo00Moo`03
0P1oogoo009oo`05O01oogooOol07`03Ool01@0OOomoogoo01l01Goo00<0
7gooOol01Woo00<207ooOol07Goo00<207ooOol00Woo00<07gooOol017oo
00@07gooOol07`Qoo`03O01oogoo025oo`0301moogoo00Aoo`0A01moogoo
HaQoofLiOomS67ooHaQoof<HOomW>GooHaQoo`03HaP1@Q010001Li`00004
HaQoof<HHaP^Ool00`0OOomoo`1COol00`80Oomoo`0MOol00`0OOomoo`1M
Ool00`0OOomoo`0nOol00`80Oomoo`1BOol00`80Oomoo`08Ool00`80Oomo
o`02Ool017`001l07`0O17oo100O0goo100O27oo00<207ooOol07Goo00<0
7gooOol00goo00<07gooOol00Woo00<07gooOol00Woo00<07gooOol01Goo
00=l07ooOol08Woo00<07gooOol00goo01807gooIcUoof<HOomS67ooHaQo
ofLiOomS67ooHaQoof<HOol2HaP1@Q010001Li`00004IcUoof<HIcT^Ool0
0`0OOomoo`1COol00`80Oomoo`0MOol00`0OOomoo`1MOol00`0OOomoo`0n
Ool00`0OOomoo`1BOol00`0OOomoo`0=Ool00g`0Oomoo`0HOol00`80Oomo
o`0MOol00`0OOomoo`04Ool01@0OOomoogoo01l017oo00<07gooOol01Goo
00=l07ooOol08goo00<07gooOol00Woo01407gooOomS67ooHaQoofLiOomS
67ooHaQoof<HOomW>Goo00=S60524040005cW00000AS67ooHaQS62ioo`03
01moogoo05=oo`030P1oogoo01eoo`0301moogoo05eoo`0301moogoo03io
o`0301moogoo059oo`0301moogoo00aoo`03O01oogoo01Uoo`030P1oogoo
01eoo`0301moogoo00Eoo`0401moogoo01l4Ool00`0OOomoo`06Ool00g`0
Oomoo`0NOol01@0OOomoogoo01l00Woo0`0O01EoofLiOomS67ooHaQoof<H
OomS67ooIcUoof<HOomS67ooHaQW>D8@00000G>L000016LiOomS66Li;Woo
00<07gooOol0Dgoo00<207ooOol07Goo00<07gooOol0GGoo00<07gooOol0
?Woo00<07gooOol0DWoo00<07gooOol037oo00=l07ooOol06Goo00<207oo
Ool07Goo00<07gooOol01Woo00<07goo01l017oo00<07gooOol01Woo00=l
07ooOol07Woo100O1Goo01407gooOomS67ooIcUoof<HOomW>GooHaQoof<H
OomS67oo00=S60524040005cW00000AS67ooHaQS62ioo`0301moogoo05=o
o`030P1oogoo01eoo`0301moogoo05eoo`0301moogoo03ioo`0301moogoo
059oo`0301moogoo00aoo`03O01oogoo01Uoo`030P1oogoo01eoo`0301mo
ogoo009oo`0501moogooOol07`02Ool01@0OOomoogoo01l027oo00=l07oo
Ool0:Goo011W>GooHaQoof<HOomS67ooHaQoof<HOomW>GooHaQoo`9S6052
4040005cW00000AW>GooHaQW>Bioo`0301moogoo05=oo`030P1oogoo01eo
o`0301moogoo05eoo`0301moogoo03ioo`0301moogoo059oo`0301moogoo
00aoo`03O01oogoo01Uoo`030P1oogoo01eoo`0301moogoo009oo`@07`=o
o`@07`Uoo`03O01oogoo02Yoo`0>HaQoof<HOomW>GooHaQoofLiOomS67oo
HaQoo`=S60524040005cW00000AS67ooHaQS62ioo`0301moogoo05=oo`03
0P1oogoo01eoo`0301moogoo05eoo`0301moogoo03ioo`0301moogoo059o
o`0301moogoo00aoo`03O01oogoo01Uoo`030P1oogoo01eoo`0301moogoo
01Ioo`03O01oogoo02Uoo`0DIcUoofLiOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS66Li@Q00005cW00000AW>GooHaQW>Bioo`0301moogoo05=oo`03
0P1oogoo01eoo`0301moogoo05eoo`0301moogoo03ioo`0301moogoo059o
o`0301moogoo00aoo`03O01oogoo01Uoo`030P1oogoo01eoo`0301moogoo
01Ioo`03O01oogoo02Yoo`0>HaQoof<HOomS67ooIcUoof<HOomS67ooIcUo
o`=S60524040005cW00000AS67ooHaQS62ioo`0301moogoo05=oo`030P1o
ogoo01eoo`0301moogoo05eoo`0301moogoo03ioo`0301moogoo059oo`03
01moogoo00aoo`03O01oogoo01Uoo`030P1oogoo01eoo`0301moogoo01Io
o`03O01oogoo02Uoo`0@IcUoof<HOomW>GooHaQoof<HOomW>GooHaQoof<H
Ool2HaP1@Q010001Li`00004IcUoof<HIcT^Ool00`0OOomoo`0OOol401l`
Ool00`80Oomoo`0MOol00`0OOomoo`1MOol00`0OOomoo`0nOol00`0OOomo
o`1BOol00`0OOomoo`0<Ool00g`0Oomoo`0IOol00`80Oomoo`0MOol00`0O
Oomoo`0FOol00g`0Oomoo`0ZOol03V<HOomS67ooHaQoof<HOomS67ooHaQo
of<HOol3HaP1@Q01000100000004HaQoof<HHaP^Ool00`0OOomoo`0JOol0
0`0OOomoo`02Ool0100OOomoo`0O<7oo00<207ooOol07Goo00<07gooOol0
GGoo00<07gooOol0?Woo00<07gooOol0DWoo00<07gooOol037oo00=l07oo
Ool06Goo00<207ooOol07Goo00<07gooOol05Woo00=l07ooOol0:Goo011W
>GooIcUoof<HOomW>GooHaQoof<HOomW>GooHaQoo`9S60524040005cW000
00AW>GooHaQW>D]oo`0501moogooOol07`04Ool00`0OOomoo`0]Ool00`80
Oomoo`3oOolDOol00`80Oomoo`0<Ool00g`0Oomoo`0IOol00`80Oomoo`0f
Ool00g`0Oomoo`0ZOol03V<HOomS67ooHaQoof<HOomW>GooHaQoof<HOol3
HaP1@Q010001Li`00004HaQoof<HHaP_Ool00`80Oomoo`07Ool00`80Oomo
o`0?Ool01@0OOomoogoo01l017oo00<07gooOol0;Goo00<207ooOol04Woo
00<207ooOol01goo00<207ooOol0Ggoo00<207ooOol01goo00<207ooOol0
:7oo00<207ooOol01goo00<207ooOol0Dgoo00<207ooOol037oo00=l07oo
Ool06Goo00<207ooOol04goo00<207ooOol01Woo00<207ooOol05goo00=l
07ooOol0:Goo01AW>GooHaQoofLiOomS67ooHaQoof<HOomS67ooIcUoof<H
IcU240000G>L000016LiOomS66Li<7oo1P800goo00<207ooOol03goo00D0
7gooOomoo`0O00Aoo`0301moogoo02eoo`030P1oogoo019oo`040P1oogoo
Ool60P1SOol60P03Ool00`80Oomoo`0XOol01080Oomoogoo1P80EWoo00<2
07ooOol037oo00=l07ooOol06Goo00<207ooOol04goo00@207ooOomoo`D2
01Yoo`03O01oogoo02Yoo`0>HaQoof<HOomS67ooIcUoof<HOomW>GooHaQo
o`=S60524040005cW00000AS67ooHaQS631oo`8200Moo`030P1oogoo00mo
o`0501moogooOol07`04Ool00`0OOomoo`0]Ool00`80Oomoo`0BOol00`80
Oomoo`05Ool20P1TOol00`80Oomoo`05Ool00`80Oomoo`0XOol00`80Oomo
o`05Ool20P1FOol00`80Oomoo`0<Ool00g`0Oomoo`0IOol00`80Oomoo`0C
Ool00`80Oomoo`04Ool20P0JOol00g`0Oomoo`0YOol046LiOomW>GooHaQo
of<HOomS67ooHaQoof<HOomS67oo0V<H0D8@0@000@00000016LiOomS66Li
<7oo00<207oo0P001Woo00<207ooOol03Goo0`0O17oo00D07gooOomoo`0O
02moo`030P1oogoo019oo`030P1oogoo00Aoo`030P1oo`8002moo`@07c5o
o`8200Ioo`030P1oogoo02Qoo`030P1oogoo00Aoo`030P1oo`8005Ioo`03
0P1oogoo00aoo`03O01oogoo01Uoo`030P1oogoo01=oo`030P1oogoo00=o
o`030P1oo`8001Yoo`03O01oogoo02Yoo`0>HaQoof<HOomW>GooHaQoofLi
OomS67ooHaQoo`=S60524040005cW00000AS67ooHaQS631oo`040P1oogoo
0P05Ool00`80Oomoo`0?Ool00`0OOomoo`02Ool401l`Ool00`80Oomoo`0B
Ool00`80Oomoo`03Ool01080Oomoo`80;Woo00<07gooOol00P0O0Woo00<0
7gooOol00Woo00@07gooOol07`Ioo`0301moogoo009oo`0301moogoo009o
o`0301moogoo00Ioo`0301moogoo00=oo`0301moogoo00Aoo`030P1oo`80
00Eoo`030P1oogoo02Qoo`030P1oogoo00=oo`040P1oogoo0P1FOol00`80
Oomoo`0<Ool00g`0Oomoo`0IOol00`80Oomoo`0COol00`80Oomoo`02Ool0
1080Oomoo`806Woo00=l07ooOol0:Goo01AW>GooHaQoof<HOomS67ooHaQo
of<HOomW>GooHaQoof<HIcU240000G>L000016LiOomS66Li<7oo00D207oo
Oomoo`8000Aoo`030P1oogoo04Qoo`030P1oogoo019oo`030P1oogoo009o
o`050P1oogooOol2000]Ool00`0OOomoo`02Ool0100OOomoo`0O0goo0P0O
0Woo00<07gooOol017oo00@07gooOomoo`807`Aoo`0301moogoo009oo`D0
7`Eoo`0301moogoo00Aoo`040P1oogoo0P04Ool00`80Oomoo`0XOol00`80
Oomoo`02Ool01@80Oomoogoo0P00EWoo00<207ooOol037oo00=l07ooOol0
6Goo00<207ooOol04goo00<207ooOol00Woo00@207ooOol201Yoo`03O01o
ogoo02Yoo`0>HaQoofLiOomS67ooIcUoof<HOomS67ooHaQoo`=S60524040
005cW00000ES67ooHaQS600O00Aoo`0401moogoo01l6Ool00`0OOomoo`02
Ool00`0OOomoo`02Ool00`0OOomoo`06Ool00`0OOomoo`03Ool00`0OOomo
o`05Ool00`80Oomoo`02Ool01@80Oomoogoo0P00BWoo00<207ooOol04Woo
00D207ooOomoo`8000Aoo`030P1oogoo02]oo`0301moogoo00=oo`0301mo
o`0O009oo`0301moo`0O009oo`@07`=oo`0601moogoo01moo`0O1Goo00<0
7gooOol00Woo00@07gooOol07`Eoo`0301moogoo00Aoo`050P1oogooOol2
0003Ool00`80Oomoo`0XOol01@80Oomoogoo0P0017oo00<207ooOol0E7oo
00<207ooOol037oo00=l07ooOol03Goo0`0O2Goo00<207ooOol04goo00D2
07ooOomoo`8000=oo`030P1oogoo01Qoo`03O01oogoo02Uoo`0@IcUoof<H
OomS67ooHaQoof<HOomW>GooHaQoofLiOol2HaP1@Q010001Li`00005IcUo
of<HHaP07`03Ool201l2Ool00`0OOomoo`04Ool0100OOomoogoo0P0O17oo
00<07gooOol00Woo1@0O1Goo00<07gooOol02goo00@207ooOol204Yoo`03
0P1oogoo019oo`040P1oogoo0P0cOol00`0OOomoo`03Ool00`0OOol07`02
Ool00`0OOol07`02Ool0100OOomoogoo0P0O00Moo`0OOomoo`0OOol07`05
Ool00`0OOomoo`02Ool0100OOomoo`0O1Goo00<07gooOol02Goo00@207oo
Ool202Yoo`040P1oogoo0P1LOol00`80Oomoo`0<Ool00g`0Oomoo`08Ool0
0`0OOomoo`05Ool00`0OOomoo`06Ool00`80Oomoo`0COol01080Oomoo`80
7goo00=l07ooOol0:Woo00iS67ooHaQoofLiOomS67ooHaQoof<HOomS67oo
0f<H0D8@0@000G>L00001F<HOomS66<H01l00Woo00<07goo01l00Woo100O
0goo00H07gooOol07goo01l5Ool00`0OOomoo`02Ool0100OOomoo`0O1Goo
00<07gooOol037oo00<207oo0P00BWoo00<207ooOol04Woo00<207oo0P00
=7oo00<07gooOol00goo00D07goo01moo`0O009oo`0401moogoo01l4Ool0
1@0OOol07goo01l00Woo00<07gooOol017oo00<07gooOol00Woo00<07goo
01l01Goo00<07gooOol02Woo00<207oo0P00:Woo00<207oo0P0037oo100O
CGoo00<207ooOol037oo00=l07ooOol027oo00<07gooOol01Goo00<07goo
Ool01Woo00<207ooOol04goo00<207oo0P0037oo100O47oo00=l07ooOol0
:Goo01AW>GooIcUoof<HOomS67ooIcUoof<HOomW>GooHaQoof<HIcU24000
0G>L00001FLiOomS66<H01l00Woo00<07goo01l00Woo00@07gooOomoo`80
7`07Ool07gooOol07goo01l01Goo00<07gooOol00Woo00@07gooOol07`Eo
o`0301moogoo00eoo`8201=oo`807cAoo`807aAoo`8203Ioo`0501moogoo
Ool07`02Ool201l3Ool0100OOomoo`0O17oo00@07goo01l07`=oo`0301mo
ogoo00Aoo`0301moogoo00=oo`807`=oo`<07`eoo`8201Aoo`807aAoo`82
00aoo`0301moogoo00807`9oo`0301moogoo009oo`0401moogoo01l6Ool0
0`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`06Ool00`0OOomoo`03
Ool00`0OOomoo`0POol00`80Oomoo`0<Ool00g`0Oomoo`08Ool00`0OOomo
o`02Ool501l6Ool201lEOol20P0<Ool00`0OOomoo`0201l2Ool00`0OOomo
o`02Ool0100OOomoo`0O1Goo00=l000OOol00goo00<07gooOol00Woo00<0
7gooOol01Woo00<07gooOol00goo00<07gooOol047oo00iS67ooHaQoof<H
OomS67ooHaQoof<HOomS67oo0f<H0D8@0@000G>L00001f<HOomW>F<H01mo
o`0O009oo`0401moogoo01l4Ool01@0OOol07goo01l00Woo00<07gooOol0
17oo00<07gooOol00Woo00<07goo01l01Goo00<07gooOol03Woo00<2000O
01l02@0O1`80100O<P80100O2P802@0O00<207ooOol0=Woo0`0O0goo0P0O
0goo00<07gooOol01P0O00=oo`0O01l00goo00<07gooOol01P0O17oo0P0O
1Goo00<07gooOol037oo00<2000O01l0200O2@80100O20802`0O00<207oo
Ool02Woo00<07gooOol00Woo00@07gooOol07`=oo`807`9oo`0301moogoo
00Aoo`0401moogooOol201l4Ool00`0OOomoo`02Ool501l5Ool00`0OOomo
o`0POol00`80Oomoo`0<Ool00g`0Oomoo`08Ool01@0OOomoogoo01l00goo
0P0O1Goo0P0O67`O2goo00<07gooOol00Woo00@07gooOol07`=oo`807`9o
o`0301moogoo00=oo`03O0007goo009oo`807`Aoo`0301moogoo009oo`D0
7`Eoo`0301moogoo00moo`0@IcUoof<HOomW>GooHaQoof<HOomW>GooHaQo
of<HOol2HaP1@Q010001Li`00004IcUoof<HHaP201l3Ool0100OOomoo`0O
17oo00@07goo01l07`=oo`0301moogoo00Aoo`0301moogoo00=oo`807`=o
o`<07`moo`82019oo`@07c9oo`@07a=oo`8207=oo`8201=oo`@07a=oo`82
00]oo`0301moogoo00=oo`0301moo`0O009oo`0301moo`0O009oo`@07`=o
o`0601moogoo01moo`0O1Goo00<07gooOol00Woo00@07gooOol07`Eoo`03
01moogoo021oo`030P1oogoo00aoo`03O01oogoo00Qoo`0501moogooOol0
7`04Ool00`0OOomoo`03Ool201l00g`O01moo`0COol00`80O1moo`0:Ool0
0`0OOomoo`03Ool00`0OOol07`02Ool00`0OOol07`02Ool401l2Ool01g`0
01moogoo01moo`0O00Eoo`0301moogoo009oo`0401moogoo01l5Ool00`0O
Oomoo`0@Ool03V<HOomS67ooHaQoofLiOomS67ooHaQoof<HOol3HaP1@Q01
0001Li`00004HaQoof<HHaP201l3Ool00`0OOomoo`0601l00goo01l07`03
Ool00`0OOomoo`0601l4Ool201l5Ool00`0OOomoo`0<Ool00`80Ool2000C
Ool201ldOol201lDOol00`80Ool2001aOol00`80Ool2000DOol201lDOol0
0`80Ool2000:Ool00`0OOomoo`03Ool00`0OOol07`02Ool00`0OOol07`02
Ool0100OOomoogoo0P0O00Moo`0OOomoo`0OOol07`05Ool00`0OOomoo`02
Ool0100OOomoo`0O1Goo00<07gooOol087oo00<207ooOol037oo00=l07oo
Ool01Woo0`0O0goo00D07gooOomoo`0O00Moo`0301ml7goo01Aoo`030P1o
og`O00Yoo`0301moogoo00=oo`0301moo`0O009oo`0301moo`0O009oo`04
01moogooOol201l01g`001moogoo01moo`0O00Eoo`0301moogoo009oo`04
01moogoo01l5Ool00`0OOomoo`0?Ool056LiOomW>GooHaQoof<HOomS67oo
HaQoofLiOomS67ooHaQW>D8@0001Li`00004IcUoof<HIcTfOol01080Oomo
o`800goo100O0goo100O1Woo00<207ooOol0>goo100O17oo0`0O0Woo00@2
07ooOol206moo`040P1oogoo0P0EOol00`80Oomoo`0BOol01080Oomoo`80
2Goo00<07gooOol00goo00D07goo01moo`0O009oo`0401moogoo01l4Ool0
1@0OOol07goo01l00Woo00<07gooOol017oo00<07gooOol00Woo00<07goo
01l01Goo00<07gooOol087oo00<207ooOol037oo00=l07ooOol027oo00<0
7gooOol00Woo0`0O2Goo00=l7gooOol04goo00@207ooOoml7`Uoo`0301mo
ogoo00=oo`0501moo`0OOol07`02Ool0100OOomoo`0O17oo00D07g`001mo
o`0O009oo`0301moogoo00Aoo`0301moogoo009oo`0301moo`0O00Eoo`03
01moogoo011oo`0>HaQoof<HOomW>GooHaQoofLiOomS67ooHaQoo`=S6052
4040005cW00000AS67ooHaQS63Eoo`050P1oogooOol20002Ool00`0OOomo
o`0201l7Ool00`0OOomoo`03Ool00`80Oomoo`0jOol00`0OOomoo`0201l3
Ool01`0OOomoogoo01moo`8000=oo`030P1oogoo00aoo`@07e]oo`050P1o
ogooOol2000EOol00`80Oomoo`0BOol01@80Oomoogoo0P002Goo00D07goo
Oomoo`0O009oo`807`=oo`0401moogoo01l4Ool0100OOol07`0O0goo00<0
7gooOol017oo00<07gooOol00goo0P0O0goo0`0O8Woo00<207ooOol03Goo
00=l07ooOol067oo00=l7gooOol04goo00D207ooOomoog`O00Uoo`0501mo
ogooOol07`02Ool201l3Ool0100OOomoo`0O17oo00Al07oo01l07`=oo`03
01moogoo00Aoo`0301moogoo00=oo`807`=oo`<07a5oo`0@IcUoof<HOomS
67ooHaQoof<HOomS67ooHaQoofLiOol2HaP1@Q010001Li`00004IcUoof<H
IcTcOol20P04Ool00`80Ool07`04Ool00`0OOomoo`05Ool00`0OOomoo`03
Ool00`80Oomoo`0iOol00`0OOomoo`02Ool01@0OOomoogoo01l00goo00<0
7goo0P0017oo0P802goo00<07gooOol00P0O0Woo00<07gooOol00Woo00@0
7gooOol07`Ioo`0301moogoo009oo`0301moogoo009oo`0301moogoo00Io
o`0301moogoo00=oo`0301moogoo02aoo`8200Aoo`030P1oogoo01=oo`03
0P1oogoo019oo`030P1oogoo009oo`8200Qoo`<07`=oo`807`=oo`0301mo
ogoo00H07`03Ool07`0O00=oo`0301moogoo00H07`Aoo`807`Eoo`0301mo
ogoo021oo`030P1oogoo00eoo`03O01oogoo01Qoo`03O1moogoo01=oo`03
0P1oogoo009oo`03O1moogoo00Moo`<07`=oo`807`=oo`0301moogoo00D0
7`04O01oo`0O01l3Ool00`0OOomoo`0601l4Ool201l5Ool00`0OOomoo`0@
Ool03V<HOomW>GooHaQoofLiOomS67ooIcUoof<HOol3HaP1@Q010001Li`0
0004HaQoof<HHaPbOol00`80Oomoo`04Ool00`80Ool07`05Ool00`0OOomo
o`04Ool00`0OOomoo`03Ool00`80Oomoo`0iOol00`0OOomoo`03Ool0100O
Ool07`0O0goo00<07goo0P001Woo00<207ooOol01goo00<07gooOol00Woo
00@07gooOol07`=oo`807`9oo`0301moogoo00Aoo`0401moogooOol201l4
Ool00`0OOomoo`02Ool501l5Ool00`0OOomoo`0[Ool00`80Oomoo`04Ool0
0`80Oomoo`0COol00`80Oomoo`0BOol00`80Oomoo`04Ool00`80Oomoo`1F
Ool00`80Oomoo`0=Ool00g`0Oomoo`0HOol00g`OOomoo`0COol00`80Oomo
o`03Ool00g`OOomoo`0IOol00g`0Oomoo`0ZOol056LiOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQW>D8@0001Li`00004IcUoof<HIcTaOol0
0`80Oomoo`05Ool00`80Ool07`05Ool00`0OOomoo`03Ool00`0OOomoo`04
Ool00`80Oomoo`0iOol00`0OOomoo`03Ool00`0OOol07`0401l2Ool00`80
Oomoo`05Ool00`80Oomoo`06Ool00`0OOomoo`03Ool00`0OOol07`02Ool0
0`0OOol07`02Ool401l3Ool01P0OOomoo`0OOol07`Eoo`0301moogoo009o
o`0401moogoo01l5Ool00`0OOomoo`0ZOol00`80Oomoo`05Ool00`80Oomo
o`0COol00`80Oomoo`0BOol00`80Oomoo`05Ool00`80Oomoo`1EOol00`80
Oomoo`0=Ool00g`0Oomoo`0HOol00g`OOomoo`0COol00`80Oomoo`04Ool0
0g`OOomoo`0HOol00g`0Oomoo`0[Ool03V<HOomS67ooIcUoof<HOomW>Goo
HaQoof<HOol3HaP1@Q010001Li`00004HaQoof<HHaP`Ool00`80Oomoo`06
Ool00`80Ool07`05Ool00`0OOomoo`0301l7Ool00`80Oomoo`0iOol00`0O
Oomoo`03Ool0100OOomoo`0O1Goo00<207ooOol01Woo00<207ooOol01Goo
00<07gooOol00goo00<07goo01l00Woo00<07goo01l00Woo00@07gooOomo
o`807`07Ool07gooOol07goo01l01Goo00<07gooOol00Woo00@07gooOol0
7`Eoo`0301moogoo02Uoo`030P1oogoo00Ioo`030P1oogoo01=oo`030P1o
ogoo019oo`030P1oogoo00Ioo`030P1oogoo05Aoo`030P1oogoo00eoo`03
O01oogoo01Qoo`03O1moogoo01=oo`030P1oogoo00Eoo`03O1moogoo01Mo
o`03O01oogoo02Yoo`0@IcUoofLiOomS67ooHaQoof<HOomS67ooIcUoof<H
Ool2HaP1@Q010001Li`00004IcUoof<HIcT_Ool00`80Oomoo`07Ool01080
Oomoo`0O0goo00D07gooOomoo`0O00Uoo`030P1oogoo03Yoo`0501moogoo
Ool07`03Ool00`0OOomoo`03Ool00`80Oomoo`07Ool00`80Oomoo`04Ool0
0`0OOomoo`03Ool01@0OOol07goo01l00Woo00@07gooOol07`Aoo`0501mo
o`0OOol07`02Ool00`0OOomoo`04Ool00`0OOomoo`02Ool00`0OOol07`05
Ool00`0OOomoo`0XOol00`80Oomoo`07Ool00`80Oomoo`0COol00`80Oomo
o`0BOol00`80Oomoo`07Ool00`80Oomoo`1COol00`80Oomoo`0=Ool00g`0
Oomoo`0HOol00g`OOomoo`0COol00`80Oomoo`06Ool00g`OOomoo`0FOol0
0g`0Oomoo`0[Ool03V<HOomS67ooHaQoofLiOomS67ooHaQoof<HOol3HaP1
@Q010001Li`00004HaQoof<HHaP^Ool00`80Oomoo`08Ool01080Oomoogoo
0`0O17oo100O1Woo00<207ooOol0>goo0`0O1Goo0`0O0Woo00<207ooOol0
27oo00<207ooOol017oo00D07gooOomoo`0O009oo`807`=oo`0401moogoo
01l4Ool0100OOol07`0O0goo00<07gooOol017oo00<07gooOol00goo0P0O
0goo0`0O:Goo00<207ooOol027oo00<207ooOol04goo00<207ooOol04Woo
00<207ooOol027oo00<207ooOol0DWoo00<207ooOol03Goo00=l07ooOol0
67oo00=l7gooOol04goo00<207ooOol01Woo00=l7`80Ool05Woo00=l07oo
Ool0:Woo01AW>GooHaQoofLiOomS67ooHaQoofLiOomS67ooHaQoof<HIcU2
40000G>L000016LiOomS66Li;Woo00<07gooOol07Goo00<207ooOol0Dgoo
00<07gooOol01Goo0`0O0goo0P0O0goo00<07gooOol01P0O00=oo`0O01l0
0goo00<07gooOol01P0O17oo0P0O1Goo00<07gooOol09goo00<07gooOol0
7Woo00<207ooOol07Goo00<07gooOol0DWoo00<207ooOol03Goo00=l07oo
Ool067oo00=l7gooOol077oo00=l7`0OOol05Woo00=l07ooOol0:goo00iS
67ooHaQoof<HOomS67ooHaQoof<HOomW>Goo0f<H0D8@0@000G>L000016<H
OomS66<H;Woo00<07gooOol07Goo00<207ooOol0Dgoo00<07gooOol0GGoo
00<07gooOol07Woo00<207ooOol07Goo00<07gooOol0DWoo00<207ooOol0
3Goo00=l07ooOol067oo00=l7gooOol077oo00=l7`0OOol05Woo00=l07oo
Ool0:Woo011W>GooIcUoof<HOomW>GooHaQoof<HOomS67ooHaQoo`9S6052
4040005cW00000AW>GooHaQW>Bioo`0301moogoo01eoo`030P1oogoo05=o
o`0301moogoo05eoo`0301moogoo01ioo`030P1oogoo01eoo`0301moogoo
059oo`030P1oogoo00eoo`03O01oogoo01Qoo`03O1moogoo01aoo`03O1l0
7goo01Ioo`03O01oogoo02]oo`0>HaQoof<HOomS67ooIcUoof<HOomW>Goo
HaQoo`=S60524040005cW00000AS67ooHaQS62ioo`0301moogoo01eoo`03
0P1oogoo05=oo`0301moogoo05eoo`0401moogooOol401l:Ool401l;Ool0
0`80Oomoo`09Ool401l@Ool00`0OOomoo`1BOol00`80Oomoo`0=Ool00g`0
Oomoo`0HOol00g`OOomoo`08Ool401l@Ool00g`O01moo`0FOol00g`0Oomo
o`0ZOol056LiOomS67ooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQW>D8@
0001Li`00004IcUoof<HIcT^Ool00`0OOomoo`0MOol00`80Oomoo`1COol0
0`0OOomoo`1MOol0100OOomoo`0O0Woo0P0O1Goo00<07gooOol00Woo00@0
7gooOol07`]oo`030P1oogoo00Qoo`0301moogoo00807`Eoo`0301moogoo
00Aoo`0501moogooOol07`1DOol00`80Oomoo`0=Ool00g`0Oomoo`0HOol0
0g`OOomoo`07Ool00`0OOomoo`0201l5Ool00`0OOomoo`03Ool00`0OOomo
o`02Ool00g`O01moo`0FOol00g`0Oomoo`0[Ool03V<HOomS67ooHaQoof<H
OomW>GooHaQoofLiOol3HaP1@Q010001Li`00004HaQoof<HHaP^Ool00`0O
Oomoo`0MOol00`80Oomoo`1COol00`0OOomoo`1MOol00`0OOol07`04Ool0
0`0OOomoo`03Ool01@0OOomoogoo01l017oo00<07gooOol027oo00<207oo
Ool01goo00<07gooOol00Woo00<07gooOol00goo00<07gooOol017oo00D0
7gooOomoo`0O05Aoo`030P1oogoo00eoo`03O01oogoo01Qoo`03O1moogoo
00Ioo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00=oo`0301mo
ogoo009oo`03O1l07goo01Ioo`03O01oogoo02Yoo`0@IcUoofLiOomS67oo
IcUoof<HOomS67ooHaQoof<HOol2HaP1@Q010001Li`00004IcUoof<HIcT^
Ool00`0OOomoo`0MOol00`80Oomoo`1COol00`0OOomoo`0ROol401l3Ool4
01l3Ool401lYOol00`0OOol07`05Ool00`0OOomoo`02Ool01@0OOomoogoo
01l017oo00<07gooOol027oo00<207ooOol01goo00<07gooOol00goo00<0
7gooOol00Woo00<07gooOol017oo00D07gooOomoo`0O05Aoo`030P1oogoo
00ioo`03O01oogoo01Moo`03O1moogoo00Ioo`0301moogoo00=oo`0301mo
ogoo009oo`0301moogoo00Aoo`0601moogooOoml7`0O5Woo00=l07ooOol0
;7oo00iS67ooHaQoof<HOomS67ooHaQoofLiOomS67oo0f<H0D8@0@000G>L
000016<HOomS66<H;Woo00<07gooOol07Goo00<207ooOol0Dgoo00<07goo
Ool09Woo00@07gooOol07`9oo`0501moogooOol07`02Ool00`0OOomoo`0W
Ool00`0OOol07`05Ool00`0OOomoo`02Ool01@0OOomoogoo01l017oo00<0
7gooOol027oo00<207ooOol01goo00<07gooOol00goo00<07gooOol00Woo
00<07gooOol017oo00D07gooOomoo`0O05Aoo`030P1oogoo00ioo`03O01o
ogoo01Moo`03O1moogoo00Ioo`0301moogoo00=oo`0301moogoo009oo`03
01moogoo00Aoo`0601moogooOoml7`0O5Woo00=l07ooOol0:goo01AW>Goo
HaQoofLiOomS67ooIcUoof<HOomS67ooHaQoof<HIcU240000G>L000016Li
OomS66Li;Woo00<07gooOol07Goo00<207ooOol0AGoo17`02Woo00<07goo
Ool09Woo00<07goo01l017oo00<07goo01l017oo00<07gooOol09Woo00<0
7goo01l01Goo00<07gooOol00Woo00D07gooOomoo`0O00Aoo`0301moogoo
00Qoo`030P1oogoo00Moo`0301moogoo00=oo`0301moogoo009oo`0301mo
ogoo00Aoo`0501moogooOol07`1DOol00`80Oomoo`0>Ool00g`0Oomoo`0G
Ool00g`OOomoo`06Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomo
o`05Ool01@0OOomoog`O01l05Woo00=l07ooOol0;7oo00iS67ooHaQoof<H
OomS67ooHaQoof<HOomW>Goo0f<H0D8@0@000G>L000016<HOomS66<H;Woo
00<07gooOol07Goo00<207ooOol0@7oo1G`017oo1G`01Goo00<07gooOol0
9Woo00<07goo01l017oo00<07goo01l017oo00<07gooOol09Woo00@07goo
Ool07`=oo`0401moogooOol301l4Ool01@0OOomoogoo01l02Woo00<207oo
Ool027oo00D07gooOomoo`0O00=oo`<07`Aoo`<07`9oo`807eAoo`030P1o
ogoo00ioo`03O01oogoo01Moo`03O1moogoo00Moo`0501moogooOol07`03
Ool301l7Ool01@0OOomoog`O01l05Woo00=l07ooOol0:goo011W>GooIcUo
of<HOomW>GooHaQoofLiOomS67ooHaQoo`9S60524040005cW00000AW>Goo
HaQW>Bioo`030P1oogoo01eoo`030P1oogoo03moo`03O01oogoo00aoo`03
O01oogoo009oo`0301moogoo02Aoo`807`9oo`0301moogoo009oo`0301mo
o`0O00Aoo`0301moogoo02Ioo`040P1oogooOol301l6Ool00`0OOomoo`02
Ool401l7Ool401lN0P0401mCOol00`80Oomoo`0>Ool00g`0Oomoo`0GOol0
0g`OOomoo`08Ool301l6Ool0100OOomoogoo1P0O00=oog`O0P005Woo00=l
07ooOol0;7oo00iS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo0f<H0D8@
0@000G>L000016<HOomS66<H;Woo00<207ooOol07Goo00<07gooOol0?Goo
0W`047oo0W`00Woo00<207ooOol097oo00D07gooOomoo`0O00Aoo`0301mo
o`0O00Aoo`0301moogoo02Ioo`030P1oogoo01Eoo`0301moogoo00Ioo`03
01moogoo01]oo`@07e=oo`030P1oogoo00ioo`03O01oogoo00eoo`030P1o
ogoo00Ioo`03O1moogoo01eoo`03O1l207oo01Eoo`03O01oogoo02]oo`0D
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomS66Li@Q00005cW000
00AW>GooHaQW>Bioo`030P1oogoo01eoo`0301moogoo03aoo`03O01oogoo
019oo`03O01oo`8002Moo`0501moogooOol07`03Ool0100OOomoo`0O0goo
00<07gooOol09Woo00<207ooOol05Goo00<07gooOol01Woo00<07gooOol0
77oo0P0OE7oo00<207ooOol03Woo00=l07ooOol03Goo00@207ooOomoo`@2
0003O1moogoo01ioo`03O1l207oo01Eoo`03O01oogoo02aoo`0>HaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoo`=S60524040005cW00000AS67ooHaQS
62ioo`030P1oogoo01eoo`0301moogoo03Yoo`9l01Ioo`9l02Aoo`@07`=o
o`@07`=oo`@07bUoo`030P1oogoo01Eoo`0301moogoo00Ioo`0301moogoo
01eoo`030P1oogoo059oo`030P1oogoo00ioo`03O01oogoo00eoo`030P1o
ogoo00Aoo`03O1l207oo01moo`03O1l207oo01Eoo`03O01oogoo02]oo`0@
IcUoofLiOomS67ooIcUoof<HOomW>GooHaQoof<HOol2HaP1@Q010001Li`0
0004IcUoof<HIcT^Ool00`80Oomoo`0MOol00`0OOomoo`0iOol00g`0Oomo
o`0GOol00`80O01oo`1MOol00`80Oomoo`0EOol00`0OOomoo`05Ool00`0O
Oomoo`0NOol00`80Oomoo`1BOol00`80Oomoo`0?Ool00g`0Oomoo`0<Ool0
0`80Oomoo`03Ool00g`OOol2000POol00g`O0P1oo`0DOol00g`0Oomoo`0]
Ool03V<HOomS67ooHaQoof<HOomS67ooHaQoofLiOol3HaP1@Q010001Li`0
0004HaQoof<HHaP^Ool00`80Oomoo`0MOol00`0OOomoo`0hOol00g`0Oomo
o`0HOol00`80Ooml001MOol00`80Oomoo`0EOol00`0OOomoo`02Ool301lQ
Ool00`80Oomoo`1BOol00`80Oomoo`0?Ool00g`0Oomoo`0<Ool00`80Oomo
o`02Ool017`OOomoo`8087oo00=l7`80Ool057oo00=l07ooOol0;7oo01AW
>GooHaQoofLiOomS67ooIcUoof<HOomS67ooHaQoof<HIcU240000G>L0000
16LiOomS66Li;Woo00<207ooOol07Goo00<07gooOol0=goo00=l07ooOol0
6Goo00@207ooOoml05aoo`030P1oogoo01=oo`<07`Aoo`0301moogoo025o
o`030P1oogoo059oo`030P1oogoo00moo`03O01oogoo00aoo`060P1oogoo
Ooml7`800Woo00<207ooOol07goo00=l7gooOol04goo00=l07ooOol0;Goo
00iS67ooHaQoof<HOomS67ooHaQoofLiOomS67oo0f<H0D8@0@000G>L0000
16<HOomS66<H;Woo00<207ooOol07Goo00<07gooOol0=Woo00=l07ooOol0
6Woo00D207ooOomoog`0021oo`030P1oogoo00Aoo`030P1oogoo00=oo`03
0P1oogoo02]oo`030P1oogoo01Eoo`0301moogoo009oo`@07b1oo`030P1o
ogoo059oo`030P1oogoo00moo`03O01oogoo00aoo`050P1oogooO1l20003
Ool00`80Oomoo`0OOol00g`OOomoo`0COol00g`0Oomoo`0/Ool046LiOomW
>GooHaQoofLiOomS67ooHaQoof<HOomS67oo0V<H0D8@0@000G>L000016Li
OomS66Li;Woo00<207ooOol07Goo00<07gooOol0=Woo00=l07ooOol06Woo
00D207ooOomoog`0021oo`030P1oogoo00Aoo`030P1oogoo00=oo`030P1o
ogoo02]oo`030P1oogoo03ioo`030P1oogoo059oo`030P1oogoo00moo`03
O01oogoo00aoo`040P1oog`O0P04Ool00`80Oomoo`0OOol00g`OOomoo`0C
Ool00g`0Oomoo`0]Ool03V<HOomS67ooHaQoof<HOomW>GooHaQoofLiOol3
HaP1@Q010001Li`00004HaQoof<HHaP^Ool00`80Oomoo`0MOol00`0OOomo
o`0eOol00g`0Oomoo`0KOol00`80Oomoo`02Ool00g`0Oomoo`0LOol00`80
Ool20004Ool00`80Ool20003Ool00`80Ool2000/Ool00`80Oomoo`0nOol0
0`80Oomoo`1BOol00`80Oomoo`0?Ool00g`0Oomoo`0<Ool00`80O1l2000>
Ool401lEOol00g`OOomoo`0COol00g`0Oomoo`0/Ool056LiOomS67ooIcUo
of<HOomS67ooHaQoof<HOomS67ooHaQW>D8@0001Li`00004IcUoof<HIcT^
Ool00`80Oomoo`0MOol00`0OOomoo`0dOol00g`0Oomoo`0KOol201l5Ool0
0g`0Oomoo`0KOol00`80Ool20004Ool00`80Ool20003Ool00`80Ool2000/
Ool00`80Oomoo`0nOol00`80Oomoo`17Ool201l8Ool201l9Ool201l6Ool0
0g`0Oomoo`0<Ool00g`O0P1oo`0=Ool00`0OOomoo`0201l2Ool00`0OOomo
o`02Ool0100OOomoo`0O1Woo00H07gooOomoog`O01l4Ool00`0OOomoo`06
Ool00`0OOomoo`03Ool00`0OO01oo`0POol401l:Ool03V<HOomS67ooHaQo
ofLiOomS67ooIcUoof<HOol3HaP1@Q010001Li`00004HaQoof<HHaP^Ool0
0`80Oomoo`1COol00g`0Oomoo`0KOol401l50P000g`00P02000;0P0;01l3
Ool01@80Oomoogoo0P000Woo00@207ooOol2009oo`040P1oogooOol30P09
01m;0P2<O1l00`80Oomoo`0<Ool00`0OOomoo`02Ool0100OOomoo`0O0goo
0P0O0Woo00<07gooOol017oo00H07gooOomoog`O01l4Ool00`0OOomoo`02
Ool501l5Ool00g`0Oomoo`0OOol00`0OOomoo`0201l2Ool00`0OOomoo`04
Ool046LiOomW>GooHaQoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@0@00
0G>L000016LiOomS66Li;Woo00<207ooOol04goo00<207ooOol01Woo00<2
07ooOol0=7oo00=l07ooOol06goo0P0ORg`O5Woo00<207ooOol0AWoo100O
1Woo100O1goo100O1Woo00=l07ooOol02Goo00Al7goo0P0200eoo`0301mo
ogoo00=oo`0301moo`0O009oo`0301moo`0O009oo`@07`=oo`0601moogoo
01ml7`0O1Goo00<07gooOol00Woo00@07gooOol07`Eoo`03O01oogoo01io
o`0301moogoo009oo`0401moogoo01l7Ool03V<HOomS67ooIcUoof<HOomW
>GooHaQoofLiOol3HaP1@Q010001Li`00004HaQoof<HHaP^Ool00`80Oomo
o`0COol01080Oomoogoo1@80=Woo00=l07ooOol07Goo00<07g`OOol01Woo
00=l07ooOol05Woo00<207oo0P0017oo00<207oo0P000goo00<207oo0P00
;goo00<207ooOol01W`O>7oo00<207ooOol0Agoo0P0O27oo0P0O2Goo0P0O
1goo00=l07ooOol02goo00<207oo0P0037oo00<07gooOol00goo00<07goo
01l00Woo00<07goo01l00Woo00@07gooOomoo`807`07Ool07gooOol07g`O
01l01Goo00<07gooOol00Woo00@07gooOol07`Eoo`03O01oogoo01ioo`03
01moogoo00=oo`0301moo`0O00<07`=oo`0DIcUoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS66Li@Q00005cW00000AW>GooHaQW>Bioo`030P1o
ogoo01=oo`030P1oogoo00Aoo`8203Eoo`03O01oogoo01moo`03O1moogoo
00Ioo`03O01oogoo01Eoo`8200Eoo`8200Eoo`030P1oogoo02ioo`030P1o
og`O009l7`=oo`9l7cMoo`030P1oogoo04Qoo`030P1oogoo019oo`030P1o
o`0O00<07`9oo`03O01oogoo00Ioo`<07`9oo`040P1oogoo0P0;Ool00`0O
Oomoo`03Ool01@0OOol07goo01l00Woo00@07gooOol07`Aoo`0801moo`0O
Ool07gooO1l07`Ioo`0301moogoo009oo`0301moo`0O00Eoo`03O01oogoo
01ioo`0301moogoo00=oo`0301moo`0O00=oo`807`9oo`0>HaQoofLiOomS
67ooIcUoof<HOomW>GooHaQoo`=S60524040005cW00000AS67ooHaQS62io
o`030P1oogoo01=oo`030P1oogoo00=oo`030P1oo`8003Eoo`03O01oogoo
01moo`03O1moogoo00Ioo`03O01oogoo01Ioo`030P1oogoo00Aoo`030P1o
ogoo00=oo`030P1oogoo02ioo`030P1oogoo00Eoo`9l7cMoo`030P1oogoo
04Qoo`030P1oogoo00Uoo`@07`Eoo`040P007gooOol201l2Ool017`0Oomo
o`0O17oo00L07gooOomoo`0OOol20003Ool00`80Oomoo`09Ool01@0OOomo
ogoo01l00Woo0P0O0goo00@07gooOol07`Aoo`0401moo`0O01l2Ool00g`O
01moo`05Ool00`0OOomoo`03Ool201l3Ool201l00g`0Oomoo`0NOol00`0O
Oomoo`03Ool00`0OOol07`04Ool04P0OOomW>GooHaQoof<HOomS67ooHaQo
of<HOomS67ooHaQoo`9S60524040005cW00000AW>GooHaQW>Bioo`030P1o
ogoo01=oo`030P1oogoo009oo`040P1oogoo0P0dOol00g`0Oomoo`0POol0
0g`OOomoo`07Ool00g`0Oomoo`1:Ool5O1l2Ool2O1l00`80Oomoo`07O1l0
0gooO1ml7`03Ool2O1l3Ool7O1l00gooO1ml7`07Ool2O1l3Ool2O1l4Ool4
O1l5Ool01G`OOomoogooO1l00Woo00<207ooOol0B7oo00<207ooOol017oo
00D07gooOomoo`0O00Aoo`0301moogoo009oo`030P1oogoo009oo`0701mo
ogooOoml07oo01l017oo00L07gooOomoo`0OOol20004Ool00`80Oomoo`09
Ool301l3Ool201l3Ool00`0OOomoo`0601l00goo01l07`02Ool017`O01mo
ogoo1P0O17oo0P0O17oo00=l000OOol087oo00D07gooOomoo`0O009oo`03
01moogoo009oo`0A01moogooHaQoof<HOomW>GooHaQoofLiOomS67ooIcUo
o`03HaP1@Q010001Li`00004HaQoof<HHaP^Ool00`80Oomoo`0COol00`80
Oomoo`02Ool01080Oomoo`80=7oo00=l07ooOol087oo00=l7gooOol01goo
00=l07ooOol0BGoo00=l7gooOol00Woo0W`O00Aoog`OO1l2009oo`9l7`9o
o`=l7`03Ooml7g`O00=oo`9l7`=oo`9l7`9oo`=l7`03Ooml7g`O00Moo`9l
7`=oo`9l7`=oo`9l7`9oo`9l7`Aoo`04O1moogooOol2O1l00goo0P1oo`19
Ool00`80Oomoo`04Ool01@0OOomoogoo01l017oo00<07gooOol00Woo00<2
07ooOol00goo00H07gooOoml07oo01l3Ool201l3Ool00`0OOol20004Ool0
0`80Oomoo`0ROol00g`OOomoo`0AOol00g`0Oomoo`0QOol301l3Ool601l0
5GooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS66Li@Q000001
Li`00004IcUoof<HIcT^Ool00`80Oomoo`0COol01@80Oomoogoo0P000goo
00<207ooOol0<Goo00=l07ooOol08Goo00=l7gooOol027oo00=l07ooOol0
C7oo0g`O00Eoog`OO1l207oo009l7`Aoo`9l7`03Ooml7g`O00=oo`9l7`9o
o`9l7`Aoo`9l7`03Ooml7g`O00Moo`9l7`=oo`9l7`9oo`9l7`Aoo`9l7`9o
o`=l7`9oo`=l7`030P1oogoo04Qoo`030P1oogoo00Aoo`0501moogooOol0
7`04Ool00`0OOomoo`02Ool00`80Oomoo`03Ool01P0OOomoog`0Ool07`=o
o`D07`9oo`030P1oogoo00=oo`030P1oogoo025oo`03O1moogoo015oo`03
O01oogoo02moo`0>HaQoofLiOomS67ooIcUoof<HOomW>GooHaQoo`=S6052
4040005cW00000AS67ooHaQS625oo`@07`Uoo`030P1oogoo01=oo`040P1o
ogoo0P0:Ool401lZOol00g`0Oomoo`0QOol00g`OOomoo`08Ool00g`0Oomo
o`1:Ool4O1l2Ool2O1l01080Ooml7g`O17oo0W`O00=oog`OO1l00goo0W`O
0Woo0W`O17oo0W`O00=oog`OO1l01goo0W`O0goo0W`O0Woo0W`O17oo0W`O
0Woo00=l7gooO1l00g`O00=oog`O0P00BWoo00<207ooOol017oo00<07goo
Ool00Woo100O1Goo00<207ooOol00goo00H07gooOoml07oo01l4Ool00`0O
Oomoo`03Ool00`80Oomoo`04Ool00`80Oomoo`0POol00g`OOomoo`0AOol0
0g`0Oomoo`0^Ool046LiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
0V<H0D8@0@000G>L000016LiOomS66Li87oo00<07gooOol00Woo00<07goo
Ool01Woo00<207ooOol04goo00<207oo0P002Woo00<07gooOol00P0O0Woo
00<07gooOol00Woo00@07gooOol07`Ioo`0301moogoo009oo`0301moogoo
009oo`0301moogoo00Ioo`0301moogoo009oo`03O0007goo01Moo`<07`Qo
o`03O1moogoo00Uoo`03O01oogoo04Qoo`9l7`Eoo`9l7`040P1oog`OO1l4
Ool2O1l00gooO1ml7`03Ool2O1l2Ool2O1l4Ool2O1l00gooO1ml7`07Ool2
O1l3Ool2O1l2Ool2O1l4Ool2O1l00gooO1ml7`02Ool2O1l2Ool2O1m:Ool0
0`80Oomoo`04Ool00`0OOomoo`02Ool0100OOomoo`0O1Goo00<2000OOol0
0Woo00L07gooOomoo`0OO0007`04Ool00`0OOomoo`03Ool00`80Oomoo`05
Ool00`80Oomoo`0OOol00g`OOomoo`0@Ool00g`0Oomoo`0`Ool03V<HOomS
67ooIcUoof<HOomW>GooHaQoofLiOol3HaP1@Q010001Li`00004HaQoof<H
HaPPOol00`0OOomoo`02Ool00`0OOomoo`05Ool201lEOol20P0:Ool00`0O
Oomoo`02Ool0100OOomoo`0O0goo0P0O0Woo00<07gooOol017oo00@07goo
Oomoo`807`Aoo`0301moogoo009oo`D07`Aoo`03O0007goo01Yoo`0301mo
ogoo00Eoo`03O1moogoo00Uoo`03O01oogoo04Qoo`9l7`9oo`9l7`04Ooml
7g`O0P02Ool2O1l2Ool3O1l00gooO1ml7`03Ool2O1l3Ool2O1l2Ool3O1l0
0gooO1ml7`07Ool2O1l3Ool2O1l3Ool2O1l2Ool2O1l2Ool017`OOomoogoo
0W`O0goo00=l7gooOol0B7oo00<207ooOol00Woo0`0O0goo00<07gooOol0
0Woo00<07gooOol00Woo00<207oo01l00P0O1Goo00=l000OOol017oo0`0O
0Woo00<207ooOol01Woo00<207ooOol07Goo00<07g`OOol04Goo00=l07oo
Ool0;goo01AW>GooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HIcU2
40000G>L000016LiOomS66Li87oo00<07gooOol00Woo00<07gooOol017oo
100O2P802P0O00<207ooOol02Goo00<07gooOol00goo00<07goo01l00Woo
00<07goo01l00Woo100O0goo00H07gooOol07goo01l5Ool00`0OOomoo`02
Ool0100OOomoo`0O0goo00=l07oo01l06goo00<07gooOol01Goo00=l7goo
Ool02Woo00=l07ooOol0B7oo17`O0Woo0W`O00@207ooOomoo`Il7`03Ooml
7g`O00Al7`Eoo`Il7`03Ooml7g`O00Ioo`El7`03Ooml7g`O00Aoo`Al7`9o
o`9l7`=oo`03O1moogoo009oo`9l7dUoo`030P1oogoo00Aoo`0301moogoo
009oo`@07`Eoo`030P1oogoo00Moo`03O01oogoo00Uoo`030P1oogoo00Mo
o`030P1oogoo01]oo`807dYl7`0:HaQoofLiOomS67ooIcUoof<HOol3HaP1
@Q010001Li`00004HaQoof<HHaPQOol401l7Ool401l6Ool401l:Ool20P0:
Ool00`0OOomoo`03Ool00`0OOol07`02Ool00`0OOol07`02Ool0100OOomo
ogoo0P0O00Moo`0OOomoo`0OOol07`05Ool00`0OOomoo`02Ool0100OOomo
o`0O0goo00=l07oo01l067oo1@0O1Woo00=l7gooOol02Woo00=l07ooOol0
87oo1@0O:goo00<207ooOol06Woo0W`O1goo0W`O0goo0W`O57oo00<207oo
Ool0B7oo00<207ooOol04Woo00<207ooOol01goo00=l07ooOol04goo00<0
7gooOol06goo100O4Goo00=l07ooOol0;goo011W>GooHaQoofLiOomS67oo
HaQoof<HOomS67ooHaQoo`9S60524040005cW00000AW>GooHaQW>B5oo`04
01moogoo01l8Ool201l6Ool00`0OOomoo`0201l4Ool00`0OOomoo`03Ool0
0`80Ool20009Ool00`0OOomoo`03Ool01@0OOol07goo01l00Woo00@07goo
Ool07`Aoo`0501moo`0OOol07`02Ool00`0OOomoo`04Ool00`0OOomoo`02
Ool00`0OOol07`03Ool00g`0Ool07`0GOol0100OOomoogoo0P0O1Woo00=l
7gooOol02Woo00=l07ooOol04Woo00D07gooOomoo`0O00Eoo`0301moogoo
009oo`0301moogoo02aoo`030P1oogoo01Yoo`9l7`Moo`9l7`=oo`9l7aAo
o`030P1oogoo04Qoo`030P1oogoo019oo`030P1oogoo00Qoo`03O01oogoo
019oo`0301moogoo01aoo`807a5oo`03O01oogoo035oo`0>HaQoof<HOomS
67ooHaQoofLiOomS67ooIcUoo`=S60524040005cW00000AS67ooHaQS621o
o`0301moogoo009oo`0301moogoo00Ioo`030P1oogoo00=oo`0301moogoo
009oo`0301moogoo009oo`0301moogoo00=oo`040P1oogoo0P09Ool01@0O
Oomoogoo01l00Woo0P0O0goo00@07gooOol07`Aoo`0401moo`0O01l3Ool0
0`0OOomoo`04Ool00`0OOomoo`03Ool201l2Ool017`001l07`0O5goo00<0
7gooOol00Woo00<07gooOol017oo00=l7gooOol02goo00=l07ooOol04Goo
00D07gooOomoo`0O00Eoo`0301moogoo00=oo`0301moogoo02Uoo`9l7`03
0P1oogoo01Yoo`9l7`Moo`9l7`=oo`9l7aAoo`030P1oogoo04Qoo`030P1o
ogoo019oo`030P1oogoo00Qoo`03O01oogoo019oo`0301moogoo01eoo`03
0P1oogoo00moo`03O01oogoo031oo`0DIcUoofLiOomS67ooIcUoof<HOomS
67ooHaQoof<HOomS66Li@Q00005cW00000AW>GooHaQW>B5oo`@07`Uoo`03
0P1oogoo00=oo`0301moogoo00=oo`0301moogoo009oo`0301moogoo009o
o`050P1oogooOol20009Ool301l3Ool201l3Ool00`0OOomoo`0601l00goo
01l07`03Ool00`0OOomoo`0601l4Ool201l2Ool017`0Oomoo`0O5goo00D0
7gooOomoo`0O00Moo`03O1moogoo00]oo`03O01oogoo015oo`0401moogoo
01l6Ool00`0OOomoo`04Ool00`0OOomoo`0XOol2O1l00`80Oomoo`0JOol2
O1l8Ool3O1l00gooO1ml7`0DOol00`80Oomoo`18Ool00`80Oomoo`0BOol0
0`80Oomoo`08Ool00g`0Oomoo`0BOol00`0OOomoo`0MOol00`80Oomoo`0?
Ool00g`0Oomoo`0aOol03V<HOomS67ooHaQoof<HOomS67ooIcUoof<HOol3
HaP1@Q010001Li`00004HaQoof<HHaP^Ool00`80Oomoo`03Ool00`0OOomo
o`03Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`80Oomoo`02Ool00`80
Oomoo`0aOol00g`0Oomoo`0IOol301l8Ool00g`OOomoo`0;Ool00g`0Oomo
o`0AOol601l4Ool00`0OOomoo`05Ool00`0OOomoo`0YOol00`80Oomoo`0n
Ool00`80Oomoo`18Ool00`80Oomoo`0BOol00`80Oomoo`08Ool00g`0Oomo
o`0BOol00`0OOomoo`0MOol00`80Oomoo`0?Ool00g`0Oomoo`0`Ool046Li
OomS67ooIcUoof<HOomW>GooHaQoof<HOomS67oo0V<H0D8@0@000G>L0000
16LiOomS66Li;Woo00<207ooOol00goo00<07gooOol00goo00<07gooOol0
0goo00D07gooOomoo`8000Eoo`030P1oogoo02moo`03O01oogoo02Eoo`03
O1moogoo00aoo`03O01oogoo011oo`0301moogoo009oo`0301moogoo009o
o`0301moogoo00Ioo`0301moogoo02Qoo`030P1oogoo03ioo`030P1oogoo
04Qoo`030P1oogoo019oo`030P1oogoo00Uoo`03O01oogoo015oo`0301mo
ogoo01eoo`030P1oogoo00ioo`03O01oogoo039oo`0>HaQoof<HOomS67oo
HaQoof<HOomS67ooIcUoo`=S60524040005cW00000AS67ooHaQS62ioo`03
0P1oogoo00Aoo`0501moogooOol07`06Ool01@0OOomoogoo0P001Woo00<2
07ooOol0;Woo00=l07ooOol09Goo00=l7gooOol037oo00=l07ooOol047oo
00<07gooOol00Woo00<07gooOol00`0O17oo00D07gooOomoo`0O02Yoo`03
0P1oogoo03ioo`030P1oogoo04Qoo`030P1oogoo019oo`030P1oogoo00Uo
o`03O01oogoo015oo`0301moogoo01eoo`030P1oogoo00ioo`03O01oogoo
035oo`0DIcUoofLiOomS67ooIcUoof<HOomW>GooHaQoof<HOomS66Li@Q00
005cW00000AW>GooHaQW>Bioo`030P1oogoo00Eoo`<07`=oo`H07`9oo`03
0P1oogoo00Eoo`030P1oogoo02aoo`03O01oogoo02Ioo`03O1moogoo00eo
o`03O01oogoo00moo`H07`Aoo`0301moogoo009oo`@07b]oo`030P1oogoo
03ioo`030P1oogoo04Qoo`030P1oogoo019oo`030P1oogoo00Uoo`03O01o
ogoo015oo`0301moogoo01eoo`030P1oogoo00ioo`03O01oogoo039oo`0>
HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoo`=S60524040005cW00000AS
67ooHaQS62ioo`030P1oogoo01=oo`030P1oogoo00Ioo`030P1oogoo02]o
o`03O01oogoo02Ioo`03O1moogoo00eoo`03O01oogoo04eoo`030P1oogoo
03ioo`030P1oogoo04Qoo`030P1oogoo019oo`030P1oogoo00Yoo`03O01o
ogoo011oo`0301moogoo01eoo`030P1oogoo00eoo`03O01oogoo039oo`0@
IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOol2HaP1@Q010001Li`0
0004IcUoof<HIcT^Ool00`80Oomoo`0COol00`80Oomoo`07Ool00`80Oomo
o`0ZOol00g`0Oomoo`0VOol00g`OOomoo`0=Ool00g`0Oomoo`1=Ool00`80
Oomoo`0nOol00`80Oomoo`18Ool00`80Oomoo`0BOol00`80Oomoo`0:Ool0
0g`0Oomoo`0@Ool00`80Oomoo`0MOol00`80Oomoo`0=Ool00g`0Oomoo`0c
Ool03V<HOomS67ooHaQoof<HOomS67ooHaQoof<HOol3HaP1@Q010001Li`0
0004HaQoof<HHaP^Ool00`80Oomoo`0MOol00`0OOomoo`0YOol00g`0Oomo
o`0WOol00g`OOomoo`0>Ool00g`0Oomoo`1<Ool00`80Oomoo`0nOol00`80
Oomoo`18Ool00`80Oomoo`0BOol00`80Oomoo`0:Ool00g`0Oomoo`0@Ool0
0`80Oomoo`0MOol00`80Oomoo`0=Ool00g`0Oomoo`0bOol056LiOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomS67ooHaQW>D8@0001Li`00004IcUoof<H
IcT^Ool00`80Oomoo`0MOol00`0OOomoo`0YOol00g`0Oomoo`0WOol00g`O
Oomoo`0>Ool00g`0Oomoo`1<Ool00`80Oomoo`0nOol00`80Oomoo`18Ool0
0`80Oomoo`0BOol00`80Oomoo`0;Ool00g`0Oomoo`0?Ool00`80Oomoo`0M
Ool00`80Oomoo`0<Ool00g`0Oomoo`0dOol03V<HOomS67ooHaQoof<HOomS
67ooHaQoofLiOol3HaP1@Q010001Li`00004HaQoof<HHaP^Ool00`80Oomo
o`0MOol00`0OOomoo`0YOol00g`0Oomoo`0WOol00g`OOomoo`0>Ool00g`0
Oomoo`1<Ool00`80Oomoo`0nOol00`80Oomoo`18Ool00`80Oomoo`0BOol0
0`80Oomoo`0;Ool00g`0Oomoo`0?Ool00`80Oomoo`0MOol00`80Oomoo`0<
Ool00g`0Oomoo`0cOol046LiOomS67ooIcUoof<HOomW>GooHaQoof<HOomS
67oo0V<H0D8@0@000G>L000016LiOomS66Li;Woo00<207ooOol07Goo00<0
7gooOol0:Goo00=l07ooOol09goo00=l7gooOol03Woo00=l07ooOol0C7oo
00<207ooOol0?Woo00<207ooOol0B7oo00<207ooOol04Woo00<207ooOol0
2goo00=l07ooOol03goo00<207ooOol07Goo00<207ooOol037oo00=l07oo
Ool0=7oo00iS67ooHaQoof<HOomS67ooHaQoofLiOomS67oo0f<H0D8@0@00
0G>L000016<HOomS66<H;Woo00<207ooOol07Goo00<07gooOol0:7oo00=l
07ooOol0:7oo00=l7gooOol03goo00=l07ooOol0Bgoo00<207ooOol0?Woo
00<207ooOol0B7oo00<207ooOol04Woo00<207ooOol037oo00=l07ooOol0
3Woo00<207ooOol07Goo00<207ooOol02goo00=l07ooOol0=7oo01AW>Goo
IcUoof<HOomW>GooHaQoof<HOomS67ooHaQoof<HIcU240000G>L000016Li
OomS66Li;Woo00<207ooOol07Goo00<07gooOol0:7oo00=l07ooOol0:7oo
00=l7gooOol03goo00=l07ooOol0Bgoo00<207ooOol0?Woo00<207ooOol0
B7oo00<207ooOol04Woo00<207ooOol037oo00=l07ooOol03Woo00<207oo
Ool07Goo00<207ooOol02goo00=l07ooOol0=Goo00iS67ooHaQoof<HOomS
67ooIcUoof<HOomW>Goo0f<H0D8@0@000G>L000016<HOomS66<H;Woo00<2
07ooOol07Goo00<07gooOol0:7oo00=l07ooOol0:7oo00=l7gooOol03goo
00=l07ooOol0Bgoo00<207ooOol0?Woo00<207ooOol0B7oo00<207ooOol0
4Woo00<207ooOol037oo00=l07ooOol03Woo00<207ooOol07Goo00<207oo
Ool02goo00=l07ooOol0=7oo011W>GooHaQoofLiOomS67ooHaQoof<HOomS
67ooHaQoo`9S60524040005cW00000AW>GooHaQW>Bioo`030P1oogoo01eo
o`0301moogoo02Qoo`03O01oogoo02Qoo`03O1moogoo00moo`03O01oogoo
04]oo`030P1oogoo03ioo`030P1oogoo04Qoo`030P1oogoo019oo`030P1o
ogoo00eoo`03O01oogoo00eoo`030P1oogoo01eoo`030P1oogoo00Yoo`03
O01oogoo03Ioo`0>HaQoof<HOomS67ooIcUoof<HOomW>GooHaQoo`=S6052
4040005cW00000AS67ooHaQS62ioo`030P1oogoo01eoo`0301moogoo02Mo
o`03O01oogoo02Uoo`03O1moogoo011oo`03O01oogoo04Yoo`030P1oogoo
03ioo`030P1oogoo03Uoo`Yl00Eoo`030P1oogoo019oo`030P1oogoo00eo
o`03O01oogoo00eoo`030P1oogoo01eoo`030P1oogoo00Yoo`03O01oogoo
03Eoo`0DIcUoofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS66Li@Q00
005cW00000AW>GooHaQW>Bioo`030P1oogoo01eoo`0301moogoo02Moo`03
O01oogoo02Uoo`03O1moogoo011oo`03O01oogoo04Yoo`030P1oogoo03io
o`030P1oogoo03Eoo`Al00Yoo`Al0003Ool207oo01=oo`030P1oogoo00eo
o`03O01oogoo00eoo`030P1oogoo01eoo`030P1oogoo00Yoo`03O01oogoo
03Ioo`0>HaQoof<HOomW>GooHaQoofLiOomS67ooIcUoo`=S60524040005c
W00000AS67ooHaQS62ioo`030P1oogoo01eoo`030P1oogoo02Moo`03O01o
ogoo02Uoo`03O1moogoo011oo`03O01oogoo04Yoo`030P1oogoo03ioo`03
0P1oogoo039oo`=l019oo`=l01=ooa420003O002008003P20003O0020080
03H2000@HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOol2HaP1@Q01
0001Li`00004IcUoof<HIcT^Ool00`80Oomoo`0MOol00`80Oomoo`0WOol0
0g`0Oomoo`0YOol00g`OOomoo`0@Ool00g`0Oomoo`1:Ool00`80Oomoo`0n
Ool00`80Oomoo`0`Ool2O00FOol01080Ooml07`08Woo00=l07ooOol037oo
00<207ooOol07Goo00<207ooOol02Goo00=l07ooOol0=goo00iW>GooIcUo
of<HOomW>GooHaQoofLiOomS67oo0f<H0D8@0@000G>L000016<HOomS66<H
;Woo00<207ooOol07Goo00<207ooOol09goo00=l07ooOol0:Goo00=l7goo
Ool047oo00=l07ooOol0BWoo00<207ooOol0?Woo00<207ooOol0;Woo0W`0
67oo00@207ooOomoo`9l025oo`03O01oogoo00]oo`030P1oogoo01eoo`03
0P1oogoo00Qoo`03O01oogoo03Moo`0DIcUoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOomS66Li@Q00005cW00000AW>GooHaQW>Bioo`030P1oogoo
01eoo`030P1oogoo02Ioo`03O01oogoo02Yoo`03O1moogoo015oo`03O01o
ogoo04Uoo`030P1oogoo03ioo`030P1oogoo02aoo`9l01Yoo`030P1oogoo
00=oo`9l01moo`03O01oogoo00]oo`030P1oogoo01eoo`030P1oogoo00Qo
o`03O01oogoo03Qoo`0>IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoo`=S
60524040005cW00000AS67ooHaQS62ioo`030P1oogoo01eoo`030P1oogoo
02Ioo`03O01oogoo02Yoo`03O1moogoo015oo`03O01oogoo04Uoo`030P1o
ogoo03ioo`030P1oogoo02]oo`03O01oogoo01Yoo`030P1oogoo00Eoo`03
O01oogoo01eoo`03O01oogoo00Yoo`030P1oogoo01eoo`030P1oogoo00Mo
o`03O01oogoo03Qoo`0@IcUoof<HOomW>GooHaQoof<HOomS67ooHaQoof<H
Ool2HaP1@Q010001Li`00004IcUoof<HIcT^Ool00`80Oomoo`0MOol00`80
Oomoo`0VOol00g`0Oomoo`0ZOol00g`OOomoo`0AOol00g`0Oomoo`19Ool0
0`80Oomoo`0nOol00`80Oomoo`0ZOol00g`0Oomoo`0KOol00`80Oomoo`06
Ool00g`0Oomoo`0LOol00g`0Oomoo`0:Ool00`80Oomoo`0MOol00`80Oomo
o`07Ool00g`0Oomoo`0iOol03VLiOomS67ooHaQoofLiOomS67ooIcUoof<H
Ool3HaP1@Q010001Li`00004HaQoof<HHaP^Ool00`80Oomoo`0MOol00`80
Oomoo`0VOol00g`0Oomoo`0ZOol00g`OOomoo`0AOol00g`0Oomoo`19Ool0
0`80Oomoo`0nOol00`80Oomoo`0XOol2O00NOol00`80Oomoo`07Ool2O00M
Ool00g`0Oomoo`09Ool00`80Oomoo`0MOol00`80Oomoo`06Ool00g`0Oomo
o`0iOol056LiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQW>D8@
0001Li`00004IcUoof<HIcT^Ool00`80Oomoo`0MOol00`80Oomoo`0VOol0
0g`0Oomoo`0ZOol00g`OOomoo`0AOol00g`0Oomoo`19Ool00`80Oomoo`0n
Ool00`80Oomoo`0WOol00g`0Oomoo`0NOol00`80Oomoo`09Ool00g`0Oomo
o`0JOol00g`0Oomoo`09Ool00`80Oomoo`0MOol00`80Oomoo`06Ool00g`0
Oomoo`0jOol03V<HOomW>GooIcUoof<HOomW>GooHaQoofLiOol3HaP1@Q01
0001Li`00004HaQoof<HHaP^Ool00`80Oomoo`0MOol00`80Oomoo`0VOol0
0g`0Oomoo`0ZOol00g`OOomoo`0AOol00g`0Oomoo`19Ool00`80Oomoo`0n
Ool00`80Oomoo`0VOol00g`0Oomoo`0OOol00`80Oomoo`0:Ool00g`0Oomo
o`0JOol00g`0Oomoo`08Ool00`80Oomoo`0MOol00`80Oomoo`05Ool00g`0
Oomoo`0jOol046LiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo0V<H
0D8@0@000G>L000016LiOomS66Li;Woo00<207ooOol07Goo00<207ooOol0
9Woo00=l07ooOol0:Woo00=l7gooOol04Goo00=l07ooOol0BGoo00<207oo
Ool0?Woo00<207ooOol09Goo00=l07ooOol087oo00<207ooOol02goo00=l
07ooOol06Goo00=l07ooOol027oo00<207ooOol07Goo00<207ooOol01Goo
00=l07ooOol0>goo00iS67ooHaQoof<HOomW>GooHaQoofLiOomS67oo0f<H
0D8@0@000G>L000016<HOomS66<H;Woo00<207ooOol07Goo00<207ooOol0
9Goo00=l07ooOol0:goo00=l7gooOol04Woo00=l07ooOol0B7oo00<207oo
Ool0?Woo00<207ooOol097oo00=l07ooOol08Goo00<207ooOol037oo00=l
07ooOol06Goo00=l07ooOol01goo00<207ooOol07Goo00<207ooOol017oo
00=l07ooOol0>goo01AW>GooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HIcU240000G>L000016LiOomS66Li;Woo00<207ooOol07Goo00<207oo
Ool09Goo00=l07ooOol0:goo00=l7gooOol04Woo00=l07ooOol0B7oo00<2
07ooOol0?Woo00<207ooOol097oo00=l07ooOol08Goo00<207ooOol037oo
00=l07ooOol06Goo00=l07ooOol01goo00<207ooOol07Goo00<207ooOol0
17oo00=l07ooOol0?7oo00iS67ooHaQoofLiOomS67ooIcUoof<HOomW>Goo
0f<H0D8@0@000G>L000016<HOomS66<H;Woo00<207ooOol07Goo00<207oo
Ool09Goo00=l07ooOol0:goo00=l7gooOol04Woo00=l07ooOol0B7oo00<2
07ooOol0?Woo00<207ooOol08goo00=l07ooOol08Woo00<07gooOol03Goo
00=l07ooOol06Goo00=l07ooOol01Woo00<207ooOol07Goo00<207ooOol0
0goo00=l07ooOol0?7oo011W>GooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQoo`9S60524040005cW00000AW>GooHaQW>Bioo`030P1oogoo01eoo`03
0P1oogoo02Eoo`03O01oogoo02]oo`03O1moogoo019oo`03O01oogoo04Qo
o`030P1oogoo03ioo`030P1oogoo029oo`03O01oogoo02=oo`0301moogoo
00ioo`03O01oogoo01Uoo`03O01oogoo00Eoo`030P1oogoo01eoo`030P1o
ogoo009oo`03O01oogoo03ioo`0>HaQoofLiOomS67ooIcUoof<HOomW>Goo
HaQoo`=S60524040005cW00000AS67ooHaQS62ioo`030P1oogoo01eoo`03
0P1oogoo02Eoo`03O01oogoo02]oo`03O1moogoo019oo`03O01oogoo04Qo
o`030P1oogoo03ioo`030P1oogoo025oo`03O01oogoo02Aoo`0301moogoo
00moo`03O01oogoo01Uoo`03O01oogoo00Aoo`030P1oogoo01eoo`050P1o
ogooOoml0010Ool056LiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo
HaQW>D8@0001Li`00004IcUoof<HIcT^Ool00`80Oomoo`0MOol00`80Oomo
o`0UOol00g`0Oomoo`0[Ool00g`OOomoo`0BOol00g`0Oomoo`18Ool00`80
Oomoo`0nOol00`80Oomoo`0QOol00g`0Oomoo`0TOol00`0OOomoo`0?Ool0
0g`0Oomoo`0IOol00g`0Oomoo`04Ool00`80Oomoo`0MOol01@80Oomoogoo
O000@Goo00iW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo0f<H0D8@0@00
0G>L000016<HOomS66<H;Woo00<207ooOol07Goo00<207ooOol09Goo00=l
07ooOol0:goo00=l7gooOol04Woo00=l07ooOol0B7oo00<207ooOol0?Woo
00<207ooOol087oo00=l07ooOol09Goo00<07gooOol047oo00=l07ooOol0
6Goo00=l07ooOol00goo00<207ooOol07Goo00@207ooOoml045oo`0@IcUo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOol2HaP1@Q010001Li`00004
IcUoof<HIcT^Ool00`80Oomoo`0MOol00`80Oomoo`0UOol00g`0Oomoo`0[
Ool00g`OOomoo`0BOol00g`0Oomoo`18Ool00`80Oomoo`0nOol00`80Oomo
o`0POol00g`0Oomoo`0UOol00`0OOomoo`0@Ool00g`0Oomoo`0JOol00g`0
Oomoo`02Ool00`80Oomoo`0MOol00`80Ooml0013Ool03V<HOomW>GooHaQo
ofLiOomS67ooIcUoof<HOol3HaP1@Q010001Li`00004HaQoof<HHaP^Ool0
0`80Oomoo`0MOol00`80Oomoo`0UOol00g`0Oomoo`0[Ool00g`OOomoo`0B
Ool00g`0Oomoo`18Ool00`80Oomoo`0nOol00`80Oomoo`0OOol00g`0Oomo
o`0VOol00`0OOomoo`0AOol00g`0Oomoo`0JOol01G`0Oomoogoo0P007goo
00<207`0Ool0@Woo01AW>GooHaQoof<HOomS67ooHaQoof<HOomS67ooHaQo
of<HIcU240000G>L000016LiOomS66Li;Woo00<207ooOol07Goo00<207oo
Ool09Goo00=l07ooOol0:goo00=l7gooOol04Woo00=l07ooOol0B7oo00<2
07ooOol0?Woo00<207ooOol07goo00=l07ooOol067oo00<07gooOol02goo
00<07gooOol04Goo00=l07ooOol06Woo00El07ooOomoo`8001moo`030P1l
07oo04=oo`0>IcUoof<HOomW>GooHaQoofLiOomS67ooIcUoo`=S60524040
005cW00000AS67ooHaQS62ioo`030P1oogoo01eoo`030P1oogoo02Aoo`03
O01oogoo02aoo`03O1moogoo01=oo`03O01oogoo04Moo`030P1oogoo03io
o`030P1oogoo01ioo`03O01oogoo00aoo`@07`=oo`@07`9oo`@07`Yoo`03
01moogoo019oo`03O01oogoo01Yoo`04O01oogoo0P0OOol00g`0Oomoo`12
Ool046LiOomS67ooIcUoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@0@00
0G>L000016LiOomS66Li;Woo00<207ooOol07Goo00<207ooOol097oo00=l
07ooOol0;7oo00=l7gooOol04goo00=l07ooOol0Agoo00<207ooOol0?Woo
00<207ooOol07Woo00=l07ooOol047oo00@07gooOol07`9oo`0401moogoo
01l3Ool00`0OOomoo`07Ool00`80Oomoo`0BOol00g`0Oomoo`0KOol00g`0
Ool2000NOol00g`00P1oo`14Ool03VLiOomS67ooHaQoofLiOomS67ooIcUo
of<HOol3HaP1@Q010001Li`00004HaQoof<HHaP^Ool00`80Oomoo`0MOol0
0`80Oomoo`0TOol00g`0Oomoo`0/Ool00g`OOomoo`0COol00g`0Oomoo`17
Ool00`80Oomoo`0nOol00`80Oomoo`0MOol00g`0Oomoo`0AOol00`0OOol0
7`04Ool00`0OOol07`04Ool00`0OOomoo`06Ool00`80Oomoo`0COol00g`0
Oomoo`0KOol00g`00P1oo`0LOol00g`0Ool20014Ool056LiOomS67ooHaQo
of<HOomS67ooHaQoof<HOomS67ooHaQW>D8@0001Li`00004IcUoof<HIcT^
Ool00`80Oomoo`0MOol00`80Oomoo`0TOol00g`0Oomoo`0/Ool00g`OOomo
o`0COol00g`0Oomoo`17Ool00`80Oomoo`0nOol00`80Oomoo`0MOol00g`0
Oomoo`0AOol00`0OOol07`04Ool00`0OOol07`04Ool00`0OOomoo`06Ool0
0`80Oomoo`0COol00g`0Oomoo`0LOol2O00JOol2O002Ool00`80Oomoo`13
Ool03V<HOomW>GooIcUoof<HOomW>GooHaQoofLiOol3HaP1@Q010001Li`0
0004HaQoof<HHaP^Ool00`80Oomoo`0MOol00`80Oomoo`0TOol00g`0Oomo
o`0/Ool00g`OOomoo`0COol00g`0Oomoo`17Ool00`80Oomoo`0nOol00`80
Oomoo`0MOol00g`0Oomoo`0?Ool201l2Ool00`0OOomoo`02Ool0100OOol0
7`0O0Woo00<07gooOol01goo00<207ooOol04goo00=l07ooOol077oo00<2
07ooO00067oo00=l07ooOol00Woo00<207ooOol0@Woo011W>GooHaQoof<H
OomS67ooHaQoof<HOomS67ooHaQoo`9S60524040005cW00000AW>GooHaQW
>Bioo`030P1oogoo01eoo`030P1oogoo02Aoo`03O01oogoo02aoo`03O1mo
ogoo01=oo`03O01oogoo04Moo`030P1oogoo03ioo`030P1oogoo01eoo`03
O01oogoo00moo`0501moogooOol07`04Ool0100OOomoogoo0P0O17oo2`80
4Goo00=l07ooOol077oo00<207ooOol00W`057oo0W`01Goo00<207ooOol0
@goo00iS67ooHaQoof<HOomW>GooHaQoofLiOomS67oo0f<H0D8@0@000G>L
000016<HOomS66<H;Woo00<207ooOol07Goo00<207ooOol097oo00=l07oo
Ool0;7oo00=l7gooOol04goo00=l07ooOol0Agoo00<207ooOol0?Woo00<2
07ooOol077oo00=l07ooOol04Goo00D07gooOomoo`0O00=oo`0301moogoo
02Aoo`03O01oogoo01]oo`030P1oogoo009oo`03O01oogoo011oo`03O01o
ogoo00Eoo`030P1oogoo049oo`0DIcUoofLiOomS67ooHaQoof<HOomS67oo
HaQoof<HOomS66Li@Q00005cW00000AW>GooHaQW>Bioo`030P1oogoo01eo
o`030P1oogoo02Aoo`03O01oogoo02aoo`03O1moogoo01=oo`03O01oogoo
04Moo`030P1oogoo03ioo`030P1oogoo01aoo`03O01oogoo00ioo`@07`=o
o`@07bMoo`03O01oogoo01]oo`030P1oogoo00=oo`9l00ioo`9l00Qoo`03
0P1oogoo04=oo`0>HaQoof<HOomW>GooHaQoofLiOomS67ooIcUoo`=S6052
4040005cW00000AS67ooHaQS62ioo`030P1oogoo01eoo`030P1oogoo02Ao
o`03O01oogoo02aoo`03O1moogoo01=oo`03O01oogoo04Moo`030P1oogoo
00Qoo`@07c9oo`030P1oogoo01aoo`03O01oogoo041oo`03O01oogoo01]o
o`030P1oogoo00Eoo`=l00Qoo`=l00Yoo`030P1oogoo049oo`0@IcUoof<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOol2HaP1@Q010001Li`00004IcUo
of<HIcT^Ool00`80Oomoo`0MOol00`80Oomoo`0TOol00g`0Oomoo`0/Ool0
0g`OOomoo`0COol00g`0Oomoo`17Ool00`80Oomoo`0<Ool00`0OOomoo`0_
Ool00`80Oomoo`0LOol00g`0Oomoo`0SOol;0P0BOol00g`0Oomoo`0KOol0
0`80Oomoo`08Ool8O00=Ool00`80Oomoo`13Ool03V<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOol3HaP1@Q010001Li`00004HaQoof<HHaP^Ool00`80
Oomoo`0MOol00`80Oomoo`0TOol00g`0Oomoo`0/Ool00g`OOomoo`0COol0
0g`0Oomoo`17Ool00`80Oomoo`0<Ool00`0OOomoo`0_Ool00`80Oomoo`0K
Ool00g`0Oomoo`0ZOol00`80Oomoo`0DOol00g`0Oomoo`0KOol00`80Oomo
o`0MOol00`80Oomoo`12Ool056LiOomS67ooHaQoof<HOomS67ooHaQoof<H
OomS67ooHaQW>D8@0001Li`00004IcUoof<HIcT^Ool00`80Oomoo`0MOol0
0`80Oomoo`0TOol00g`0Oomoo`0/Ool00g`OOomoo`0COol00g`0Oomoo`16
Ool201l>Ool00`0OOomoo`0_Ool00`80Oomoo`0KOol00g`0Oomoo`0ZOol0
0`80Oomoo`0EOol00g`0Oomoo`0JOol00`80Oomoo`0MOol00`80Oomoo`13
Ool03VLiOomS67ooIcUoof<HOomW>GooHaQoofLiOol3HaP1@Q010001Li`0
0004HaQoof<HHaP^Ool00`80Oomoo`0MOol00`80Oomoo`0TOol00g`0Oomo
o`0<OolP0P000g`O0P02000C0P000g`00P0200150P0401l;Ool201lbOol0
0`80Oomoo`0KOol00g`0Oomoo`12Ool00g`0Oomoo`0JOol00`80Oomoo`0M
Ool00`80Oomoo`12Ool046LiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67oo0V<H0D8@0@000G>L000016LiOomS66Li;Woo00<207ooOol07Goo00<2
07ooOol097oo00=l07ooOol037oo00<207ooOol07Goo00=l7gooOol04goo
00=l07ooOol0AGoo100O2goo00<07gooOol0<Goo00<207ooOol06goo00=l
07ooOol04Woo0`0O5Goo00<07gooOol05Goo00=l07ooOol06Woo00<207oo
Ool07Goo00<207ooOol0@goo00iS67ooIcUoof<HOomW>GooHaQoofLiOomS
67oo0f<H0D8@0@000Goo000016<HOomS66<H;Woo00<207ooOol07Goo00<2
07ooOol097oo00=l07ooOol037oo00<207ooOol07Goo00=l7gooOol04goo
00=l07ooOol0AWoo0P0O3Goo00<07gooOol0<7oo00<207ooOol06goo00=l
07ooOol04Goo00D07gooOomoo`0O00Aoo`0301moogoo00eoo`0301moogoo
01Eoo`03O01oogoo01Yoo`030P1oogoo01eoo`030P1oogoo049oo`0CIcUo
of<HOomS67ooHaQoof<HOomS67ooHaQoof<HOomS66Li@Q000P00000016Li
OomS66Li;Woo00<207ooOol07Goo00<207ooOol097oo00=l07ooOol037oo
00<207ooOol07Goo00=l7gooOol04goo00=l07ooOol0Agoo00<207ooOol0
27oo100O<Woo00<207ooOol06goo00=l07ooOol047oo00<07gooOol01goo
00<07gooOol03Goo00<07gooOol05Goo00=l07ooOol06Woo00<207ooOol0
7Goo00<207ooOol0@goo00iW>GooHaQoofLiOomS67ooIcUoof<HOomW>Goo
0f<H0D8@0@000D8@000016<HOomS66<H;Woo00<207ooOol07Goo00<207oo
Ool097oo00=l07ooOol037oo00<207ooOol07Goo00=l7gooOol04goo00=l
07ooOol0Agoo00<207ooOol0?Woo00<207ooOol06goo00=l07ooOol047oo
00<07gooOol01goo00<07gooOol03Goo00<07gooOol05Goo00=l07ooOol0
6Woo00<207ooOol07Goo00<207ooOol0@Woo011W>GooHaQoofLiOomS67oo
HaQoof<HOomS67ooHaQoo`9S60524040005S600000AW>GooHaQW>Bioo`03
0P1oogoo01eoo`030P1oogoo02Aoo`03O01oogoo00aoo`030P1oogoo01eo
o`03O1moogoo01=oo`03O01oogoo04Moo`030P1oogoo03ioo`030P1oogoo
01]oo`03O01oogoo011oo`0301moogoo00Moo`0301moogoo00eoo`0301mo
ogoo01Eoo`03O01oogoo01Yoo`030P1oogoo01eoo`030P1oogoo04=oo`0>
IcUoof<HOomS67ooIcUoof<HOomW>GooHaQoo`=S60524040005S600000AS
67ooHaQS62ioo`030P1oogoo01eoo`030P1oogoo02Aoo`03O01oogoo00ao
o`030P1oogoo01eoo`03O1moogoo01=oo`03O01oogoo04Moo`030P1oogoo
03ioo`030P1oogoo01]oo`03O01oogoo011oo`0301moogoo00Moo`0301mo
ogoo00eoo`0301moogoo01Eoo`03O01oogoo01Yoo`030P1oogoo01eoo`03
0P1oogoo049oo`0@IcUoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOol2
HaP1@Q010001@Q000004IcUoof<HIcT^Ool00`80Oomoo`0MOol00`80Oomo
o`0TOol00g`0Oomoo`0<Ool00`80Oomoo`0MOol00g`OOomoo`0COol00g`0
Oomoo`17Ool00`80Oomoo`0nOol00`80Oomoo`0KOol00g`0Oomoo`0AOol0
1@0OOomoogoo01l00Woo0`0O3goo00<07gooOol05Goo00=l07ooOol06Woo
00<207ooOol07Goo00<207ooOol0@goo00iS67ooIcUoofLiOomS67ooIcUo
of<HOomW>Goo0f<H0D8@0@000D8@000016<HOomS66<H;Woo00<207ooOol0
7Goo00<207ooOol097oo00=l07ooOol037oo00<207ooOol07Goo00=l7goo
Ool04goo00=l07ooOol0Agoo00<207ooOol0?Woo00<207ooOol06goo00=l
07ooOol04Woo0`0O1Goo00<07gooOol03Goo00<07gooOol05Goo00=l07oo
Ool06Woo00<207ooOol07Goo00<207ooOol0@Woo01AW>GooHaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoof<HIcU240000Goo000016LiOomS66Li;Woo
00<207ooOol07Goo00<207ooOol097oo00=l07ooOol037oo00<207ooOol0
7Goo00=l7gooOol04goo00=l07ooOol0Agoo00<207ooOol0?Woo00<207oo
Ool06goo00=l07ooOol0:Woo00<07gooOol057oo00=l07ooOol06goo00<2
07ooOol07Goo00<207ooOol0@goo00iS67ooHaQoof<HOomW>GooHaQoofLi
OomS67oo0f<H0D8@0@000F<H000016<HOomS66<H;Woo00<207ooOol07Goo
00<207ooOol09Goo00=l07ooOol02goo00<207ooOol07Goo00=l7gooOol0
4Woo00=l07ooOol0B7oo00<207ooOol0?Woo00<207ooOol077oo00=l07oo
Ool0:Goo00<07gooOol057oo00=l07ooOol06goo00<207ooOol07Goo00<2
07ooOol0@Woo011W>GooIcUoof<HOomS67ooHaQoof<HOomS67ooIcUoo`9S
605240400052400000AW>GooHaQW>Bioo`0301moogoo01eoo`030P1oogoo
02Eoo`03O01oogoo00]oo`030P1oogoo01eoo`03O1moogoo019oo`03O01o
ogoo04Qoo`030P1oogoo03ioo`030P1oogoo01aoo`03O01oogoo02Uoo`03
0P1oogoo01Aoo`03O01oogoo01]oo`030P1oogoo01eoo`030P1oogoo04=o
o`0>HaQoof<HOomW>GooHaQoofLiOomS67ooHaQoo`=S6052404000524000
00AS67ooHaQS62ioo`0301moogoo01eoo`030P1oogoo02Eoo`03O01oogoo
00]oo`030P1oogoo01eoo`03O1moogoo019oo`03O01oogoo04Qoo`030P1o
ogoo03ioo`030P1oogoo01aoo`03O01oogoo02Uoo`030P1oogoo01Aoo`03
O01oogoo01]oo`030P1oogoo01eoo`030P1oogoo049oo`0@IcUoof<HOomS
67ooHaQoof<HOomS67ooIcUoof<HOol2HaP1@Q010001Ool00004IcUoof<H
IcT^Ool00`0OOomoo`0MOol00`80Oomoo`0UOol00g`0Oomoo`0;Ool00`80
Oomoo`0MOol00g`OOomoo`0BOol00g`0Oomoo`18Ool00`80Oomoo`0nOol0
0`80Oomoo`0LOol00g`0Oomoo`0YOol00`80Oomoo`0DOol00g`0Oomoo`0K
Ool00`80Oomoo`0MOol00`80Oomoo`13Ool03V<HOomW>GooHaQoofLiOomS
67ooHaQoof<HOol3HaP1@Q010001HaP00004HaQoof<HHaP^Ool00`0OOomo
o`0MOol00`80Oomoo`0UOol00g`0Oomoo`0;Ool00`80Oomoo`0MOol00g`O
Oomoo`0BOol00g`0Oomoo`18Ool00`80Oomoo`0nOol00`80Oomoo`0MOol0
0g`0Oomoo`0XOol00`80Oomoo`0COol00g`0Oomoo`0LOol00`80Oomoo`0M
Ool00`80Oomoo`12Ool056LiOomS67ooHaQoof<HOomS67ooIcUoof<HOomS
67ooHaQW>D8@0001HaP00004IcUoof<HIcT^Ool00`0OOomoo`0MOol00`80
Oomoo`0UOol00g`0Oomoo`0;Ool00`80Oomoo`0MOol00g`OOomoo`0BOol0
0g`0Oomoo`18Ool00`80Oomoo`0nOol00`80Oomoo`0MOol00g`0Oomoo`0X
Ool00`80Oomoo`0COol00g`0Oomoo`0LOol00`80Oomoo`0MOol00`80Oomo
o`13Ool03VLiOomS67ooIcUoof<HOomS67ooHaQoofLiOol3HaP1@Q010001
HaP00004HaQoof<HHaP^Ool00`0OOomoo`0MOol00`80Oomoo`0UOol00g`0
Oomoo`0;Ool00`80Oomoo`0MOol00g`OOomoo`0BOol00g`0Oomoo`18Ool0
0`80Oomoo`0nOol00`80Oomoo`0MOol00g`0Oomoo`0XOol00`80Oomoo`0C
Ool00g`0Oomoo`0LOol00`80Oomoo`0MOol00`80Oomoo`12Ool046LiOomS
67ooHaQoof<HOomW>GooHaQoof<HOomS67oo0V<H0D8@0@000F<H000016Li
OomS66Li;Woo00<07gooOol07Goo00<207ooOol09Goo00=l07ooOol02goo
00<207ooOol07Goo00=l7gooOol04Woo00=l07ooOol0B7oo00<207ooOol0
?Woo00<207ooOol07Goo00=l07ooOol0:7oo00<207ooOol04goo00=l07oo
Ool077oo00<207ooOol07Goo00<207ooOol0@goo00iS67ooIcUoof<HOomS
67ooHaQoofLiOomS67oo0f<H0D8@0@000F<H000016<HOomS66<H;Woo00<0
7gooOol07Goo00<207ooOol09Goo00=l07ooOol02goo00<207ooOol07Goo
00=l7gooOol04Woo00=l07ooOol0B7oo00<207ooOol0?Woo00<207ooOol0
7Woo00=l07ooOol09goo00<207ooOol04Woo00=l07ooOol07Goo00<207oo
Ool07Goo00<207ooOol027oo00<07gooOol00goo00<07gooOol0<Goo01AW
>GooHaQoof<HOomW>GooHaQoof<HOomS67ooIcUoof<HIcU240000F<H0000
16LiOomS66Li;Woo00<07gooOol07Goo00<207ooOol09Goo00=l07ooOol0
2goo00<207ooOol07Goo00=l7gooOol04Woo00=l07ooOol0B7oo00<207oo
Ool0?Woo00<207ooOol07Woo00=l07ooOol09goo00<207ooOol04Woo00=l
07ooOol07Goo00<207ooOol07Goo00<207ooOol027oo00<07gooOol00goo
00<07gooOol0<Woo00iS67ooIcUoof<HOomS67ooIcUoof<HOomS67oo0f<H
0D8@0@000F<H000016<HOomS66<H;Woo00<07gooOol07Goo00<207ooOol0
9Woo00=l07ooOol02Woo00<207ooOol07Goo00=l7gooOol04Goo00=l07oo
Ool0BGoo00<207ooOol0?Woo00<207ooOol07goo00=l07ooOol09Woo00<2
07ooOol04Goo00=l07ooOol07Woo00<207ooOol07Goo00<207ooOol027oo
00<07gooOol017oo00<07gooOol0<7oo011W>GooHaQoof<HOomW>GooHaQo
of<HOomW>GooHaQoo`9S60524040005S600000AW>GooHaQW>Bioo`0301mo
ogoo01eoo`030P1oogoo02Ioo`03O01oogoo00Yoo`030P1oogoo01eoo`03
O1moogoo015oo`03O01oogoo04Uoo`030P1oogoo03ioo`030P1oogoo01mo
o`03O01oogoo02Ioo`030P1oogoo015oo`03O01oogoo01ioo`030P1oogoo
01aoo`807`Yoo`0301moogoo00Aoo`0301moogoo035oo`0>HaQoof<HOomS
67ooHaQoof<HOomS67ooHaQoo`=S60524040005S600000AS67ooHaQS62io
o`030P1oogoo00Qoo`030P1oogoo019oo`030P1oogoo02Ioo`03O01oogoo
00Yoo`030P1oogoo019oo`030P1oogoo00Qoo`03O1moogoo015oo`03O01o
ogoo04Uoo`030P1oogoo03ioo`030P1oogoo021oo`03O01oogoo02Eooa<2
0003O002008003d200@07`Uoo`0301moogoo00Eoo`0301moogoo02moo`0C
IcUoofLiOomS67ooHaQoofLiOomS67ooHaQoof<HOomS66Li@Q000P000000
16LiOomS66Li;goo00<207ooOol01goo00<207ooOol04Woo00<207ooOol0
9Woo00=l07ooOol02Woo00<207ooOol04Woo00<207ooOol01goo00=l7goo
Ool04Woo00=l07ooOol0BGoo00<207ooOol0?Woo00<207ooOol087oo00=l
07ooOol0>7oo00=l07ooOol07goo00<207ooOol06goo100O1goo0`0O1goo
00<07gooOol0<7oo00iS67ooHaQoofLiOomS67ooIcUoof<HOomW>Goo0f<H
0D8@0@000D8@000016<HOomS66<H<7oo00<207ooOol01Woo00<207ooOol0
4Woo00<207ooOol09Woo00=l07ooOol02Woo00<207ooOol04Woo00<207oo
Ool01Woo00=l7gooOol04goo00=l07ooOol0BGoo00<207ooOol0?Woo00<2
07ooOol08Goo00=l07ooOol0=Woo00=l07ooOol087oo00<207ooOol077oo
0P0O2Woo00@07gooOomoo`H07c1oo`0@IcUoof<HOomS67ooHaQoof<HOomS
67ooHaQoof<HOol2HaP1@Q010001HaP00004IcUoof<HIcTaOol00`80Oomo
o`05Ool00`80Oomoo`0BOol00`80Oomoo`0VOol00g`0Oomoo`0:Ool00`80
Oomoo`0BOol00`80Oomoo`04Ool2O1lFOol00g`0Oomoo`19Ool00`80Oomo
o`0nOol00`80Oomoo`0QOol00g`0Oomoo`0fOol00g`0Oomoo`0POol00`80
Oomoo`0MOol00`80Oomoo`13Ool03V<HOomW>GooHaQoof<HOomS67ooIcUo
of<HOol3HaP1@Q010001HaP00004HaQoof<HHaPbOol00`80Oomoo`04Ool0
0`80Oomoo`0BOol00`80Oomoo`0VOol00g`0Oomoo`0:Ool00`80Oomoo`0B
Ool00`80Oomoo`03Ool00g`O0P1oo`0FOol00g`0Oomoo`19Ool00`80Oomo
o`0nOol00`80Oomoo`0ROol00g`0Oomoo`0dOol00g`0Oomoo`0QOol00`80
Oomoo`0MOol00`80Oomoo`12Ool046LiOomS67ooHaQoofLiOomS67ooHaQo
of<HOomS67oo0V<H0D8@0@000F<H000016LiOomS66Li<goo0P8017oo00<2
07ooOol04Woo00<207ooOol09goo00=l07ooOol02Goo00<207ooOol04Woo
00<207ooOol00Woo00=l7`80Ool05Woo00=l07ooOol0BWoo00<207ooOol0
?Woo00<207ooOol08goo00=l07ooOol0<Woo00=l07ooOol08Woo00<207oo
Ool07Goo00<207ooOol0@goo00iW>GooHaQoof<HOomS67ooIcUoof<HOomW
>Goo0f<H0D8@0@000F<H000016<HOomS66<H=Goo00D207ooOomoo`8001Ao
o`030P1oogoo02Moo`03O01oogoo00Uoo`030P1oogoo019oo`050P1oogoo
Ooml7`0IOol00g`0Oomoo`1:Ool00`80Oomoo`0nOol00`80Oomoo`0TOol0
0g`0Oomoo`0`Ool00g`0Oomoo`0SOol00`80Oomoo`0MOol00`80Oomoo`12
Ool056LiOomS67ooIcUoof<HOomS67ooHaQoof<HOomS67ooHaQW>D8@0001
HaP00005IcUoof<HIcUoo`0401laOol01080Oomoo`8057oo00<207ooOol0
9goo00=l07ooOol02Goo00<207ooOol04Woo00@207ooOoml7`Moo`@07`mo
o`03O01oogoo04Yoo`030P1oogoo03ioo`030P1oogoo02Aoo`03O01oogoo
031oo`03O01oogoo02=oo`030P1oogoo01eoo`030P1oogoo04=oo`0>IcUo
of<HOomS67ooIcUoof<HOomW>GooHaQoo`=S60524040005S600000ES67oo
HaQS600O009oo`807`9oo`0301moogoo00Aoo`0301moogoo009oo`0401mo
ogoo01l8Ool00`0OOomoo`06Ool00`0OOomoo`03Ool00`0OOomoo`06Ool0
0`80Ool2000DOol00`80Oomoo`0WOol00g`0Oomoo`09Ool00`80Oomoo`0B
Ool00`80O1ml7`07Ool00`0OOomoo`0201l2Ool00`0OOomoo`04Ool00`0O
Oomoo`02Ool0100OO01oo`0O27oo00<07gooOol01Woo00<07gooOol00goo
00<07gooOol0<7oo00<207ooOol0?Woo00<207ooOol09Goo00=l07ooOol0
;Woo00=l07ooOol097oo00<207ooOol07Goo00<207ooOol0@Woo011W>Goo
HaQoofLiOomS67ooHaQoof<HOomS67ooIcUoo`9S60524040005S600000AW
>GooHaQW>@Aoo`0401moogoo01l6Ool0100OOomoogoo0P0O0Woo00<07goo
Ool01Woo00<07gooOol00Woo1@0O1Goo00<07gooOol01goo0P8057oo00<2
07ooOol09goo00=l07ooOol027oo0P0O57oo00=l7`80Ool01Woo00<07goo
Ool00Woo00@07gooOol07`Ioo`0401moogooOol201l00g`0Ool07`08Ool0
0`0OOomoo`02Ool501l5Ool00`0OOomoo`0`Ool00`80Oomoo`0nOol00`80
Oomoo`0VOol00g`0Oomoo`0/Ool00g`0Oomoo`0UOol00`80Oomoo`0MOol0
0`80Oomoo`13Ool03VLiOomS67ooHaQoof<HOomW>GooHaQoof<HOol3HaP1
@Q01000100000004HaQoof<HHaP5Ool00`0OOol07`0301l3Ool01P0OOomo
o`0OOol07`9oo`@07`Ioo`0301moogoo009oo`0401moogoo01l5Ool00`0O
Oomoo`08Ool00`8001l07`0801le0P000g`00P0200060P0401l90P0901l0
0g`O0P1oo`07Ool00`0OOomoo`03Ool00`0OOol07`0301l3Ool01P0OOomo
o`0OOoml009oo`@07`Ioo`0301moogoo009oo`0401moogoo01l5Ool00`0O
Oomoo`0`Ool00`80Oomoo`0nOol00`80Oomoo`0WOol00g`0Oomoo`0ZOol0
0g`0Oomoo`0VOol00`80Oomoo`0MOol00`80Oomoo`12Ool046LiOomS67oo
IcUoof<HOomS67ooHaQoofLiOomS67oo0V<H0D8@0@000F<H000016LiOomS
66Li1Goo00<07goo01l00goo0P0O00Moo`0OOomoo`0OOol07`02Ool0100O
Oomoogoo0P0O17oo00<07gooOol00Woo00@07gooOol07`Eoo`0301moogoo
00Moo`8201Aoo`030P1oogoo02Qoo`03O01oogoo00Ioo`@07a=oo`03O1l2
07oo00Ioo`0301moogoo00=oo`0301moo`0O00=oo`807`07Ool07gooOol0
7gooO0000Woo00@07gooOomoo`807`Aoo`0301moogoo009oo`0401moogoo
01l5Ool00`0OOomoo`0`Ool00`80Oomoo`0nOol00`80Oomoo`0XOol2O00X
Ool2O00YOol00`80Oomoo`0MOol00`80Oomoo`13Ool03VLiOomS67ooHaQo
ofLiOomS67ooHaQoof<HOol3HaP1@Q010001HaP00004HaQoof<HHaP5Ool0
0`0OOol07`04Ool01@0OOol07goo01l00Woo00@07gooOol07`Aoo`0301mo
ogoo00=oo`0301moogoo009oo`0301moo`0O00Eoo`0301moogoo00Ioo`03
0P1oo`8001Aoo`030P1oogoo02Qoo`03O01oogoo00Moo`807aAoo`030P1l
7g`O00Ioo`0301moogoo00=oo`0301moo`0O00Aoo`0501moo`0OOol07`02
Ool017`0Oomoo`0O17oo00<07gooOol00goo00<07gooOol00Woo00<07goo
01l01Goo00<07gooOol0<7oo00<207ooOol0?Woo00<207ooOol0:Woo00=l
07ooOol097oo00=l07ooOol0:Goo00<207ooOol07Goo00<207ooOol0@Woo
01AW>GooHaQoof<HOomS67ooHaQoofLiOomS67ooHaQoof<HIcU240000F<H
00001FLiOomS66<H01l00goo00@07gooOol07`Aoo`0401moo`0O01l3Ool0
100OOomoo`0O17oo00<07gooOol00goo00<07gooOol00goo0P0O0goo0`0O
00=oo`800P001@800Woo00<207ooOol04Woo00<207ooOol0:7oo00=l07oo
Ool07Goo00@207ooOoml7`H2000501moogooOol07`02Ool00`0OOomoo`02
Ool0100OOol07`0O0goo00Al07ooOol07`Aoo`0301moogoo00=oo`0301mo
ogoo00=oo`807`=oo`<07c9oo`030P1oogoo03ioo`030P1oogoo02]oo`03
O01oogoo029oo`03O01oogoo02Yoo`030P1oogoo01eoo`030P1oogoo04=o
o`0>HaQoofLiOomW>GooHaQoof<HOomS67ooIcUoo`=S60524040005S6000
00ES67ooIcUS67oo00<07`=oo`H07`03Ool07`0O00=oo`0301moogoo00H0
7`03Ool07`0O00@07`Aoo`807`Eoo`0301moogoo00Aoo`82009oo`030P1o
ogoo019oo`030P1oogoo02Uoo`03O01oogoo01aoo`050P1oogoo0P1l7`06
Ool301l3Ool601l00goo01l07`02Ool017`001moogoo1P0O00=oo`0O01l0
100O17oo0P0O1Goo00<07gooOol0<7oo00<207ooOol0?Woo00<207ooOol0
;7oo0W`087oo0W`0;Goo00<207ooOol07Goo00<207ooOol0@Woo011W>Goo
HaQoof<HOomS67ooIcUoof<HOomS67ooHaQoo`9S60524040005oo`0000AW
>GooHaQS63Aoo`030P1oo`80009oo`030P1oogoo00=oo`@07`=oo`@07`Ao
o`030P1oogoo02Uoo`03O01oogoo01aoo`060P1oogoo0P1oog`O5Woo00=l
07ooOol0C7oo00<207ooOol0?Woo00<207ooOol0;Woo0W`077oo0W`0;goo
00<207ooOol07Goo00<207ooOol0@goo00iS67ooHaQoof<HOomS67ooHaQo
ofLiOomS67oo0f<H0D8@0@000F<H000016<HOomS66<H<goo00@207ooOol2
009oo`030P1oogoo009oo`0301moogoo00807`Moo`0501moogooOol2000[
Ool00g`0Oomoo`0LOol01080Oomoo`800Woo00=l7gooOol04goo00=l07oo
Ool0C7oo00<207ooOol0?Woo00<207ooOol0<7oo0W`067oo0W`0<Goo00<2
07ooOol07Goo00<207ooOol0@Woo01=W>GooIcUoof<HOomW>GooHaQoof<H
OomS67ooIcUoof<HIcU2400200000004IcUoof<HIcTbOol01@80Oomoogoo
0P000Woo00D207ooOomoo`0O00Aoo`0301moogoo00Eoo`0501moogooOol2
000[Ool00g`0Oomoo`0=Ool401l;Ool01080Oomoo`800goo0W`O4goo00=l
07ooOol0C7oo00<207ooOol0?Woo00<207ooOol0<Woo0g`04Woo0g`0<goo
00<207ooOol07Goo00<207ooOol0@goo00iS67ooIcUoof<HOomS67ooIcUo
of<HOomS67oo0f<H0D8@0@000D8@000016<HOomS66<H<Goo00<207ooOol0
0Woo00@207ooOol200=oo`0301moogoo00=oo`0301moogoo00Aoo`0501mo
ogooOol2000/Ool00g`0Oomoo`0;Ool00`0OOomoo`0201l6Ool00`0OOomo
o`02Ool01080Oomoo`8017oo00<207`OOol047oo00=l07ooOol0CGoo00<2
07ooOol0?Woo00<207ooOol0=Goo17`02Woo17`0=Woo00<207ooOol07Goo
00<207ooOol0@Woo011W>GooHaQoof<HOomW>GooHaQoof<HOomW>GooHaQo
o`9S60524040005S600000AW>GooHaQW>C1oo`030P1oogoo00Ioo`050P1o
ogooOol07`05Ool00`0OOomoo`02Ool201l4Ool00`80Oomoo`0ZOol00g`0
Oomoo`0:Ool00`0OOomoo`02Ool00`0OOomoo`0501l4Ool00`80Oomoo`06
Ool00`80O1moo`0?Ool00g`0Oomoo`1=Ool00`80Oomoo`0nOol00`80Oomo
o`0iOol:O00jOol00`80Oomoo`0MOol00`80Oomoo`13Ool03VLiOomS67oo
HaQoof<HOomS67ooHaQoof<HOol3HaP1@Q010001HaP00004HaQoof<HHaP_
Ool00`80Oomoo`07Ool01@80Oomoogoo01l01Goo00<07gooOol00Woo00<0
7gooOol00goo00<207ooOol0:Woo00=l07ooOol02Woo00<07gooOol00goo
00@07gooOol07`9oo`0301moogoo009oo`030P1oogoo00Moo`03O1moogoo
00ioo`03O01oogoo04eoo`030P1oogoo03ioo`030P1oogoo07eoo`030P1o
ogoo01eoo`030P1oogoo049oo`0@IcUoof<HOomW>GooHaQoofLiOomS67oo
HaQoof<HOol2HaP1@Q010001HaP00004IcUoof<HIcTnOol01@0OOomoogoo
01l01Woo00<07gooOol00Woo00<207ooOol0:goo00=l07ooOol02Goo00<0
7gooOol00goo00@07gooOol07`9oo`0301moogoo00aoo`03O1moogoo00eo
o`03O01oogoo04ioo`030P1oogoo03ioo`030P1oogoo07eoo`030P1oogoo
01eoo`030P1oogoo04=oo`0>IcUoof<HOomS67ooHaQoofLiOomS67ooIcUo
o`=S60524040005S600000AS67ooHaQS62ioo`0301moogoo00ioo`<07`Ao
o`@07`Aoo`030P1oogoo02]oo`03O01oogoo00Uoo`0301moogoo00=oo`07
01moogooOol07goo01l03Woo00=l7`0OOol03Goo00=l07ooOol0CWoo00<2
07ooOol0?Woo00<207ooOol0OGoo00<207ooOol07Goo00<207ooOol0@Woo
01AW>GooHaQoofLiOomS67ooHaQoof<HOomS67ooHaQoof<HIcU240000Goo
000016LiOomS66Li;Woo00<07gooOol07Goo00<207ooOol0;7oo00=l07oo
Ool02Goo00D07gooOomoo`0O00Eoo`807`ioo`03O1l07goo00aoo`03O01o
ogoo04moo`030P1oogoo03ioo`030P1oogoo07eoo`030P1oogoo01eoo`03
0P1oogoo04=oo`0>IcUoof<HOomS67ooIcUoof<HOomW>GooHaQoo`=S6052
4040005S600000AS67ooHaQS62ioo`0301moogoo01eoo`030P1oogoo02ao
o`03O01oogoo00Yoo`<07`Ioo`807`ioo`03O1l07goo00aoo`03O01oogoo
04moo`030P1oogoo03ioo`030P1oogoo07eoo`030P1oogoo01eoo`030P1o
ogoo049oo`0@IcUoof<HOomW>GooHaQoof<HOomS67ooHaQoofLiOol2HaP1
@Q010001Ool00004IcUoof<HIcT^Ool00`0OOomoo`0MOol00`80Oomoo`0/
Ool00g`0Oomoo`0SOol00g`O01moo`0<Ool00g`0Oomoo`1?Ool00`80Oomo
o`0nOol00`80Oomoo`1mOol00`80Oomoo`0MOol00`80Oomoo`13Ool03VLi
OomS67ooHaQoof<HOomW>GooHaQoof<HOol3HaP1@Q010001HaP00004HaQo
of<HHaP^Ool00`0OOomoo`0MOol00`80Oomoo`0]Ool00g`0Oomoo`0ROol0
0g`O01moo`0;Ool00g`0Oomoo`1@Ool00`80Oomoo`0nOol00`80Oomoo`1m
Ool00`80Oomoo`0MOol00`80Oomoo`12Ool056LiOomS67ooIcUoof<HOomS
67ooHaQoofLiOomS67ooHaQW>D8@0001Ool00004IcUoof<HIcT^Ool00`0O
Oomoo`0MOol00`80Oomoo`0]Ool00g`0Oomoo`0ROol00g`O01moo`0;Ool0
0g`0Oomoo`1@Ool00`80Oomoo`0nOol00`80Oomoo`1mOol00`80Oomoo`0M
Ool00`80Oomoo`13Ool03VLiOomS67ooHaQoofLiOomS67ooHaQoof<HOol3
HaP1@Q010001HaP00004HaQoof<HHaP^Ool00`0OOomoo`0MOol00`80Oomo
o`0]Ool00g`0Oomoo`0ROol00g`O01moo`0;Ool00g`0Oomoo`1@Ool00`80
Oomoo`0nOol00`80Oomoo`1mOol00`80Oomoo`0MOol00`80Oomoo`12Ool0
46LiOomS67ooHaQoof<HOomS67ooIcUoof<HOomS67oo0V<H0D8@0@000Goo
000016LiOomS66Li;Woo00<07gooOol07Goo00<207ooOol0;Woo00=l07oo
Ool08Goo00=l7`0OOol02Woo00=l07ooOol0DGoo00<207ooOol0?Woo00<2
07ooOol0OGoo00<207ooOol07Goo00<207ooOol0@goo00iS67ooIcUoofLi
OomS67ooHaQoof<HOomS67oo0f<H0D8@0@000F<H000016<HOomS66<H;Woo
00<07gooOol07Goo00<207ooOol0;Woo00=l07ooOol08Goo00=l7`0OOol0
2Woo00=l07ooOol0DGoo00<207ooOol0?Woo00<207ooOol0OGoo00<207oo
Ool07Goo00<207ooOol0@Woo01AW>GooHaQoof<HOomS67ooIcUoof<HOomW
>GooHaQoof<HIcU240000Goo000016LiOomS66Li;Woo00<07gooOol07Goo
00<207ooOol0;goo00=l07ooOol087oo00=l7`0OOol02Goo00=l07ooOol0
DWoo00<207ooOol0?Woo00<207ooOol0OGoo00<207ooOol07Goo00<207oo
Ool0@goo00iS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo0f<H0D8@0@00
0F<H000016<HOomS66<H;Woo00<207ooOol07Goo00<207ooOol0;goo00=l
07ooOol087oo00=l7`80Ool02Goo00=l07ooOol0DWoo00<207ooOol0?Woo
00<07gooOol0OGoo00<207ooOol07Goo00<207ooOol0@Woo40000V<H0D8@
0@000Goo000016LiOomS66Li;Woo00<207ooOol07Goo00<207ooOol0<7oo
00=l07ooOol07goo00=l7`80Ool027oo00=l07ooOol0Dgoo00<207ooOol0
?Woo00<07gooOol0OGoo00<207ooOol07Goo00<207ooOol0@Woo00=W>D8@
@Q00348@00D006<HHaQ24000005S600000AS67ooHaQS62ioo`030P1oogoo
01eoo`030P1oogoo031oo`03O01oogoo01moo`03O1l207oo00Qoo`03O01o
ogoo05=oo`030P1oogoo03ioo`0301moogoo07eoo`030P1oogoo01eoo`03
0P1oogoo049oo`0@HaQoofLiHaQW>F<HIcUS66LiHaQW>F<HIcUS648@0002
HaP1@Q010001Ool00004IcUoof<HIcT^Ool00`80Oomoo`0MOol00`80Oomo
o`0aOol00g`0Oomoo`0NOol00g`O0P1oo`07Ool00g`0Oomoo`1DOol00`80
Oomoo`0nOol00`0OOomoo`1mOol00`80Oomoo`0MOol00`80Oomoo`12Ool0
0fLiOomS600;HaP01T8@001S66<H@Q00005S600000AS67ooHaQS62ioo`03
0P1oogoo01eoo`030P1oogoo035oo`03O01oogoo01ioo`03O1l207oo00Mo
o`03O01oogoo05Aoo`030P1oogoo03ioo`0301moogoo07eoo`030P1oogoo
01eoo`030P1oogoo049oo`03HaQoof<H00]S6006@Q0006<HHaQ240000Goo
000016LiOomS66Li;Woo00<207ooOol00Woo0`0O67oo00<207ooOol0<Woo
00=l07ooOol07Goo00=l7`80Ool01Woo00=l07ooOol0EGoo00<207ooOol0
?Woo00<07gooOol0OGoo00<207ooOol07Goo00<207ooOol0@Woo00=W>Goo
HaP00f<H00AW>F<HHaQW>@9S6004IcUS648@0002HaP1@Q010001HaP00004
HaQoof<HHaP^Ool01@80Oomoogoo01l00goo00<07gooOol05Goo00<207oo
Ool0<goo00=l07ooOol077oo00=l7`80Ool00goo00<07gooO000F7oo00<2
07ooOol0?Woo00<07gooOol0OGoo00<207ooOol07Goo00<207ooOol0@Woo
00IS67ooHaQW>F<HIcT2HaP016LiHaQS66Li0V<H00I24000HaQS648@0001
Ool00004IcUoof<HIcT^Ool01@80Oomoogoo01l00goo00<07gooOol05Goo
00<207ooOol0<goo00=l07ooOol077oo00=l7`80Ool00goo00<07gooO000
F7oo00<207ooOol0?Woo00<07gooOol0OGoo00<207ooOol07Goo00<207oo
Ool0@Woo00=W>GooHaP02f<H00I24000HaQS648@0001HaP00004HaQoof<H
HaP^Ool00`80Oomoo`0201l3Ool00`0OOomoo`0EOol00`80Oomoo`0dOol0
0g`0Oomoo`0KOol00g`O0P1oo`04Ool00g`0Oomoo`1GOol00`80Oomoo`0n
Ool00`0OOomoo`1mOol00`80Oomoo`0MOol00`80Oomoo`12Ool046<HOomS
66<HIcUS66LiHaQW>F<HIcUS66LiHaQ240000V<H0D8@0@000Goo000016Li
OomS66Li;Woo00<207ooOol01@0O67oo00<207ooOol0=Goo00=l07ooOol0
6Woo00=l7`80Ool00goo00=l000OOol0F7oo00<207ooOol0?Woo00<07goo
Ool0OGoo00<207ooOol07Goo00<207ooOol0@Woo00AS67ooHaQW>@YS6006
@Q0006<HHaQ240000F<H000016<HOomS66<H;Woo00D07gooOomoo`0O01]o
o`030P1oogoo03Ioo`03O01oogoo01Uoo`03O1l07goo009oo`04O01oogoo
01mHOol00`80Oomoo`0nOol00`80Oomoo`1mOol00`80Oomoo`0MOol00`80
Oomoo`0nOol40P000f<HOomS6002HaP01fLiHaQW>F<HIcUS66Li009S6006
@Q0006<HHaQ240000Goo000016LiOomS66Li;Woo00D07gooOomoo`0O01]o
o`030P1oogoo03Ioo`03O01oogoo01Uoo`03O1l07goo009oo`04O01oogoo
01mHOol00`80Oomoo`0nOol00`80Oomoo`1mOol00`80Oomoo`0MOol00`80
Oomoo`0nOol01P80OomoogooHaQoo`9S6003IcUS66<H00MS6006@Q0006<H
HaQ240000F<H000016<HOomS66<H;Woo00<07gooOol00Woo0`0O67oo00<2
07ooOol0=goo00=l07ooOol067oo00El7`0OOomoog`000D07eMoo`030P1o
ogoo03eoo`8207moo`030P1oogoo01eoo`030P1oogoo03ioo`060P1oogoo
OomW>Goo16<H00YW>F<HIcUS66LiHaQW>F<H@Q00009S60524040005oo`00
00AW>GooHaQW>Bioo`0301moogoo01eoo`030P1oogoo03Qoo`03O01oogoo
01Moo`04O1l07gooO01MOol00`80Oomoo`0kOol20P21Ool00`80Oomoo`0M
Ool00`80Oomoo`0nOol02P80OomoogooHaQoof<HIcUS66Li26<H00I24000
HaQS648@0001HaP00004HaQoof<HHaP^Ool00`0OOomoo`0MOol00`80Oomo
o`0iOol00g`0Oomoo`0FOol00g`O01ml001NOol00`80Oomoo`0[Ool401l:
Ool20P23Ool00`80Oomoo`0MOol00`80Oomoo`0nOol01@80OomoogooIcT0
3Goo00I24000HaQS648@0001Ool00004IcUoof<HIcT^Ool00`0OOomoo`0M
Ool00`80Oomoo`0jOol2O00FOol00g`OO01oo`1NOol00`80Oomoo`0WOol0
1@0OOomoogoo01l00Woo00@07gooOol07`9oo`0301moogoo00Aoo`<2081o
o`030P1oogoo01eoo`030P1oogoo03ioo`040P1oogooOol?HaP01@00HaQS
648@00000F<H000016<HOomS66<H;Woo00<07gooOol07Goo00<207ooOol0
?7oo00=l07ooOol04Woo00=l07`O01l0Ggoo00<207ooOol08goo1@0O0Woo
00<07gooOol00Woo00<07goo01l00P0O2Woo0`80OGoo00<207ooOol07Goo
00<207ooOol0?Woo01@207ooOomoofLiOomS67ooHaQoof<HOomS67ooHaQo
of<HOomS67oo0V<H0D8@0@000Goo000016LiOomS66Li;Woo00<07gooOol0
7Goo00<207ooOol0?Goo0W`047oo0W`000=oog`O01l0Ggoo00<207ooOol0
97oo00@07gooOol07`9oo`0301moogoo009oo`0501moo`0OOol07`0=Ool2
0P1kOol00`80Oomoo`0MOol00`80Oomoo`0nOol00`80Oomoo`02Ool03V<H
OomS67ooHaQoof<HOomS67ooHaQoof<HOol3HaP1@Q010001HaP00004HaQo
of<HHaP^Ool00`0OOomoo`0MOol00`80Oomoo`0oOol00g`0Oomoo`0<Ool0
1W`0OomoogooO1l07emoo`030P1oogoo02Aoo`0401moogoo01l2Ool00`0O
Oomoo`02Ool00`0OOol07`02Ool00`0OOomoo`07Ool30P1mOol00`80Oomo
o`0MOol00`80Oomoo`0nOol06080OomoogooIcUoof<HOomS67ooHaQoof<H
OomS67ooHaQoof<HOomS66Li@Q00005oo`0000AW>GooHaQW>Bioo`0301mo
ogoo01eoo`030P1oogoo041oo`El00Aoo`El00Aoo`03O1l07goo05ioo`03
0P1oogoo02Eoo`0301moo`0O009oo`0301moogoo009oo`0301moo`0O00=o
o`0301moogoo00=oo`<2081oo`030P1oogoo01eoo`030P1oogoo03ioo`03
0P1oogoo009oo`0>HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoo`=S6052
4040005S600000AS67ooHaQS62ioo`0301moogoo01eoo`030P1oogoo04Eo
o`Al00Uoo`03O1l07goo05ioo`030P1oogoo02Ioo`807`=oo`0701moogoo
Ool07goo01l01goo0P80Pgoo00<207ooOol07Goo00<207ooOol0?Woo01@2
07ooOomoofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo0V<H0D8@
0@000Goo000016LiOomS66LiCWoo00<207ooOol0DGoo00=l7gooOol0Ggoo
00<207ooOol09Woo0P0O0goo100O0Woo00<07gooOol01goo0`80P7oo00<2
07ooOol07Goo00<207ooOol0?Woo00<207ooOol00Woo00iS67ooIcUoof<H
OomS67ooIcUoof<HOomW>Goo0f<H0D8@0@000F<H000016<HOomS66<H0Woo
00<07gooOol07Woo00<207ooOol01goo00<207ooOol07Woo00<207ooOol0
DWoo00=l7goo0P002Goo00<207ooOol0DWoo00<207ooOol0?Woo0`80OGoo
00<207ooOol07Goo00<207ooOol0?Woo01P207ooOomoofLiOomS67ooHaQo
ofLiOomS67ooHaQoof<HOomS67ooHaQW>D8@0001Ool00004IcUoof<HHaP3
01lPOol00`80Oomoo`02Ool50P0QOol00`80Oomoo`1COol00g`OOol20004
0P04Ool00`80Oomoo`1BOol00`80Oomoo`11Ool20P1kOol00`80Oomoo`0M
Ool00`80Oomoo`0nOol00`80Oomoo`02Ool03V<HOomS67ooHaQoof<HOomS
67ooIcUoof<HOol3HaP1@Q010001HaP00004HaQoofLiHaP2Ool00`0OOomo
o`0NOol00`80Oomoo`05Ool20P0QOol00`80Oomoo`1DOol00g`O0P020007
Ool00`80Oomoo`1BOol00`80Oomoo`0bOol401l9Ool20P1mOol00`80Oomo
o`0MOol00`80Oomoo`0nOol05080OomoogooIcUoofLiOomS67ooHaQoofLi
OomS67ooHaQoofLiOol2HaP1@Q010001Ool00004IcUoof<HHaP2Ool00`0O
Oomoo`0NOol00`80Oomoo`04Ool00`80Ool2000QOol00`80Oomoo`1EOol0
0g`OOol20006Ool00`80Oomoo`1BOol00`80Oomoo`0ZOol01@0OOomoogoo
01l01goo00<07gooOol017oo0P80Ogoo00<207ooOol07Goo00<207ooOol0
?Woo00<207ooOol00Woo00iS67ooHaQoofLiOomS67ooHaQoof<HOomS67oo
0f<H0D8@0@000F<H00001f<HOomS66<H01moo`0O021oo`030P1oogoo00=o
o`040P1oogoo0P0QOol00`80Oomoo`1EOol01080O1moo`801Goo00<207oo
Ool0DWoo00<207ooOol0:Woo00D07gooOomoo`0O00Moo`0301moogoo009o
o`82085oo`030P1oogoo01eoo`030P1oogoo03ioo`0H0P1oogooOomW>Goo
HaQoof<HOomS67ooHaQoofLiOomS67ooHaQoof<HIcU240000Goo00001FLi
OomS66LiOol00P0O87oo00<207ooOol00Woo00D207ooOomoo`80025oo`03
0P1oogoo05Eoo`050P1oog`OOol20004Ool00`80Oomoo`1BOol00`80Oomo
o`0ZOol0100OOomoo`0O27oo00<07gooOol00P80Pgoo00<207ooOol07Goo
00<207ooOol0?Woo00<207ooOol00Woo00iS67ooIcUoof<HOomW>GooHaQo
of<HOomS67oo0f<H0D8@0@000F<H00001F<HOomS66<HOol00P0O87oo00D2
07ooOomoo`8000Aoo`030P1oogoo01moo`030P1oogoo025oo`@07c1oo`06
0P1oogooO1moo`800goo00<207ooOol0DWoo00<207ooOol0:Woo1P0O1Goo
00<07gooOol00goo0`80P7oo00<207ooOol07Goo00<207ooOol0?Woo01@2
07ooOomoofLiOomS67ooHaQoof<HOomS67ooHaQoofLiOomS67oo0V<H0D8@
0@000Goo000016LiOomS66Li8goo00@207ooOol200Eoo`030P1oogoo01mo
o`030P1oogoo021oo`0301moogoo00807`9oo`0301moogoo009oo`0401mo
ogoo01l6Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`06Ool0
0`0OOomoo`03Ool00`0OOomoo`03Ool01`80OomoogooO1moo`80009oo`03
0P1oogoo059oo`030P1oogoo02Yoo`0301moogoo009oo`0301moogoo00<0
7`Uoo`<207eoo`030P1oogoo01eoo`030P1oogoo03ioo`030P1oogoo009o
o`0>IcUoof<HOomW>GooHaQoofLiOomS67ooHaQoo`=S60524040005S6000
00AS67ooHaQS62=oo`030P1oo`8000ioo`@07aIoo`030P1oogoo01moo`03
01moogoo009oo`0401moogoo01l3Ool201l2Ool00`0OOomoo`04Ool0100O
Oomoogoo0P0O17oo00<07gooOol00Woo1@0O1Goo00<07gooOol027oo00El
7goo0P1oo`8005Aoo`030P1oogoo02Yoo`0301moogoo009oo`0401moogoo
01l>Ool20P1kOol00`80Oomoo`0MOol00`80Oomoo`0nOol06080Oomoogoo
IcUoof<HOomS67ooHaQoof<HOomS67ooIcUoof<HOomS66Li@Q00005oo`00
00AW>GooHaQW>B=oo`8200ioo`0301moogoo00807`9oo`0301moogoo009o
o`0401moogoo01l6Ool00`0OOomoo`02Ool00`80Oomoo`02Ool00`0OOomo
o`06Ool00`0OOomoo`03Ool00`0OOomoo`0;Ool00`0OOomoo`03Ool00`0O
Ool07`02Ool00`0OOol07`02Ool401l3Ool01P0OOomoo`0OOol07`Eoo`03
01moogoo009oo`0401moogoo01l5Ool00`0OOomoo`09OolIO1loOol00`80
Oomoo`0ZOol601l2Ool401l:Ool20P1lOol00`80Oomoo`0MOol00`80Oomo
o`0nOol00`80Oomoo`02Ool03V<HOomW>GooHaQoof<HOomW>GooHaQoof<H
Ool3HaP1@Q010001HaP00004HaQoof<HHaP3OolG0P0901l00`80Oomoo`0<
Ool00`0OOomoo`02Ool0100OOomoo`0O0goo0P0O0Woo00<07gooOol017oo
00H07gooOomoo`0O0P04Ool00`0OOomoo`02Ool501l5Ool00`0OOomoo`0;
Ool00`0OOomoo`03Ool00`0OOol07`02Ool00`0OOol07`02Ool0100OOomo
ogoo0P0O00Moo`0OOomoo`0OOol07`05Ool00`0OOomoo`02Ool0100OOomo
o`0O1Goo00<07gooOol037oo00<2000O01l01`0O2`8000=l7gooOol0?Goo
00<207ooOol0?goo00<207ooOol0O7oo00<207ooOol07Goo00<207ooOol0
?Woo01@207ooOomoofLiOomS67ooHaQoofLiOomS67ooHaQoof<HOomS67oo
0V<H0D8@0@000Goo000016LiOomS66Li0goo00<207ooOol07Goo0P803Goo
00<07gooOol00goo00<07goo01l00Woo00<07goo01l00Woo100O0goo00H0
7gooOol07goo0P05Ool00`0OOomoo`02Ool0100OOomoo`0O1Goo00<07goo
Ool02goo00<07gooOol00goo00D07goo01moo`0O009oo`0401moogoo01l4
Ool01@0OOol07goo01l00Woo00<07gooOol017oo00<07gooOol00Woo00<0
7goo01l01Goo00<07gooOol02goo0P8057oo00=l7gooOol0?Goo00<207oo
Ool0?Woo00<07gooOol0OGoo00<207ooOol07Goo00<207ooOol0?Woo00<2
07ooOol00Woo00iS67ooIcUoof<HOomS67ooHaQoof<HOomW>Goo0f<H0D8@
0@000F<H000016<HOomS66<H0goo00<207ooOol07Goo00<207oo0P0037oo
00<07gooOol00goo00<07goo01l00Woo00<07goo01l00Woo00@07gooOomo
o`807`07Ool07gooOol07goo0P001Goo00<07gooOol00Woo00@07gooOol0
7`Eoo`0301moogoo00aoo`0501moogooOol07`02Ool201l3Ool0100OOomo
o`0O17oo00@07goo01l07`=oo`0301moogoo00Aoo`0301moogoo00=oo`80
7`=oo`<07`aoo`030P1oo`8001Aoo`03O1moogoo03eoo`030P1oogoo03io
o`0301moogoo07eoo`030P1oogoo01eoo`030P1oogoo03ioo`0H0P1oogoo
OomW>GooHaQoof<HOomW>GooHaQoofLiOomS67ooHaQoof<HIcU240000Goo
000016LiOomS66Li0goo00<207ooOol047oo100O2Goo00@207ooOol200]o
o`0301moogoo00=oo`0501moo`0OOol07`02Ool0100OOomoo`0O17oo00D0
7goo01moo`0O009oo`030P1oogoo00Aoo`0301moogoo009oo`0301moo`0O
00Eoo`0301moogoo00eoo`<07`=oo`807`=oo`0301moogoo00H07`03Ool0
7`0O00=oo`0301moogoo00H07`Aoo`807`Eoo`0301moogoo00Uoo`040P1o
ogoo0P0DOol00g`OOomoo`0mOol00`80Oomoo`0nOol00`0OOomoo`1mOol0
0`80Oomoo`0MOol00`80Oomoo`0nOol00`80Oomoo`02Ool03V<HOomS67oo
HaQoofLiOomS67ooHaQoof<HOol3HaP1@Q010001HaP00004HaQoof<HHaP3
Ool00`80Oomoo`0?Ool00`0OOomoo`0201l5Ool01@0OOomoogoo0P000goo
00<207ooOol02Goo00D07gooOomoo`0O009oo`807`=oo`0401moogoo01l4
Ool0100OOol07`0O0goo00<207ooOol017oo00<07gooOol00goo0P0O0goo
0`0OB7oo00D207ooOomoo`8001Aoo`03O1moogoo03eoo`030P1oogoo03io
o`0301moogoo07eoo`030P1oogoo01eoo`030P1oogoo03ioo`0D0P1oogoo
OomW>GooIcUoof<HOomS67ooHaQoofLiOomS67ooIcUoo`9S60524040005o
o`0000AW>GooHaQW>@=oo`030P1oogoo00ioo`0301moogoo009oo`0301mo
ogoo00=oo`0501moogooOol20004Ool00`80Oomoo`09Ool301l3Ool201l3
Ool00`0OOomoo`0601l00goo01l07`03Ool00`80Oomoo`0601l4Ool201l5
Ool00`0OOomoo`15Ool00`80Oomoo`02Ool01080Oomoogoo100O0Woo1@0O
1Woo00=l7gooOol0?Goo00<207ooOol0?Woo00<07gooOol0OGoo00<207oo
Ool07Goo00<207ooOol0?Woo00<207ooOol00Woo00iS67ooHaQoofLiOomS
67ooHaQoof<HOomS67oo0f<H0D8@0@000F<H000016<HOomS66<H0goo00<2
07ooOol03Woo00<07gooOol00goo00<07gooOol00Woo00D07gooOomoo`80
00Eoo`030P1oogoo029oo`030P1oogoo05Qoo`030P1oogoo00=oo`040P1o
ogoo01l2Ool201l3Ool00`0OOomoo`07Ool00g`OOomoo`0mOol00`80Oomo
o`0nOol00`0OOomoo`1mOol00`80Oomoo`0MOol00`80Oomoo`0nOol06080
OomoogooIcUoof<HOomS67ooHaQoofLiOomS67ooIcUoof<HOomS66Li@Q00
005oo`0000AW>GooHaQW>@=oo`030P1oogoo00ioo`0301moogoo00=oo`03
01moogoo009oo`0501moogooOol20006Ool00`80Oomoo`0QOol00`80Oomo
o`1GOol00`80Oomoo`04Ool00`80Ool07`04Ool00`0OOomoo`02Ool00`0O
Oomoo`06Ool00g`OOomoo`0mOol00`80Oomoo`0nOol00`0OOomoo`1mOol0
0`80Oomoo`0MOol00`80Oomoo`0nOol00`80Oomoo`02Ool03V<HOomW>Goo
HaQoof<HOomS67ooHaQoof<HOol3HaP1@Q010001HaP00004HaQoof<HHaP3
Ool00`80Oomoo`0>Ool00`0OOomoo`03Ool00`0OOomoo`02Ool01@0OOomo
ogoo0P001goo00<207ooOol087oo00<207ooOol0EWoo00<207ooOol01Goo
00<207oo01l01Goo00<07gooOol00Woo00<07gooOol01Goo00=l7gooOol0
?Goo00<207ooOol0?Woo00<07gooOol0OGoo00<207ooOol07Goo00<207oo
Ool0?Woo01@207ooOomoofLiOomS67ooHaQoofLiOomS67ooIcUoof<HOomS
67oo0V<H0D8@0@000Goo000016LiOomS66Li0goo00<207ooOol03goo00D0
7gooOomoo`0O00=oo`<07`=oo`030P1oogoo00Ioo`030P1oogoo01moo`03
0P1oogoo05Eoo`030P1oogoo00Ioo`030P1oo`0O00Eoo`0301moogoo00=o
o`0301moogoo00Aoo`03O1moogoo03eoo`030P1oogoo03ioo`0301moogoo
07eoo`030P1oogoo01eoo`030P1oogoo03ioo`030P1oogoo009oo`0>IcUo
of<HOomS67ooHaQoof<HOomS67ooHaQoo`=S60524040005S600000AS67oo
HaQS60=oo`030P1oogoo011oo`<07`Ioo`0501moogooOol20009Ool00`80
Oomoo`0NOol00`80Oomoo`1DOol00`80Oomoo`07Ool00`80Ool07`05Ool0
0`0OOomoo`04Ool00`0OOomoo`03Ool00g`OOomoo`0mOol00`80Oomoo`0n
Ool00`0OOomoo`1mOol00`80Oomoo`0MOol00`80Oomoo`0nOol06080Oomo
ogooIcUoof<HOomW>GooHaQoofLiOomS67ooIcUoof<HOomS66Li@Q00005o
o`0000AW>GooHaQW>@=oo`0301moogoo01eoo`030P1oogoo00Qoo`030P1o
ogoo01eoo`030P1oogoo05=oo`030P1oogoo00Qoo`040P1oogoo01l3Ool0
1@0OOomoogoo01l00goo00<07gooOol00goo00=l7gooOol0?Goo00<207oo
Ool0?Woo00<207ooOol0OGoo00<207ooOol07Goo00<207ooOol0?Woo1080
00moofLiOomS67ooHaQoof<HOomS67ooHaQoof<HOol00f<H0D8@0@000F<H
000016<HOomS66<H0goo00<07gooOol0:7oo00<07gooOol07Goo00<207oo
Ool0Dgoo00<07gooOol037oo0`0O17oo100O1Woo00=l7gooOol0?Goo00<2
07ooOol0?Woo00<207ooOol0OGoo00<207ooOol07Goo00<207ooOol0@Woo
011W>GooHaQoofLiOomS67ooHaQoofLiOomS67ooIcUoo`9S60524040005o
o`0000AW>GooHaQW>@=oo`0301moogoo02Qoo`0301moogoo01eoo`030P1o
ogoo05=oo`0301moogoo01eoo`03O1moogoo03eoo`030P1oogoo03ioo`03
0P1oogoo07eoo`030P1oogoo01eoo`030P1oogoo04=oo`0>IcUoof<HOomS
67ooIcUoof<HOomS67ooHaQoo`=S60524040005S600000AS67ooHaQS60=o
o`0301moogoo02Qoo`0301moogoo01eoo`030P1oogoo05=oo`0301moogoo
01eoo`03O1moogoo03eoo`030P1oogoo03ioo`030P1oogoo07eoo`030P1o
ogoo01eoo`030P1oogoo049oo`0DIcUoof<HOomW>GooHaQoof<HOomS67oo
IcUoof<HOomS66Li@Q00005oo`0000AW>GooHaQW>@=oo`0301moogoo02Qo
o`0301moogoo01eoo`030P1oogoo05=oo`0301moogoo01eoo`03O1moogoo
03eoo`030P1oogoo03ioo`030P1oogoo07eoo`030P1oogoo01eoo`030P1o
ogoo04=oo`0>IcUoof<HOomS67ooHaQoofLiOomS67ooHaQoo`=S60524040
005S600000AS67ooHaQS60=oo`0301moogoo02Qoo`0301moogoo01eoo`03
0P1oogoo05=oo`0301moogoo01eoo`03O1moogoo03eoo`030P1oogoo03io
o`030P1oogoo03Ioo`<07dAoo`030P1oogoo01eoo`030P1oogoo049oo`0@
IcUoof<HOomW>GooHaQoof<HOomS67ooHaQoof<HOol2HaP1@Q0100010000
0004IcUoof<HIcT3Ool00`0OOomoo`0XOol00`0OOomoo`0MOol00`80Oomo
o`1COol00`0OOomoo`0MOol00g`OOomoo`0mOol00`80Oomoo`0nOol00`80
Oomoo`0`Ool00`0OOomoo`02Ool01@0OOomoogoo01l0@goo00<207ooOol0
67oo17`000=oo`80Ool0A7oo00iW>GooHaQoof<HOomW>GooHaQoofLiOomS
67oo0f<H0D8@0@000D8@000016<HOomS66<H0goo00<07gooOol0:7oo00<0
7gooOol07Goo00<207ooOol0Dgoo00<07gooOol07Goo00=l7gooOol0?Goo
00<207ooOol0?Woo00<207ooOol0<7oo00<07gooOol00Woo00D07gooOomo
o`0O04=oo`030P1oogoo01Ioo`9l00Aoo`9l04Aoo`0@IcUoof<HOomS67oo
HaQoof<HOomS67ooHaQoofLiOol2HaP1@Q010001HaP00004IcUoof<HIcT3
Ool00`0OOomoo`0XOol00`0OOomoo`0MOol00`80Oomoo`0VOol501lXOol0
0`0OOomoo`0MOol00g`OOomoo`0mOol00`80Oomoo`0nOol00`80Oomoo`0`
Ool0100OOomoogoo0P0O0goo00<07gooOol0@Goo00<207ooOol057oo0W`0
1goo00<207`0O000@goo00iS67ooIcUoofLiOomS67ooHaQoofLiOomS67oo
0f<H0D8@0@000F<H000016<HOomS66<H0goo00<07gooOol0:7oo00<07goo
Ool07Goo00<207ooOol09goo00<07gooOol0:Goo00<07gooOol07Goo00=l
7gooOol0?Goo00<207ooOol0?Goo0P0O<Woo00@07gooOomoo`D07dAoo`03
0P1oogoo01=oo`03O01oogoo00Moo`040P1oogooO011Ool056LiOomS67oo
HaQoof<HOomW>GooHaQoof<HOomS67ooHaQW>D8@0001HaP00004IcUoof<H
IcT^Ool00`0OOomoo`0MOol00`80Oomoo`0XOol00`0OOomoo`0XOol00`80
Oomoo`0MOol00g`OOomoo`0mOol00`80Oomoo`0lOol401lZ0P07Ool00`0O
Oomoo`02Ool00`0OOomoo`15Ool00`80Oomoo`0COol00g`0Oomoo`07Ool0
1080Oomoog`07Goo908000moof<HOomS67ooHaQoof<HOomS67ooHaQoofLi
Ool00f<H0D8@0@000F<H00001F<HOomS66<HOol01@80:7oo00<207ooOol0
7Goo00<207ooOol0:Goo00<07gooOol09goo00<207ooOol07Goo00=l7goo
Ool0?Goo00<207ooOol0?7oo100O:Goo00<207ooOol00goo0`0O17oo00<0
7gooOol0AGoo00<207ooOol04Woo00=l07ooOol027oo00D207ooOomoog`0
01aoo`030P1oogoo025oo`0@IcUoof<HOomW>GooHaQoof<HOomW>GooHaQo
of<HOol2HaP1@Q01000100000005IcUoof<HHaP20002Ool00`80Oomoo`02
0P0VOol00`80Oomoo`0MOol00`80Oomoo`0ZOol00`0OOomoo`0VOol00`80
Oomoo`0MOol00g`OOomoo`0mOol00`80Oomoo`0mOol201lZOol00`80Oomo
o`05Ool00`0OOomoo`03Ool301m4Ool00`80Oomoo`0AOol00g`0Oomoo`09
Ool00`80Oomoo`02Ool00g`0Oomoo`0IOol00`80Oomoo`0ROol03V<HOomS
67ooHaQoofLiOomS67ooHaQoof<HOol3HaP1@Q010001HaP00004HaQoofLi
HaP3Ool00`80Oomoo`02Ool20P0TOol00`80Oomoo`0MOol00`80Oomoo`0[
Ool00`0OOomoo`0UOol00`80Oomoo`0MOol00g`OOomoo`0mOol00`80Oomo
o`0nOol00`80Oomoo`0XOol00`80Oomoo`1BOol00`80Oomoo`0@Ool00g`0
Oomoo`0:Ool00`80Oomoo`03Ool00g`0Oomoo`0HOol00`80Oomoo`0QOol0
46LiOomW>GooHaQoof<HOomS67ooHaQoofLiOomS67oo0V<H0D8@0@000F<H
00001FLiOomS66LiOol01@8017oo00<207ooOol08Goo00<207ooOol07Goo
00<207ooOol09goo00D07gooOomoo`0O02Moo`030P1oogoo01eoo`03O1mo
ogoo03eoo`030P1oogoo03ioo`030P1oogoo02Qoo`030P1oogoo059oo`03
0P1oogoo011oo`03O01oogoo00Yoo`030P1oogoo00=oo`03O01oogoo01Qo
o`030P1oogoo029oo`0>HaQoof<HOomW>GooHaQoofLiOomS67ooHaQoo`=S
60524040005S600000AS67ooIcUS60=oo`030P1oogoo00Eoo`030P1oogoo
021oo`030P1oogoo01eoo`030P1oogoo02Moo`@07bQoo`030P1oogoo01eo
o`03O1moogoo03eoo`030P1oogoo03ioo`030P1oogoo02Qoo`030P1oogoo
059oo`030P1oogoo00moo`03O01oogoo00]oo`030P1oogoo00Aoo`03O01o
ogoo01Moo`030P1oogoo025oo`0DIcUoof<HOomS67ooHaQoof<HOomS67oo
HaQoofLiOomS66Li@Q00005S600000AW>GooHaQW>@=oo`030P1oogoo00Eo
o`030P1oogoo021oo`030P1oogoo01eoo`030P1oogoo05=oo`030P1oogoo
01eoo`03O1moogoo03eoo`030P1oogoo03ioo`030P1oogoo02Qoo`030P1o
ogoo059oo`030P1oogoo00moo`03O01oogoo00]oo`030P1oogoo00Aoo`03
O01oogoo01Moo`030P1oogoo029oo`0>HaQoofLiOomS67ooIcUoof<HOomW
>GooHaQoo`=S60524040005S600000AS67ooHaQS60aoo`030P1oogoo01mo
o`030P1oogoo01eoo`030P1oogoo05=oo`030P1oogoo01eoo`03O1moogoo
03eoo`030P1oogoo03ioo`030P1oogoo02Qoo`030P1oogoo059oo`030P1o
ogoo00ioo`03O01oogoo00aoo`030P1oogoo00Eoo`03O01oogoo01Ioo`03
0P1oogoo025oo`0@IcUoof<HOomS67ooHaQoof<HOomS67ooHaQoof<HOol2
HaP1@Q010001HaP00004IcUoof<HIcT<Ool00`80Oomoo`0OOol00`80Oomo
o`0MOol00`80Oomoo`1COol00`80Oomoo`0MOol00g`OOomoo`0mOol00`80
Oomoo`0nOol00`80Oomoo`0XOol00`80Oomoo`1BOol00`80Oomoo`0>Ool0
0g`0Oomoo`0<Ool00`80Oomoo`05Ool00g`0Oomoo`0FOol00`80Oomoo`0R
Ool03V<HOomS67ooIcUoof<HOomW>GooHaQoof<HOol3HaP1@Q010001HaP0
0004HaQoof<HHaP=Ool00`80Oomoo`0NOol00`80Oomoo`0MOol00`80Oomo
o`1COol00`80Oomoo`0MOol00g`OOomoo`0mOol00`80Oomoo`0nOol00`80
Oomoo`0XOol00`80Oomoo`1BOol00`80Oomoo`0>Ool00g`0Oomoo`0<Ool0
0`80Oomoo`05Ool00g`0Oomoo`0FOol00`80Oomoo`0QOol056LiOomW>Goo
HaQoof<HOomS67ooHaQoofLiOomS67ooHaQW>D8@0001Ool00004IcUoof<H
IcT=Ool00`80Oomoo`0NOol00`80Oomoo`0MOol00`80Oomoo`0WOol201lY
Ool201lOOol00g`OOomoo`0mOol00`80Oomoo`0nOol00`80Oomoo`0XOol0
0`80Oomoo`1BOol00`80Oomoo`0>Ool00g`0Oomoo`0<Ool00`80Oomoo`05
Ool00g`0Oomoo`0FOol00`80Oomoo`0ROol03V<HOomS67ooHaQoofLiOomS
67ooHaQoof<HOol3HaP1@Q010001HaP00004HaQoof<HHaP=Ool00`80Oomo
o`0NOom90P0401lW0P0401lNOol00g`OOomoo`0mOol00`0OOomoo`0nOol0
0`0OOomoo`0XOol00`80Oomoo`1BOol00`80Oomoo`0=Ool00g`0Oomoo`0=
Ool00`0OOomoo`06Ool00g`0Oomoo`0EOol00`80Oomoo`0QOol046LiOomS
67ooIcUoof<HOomS67ooIcUoof<HOomW>Goo0V<H0D8@0@000F<H000016Li
OomS66Li3Goo00<207ooOol0?Woo00<207ooOol09Woo100O9goo100O7Woo
00=l7gooOol0?Goo00<07gooOol0?Woo00<07gooOol0:7oo00<207ooOol0
DWoo00<207ooOol03Goo00=l07ooOol03Goo00<07gooOol01Woo00=l07oo
Ool05Goo00<07gooOol08Woo00iS67ooHaQoof<HOomS67ooHaQoof<HOomS
67oo0f<H0D8@0@000@0@000016<HOomS66<H3Goo00<207ooOol0?Woo00<2
07ooOol09goo0P0O:Goo0P0O7goo00=l7gooOol0?Goo00<07gooOol0?Woo
00<07gooOol0:7oo00<207ooOol0DWoo00<207ooOol03Goo00=l07ooOol0
3Goo00<07gooOol01Woo00=l07ooOol05Goo00<07gooOol08Goo01AW>Goo
IcUoof<HOomW>GooHaQoof<HOomW>GooHaQoof<HIcU240000@0@000016Li
OomS66Li3Goo00<207ooOol0?Woo00<207ooOol0:7oo00<07gooOol0:7oo
00<207ooOol07Goo00=l7gooOol0?Goo00<07gooOol0?Woo00<07gooOol0
:7oo00<207ooOol0DWoo00<207ooOol037oo00=l07ooOol03Woo00<07goo
Ool01goo00=l07ooOol057oo00<07gooOol08Woo00iS67ooHaQoof<HOomS
67ooIcUoof<HOomS67oo0f<H0D8@0@000@00000016<HOomS66<H37oo00<2
07ooOol0?goo00<207ooOol0:7oo00<07gooOol0:7oo00<207ooOol07Goo
00=l7gooOol0?Goo00<07gooOol0?Woo00<07gooOol0:7oo00<207ooOol0
DWoo00<207ooOol037oo00=l07ooOol03Woo00<07gooOol01goo00=l07oo
Ool057oo00<07gooOol08Goo011W>GooHaQoofLiOomS67ooHaQoof<HOomS
67ooHaQoo`9S605240400052400000AW>GooHaQW>@aoo`030P1oogoo03mo
o`030P1oogoo02Qoo`0301moogoo02Qoo`030P1oogoo01eoo`03O1moogoo
03eoo`0301moogoo03ioo`0301moogoo02Qoo`030P1oogoo059oo`030P1o
ogoo00aoo`03O01oogoo00ioo`0301moogoo00Moo`03O01oogoo01Aoo`03
01moogoo029oo`0>HaQoof<HOomS67ooIcUoof<HOomW>GooHaQoo`=S6052
4040005S600000ES67ooHaQS67oo00D200Eoo`030P1oogoo041oo`030P1o
ogoo02Qoo`0301moogoo02Qoo`030P1oogoo01eoo`03O1moogoo03eoo`03
01moogoo03ioo`0301moogoo02Qoo`030P1oogoo059oo`030P1oogoo00ao
o`03O01oogoo00ioo`0301moogoo00Moo`03O01oogoo01Aoo`0301moogoo
025oo`0@IcUoofLiOomS67ooHaQoof<HOomS67ooHaQoofLiOol2HaP1@Q01
0001HaP00004IcUoof<HIcT;Ool00`80Oomoo`10Ool00`80Oomoo`0XOol0
0`0OOomoo`0XOol00`80Oomoo`0MOol00g`OOomoo`0mOol00`0OOomoo`0n
Ool00`0OOomoo`0XOol00`80Oomoo`1BOol00`80Oomoo`0;Ool00g`0Oomo
o`0?Ool00`0OOomoo`08Ool00g`0Oomoo`0COol00`0OOomoo`0ROol03V<H
OomS67ooIcUoof<HOomS67ooIcUoof<HOol3HaP1@Q010001HaP00004HaQo
of<HHaP:Ool00`80Oomoo`11Ool00`80Oomoo`0XOol00`0OOomoo`0XOol0
0`80Oomoo`0MOol00g`OOomoo`0mOol00`0OOomoo`0nOol00`0OOomoo`0X
Ool00`80Oomoo`1BOol00`80Oomoo`0;Ool00g`0Oomoo`0?Ool00`0OOomo
o`08Ool00g`0Oomoo`0COol00`0OOomoo`0QOol056LiOomS67ooHaQoof<H
OomW>GooHaQoof<HOomS67ooHaQW>D8@0001HaP00004IcUoof<HIcT8Ool2
0P14Ool00`80Oomoo`0XOol00`0OOomoo`0XOol00`80Oomoo`0MOol00g`O
Oomoo`0mOol00`0OOomoo`0nOol00`0OOomoo`0XOol00`80Oomoo`1BOol0
0`80Oomoo`0;Ool00g`0Oomoo`0?Ool00`0OOomoo`08Ool00g`0Oomoo`0C
Ool00`0OOomoo`0ROol03V<HOomW>GooHaQoof<HOomS67ooHaQoofLiOol3
HaP1@Q010001HaP00005HaQoof<HHaP20005Ool20P16Ool00`80Oomoo`0X
Ool00`0OOomoo`0>Ool401lFOol00`80Oomoo`0MOol00g`OOol07`0301lj
Ool00`0OOomoo`0nOol00`0OOomoo`0>Ool401lFOol00`80Oomoo`0eOol4
01lIOol00`80Oomoo`0;Ool00g`0Oomoo`0?Ool00`0OOomoo`08Ool00g`0
Oomoo`0COol00`0OOomoo`0QOol046LiOomS67ooHaQoofLiOomS67ooIcUo
of<HOomS67oo0V<H0D8@0@000F<H00001FLiOomS66LiOol01@80B7oo00<2
07ooOol0:7oo00<207ooOol027oo00<207ooOol00Woo00<07gooOol00P0O
0Woo00<07gooOol017oo00<07gooOol00Woo00@07gooOol07`Aoo`050P1o
ogooOol07`08Ool00`0OOomoo`03Ool00`0OOomoo`0:Ool017`O01moogoo
0P0O0Woo00<07gooOol017oo00<07gooOol00Woo00@07gooOol07`Qoo`03
01moogoo00Ioo`0301moogoo00=oo`0301moogoo00Aoo`030P1oogoo00Mo
o`030P1oogoo03ioo`030P1oogoo00Moo`030P1oogoo00=oo`0301moogoo
00807`9oo`0301moogoo00Aoo`0301moogoo009oo`0401moogoo01l4Ool0
1@80Oomoogoo01l027oo00<07gooOol00goo00<07gooOol08Goo00<07goo
Ool00P0O0Woo00<07gooOol017oo00<07gooOol00Woo00@07gooOol07`Mo
o`030P007goo00Moo`0701moogooOoml07oo01l01Goo00<207ooOol01goo
00<207ooOol027oo00=l07ooOol027oo00<207ooOol027oo00<207ooOol0
8Woo00iS67ooHaQoof<HOomS67ooHaQoof<HOomS67oo0f<H0D8@0@000F<H
000016<HOomS66<H0goo00<07gooOol0B7oo00<207ooOol0:Goo00<207oo
Ool01goo00D207ooOomoo`0O00Aoo`0401moogoo01l6Ool0100OOomoogoo
0P0O0Woo00<07gooOol00Woo00D207ooOomoo`0O00Aoo`D07`Eoo`0301mo
ogoo00Yoo`03O1moogoo009oo`0401moogoo01l6Ool0100OOomoogoo0P0O
0Woo00<07gooOol01Woo00<07gooOol00Woo1@0O1Goo00<07gooOol017oo
00<207ooOol01Woo00<207ooOol0@7oo00<207ooOol01Woo00<207ooOol0
0Woo00<07gooOol00Woo00@07gooOol07`Ioo`0401moogooOol201l2Ool0
0`0OOomoo`02Ool01@80Oomoogoo01l017oo1@0O1Goo00<07gooOol087oo
00<07gooOol00Woo00@07gooOol07`Ioo`0401moogooOol201l2Ool00`0O
Oomoo`05Ool00`8001moo`03Ool501l3Ool00g`0Ool07`05Ool00`80Oomo
o`06Ool00`80Oomoo`09Ool00g`0Oomoo`08Ool00`80Oomoo`07Ool00`80
Oomoo`0ROol056LiOomW>GooHaQoof<HOomW>GooHaQoofLiOomS67ooHaQW
>D8@0001HaP00004IcUoof<HIcT3Ool00`0OOomoo`18Ool00`80Oomoo`0Z
Ool00`80Oomoo`06Ool01@80Oomoogoo01l01Goo00<07goo01l00`0O0goo
00H07gooOol07goo01l2Ool401l00goo0P1oo`03Ool00`0OOomoo`02Ool0
100OOomoo`0O1Goo00<07gooOol02Woo00=l7gooOol00goo00<07goo01l0
0`0O0goo00H07gooOol07goo01l2Ool401l6Ool00`0OOomoo`02Ool0100O
Oomoo`0O1Goo00<07gooOol017oo00<207ooOol01Goo00<207ooOol0@Woo
00<207ooOol01Goo00<207ooOol00Woo00<07gooOol00goo00<07goo01l0
0`0O0goo00H07gooOol07goo01l2Ool401l00goo0P1oo`03Ool00`0OOomo
o`02Ool0100OOomoo`0O1Goo00<07gooOol087oo00<07gooOol00goo00<0
7goo01l00`0O0goo00H07gooOol07goo01l2Ool401l4Ool00`80Ool07`04
Ool0100OOomoo`0O0goo00=l07oo01l01Goo00<207ooOol01Goo00<207oo
Ool02Woo00=l07ooOol027oo00<207ooOol01Woo00<207ooOol097oo00iS
67ooHaQoofLiOomS67ooHaQoof<HOomS67oo0f<H0D8@0@000F<H000016<H
OomS66<H0goo00<07gooOol03Goo0`0O>7oo00<207ooOol0:goo00<207oo
Ool01Goo00D207ooOomoo`0O00Eoo`0301moo`0O00=oo`807`07Ool07goo
Ool07goo01l00Woo00H07gooOomoo`0O0P04Ool00`0OOomoo`02Ool0100O
Oomoo`0O1Goo00<07gooOol02Woo00=l7gooOol00goo00<07goo01l00goo
0P0O00Moo`0OOomoo`0OOol07`02Ool0100OOomoogoo0P0O17oo00<07goo
Ool00Woo00@07gooOol07`Eoo`0301moogoo00Aoo`030P1oogoo00Aoo`03
0P1oogoo04Aoo`030P1oogoo00Aoo`030P1oogoo009oo`0301moogoo00=o
o`0301moo`0O00=oo`807`07Ool07gooOol07goo01l00Woo00H07gooOomo
o`0O0P04Ool00`0OOomoo`02Ool0100OOomoo`0O1Goo00<07gooOol087oo
00<07gooOol00goo00<07goo01l00goo0P0O00Moo`0OOomoo`0OOol07`02
Ool0100OOomoogoo0P0O0Woo00<207oo01l017oo00@07gooOol07`=oo`03
O01oo`0O00Eoo`030P1oogoo00Aoo`030P1oogoo00]oo`03O01oogoo00Qo
o`030P1oogoo00Eoo`030P1oogoo02Aoo`0@IcUoof<HOomS67ooHaQoof<H
OomW>GooHaQoof<HOol2HaP1@Q010001HaP00004IcUoof<HIcT3Ool00`0O
Oomoo`05Ool01@0OOomoogoo01l00Woo00D07gooOomoo`0O03Moo`030P1o
ogoo02aoo`030P1oogoo00Aoo`050P1oogooOol07`05Ool00`0OOol07`04
Ool01@0OOol07goo01l00Woo00@07gooOol07`Aoo`030P1oogoo00=oo`03
01moogoo009oo`0301moo`0O00Eoo`0301moogoo00Yoo`03O1moogoo00=o
o`0301moo`0O00Aoo`0501moo`0OOol07`02Ool0100OOomoo`0O17oo00<0
7gooOol00goo00<07gooOol00Woo00<07goo01l01Goo00<07gooOol017oo
00<207ooOol00goo00<207ooOol0AWoo00<207ooOol00goo00<207ooOol0
0Woo00<07gooOol00goo00<07goo01l017oo00D07goo01moo`0O009oo`04
01moogoo01l4Ool00`80Oomoo`03Ool00`0OOomoo`02Ool00`0OOol07`05
Ool00`0OOomoo`0POol00`0OOomoo`03Ool00`0OOol07`04Ool01@0OOol0
7goo01l00Woo00@07gooOol07`Aoo`0401moogoo0P02Ool00`0OOomoo`02
Ool00`0OOol07`03Ool00g`0Ool07`05Ool00`80Oomoo`03Ool00`80Oomo
o`0<Ool00g`0Oomoo`08Ool00`80Oomoo`04Ool00`80Oomoo`0VOol03V<H
OomW>GooHaQoofLiOomS67ooHaQoofLiOol3HaP1@Q010001HaP00004HaQo
of<HHaP3Ool00`0OOomoo`04Ool00`0OOol07`02Ool0100OOomoo`0O0goo
00<07gooOol0=Goo00<207ooOol0;Goo0P8017oo00<207ooOol00Woo00D0
7gooOomoo`0O009oo`0301moogoo009oo`0401moo`0O01l3Ool0100OOomo
o`0O17oo00<207ooOol00goo00<07gooOol00goo0P0O0goo0`0O37oo00=l
7`0OOol00Woo00@07gooOol07`Aoo`0401moo`0O01l3Ool0100OOomoo`0O
17oo00<07gooOol00goo00<07gooOol00goo0P0O0goo0`0O1Woo00<207oo
Ool00Woo00<207ooOol0B7oo00<207ooOol00Woo00<207ooOol00goo00D0
7gooOomoo`0O009oo`0301moogoo009oo`0401moo`0O01l3Ool0100OOomo
o`0O17oo00<207ooOol00goo00<07gooOol00goo0P0O0goo0`0O8goo00D0
7gooOomoo`0O009oo`0301moogoo009oo`0401moo`0O01l3Ool0100OOomo
o`0O17oo00@07gooOol2009oo`0301moogoo00=oo`807`9oo`04O0007`0O
01l5Ool00`80Oomoo`02Ool00`80Oomoo`0>Ool00g`0Oomoo`07Ool00`80
Oomoo`02Ool20P0XOol056LiOomS67ooHaQoof<HOomS67ooHaQoof<HOomS
67ooHaQW>D8@0001Ool00004IcUoof<HIcT3Ool00`0OOomoo`04Ool00`0O
Ool07`02Ool0100OOomoo`0O0goo00<07gooOol0=Goo00<207ooOol0;goo
00D207ooOomoo`8000Eoo`<07`=oo`H07`03Ool07`0O00=oo`0301moogoo
00D07`030P1oo`0O00D07`Aoo`807`Eoo`0301moogoo00Yoo`03O1moo`0O
00807`=oo`H07`03Ool07`0O00=oo`0301moogoo00H07`03Ool07`0O00@0
7`Aoo`807`Eoo`0301moogoo00Aoo`050P1oogooOol2001<Ool01@80Oomo
ogoo0P001Woo0`0O0goo1P0O00=oo`0O01l00goo00<07gooOol01@0O00<2
07oo01l01@0O17oo0P0O1Goo00<07gooOol08Woo0`0O0goo1P0O00=oo`0O
01l00goo00<07gooOol01P0O00=oo`0O0P00100O17oo0P0O0Woo00Al07oo
Ool07`Eoo`050P1oogooOol2000AOol00g`0Oomoo`07Ool01@80Oomoogoo
0P00:goo00iW>GooHaQoofLiOomS67ooHaQoofLiOomS67oo0f<H0D8@0@00
0@0@000016<HOomS66<H0goo00<07gooOol017oo00<07goo01l00Woo00D0
7gooOomoo`0O009oo`0301moogoo03Eoo`030P1oogoo031oo`040P1oogoo
0P0OOol00`80Oomoo`0MOol00g`OOomoo`0cOol01080Oomoo`80CWoo00@2
07ooOol2021oo`030P1oogoo059oo`030P1oogoo00Yoo`03O01oogoo00Io
o`040P1oogoo0P0BOol00g`0Oomoo`07Ool01080Oomoo`801goo100O87oo
011W>GooHaQoof<HOomS67ooIcUoof<HOomS67ooHaQoo`9S605240400040
400000AW>GooHaQW>@=oo`0301moogoo00=oo`0401moogoo01l7Ool301lg
Ool00`80Oomoo`0aOol00`80Ool2000OOol00`80Oomoo`0MOol00g`OOomo
o`0cOol00`80Ool2001@Ool00`80Ool2000POol00`80Oomoo`1BOol00`80
Oomoo`0:Ool00g`0Oomoo`06Ool00`80Ool2000COol00g`0Oomoo`07Ool0
0`80Ool20007Ool00`0OOomoo`0201l2Ool00`0OOomoo`04Ool00`0OOomo
o`02Ool0100OOomoo`0O27oo00<07gooOol017oo00iS67ooIcUoof<HOomS
67ooHaQoof<HOomW>Goo0f<H0D8@0@000F<H000016<HOomS66<H0goo00<0
7gooOol00goo00D07gooOomoo`0O00Qoo`0301moogoo03Eoo`030P1oogoo
039oo`8201ioo`807amoo`03O1moogoo03=oo`82059oo`8201moo`807eAo
o`030P1oogoo00Moo`807`03Ooml07oo00Moo`8201Aoo`03O01oogoo00Mo
o`8200Moo`0301moogoo009oo`0401moogoo01l6Ool0100OOomoogoo0P0O
0Woo00<07gooOol01Woo00<07gooOol00Woo01407f<HOomW>GooHaQoofLi
OomS67ooIcUoof<HOomS67oo009S60524040005S600000AW>GooHaQW>@=o
o`030P1oogoo009oo`0301moogoo009oo`0401moo`0O01l5Ool00`0OOomo
o`0eOol00`80Oomoo`0cOol00`8001l07`0901lB0P0401lN0P000g`O0P02
000Y0P0:01l00`80Oomoo`1BOol00`8001l07`0801lD0P0401mL0P0401l0
0g`00P02000L0P000g`001l07`0701l00`80Oomoo`06Ool00`0OOomoo`03
Ool00`0OOol07`0301l3Ool01P0OOomoo`0OOol07`9oo`@07`Ioo`0301mo
ogoo00=oo`0>HaQoof<HOomS67ooHaQoof<HOomS67ooHaQoo`=S60524040
005oo`0000AS67ooHaQS60=oo`030P1oogoo04Qoo`030P1oogoo039oo`82
01eoo`@07aioo`03O1moogoo03=oo`82059oo`8201ioo`@07e=oo`030P1o
ogoo00Ioo`@07`03O01oogoo00Ioo`8201Aoo`03O01oogoo00Moo`8200Mo
o`0301moogoo00=oo`0301moo`0O00=oo`807`07Ool07gooOol07goo01l0
0Woo00@07gooOomoo`807`Aoo`0301moogoo009oo`0DIcUoof<HOomW>Goo
HaQoofLiOomS67ooIcUoof<HOomS66Li@Q00005S600000AW>GooHaQW>@=o
o`030P1oogoo04Qoo`030P1oogoo035oo`030P1oo`8001ioo`807amoo`03
O1moogoo03=oo`030P1oo`80051oo`030P1oo`8001moo`807eAoo`030P1o
ogoo00Moo`807`03Ooml07oo00Moo`030P1oo`8001=oo`03O01oogoo00Mo
o`030P1oo`8000Ioo`0301moogoo00=oo`0301moo`0O00Aoo`0501moo`0O
Ool07`02Ool0100OOomoo`0O17oo00<07gooOol00goo00<07gooOol00Woo
00iW>GooHaQoof<HOomS67ooHaQoof<HOomS67oo0f<H0D8@0@000G>L0000
16<HOomS66<H0goo00<207ooOol0B7oo00<207ooOol0<7oo00@207ooOol2
03moo`03O1moogoo03=oo`040P1oogoo0P1>Ool01080Oomoo`80MGoo00<2
07ooOol02Woo00=l07ooOol01Woo00@207ooOol2019oo`03O01oogoo00Mo
o`040P1oogoo0P06Ool01@0OOomoogoo01l00Woo00<07gooOol00Woo00@0
7goo01l07`=oo`0401moogoo01l4Ool00`0OOomoo`03Ool0500OOomoogoo
IcUoof<HOomW>GooHaQoof<HOomW>GooHaQoofLiOol2HaP1@Q010001Li`0
0004IcUoof<HIcT3Ool00`80Oomoo`18Ool00`80Oomoo`0ZOol70P02Ool0
0`80Oomoo`0mOol00g`OOomoo`0cOol00`80Oomoo`060P14Ool60P02Ool0
0`80Oomoo`1cOol00`80Oomoo`0:Ool00g`0Oomoo`06Ool00`80Oomoo`06
0P0=Ool00g`0Oomoo`07Ool00`80Oomoo`060P02Ool301l3Ool601l00goo
01l07`03Ool00`0OOomoo`0601l00goo01l07`0401l3Ool03VLiOomS67oo
HaQoofLiOomS67ooHaQoof<HOol3HaP1@Q010001Li`00004HaQoof<HHaP3
Ool00`80Oomoo`18Ool00`80Oomoo`0^Ool00`80Ool20002Ool00`80Oomo
o`03Ool401l3Ool401l_Ool00g`OOomoo`0SOol401l3Ool301l6Ool01P80
Oomoo`80Ool204Yoo`030P1oo`80009oo`030P1oogoo00Aoo`@07`Uoo`D0
7eIoo`@07`=oo`030P1oogoo00Aoo`@07`9oo`03O01oogoo00Ioo`060P1o
ogoo0P1oo`8047oo00=l07ooOol01goo00H207ooOol207oo0P0YOol056Li
OomS67ooIcUoof<HOomS67ooHaQoofLiOomS67ooHaQW>D8@0001Li`00004
IcUoof<HIcT3Ool00`80Oomoo`18Ool00`80Oomoo`0]Ool01080Oomoo`80
0Woo00<207ooOol00Woo00<07gooOol00P0O0Woo00<07gooOol00Woo00<0
7gooOol0;7oo00=l7gooOol08Woo00<07gooOol00P0O1Woo00<07gooOol0
0goo00H207ooOol207oo0P1:Ool00`80Ool20002Ool00`80Oomoo`03Ool0
0`0OOomoo`0201l5Ool00`0OOomoo`02Ool00`0OOomoo`1FOol00`0OOomo
o`0201l3Ool00`80Ool07`08Ool00`0OOoml0002Ool00`0OOomoo`03Ool0
1P80Oomoo`80Ool2011oo`03O01oogoo00Moo`040P1oogoo0P02Ool00`80
Oomoo`0WOol03VLiOomS67ooHaQoof<HOomW>GooHaQoof<HOol3HaP1@Q01
0001Li`00004HaQoof<HHaP3Ool00`80Oomoo`18Ool00`80Oomoo`0/Ool0
1@80Oomoogoo0P000Woo00D207ooOomoo`0O00Aoo`0401moogoo01l4Ool0
0`0OOomoo`0/Ool00g`OOomoo`0QOol00`0OOomoo`02Ool00`0OOomoo`04
Ool00`0OOomoo`03Ool01080Oomoo`800Woo00<207ooOol0AWoo00@207oo
Ool2009oo`030P1oogoo009oo`0301moogoo009oo`0301moogoo00=oo`03
01moogoo00=oo`0301moogoo05Aoo`0301moogoo009oo`0701moogooOol2
07oo01l027oo00H07gooOoml07oo01l5Ool01080Oomoo`800Woo00<207oo
Ool037oo00=l07ooOol027oo00@207ooOol200=oo`030P1oogoo02Eoo`0@
IcUoof<HOomW>GooHaQoof<HOomS67ooHaQoof<HOol2HaP1@Q010001Li`0
0004IcUoof<HIcT3Ool00`80Oomoo`18Ool00`80Oomoo`0[Ool00`80Oomo
o`02Ool01080Oomoo`800goo00<07gooOol00goo00<07goo01l017oo00<0
7gooOol0;7oo00=l7gooOol08Goo00<07gooOol00goo00<07gooOol01@0O
17oo00@207ooOol200=oo`030P1oogoo04Aoo`050P1oogooOol20002Ool0
0`80Oomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`04
Ool00`0OOomoo`1COol00`0OOomoo`03Ool01P0OOomoo`80Ool07`Qoo`06
01moogooO01oo`0O1Goo00@207ooOol200=oo`030P1oogoo00]oo`03O01o
ogoo00Qoo`040P1oogoo0P04Ool00`80Oomoo`0UOol03VLiOomS67ooHaQo
ofLiOomS67ooIcUoof<HOol3HaP1@Q010001Li`00004HaQoof<HHaP3Ool0
0`80Oomoo`18Ool00`80Oomoo`0ZOol00`80Oomoo`06Ool01@80Oomoogoo
01l01Goo00<07gooOol0100O;goo00=l7gooOol08Goo00<07gooOol00goo
00<07goo01l00goo0P0O17oo00<207ooOol01Goo00<207ooOol0@Woo00<2
07ooOol01Goo00<207ooOol00Woo00<07gooOol00goo00<07gooOol00Woo
00<07gooOol01Goo00<07gooOol0DWoo00<07gooOol00goo00H07gooOol2
07oo01l6Ool201l3Ool00g`0Ool07`05Ool00`80Oomoo`05Ool00`80Oomo
o`0:Ool00g`0Oomoo`08Ool00`80Oomoo`06Ool00`80Oomoo`0SOol056Li
OomS67ooHaQoof<HOomS67ooHaQoof<HOomW>GooHaQW>D8@0001Li`00004
IcUoof<HIcT3Ool00`80Oomoo`18Ool00`80Oomoo`0YOol00`80Oomoo`07
Ool01@80Oomoogoo01l01Goo00@07gooOol07`9oo`0301moogoo02eoo`03
O1moogoo025oo`0301moogoo00=oo`0301moo`0O00Aoo`0301moogoo009o
o`030P1oogoo00Ioo`030P1oogoo041oo`030P1oogoo00Ioo`030P1oogoo
009oo`0301moogoo00=oo`0301moogoo009oo`0301moogoo00Ioo`0301mo
ogoo055oo`0301moogoo00=oo`0601moogoo0P1oo`0O1Woo00<07gooOol0
0Woo00=l07oo01l01Goo00<207ooOol01Woo00<207ooOol02Goo00=l07oo
Ool027oo00<207ooOol01goo00<207ooOol08goo00iS67ooIcUoofLiOomS
67ooHaQoofLiOomS67oo0f<H0D8@0@000G>L000016<HOomS66<H0goo00<2
07ooOol0B7oo00<207ooOol0>7oo00D07gooOomoo`0O009oo`0301moogoo
009oo`0301moogoo02aoo`03O1moogoo029oo`0501moogooOol07`02Ool0
1@0OOomoogoo01l0H7oo00D07gooOomoo`0O00=oo`<07`Aoo`0501moogoo
Ool07`1DOol01@0OOomoogoo01l00goo00<2000O01l01goo00D07gooOomo
og`000807aYoo`03O01oogoo03Moo`0@IcUoof<HOomS67ooHaQoofLiOomS
67ooHaQoof<HOol2HaP1@Q010001Li`00004IcUoof<HIcT3Ool00`80Oomo
o`18Ool00`80Oomoo`0XOol00`0OOomoo`0>Ool301l4Ool401l_Ool00g`O
Oomoo`0SOol301l4Ool301l@Ool00`0OOomoo`0nOol00`0OOomoo`0>Ool3
01l6Ool00`0OOomoo`02Ool401mFOol301l4Ool00`80Ool07`04Ool401l3
Ool00g`0Ool07`0?Ool00`0OOomoo`08Ool00g`0Oomoo`0COol00`0OOomo
o`0ROol03V<HOomS67ooHaQoof<HOomS67ooHaQoof<HOol3HaP1@Q010001
Li`00004HaQoof<HHaP3Ool00`80Oomoo`18Ool00`80Oomoo`0XOol00`0O
Oomoo`18Ool00g`OOomoo`0mOol00`0OOomoo`0nOol00`0OOomoo`1mOol0
0`80Oomoo`0;Ool00g`0Oomoo`0?Ool501l6Ool017`0Oomoogoo100O0Woo
1@0O1goo00<07gooOol08Goo01AW>GooIcUoof<HOomW>GooHaQoofLiOomS
67ooIcUoof<HIcU240000G>L000016LiOomS66Li0goo00<207ooOol0B7oo
00<207ooOol0:7oo00<07gooOol0B7oo00=l7gooOol0?Goo00<07gooOol0
?Woo00<07gooOol0OGoo00<207ooOol02goo00=l07ooOol03goo00<07goo
Ool00P0O1Goo00<07g`0Ool01Woo00@07gooOol07`Yoo`0301moogoo029o
o`0>HaQoofLiOomS67ooHaQoof<HOomS67ooHaQoo`=S60524040005cW000
00AS67ooHaQS60=oo`030P1oogoo04Qoo`030P1oogoo02Qoo`0301moogoo
04Qoo`03O1moogoo03eoo`0301moogoo03ioo`0301moogoo07eoo`030P1o
ogoo00]oo`03O01oogoo00ioo`807`=oo`0301moogoo00=oo`0301ml07oo
00Ioo`0501moogooOol07`09Ool00`0OOomoo`0QOol046LiOomS67ooHaQo
ofLiOomS67ooHaQoofLiOomS67oo0V<H0D8@0@000G>L000016LiOomS66Li
0goo00<207ooOol0B7oo00<207ooOol0:7oo00<07gooOol0B7oo00=l7goo
Ool0?Goo00<07gooOol0?Woo00<07gooOol0OGoo00<207ooOol037oo00=l
07ooOol03Goo0P0O17oo00<07gooOol00Woo00=l07ooOol01Woo00<07goo
Ool00Woo00<07gooOol01Woo00<07gooOol08Woo00iW>GooHaQoof<HOomS
67ooIcUoof<HOomS67oo0f<H0D8@0@000G>L000016<HOomS66<H0goo00<2
07ooOol0B7oo00<207ooOol0:7oo00<07gooOol0B7oo00=l7gooOol0?Goo
00<07gooOol0?Woo00<07gooOol0OGoo00<207ooOol037oo00=l07ooOol0
3Goo0P0O17oo00<07gooOol00Woo00=l07ooOol017oo0P0O1Woo00<07goo
Ool01Goo00<07gooOol08Goo01AW>GooHaQoofLiOomS67ooHaQoof<HOomS
67ooHaQoof<HIcU240000G>L000016LiOomS66Li0goo00<207ooOol0B7oo
00<207ooOol0:7oo00<07gooOol0B7oo00=l7gooOol0?Goo00<07gooOol0
?Woo00<07gooOol0OGoo00<207ooOol037oo00=l07ooOol03Goo0P0O17oo
00<07gooOol00Woo00=l07ooOol017oo00<07gooOol01Woo00<07gooOol0
17oo00<07gooOol08Woo00iW>GooHaQoof<HOomW>GooHaQoofLiOomS67oo
0f<H0D8@0@000G>L000016<HOomS66<H0goo00<207ooOol0B7oo00<207oo
Ool0:7oo00<07gooOol0B7oo00=l7gooOol0?Goo00<07gooOol0?Woo00<0
7gooOol0OGoo00<207ooOol037oo00=l07ooOol03Woo00D07gooOomoo`0O
00=oo`807`03O01oogoo00Eoo`0501moogooOol07`03Ool00`0OOomoo`04
Ool00`0OOomoo`0QOol046LiOomS67ooIcUoof<HOomS67ooHaQoof<HOomS
67oo0V<H0D8@0@000G>L000016LiOomS66Li0goo00<207ooOol0B7oo00<2
07ooOol0:7oo00<07gooOol0B7oo00=l7gooOol0?Goo00<07gooOol0?Woo
00<07gooOol0OGoo00<207ooOol03Goo00=l07ooOol03Goo100O1Goo00=l
000OOol00goo100O0goo100O1goo00<07gooOol08Woo00iW>GooHaQoof<H
OomS67ooIcUoof<HOomW>Goo0f<H0D8@0@000G>L000016<HOomS66<H0goo
00<207ooOol0B7oo00<207ooOol0:7oo00<07gooOol0B7oo00=l7gooOol0
?Goo00<07gooOol0?Woo00<07gooOol0OGoo00<207ooOol03Goo00=l07oo
Ool03Goo00<07gooOol01Woo00=l07ooOol05Goo00<07gooOol08Goo01AW
>GooHaQoofLiOomS67ooHaQoof<HOomS67ooHaQoof<HIcU240000G>L0000
16LiOomS66Li0goo00<207ooOol0B7oo00<207ooOol0:7oo00<07gooOol0
B7oo00=l7gooOol0?Goo00<207ooOol0?Woo00<207ooOol0OGoo00<207oo
Ool03Goo00=l07ooOol03Goo00<207ooOol01Woo00=l07ooOol05Goo00<2
07ooOol08Woo00iW>GooHaQoof<HOomW>GooHaQoofLiOomS67oo0f<H0D8@
0@000G>L000016<HOomS66<H0goo00<207ooOol0B7oo00<207ooOol0:7oo
00<207ooOol0B7oo00=l7gooOol0?Goo00<207ooOol0?Woo00<207ooOol0
OGoo00<207ooOol03Woo00=l07ooOol037oo00<207ooOol01Goo00=l07oo
Ool05Woo00<207ooOol08Goo40000V<H0D8@0@000G>L000016LiOomS66Li
0goo00<207ooOol0B7oo00<207ooOol0:7oo00<207ooOol0B7oo00=l7goo
Ool0?Goo00<207ooOol0?Woo00<207ooOol0OGoo00<207ooOol03Woo00=l
07ooOol037oo00<207ooOol01Goo00=l07ooOol05Woo00<207ooOol08Goo
00=S648@@Q00348@00D006<HHaQ24000005cW00000AS67ooHaQS60=oo`03
0P1oogoo04Qoo`030P1oogoo02Qoo`030P1oogoo04Qoo`03O1moogoo03eo
o`030P1oogoo03ioo`030P1oogoo07eoo`030P1oogoo00ioo`03O01oogoo
00aoo`030P1oogoo00Eoo`03O01oogoo01Ioo`030P1oogoo025oo`0@IcUo
ofLiHaQW>F<HIcUS66LiHaQW>F<HIcUS648@0002HaP1@Q010001Li`00004
IcUoof<HIcT3Ool00`80Oomoo`18Ool00`80Oomoo`0XOol00`80Oomoo`18
Ool00g`OOomoo`0mOol00`80Oomoo`0nOol00`80Oomoo`1mOol00`80Oomo
o`0>Ool00g`0Oomoo`0<Ool00`80Oomoo`05Ool00g`0Oomoo`0FOol00`80
Oomoo`0QOol00f<HOomS600;HaP01T8@001S66<H@Q00005cW00000AS67oo
HaQS60=oo`030P1oogoo04Qoo`030P1oogoo02Qoo`030P1oogoo04Qoo`03
O1moogoo03eoo`030P1oogoo03ioo`030P1oogoo07eoo`030P1oogoo00mo
o`03O01oogoo00]oo`030P1oogoo00Aoo`03O01oogoo01Moo`030P1oogoo
025oo`03IcUoof<H00]S6006@Q0006<HHaQ240000G>L000016LiOomS66Li
0goo00<207ooOol0B7oo00<207ooOol0:7oo00<207ooOol0B7oo00=l7goo
Ool0?Goo00<207ooOol0?Woo00<207ooOol0OGoo00<207ooOol03goo00=l
07ooOol02goo00<207ooOol017oo00=l07ooOol05goo00<207ooOol08Goo
00=S67ooHaP00f<H00AW>F<HHaQW>@9S6004IcUS648@0002HaP1@Q010001
Li`00004HaQoof<HHaP3Ool00`80Oomoo`18Ool00`80Oomoo`0XOol00`80
Oomoo`18Ool00g`OOomoo`0mOol00`80Oomoo`0nOol00`80Oomoo`1mOol0
0`80Oomoo`0@Ool00g`0Oomoo`0:Ool00`80Oomoo`03Ool00g`0Oomoo`0H
Ool00`80Oomoo`0QOol016LiOomS66Li1`000f<H00I24000HaQS648@0001
Li`00004IcUoof<HIcT3Ool00`80Oomoo`18Ool00`80Oomoo`0XOol00`80
Oomoo`18Ool00g`OOomoo`0mOol00`80Oomoo`0nOol00`80Oomoo`1mOol0
0`80Oomoo`0@Ool00g`0Oomoo`0:Ool00`80Oomoo`03Ool00g`0Oomoo`0H
Ool00`80Oomoo`0QOol00f<HOomS6002HaP50004HaP01T8@001S66<H@Q00
005cW00000AS67ooHaQS60=oo`030P1oogoo04Qoo`030P1oogoo02Qoo`03
0P1oogoo04Qoo`03O1moogoo03eoo`030P1oogoo03ioo`030P1oogoo07eo
o`030P1oogoo015oo`03O01oogoo00Uoo`030P1oogoo009oo`03O01oogoo
01Uoo`030P1oogoo025oo`03IcUoof<H00=S60<000=S6004IcUS648@0002
HaP1@Q010001Li`00004IcUoof<HIcT3Ool00`80Oomoo`18Ool00`80Oomo
o`0WOol201m:Ool00g`OOomoo`0lOol201loOol201mnOol201lDOol00g`0
Oomoo`07Ool201l3Ool00g`0Oomoo`0IOol201lSOol00f<HOomS6002HaP0
0fLiHaP00002HaP01VLiHaQS66<H@Q00009S60524040005cW00000AS67oo
HaQS60=oo`030P1oogoo00D07`=oo`@07caoobT200@07dT20003O1l20080
03/200@07cd200@07g`200@07a@20003O002008000D200@07`030P1l0080
01X200@07b820003HaQoof<H00US6004IcUS648@0002HaP1@Q010001Li`0
0004IcUoof<HIcT3Ool01@80Oomoogoo01l01Goo00<07gooOol00Woo00<0
7gooOol0HWoo100OBGoo00=l7gooOol0>goo100O?Goo100OO7oo100O57oo
00=l07ooOol01Goo100O00=oog`0Ool06Woo100O8Woo00AW>GooHaQW>@IS
6006IcUS66<HHaQ240000V<H0D8@0@000G>L000016<HOomS66<H0goo00<2
07ooOol00Woo00<07gooOol00Woo00<07gooOol00Woo00<07gooOol0Hgoo
0P0OBWoo00=l7gooOol0?7oo0P0O?goo0P0OOWoo0P0O5Woo0W`01Woo0P0O
0W`07Goo0P0O8goo00=S67ooHaP00V<H00=W>F<HHaP016<H00AW>F<H@Q00
009S60524040005cW00000AW>GooHaQW>@=oo`030P1oogoo00=oo`0501mo
ogooOol07`04Ool00`0OOomoo`2_Ool00g`OOomoo`3oOolHOol2O004Ool2
O014Ool016<HOomS66Li16<H00=W>F<HIcT00f<H00I24000HaQS648@0001
Li`00004HaQoof<HHaP3Ool00`80Oomoo`04Ool0100OOomoogoo100O/Woo
00=l7gooOol0ogoo6Woo17`0AWoo00=W>GooOol02goo00I24000HaQS648@
0001Li`00004IcUoof<HIcT3Ool00`80Oomoo`05Ool0100OOomoo`0O0Woo
00<07gooOol0/7oo00<207ooOol0ogooI7oo3f<H00D006<HHaQ24000005c
W00000AS67ooHaQS6?l00?l003`0009S60524040005cW00000EW>GooHaQS
66Li0?mS6?mS62aS6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00=W>F<H
HaP00V<H0D8@0@000G>L00000f<HOomW>@06HaP00fLiHaP0000M00000f<H
0000000L00000f<H0000000L000016<HIcUS66Li16<H00=W>@0000007000
00US66LiHaQW>F<HIcUS66LiHaP07P0000=S60000000700000=S60000000
700000=S60000000700000US66LiHaQW>F<HIcUS66LiHaP07P0000=S6000
0000700000=S60000000700000=S60000000700000=S60000000700000AS
66LiHaQW>@AS601aIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>@0AHaP00fLi@Q000001Li`00003IcUoof<H00MS6003
0012448@01a240030012448@01a240030012448@01a24003001S66<H00ES
60030012448@01a24003001S66<H00ES60030012448@01a240030012448@
01a240030012448@01a240030012448@01a24003001S66<H00ES60030012
448@01a240030012448@01a240030012448@01a240030012448@01a24003
0012448@01a24003001S66<H08QS60524040005cW00000=S67ooHaP00f<H
00IW>F<HHaQS6000OolM@Q000`00Oom2400L@Q000`00Oom2400L@Q000`00
HaQS6003HaP016LiHaP007oo7D8@00<006<HHaP01F<H00<007oo@Q00748@
00<007oo@Q00748@00<007oo@Q00748@00<007oo@Q00748@00<006<HHaP0
1F<H00<007oo@Q00748@00<007oo@Q00748@00<007oo@Q00748@00<007oo
@Q00748@00<007oo@Q00748@00<006<HHaP00f<H00=W>F<HOol0P7oo0V<H
0D8@0@000G>L00001FLiOomS66<HIcT01F<H00<007ooHaP06V<H0T8@00<0
07ooHaP06V<H0T8@00<007ooHaP06V<H0T8@00D006<HHaQS66Li00=S6003
001oof<H01YS60924003001S66<H009S6005IcUS66<H001oo`0KHaP2@Q00
0`00OomS600JHaP2@Q000`00OomS600JHaP2@Q000`00OomS600JHaP2@Q00
0`00HaQS6002HaP01FLiHaQS6000Ool06f<H0T8@00<007ooHaP06V<H0T8@
00<007ooHaP06V<H0T8@00<007ooHaP06V<H0T8@00<007ooHaP06V<H0T8@
00D006<HHaQS66Li00=S6003@Q1S66<H07iS6004IcUS648@0001Li`00003
HaQoof<H009S6003IcUS66Li009S6003001oofLi01YS60924003001oofLi
01YS60924003001oofLi01YS60924004001S66<HIcT4HaP00`00OomW>@0J
HaP2@Q001000HaQS66Li16<H00<007ooIcT056<H00=206<HHaP00f<H0T8@
00<007ooIcT056<H00=206<HHaP00f<H0T8@00<007ooIcT056<H00=206<H
HaP00f<H0T8@00<007ooIcT056<H00=206<HHaP00f<H0T8@00@006<HHaQW
>@AS6003001oofLi00]S60=24004001207oP0003On000`00On120002HaP2
@Q000`00OomW>@0;HaP3@Q001000@P1oh0000WoP00Ioo`00On1oh6LiHaP2
@Q000`00OomW>@0JHaP2@Q000`00OomW>@0:HaP6@Q0:HaP2@Q000`00OomW
>@06HaP20009HaP30006HaP2@Q001000HaQS66Li0V<H00AW>F<H@Q00079o
o`d0009S60524040005cW00000EW>GooHaQS66Li00ES6003001oof<H00=S
6003IcU2448@00m24005HaQW>F<HIcUS6002@Q000`00OomS6002HaP066Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
60924003001oof<H00=S6003IcU2448@00m24005HaQW>F<HIcUS6002@Q00
0`00HaQS6002HaP01FLiHaQS6000Ool00f<H00=W>F<H00003P0000MS66Li
HaQW>F<HIcUS6002@Q000`00HaQS6002HaP01FLiHaQS6000Ool016<H01MW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS6480001206LiHaQW>F<H
00924003001oof<H00=S600GIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQ20000@P1W>F<HIcUS6002@Q000`00OomS6003HaP05fLiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<H@P000480IcUS66LiHaP00T8@00<0
07ooHaP00f<H01MW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS6480
001206LiHaQW>F<H00924003001S66<H009S6005IcUS66<H001oo`03HaP0
26LiHaQW>F<HIcUS66LiHaP3@Q001000@P1oh0000goP00@007oP@P00009S
60924003001oof<H009S6008IcUS66LiHaQW>F<HIcUS60=24004001207oP
0002On001Goo001oh7oP00000V<H0T8@00<007ooHaP00V<H01QW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaP2@Q00
0`00OomS6002HaP01VLiHaQW>F<HIcUS60P07`0:@Q1S66LiHaQW>F<HIcUS
66LiHaP2@Q000`00OomS6003HaP00fLiHaP00002@P002@00HaQW>F<HIcUS
66LiHaP00003@P001P00HaQW>F<HIcUS60924003001S66<H00ES6003@Q00
07oo075oo`03IcU2448@00Y2409S60524040005cW00000=S67ooHaP00V<H
00=W>F<HIcT00V<H00H007ooHaQS66LiHaPA00000d8@HaQS6003HaP2@Q00
0`00OomS600A0009HaP2@Q001P00OomS66<HIcUS61800003@Q1S66<H009S
60924004001S66<HIcT4HaP00`00OomS6003HaP00`000ol3o`0;0ol00`00
0Q000006HaP2@Q001000HaQS66Li16<H00D007ooHaQS66Li009S600301mS
66<H00]S6005@P00048000120003HaP2@Q001@00OomS66<HIcT046<H00E2
0000@P00048000=S60924005001oof<HHaQW>@0@HaP01D8000120000@P00
0f<H0T8@00D007ooHaQS66Li011S6005@P00048000120003HaP2@Q001000
HaQS66Li16<H00<007ooHaP02V<H0T8@00@00480On0000=oh004001oh480
0003HaP2@Q000`00OomS600:HaP2@Q001000@P1oh0000WoP00Eoo`00On1o
h00000=S60924003001oof<H00US60a240ES60924003001oof<H00MS60X0
7`03@Q1S66<H00IS60924005001oof<HHaQW>@03HaP01@00On1204800000
1F<H00<00480@P000WoP00<006<HHaP00f<H0T8@00H006<HHaQW>F<HIcT2
HaP00d8@001oo`1aOol00fLiOomW>@02HaP016LiHaQS66Li1F<H00=W>D8@
00000G>L00001FLiOomS66<HIcT01F<H00<007ooHaP00f<H00<007ooOol0
3Goo00L0048@HaQW>F<HIcUS6002@Q000`00OomS6002000?@P000`00HaQW
>@02HaP016LiHaQW>F<H0T8@00<007ooHaP00V<H00@007`0O01l00800003
HaQW>F<H00P0009l0005001246<HIcUS6002@Q000`00HaQS6002HaP02FLi
HaQS6000OomS66LiHaP0000>0ol02@000Q024000HaQW>F<HIcUS6002@Q00
0`00HaQS6002HaP01FLiHaQS6000Ool01F<H00<07f<HIcT00V<H00iW>F<H
IcUS66LiHaQW>F<H@P000480Oomoh0000f<H0T8@00<007ooHaP00V<H1`0O
00iW>F<HIcUS66LiHaQW>F<H@P000480Oomoh0000f<H0T8@00<007ooHaP0
0V<H01EW>F<HHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQ20000@P1oogoP
00000f<H0T8@00<007ooHaP00V<H01EW>F<HHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQ20000@P1oogoP00000f<H0T8@00<006<HHaP00V<H00EW>F<H
HaP007oo009S6008IcUS66LiHaQW>F<HIcUS60924004001207oP0003On00
1000On1200000V<H00IW>F<H@Q124000Ool2HaP026LiHaQW>F<HIcUS66Li
HaP2@Q001000@P1oh0000WoP00Eoo`00On1oh00000AS6092400<001oof<H
HaQW>F<HIcUS66LiHaQW>F<H348@00ES66LiHaQW>F<H00924007001oof<H
HaQW>F<HIcT00V<H1@0O00=246<HHaP00V<H0P0O00Q246LiHaQS66LiHaQW
>F<H0T8@00<007ooHaP01F<H00D007oPOn12000000AS600300120480009o
h003001S66<H009S6007IcUS648@@Q0006<HIcT00f<H00AW>F<H@Q00079o
o`03HaQoof<H00US6005IcUS66<H@Q000001Li`00003HaQoof<H009S6003
IcUS66Li009S6007001oof<HHaQW>F<H00003goo00<0048@HaP00f<H00UW
>D8@@Q0007ooIcT007oP00003d8000<006<HHaP016<H00EW>D8@@Q0007oo
00=S6004001l07`0O0020003HaP80002O0000`00@Q1S6002HaP2@Q001000
HaQS66Li16<H00<007ooHaP00V<H00<000?o0ol030?o0P000P8@00<006<H
HaP00V<H0T8@00@006<HHaQW>@AS6005001oof<HIcUS600501l9HaP01T80
001207ooOn0000AS60924003001oof<H009S60L07`MS6006@P000480Oomo
h00016<H0T8@00<007ooHaP016<H00=W>F<HHaP02F<H00I20000@P1oogoP
0004HaP2@Q000`00OomS6004HaP00fLiHaQS6009HaP01T80001207ooOn00
00AS60924004001S66<HIcT4HaP00`00OomS6009HaP01D8@001207oP0000
0goP00@007oP@P0000ES60924003001oof<H00US6005@Q000480On000002
On001Goo001oh7oP000016<H00EW>D8@@Q0007oo00QS60`0009240AS6005
IcU2448@001oo`07HaP401l00d8@HaQS6004HaP00`0O@Q1S6005HaP026Li
@Q124000OomS66LiHaP40004On0500001480HaQoh00016<H00=W>F<HHaP0
0T8@00D006<HHaQS66Li00=S6003@Q0007oo075oo`05IcUoof<HHaQW>@02
HaP01FLiHaQW>F<HIcT00f<H0D8@0@000G>L00001FLiOomS66<HIcT01F<H
00<007ooHaP00f<H00<007ooOol03Goo00D0048@IcUS66Li009S60924004
001oof<H0002On000`00@P12000=@P001@00HaQW>F<HIcT00V<H0T8@00<0
07ooHaP00V<H00@007`0O01l008000=S60P0009l0005001246<HIcUS6002
@Q000`00HaQS6002HaP01FLiHaQS6000Ool00V<H4`0000H24000HaQS66Li
HaP2@Q000`00HaQS6002HaP01FLiHaQS6000Ool01F<H00<07f<HHaP00V<H
00aW>F<HIcUS66LiHaQ20000@P1oogoP0003HaP026LiHaQ2448@001oof<H
IcT:HaP02VLiHaQW>F<H@P000480Oomoh0000f<H00YW>F<H@Q124000OomS
66LiHaQW>@9S60X00006@P000480Oomoh0000f<H00IW>F<H@Q124000Ool2
HaP056LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQ20000@P1oogoP0003
HaP01FLiHaQ2448@000016<H00EW>F<HHaP007oo00=S6009IcUS66LiHaQW
>F<H@Q0007oo008000=oh004001oh4800006HaP2@Q000`00OomS6002HaP0
2FLiHaQW>F<HIcUS648@001S60020002On001Goo001oh7oP00000f<H00=W
>F<HHaP00T8@00<007ooHaP00V<H00=W>F<HIcT00V<H00<007ooOol027oo
00<0048@@Q000V<H00=W>F<HHaP00T8@00<007ooHaP00V<H00=W>F<HHaP0
1@0O00E246<HHaQS66Li00IS6003IcUS66Li009S60924003001oof<H009S
6003001oogoo008000=oh005001oogoo00120003On001000HaQS66Li16<H
0T8@00<006<HIcT00f<H00AW>F<H@Q00079oo`03HaQoof<H009S6003IcUS
66<H00ES6004IcUS648@0001Li`00003HaQoof<H009S6003IcUS66Li009S
6003001oof<H00=S6003001oogoo00eoo`03001246<H00AS60924004001o
ofLi0003On000`00@P12000=@P000`00HaQS6003HaP2@Q000`00OomS6002
HaP01000O01l07`00P000f<H20000W`000<0048@HaP00V<H0T8@00@006<H
HaQW>@AS6005001oof<HHaP0000@0ol010000Q00000016<H0T8@00@006<H
HaQW>@AS6005001oof<HHaQW>@02HaP00`0OHaQS6007HaP01T80001207oo
On0000IS60924003001oof<H00QS6003IcUS66<H00=S6006@P000480Oomo
h0001V<H0T8@00<007ooHaP01F<H00<007ooOol01Woo00E20000@P1oogoP
008000ES60924003001oof<H00AS6003IcUS66<H00MS6006@P000480Oomo
h0001V<H0T8@00@006<HHaQW>@AS6004001oof<HIcT7HaP01D8@001oogoo
00000WoP00H007oP@P0006<HIcT3HaP026LiHaQ2448@001oof<HIcT7HaP0
248@001S66<H001oh7oo0002On000`00HaQS6005HaP2@Q001000OomS66Li
1F<H0`0@2Goo00P0048@@Q1S66LiHaQW>F<H0T8@00@007ooHaQW>@AS60D0
7`03@Q1S66Li009S60924003IcUS66<H00IS60924003001oof<H009S6005
001oogooOol00004On001000Ool004800WoP00<006<HHaP00f<H00=W>F<H
IcT00T8@00D006<HHaQS66Li00=S6005@Q0007ooOol00007Ool00`00Oomo
o`1UOol00fLiOomS6004HaP00fLiHaQW>@05HaP1@Q010001Li`00005IcUo
of<HHaQW>@05HaP01000OomS66Li0V<H00<007ooOol03Goo00L0048@HaQW
>F<HIcUS6002@Q001000OomS600017oP00<00480@P003D8000D006<HHaQW
>F<H00924003001oofLi009S6004001l07`0O0020003HaP80002O0001@00
@Q1S66LiHaP00T8@00<006<HHaP00V<H00EW>F<HHaP007oo009S60030003
o`?o00h3o`040002408@0002HaP01FLiHaQ2448@000016<H00IW>F<HHaP0
07ooIcT7HaP500001f<H@P000480Oomoh00000ES6006IcUS648@@Q0007oo
16<H00AW>F<HIcUS60D00007HaQ20000@P1oogoP00001F<H00YW>F<H@Q12
4000OomS66LiHaQW>@9S6003001oo`0000@0009oo`08001207ooOn0007oo
001W>@9S6006IcUS648@@Q0007oo0V<H00IW>F<HIcUS66LiHaP50002HaP0
1@00@P1oogoP00001F<H00EW>F<H@Q12400000AS6005IcUS66<H001oo`04
HaP01VLiHaQW>F<H@Q0000Aoo`800003On12000000QS60924003001oof<H
00=S6006IcUS66LiHaQ240000f<H00=oo`0000000WoP00D006<HHaQS66Li
00AS60924003001oof<H00=S60H040Uoo`030012448@00ES60924003001o
of<H009S6003IcUS66<H00D07`05@Q1S66<HIcU2400201l02D8@HaQS66Li
HaQW>F<HIcUS6002@Q000`00OomS60030004Ool01000On1oh7oP0P0000A2
06<HOn1oh08000=S6004IcUS66<HHaP2@Q000`00HaQS6003HaP016LiHaQ2
40000Woo00<007ooOol017oo00<007ooOol0IWoo00MS67ooHaQS66LiHaQW
>@04HaP01VLiHaQW>F<H@Q00005cW00000=S67ooHaP00V<H00=W>F<HIcT0
0V<H00<007ooHaP00f<H00<007ooOol03Goo00<0048@HaP00f<H00MW>D8@
@Q0007ooIcT00005On000`00@P12000=@P001000HaQS66<H0T8@00<007oo
HaP00V<H00@007`0O01l008000=S60P0009l0003001246<H009S60924004
001S66<HIcT4HaP01@00OomS66<H000040?o00D0008@0Q02400000=S6092
4004001S66<HIcT4HaP00`00OomS6002HaP00fLiHaQS60020005HaP20000
148@Oomoh0000f<H00=W>F<HHaP00V<H0T8@00@007ooHaQW>@AS608000ES
60800004@Q1oogoP0003HaP00fLiHaQS6002HaP2@Q000`00OomS6003HaP0
16LiHaP000001Goo0`0000=oogoP00000Woo00<006<HHaP00f<H0T8@00<0
07ooHaP016<H00=W>@0000001F<H0P0000A247ooOn0000=S6003IcUS66<H
009S60924004001S66<HIcT4HaP01@00OomS66<HIcT01F<H00=24000Ool0
17oo00<0048000001F<H00AW>F<HIcUS60924005001oof<HHaQW>@05HaP0
148@001S66<H0goo00<007oP00000f<H00IW>F<HHaQW>F<HIcT2@Q001@00
OomS66<HIcT00V<H00=W>F<H01000P0@2Goo00P0048@@Q1S66LiHaQW>F<H
0T8@00<007ooHaP01T8@100O0T8@0V<H100O0d8@16<H00EW>D8@@Q0007oo
00=S6006001oo`00001oo`000goP00=20000@P000goP0P001F<H00EW>F<H
@Q124000009S6007IcUS66<HHaQW>D8@00000Woo00<007ooOol017oo00<0
07ooOol0IWoo00=W>GooHaP016<H00<006<HIcT01F<H0D8@0@000G>L0000
1FLiOomS66<HIcT01F<H00@007ooHaQW>@9S6003001oogoo00eoo`050012
46<HHaQW>@02HaP2@Q001000OomS60001WoP00<00480@P003D8000<006Li
HaP00T8@00<007ooHaP00V<H00@007`0O01l00d0009l0005001246<HIcUS
6002@Q000`00HaQS6002HaP01FLiHaQS6000Ool00V<H4`000P8@00@006<H
IcUS60924003001S66<H009S6007IcUS66<H001oof<HIcT00f<H00<006<H
HaP01F<H00EW>Goo0012400000MS6006IcUS648@@Q0007oo1F<H00<006<H
HaP01F<H00EW>Goo0012400000MS6006IcUS648@@Q0007oo0V<H00AW>F<H
HaP000Uoo`<000=oo`06001S66<HHaQW>F<H0T8@00D007ooHaQS66Li009S
6003001S66<H00MS60030012400000MS6005IcUS648@@Q000004HaP01fLi
HaQS6000OomS66Li00=S6004IcUS648@0007Ool01@00HaQS66<HIcT01V<H
0T8@00@007ooHaQW>@=S6006IcUS648@001S66Li1Goo00<006<HHaP026<H
0T8@00<007ooIcT01f<H00<007ooOol027oo00@0048@@Q1W>@AS60924003
001oof<H00El0003@Q007`0O00<07`=240@07`<20003@Q1S66Li009S6092
4003001oof<H009S608000920006001S6000HaQ200000T800WoP00@007oo
001S60800004IcUS66<HHaP2@Q000`00HaQW>@02HaP01FLiHaQS648@0000
0Woo00<007ooOol017oo00<007ooOol0IWoo00IS67ooHaQS66LiHaP30002
HaP01VLiHaQW>F<H@Q00005cW00000=S67ooHaP00V<H00=W>F<HIcT00V<H
00<007ooHaP00f<H00<007ooOol03Goo00<0048@HaP016<H0T8@00@007oo
IcT000Moh0l000=S60924003001oof<H009S6003001l07`0011l00030012
46<H009S60924004001S66<HIcT4HaP01@00OomW>F<H000040?o00D0008@
0002400000=S60924004001S66<HIcT4HaP00`00OomS6002HaP01VLi001S
66<HIcUS60<07`=S6003Ool006<H009S6007IcUS66<HHaQW>F<HIcT00T8@
00L007ooHaQS66LiHaP00003HaP00fLiHaQS6004HaP00goo001S6002HaP0
1fLiHaQS66<HIcUS66Li00924003001oof<H00=S6003001oogoo00Uoo`03
001oogoo009oo`04001S66<HIcT2HaP2@Q000`00OomS6002HaP00fLi001S
600901l00f<H001S6002HaP01fLiHaQS66<HIcUS66Li00924004001S66<H
IcT4HaP00`00OomS6002HaP01VLiHaQS66<H@Q0000Eoo`8000IS6003IcUS
66Li009S60924003001oof<H009S6007IcUS66<HHaQ24000HaP017oo0P00
16<H00AW>F<HHaQW>@=S60924005001oof<HHaQW>@03HaP00fLiHaP0000:
Ool00`00@Q124002HaP00fLiHaQS6002@Q000`00OomS6005O0000d8@HaP0
7`0901l2HaP30P00148@HaQS66<H0T8@00<007ooIcT00V<H0P000d800`00
00=20000@P000goP00@007ooOol0009oo`04001S66<HIcT2@Q002P00HaQS
66<HIcUS66LiHaQ240000Woo1`00JGoo00=W>GooHaP00V<H1@0016<H00=W
>D8@00000G>L00001FLiOomS66<HIcT01F<H00<007ooHaP00f<H00<007oo
Ool03Goo00L0048@HaQW>F<HIcUS6002@Q001000OomS600047oP00<006<H
HaP01V<H0T8@00<007ooHaP00V<H00@007`0O01l00`000=l0005001246<H
IcUS6002@Q000`00HaQS6002HaP01FLiHaQS6000Ool00f<H00<000?o0ol0
3@?o00<0008@0Q000P000f<H0T8@00<006<HHaP00V<H00EW>F<HHaP007oo
00AS6003001S66<H009S60<07`=S6004Ool006<HIcT4HaP016LiHaQS66<H
0T8@00<007ooIcT00f<H00<006<HIcT016<H00QW>F<HHaQS67oo001S66Li
16<H00AW>F<HHaQS60924004001oof<HIcT2HaP00`00Oomoo`09Ool00`00
Oomoo`02Ool00`00HaQS6003HaP2@Q001000OomS66Li0V<H00<006<H01l0
1goo00<07f<H00001V<H00AW>F<HHaQS60924003001S66<H009S6005IcUS
66<H001oo`02HaP00fLiHaQW>@02HaP30002Ool20007HaP01VLiHaQW>F<H
IcUS60924007001oof<HHaQW>F<HIcT00V<H0`000Woo0P0000EW>F<HHaQS
66Li00IS6006IcUS648@@Q0007oo0f<H00AW>F<HHaQS60<040Uoo`080012
448@HaQW>F<HIcUS60924004001oof<HHaP3O0001D8@HaQW>F<HO0001`0O
00A246<HHaQS60<20003@Q1W>F<H00924003001oof<H009S60800003@P1S
67oP009200800005@P1oh7oPOn000003Ool00`00Oomoo`020002HaP2@Q00
0`00HaQW>@05HaP01D8@001oogoo00001Goo00<007ooOol0Igoo00AS67oo
HaQS60L00006HaQW>F<HHaQ240000G>L00000f<HOomS6002HaP00fLiHaQW
>@02HaP01000OomS66Li0V<H00<007ooOol03Goo00<0048@HaP00f<H00MW
>D8@@Q0007ooIcT0000@On000`00HaQS6005HaP01FLi@Q124000Ool00f<H
00@007`0O00000aoo`05001l07`000124003HaP2@Q001000HaQS66Li16<H
00<007ooIcT00f<H3`00108@00@006<HHaQW>@924004001S66<HIcT4HaP0
1P00OomS66LiHaP0009S6003IcUS66<H00<07`AS6003Ool006<H00=S6003
IcUS66Li009S60924003001oof<H009S6003001S66<H00MS6005IcUS66<H
Ool00004HaP00fLiHaQW>@02HaP2@Q000`00OomS6002HaP00`00Oomoo`07
01l4Ool01@00Oomoogoo00000V<H00=W>F<HIcT00T8@00<007ooHaP00V<H
00@006<HHaP07`Moo`0401mS66<H0004HaP00fLiHaQW>@02HaP2@Q001000
HaQS66Li16<H00<007ooHaP01V<H1@000V<H00AW>F<HHaQW>@IS6003IcUS
66Li00924003001oof<H00IS60D000US6003IcUS66Li00=S60924004001o
of<HIcT2HaP60109Ool00`00@Q124005HaP2@Q001000OomW>F<H0g`000A2
46<HHaQS60=l0003@Q1S608000820004@Q1S66LiHaP30P000d8@HaQS6002
@Q000`00OomS6002HaP01000Ool004800WoP14800goP00D007ooOomoo`00
009oo`04001S66<HHaP2@Q002P00HaQS66<HIcUS66LiHaQ240000Woo00<0
07ooOol017oo00<007ooOol0IWoo00=W>GooHaP02f<H00=W>D8@00000G>L
00001FLiOomS66<HIcT01F<H00<007ooHaP00f<H00<007ooOol03Goo00D0
048@HaQS66Li009S60924004001oof<H000@On001@00HaQS66<HIcT016<H
0T8@00<007ooIcT00V<H00@007`0O00000aoo`08001l07`0001246<HIcUS
60924003001S66<H009S6005IcUS66<H001oo`03HaP00fLiHaP0000<Ool2
00030Q001000HaQS66<H0T8@00<006<HHaP00V<H00EW>F<HHaP007oo00=S
6003001S66<H00T07`9S6005001S66<HHaQW>@05HaP2@Q000`00OomS6002
HaP00`00IcUS6003HaP00fLiHaQW>@05HaP01@00HaQS66<HIcT01F<H0T8@
00<007ooHaP00V<H00@007ooOol07`Eoo`0301moogoo009oo`05001oogoo
Ool00005HaP2@Q000`00OomS6002HaP01000HaQS600O1goo00@07f<HHaP0
00=S6003IcUS66<H00=S60924003001S66<H009S6005IcUS66<H001oo`02
HaP00fLiHaQW>@02HaP30009HaP01FLiHaQW>F<HIcT00f<H0T8@00L007oo
HaQS66LiHaQW>@02HaP30006HaP01FLiHaQS66<HIcT016<H00IW>F<H@Q12
4000Ool4HaP00fLiHaQS60030109Ool02000@Q1246<HIcUS66LiHaP2@Q00
1000OomS66<H0g`000A246<HHaQS60=l0003@Q1S608000820004@Q1S66<H
HaP30P000d8@IcUS6002@Q000`00OomS6002HaP01@00Oomoo`00@P000WoP
0T8017oP00D007ooOol006<H008000AS60924003001S66<H00ES6005@Q00
07ooOol00006Ool00`00Oomoo`1VOol016<HOomS66Li26<H00EW>F<HHaQ2
4000005cW00000=S67ooHaP00V<H00=W>F<HIcT00V<H00<007ooHaP00f<H
00<007ooOol03Goo00L0048@HaQW>F<HIcUS6002@Q001000OomW>@001WoP
2P001V<H00=W>F<HHaP00T8@00<007ooHaP00V<H00@007`0O00000aoo`05
001l07`000124003HaP2@Q001000HaQS66Li16<H00<007ooHaP016<H00<0
07ooOol02goo0P000P8@00@006<HHaQS60924003001S66Li00=S6004IcUS
6000Ool3HaP00`00HaQS600901l2HaP00`00HaQS6003HaP016LiHaQW>F<H
0T8@00<007ooHaP00V<H00D006<HHaQS66Li00D07`AS6003001S66<H00=S
6004IcUS66LiHaP2@Q000`00OomS6002HaP01000Oomoo`0O1Goo00<07goo
Ool00Woo00D007ooOomoo`00009S6003IcUS66<H00924003001oof<H009S
6004001S66<H01l7Ool0100OHaQS60000V<H00MW>F<HIcUS66LiHaQW>@02
@Q001000HaQS66Li16<H00<007ooHaP02F<H00=W>F<HHaP00V<H00AW>F<H
HaQW>@ES6003IcUS66<H00924003001oof<H00=S61E2409S60924005001o
of<HHaQW>@03HaP00fLiHaP0000:Ool00`00@Q124004HaP01FLi@Q124000
Ool00V<H2W`000=246Li0P000P8000=246<HHaP00`8000A246<HHaQS6092
4003001oofLi009S6005001oogooOol00007On001@00Oomoogoo00001F<H
00EW>F<H@Q124000009S6003IcUS66Li009S6005@Q0007ooOol00005Ool0
0`00Oomoo`1WOol00fLiOomS6002HaP01VLiHaQS66LiHaQW>@AS60524040
005cW00000EW>GooHaQS66Li00ES6004001oof<HIcT2HaP00`00Oomoo`0=
Ool00`00HaQS6004HaP2@Q001@00OomS66<H000017oP00<006<HHaP02F<H
100016<H0T8@00<007ooHaP00V<H00@007`0O00000aoo`08001l07`00012
46<HIcUS60924003001S66<H009S6005IcUS66<H001oo`06HaP00`00Oomo
o`070004Ool30002HaP01FLiHaQ2448@00000f<H00IW>F<HHaQS6000Ool3
HaP00`00OomS600901l2HaP01P00HaQS66LiHaQW>@AS60924007001oof<H
IcUS6000Ool02F<H00AW>F<HHaP0009S6003IcUS66Li00AS60924003001o
ofLi009S6004001oogoo01l5Ool00`0OOomoo`02Ool01`00Oomoogoo001S
66Li00=S60924006001oof<HIcUS60000V<H00<07gooOol01Goo00@07f<H
HaP000US60924003001S66<H009S6009IcUS66<H001oof<HIcUS66Li01E2
409S60924005001oof<HIcUS600F00001fLiHaQ2448@001oofLi00MS6003
001oogoo00Qoo`030012448@009S6003IcUS66<H00924004001oof<HHaP:
O0000d8@HaP200020P000d8@HaP200020P001D8@HaQS66LiHaP00T8@00<0
07ooHaP00`000goo00<00480On001GoP00D007ooOol006Li00=S6004IcUS
66<HHaP2@Q000`00HaQW>@05HaP0148@001oogoo1P00JWoo00=S67ooHaP0
0f<H00=W>F<HHaP016<H00AW>F<H@Q00005cW00000=S67ooHaP00V<H00=W
>F<HIcT00V<H00<007ooHaP00f<H00<007ooOol027oo1P000V<H00AW>F<H
IcUS60924003001oofLi009S60@0009S6007IcUS66LiHaQW>F<HIcT016<H
0`000V<H00IW>F<H@Q124000Ool3HaP01000O01l000037oo00D007`0O000
048@00=S60924004001S66<HIcT4HaP01@00OomS66<HIcT00f<H00<007oo
Ool02goo00<006<HHaP016<H0T8@00H006<HHaQW>F<HIcT2HaP00`00OomS
6002HaP00`00OomS6003HaP301l5HaP00`00HaQS6003HaP016LiHaQW>F<H
0T8@00<007ooHaP00V<H00<007ooHaP01V<H00IW>F<HHaQS66Li0005HaP0
16LiHaQW>F<H0T8@00<007ooHaP00V<H00@007ooOol07`Eoo`0301moogoo
009oo`05001oogooOol00003HaP01VLiHaQ2448@001oo`=S6004001S66<H
01l7Ool03@0OHaQS6000HaQW>F<HIcUS66LiHaQW>F<H00924004001S66<H
IcT4HaP00`00OomS6002HaPF0002HaP2@Q000`00OomS6002HaPF0002HaP2
@Q000`00OomS6002HaP016LiHaQS66<H0`0@2Goo00P0048@@Q1S66LiHaQW
>F<H0T8@00@007ooIcUS60=l0004@Q1S66<HHaP3O0000d8@HaP200060P00
1T8@HaQS66LiHaQW>@924003001oofLi009S6006001oogooOol004801GoP
00<007ooOol00P001V<H00EW>F<H@Q12400000=S6006IcUS66LiHaQ24000
LWoo00AW>GooHaQW>@AS6009IcUS66LiHaQW>F<HIcU24000005cW00000EW
>GooHaQS66Li00ES6004001oof<HIcT2HaP00`00Oomoo`08Ool01@00Oomo
ogoo00001f<H0T8@00<007ooHaP04V<H00AW>F<H000000AS60924003001o
of<H009S6004001l07`0000<Ool02000O01l0000@Q1S66LiHaP2@Q000`00
HaQS6002HaP01VLiHaQS6000OomW>@ES6003001oogoo00]oo`03001S66<H
00AS60924003001S66<H00ES6004001oof<HIcT2HaP00`00OomS6002HaP3
01l4HaP01`00HaQS66<HIcUS66Li00AS60924003001oof<H00=S6006001o
of<HIcUS66Li1V<H00L006<HHaQS66LiHaQW>@04HaP2@Q000`00OomS6003
HaP00`00Ool07`05Ool01@0OOomoogoo000017oo00<006<HIcT00f<H0T8@
00<007ooHaP00f<H00<006<H01l01goo00@07f<H001W>@US60924003001S
66<H009S6007IcUS66<H001oof<HIcT026<H00=W>F<HHaP036<H00IW>F<H
@Q124000Ool3HaPF0002HaP2@Q000`00OomS6003HaP60109Ool00`00@Q12
4005HaP2@Q001000OomS66<H0g`000A246<HHaQS60=l0003@Q1S60800082
0003@Q1S608000820003@Q1W>F<H009S60924006001oof<HIcUS60000Woo
00<00480On001GoP00@007oo000000ES6004IcUS66<HHaP2@Q000`00HaQW
>@05HaP00d8@001oo`1aOol00f<HOomS6002HaP00fLiHaQW>@07HaP1@Q01
0001Li`00003HaQoof<H009S6003IcUS66Li009S6003001oof<H00=S6003
001oogoo00Qoo`04001oogoo0003HaP00fLiHaQW>@02HaP2@Q000`00OomW
>@0<HaP00`00HaQS6004HaP00`00HaP00002HaP01VLiHaQ2448@001oo`=S
6004001l07`0000<Ool01@00O01l0000@Q000f<H0T8@00@006<HHaQW>@AS
6005001oof<HHaQW>@04HaP00`00Oomoo`080002Ool01000HaQS66Li0V<H
00AW>D8@@Q00009S6003IcUS66Li009S6003001oof<H00=S6003001oof<H
009S60<07`9S6003IcUS6000009S6008IcUS66<HHaQW>F<HIcUS60924003
001oof<H00=S6003001oof<H00AS6003IcUS66Li009S6003001S66<H00AS
6004IcUS66LiHaP2@Q000`00OomS6003HaP00`00Ool07`0601l3Ool60003
HaP026LiHaQ2448@001oof<HIcT2HaP00`00HaP07`0801l036<H001S66<H
IcUS66LiHaQW>F<HIcUS60924004001S66<HIcT4HaP00`00OomS600BHaP0
16LiHaQS66Li16<H0T8@00<007ooHaP05f<H00=W>F<HHaP00T8@00@007oo
HaQW>@=S6003IcUS600@008040Uoo`080012448@HaQW>F<HIcUS60924004
001oof<HHaP3O000148@HaQS66<H0g`000=246<H0P000P8000=246<HHaP0
0`8000A246<HIcUS60924003001oofLi009S60@00003@P1oh7oP00Aoh080
00ES6006IcUS66<HHaQW>F<H0T8@00X006<HHaQS66LiHaQW>F<H@Q00079o
o`03IcUoogoo00Yoo`9S60524040005cW00000EW>GooHaQS66Li00ES6004
001oof<HIcT2HaP00`00Oomoo`08Ool00`00Ool00005HaP016LiHaQW>F<H
0T8@00<007ooHaP016<H00AW>F<HHaQW>@9S6006IcUS66<H001S66Li0V<H
00<006<HHaP01F<H0T8@00<007ooIcT00V<H00@007`0O00000aoo`08001l
07`0001246<HIcUS60924003001S66<H009S6005IcUS66<H001oo`04HaP0
16LiHaQS60003Goo00<006<HHaP00f<H0T8@00<006<HIcT01F<H00@007oo
HaQW>@=S6003001oogoo00MS6003001S66<H009S6003IcUS66Li00AS6092
4005001oof<HHaQW>@02HaP01P00OomoofLiHaQW>@AS6008001S66<HIcUS
66LiHaQW>@AS60924004001oof<HIcT3HaP00`00Oomoo`07Ool00`00HaQS
6005HaP016LiHaQS66<H0T8@00<007ooHaP016<H00<006<HHaP01f<H00<0
06<HHaP02F<H0T8@00<006<HHaP00V<H00EW>F<HHaP007oo009S6005IcUS
66LiHaQW>@0:HaP00fLiHaQS6005HaP026LiHaQ2448@001oof<HIcT5HaP0
3FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00MS60924003001oof<H00MS
6003001oogoo00Qoo`04001S66<HIcT4HaP2@Q000`00OomS6002HaP3O000
0d8@HaQl0002O0000d8@HaQS60030P000d8@HaQS60030P00148@HaQS66<H
0T8@00<007ooHaP01F<H00<00480On0017oP00<006<HHaP00f<H00=W>F<H
HaP00V<H00=W>F<HHaP00T8@00<006<HHaP01F<H00=24000Ool0LGoo3F<H
00AW>F<H@Q00005cW00000=S67ooHaP00V<H00=W>F<HIcT00V<H00<007oo
HaP00f<H00<007ooOol027oo0P0016<H00=W>F<HHaP00f<H0T8@00<007oo
HaP00V<H00=W>F<HHaP016<H00=W>F<HHaP00V<H10001F<H00=W>F<HHaP0
0T8@00<007ooHaP00V<H00@007`0O00000aoo`05001l07`000124003HaP2
@Q001000HaQS66Li16<H00D007ooHaQS66Li00AS6003001oogoo00]oo`04
001S66<HIcT2HaP2@Q001@00HaQS66<HIcT00f<H00<007ooHaP00V<H00=W
>F<HHaP00P000f<H00AW>F<H0000009S6003IcUS66<H00=S6004IcUS66Li
HaP2@Q000`00OomS6005HaP20004HaP00fLi00000008HaP016LiHaQW>F<H
0T8@00<007ooHaP01F<H0P001Goo0P000V<H00=W>F<HIcT01F<H00IW>F<H
@Q124000Ool3HaP00fLiHaQS60020005HaP20003HaP01fLiHaQW>F<HIcUS
66Li009S60924004001S66<HIcT4HaP00`00OomS6007HaP01fLiHaQW>F<H
IcUS66Li00AS6004IcUS66<HIcT4HaP2@Q000`00OomS6002HaP00fLiHaQS
600DHaP01FLi@Q124000Ool00V<H00=W>F<HHaP00V<H00=W>@0000002P00
16<H00=W>F<HHaP00T8@00<007ooIcT00V<H0g`000=246<HO0000W`000=2
46<HHaP00`8000=246<HIcT00`8000A246<HIcUS60924003001oof<H00AS
6003IcT0048000Eoh003001S66Li00ES6006IcUS66LiHaQW>F<H0T8@00H0
06<HHaQW>F<HIcT2HaP00d8@0000001n0002HaP1@Q010001Li`00005IcUo
of<HHaQW>@05HaP01000OomS66Li0V<H30000f<H00QW>F<HHaQS66LiHaQW
>F<H0T8@00@007ooHaQW>@AS6003IcUS66Li00AS6003IcUS66<H00AS6007
IcUS66<HIcUS66LiHaP00T8@00<007ooHaP00V<H50000V<H00EW>F<H@Q12
400000AS6009IcUS66<H001oof<HIcUS66Li00=S60l000=S6005IcUS648@
@Q000002HaP00fLiHaQW>@02HaP00`00OomS6005HaP00fLiHaP000040005
HaP01FLiHaQW>F<HIcT016<H0T8@00D007ooHaQS66Li00ES60D0009S6008
IcUS66<HIcUS66LiHaQW>@AS60924003001oof<H009S6003IcUS66<H009S
60D00003IcUS66<H00MS6004IcUS66<HHaP2@Q001000OomS66Li1V<H1@00
16<H00YW>F<HIcUS66LiHaQW>F<HIcUS60924003001S66<H009S600=IcUS
66<H001oof<HIcUS66LiHaQW>F<HIcT01f<H00=W>F<HIcT00V<H00=W>F<H
HaP00V<H00QW>F<H@Q124000OomS66Li0f<H00=W>F<HHaP03V<H00=W>F<H
IcT00V<H0T8@00@007ooHaQW>AES6004IcUS66LiHaP2@Q000`00OomS6002
HaP8O0000d8@HaP200030P000d8@HaP200020P000d8@HaQS6002HaP2@Q00
1@00OomS66<HIcT00V<H2@001V<H00=W>F<HHaP016<H0T8@00P006<HIcUS
66LiHaQW>F<HPD8@0V<H0D8@0@000G>L00000f<HOomS6002HaP00fLiHaQW
>@02HaP00`00OomS600DHaP00fLiHaQS6002HaP01FLi@Q124000Ool00f<H
00=W>F<HHaP00f<H00=W>F<HIcT036<H00=W>F<HIcT00T8@00<007ooHaP0
5F<H00=W>F<HHaP00V<H0T8@00@006<HHaQW>@AS6003001oof<H00AS6003
IcUS66<H00mS6004IcUS66<HHaP2@Q000`00HaQS6005HaP01@00OomS66<H
IcT02f<H00=W>F<HHaP01V<H00AW>F<HIcUS60924003001oof<H009S6003
IcUS66<H00]S6003IcUS66<H00=S6004IcUS66LiHaP2@Q001000OomS66Li
4f<H00IW>F<HHaQS66LiHaP2@Q000`00OomS600AHaP02FLiHaQW>F<HIcUS
66LiHaQW>@02@Q001000HaQS66Li16<H00<007ooHaP01f<H00=W>F<HIcT0
0V<H00=W>F<HHaP01V<H00EW>F<HIcUS66Li00924003001oof<H009S600C
IcUS66<HHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H0T8@
00<007ooHaP00V<H00=W>F<HHaP00V<H00=W>F<HHaP00V<H00=W>F<HIcT0
1F<H00=W>F<HHaP00f<H0T8@00<007ooHaP016<H17`000A246<HHaQS60P2
0006@Q1S66LiHaQW>F<H0T8@00<007ooHaP046<H00YW>F<HIcUS66LiHaQW
>F<HIcUS60924003001S66<H009S6003IcUS66Li00=S6004IcUS66<HIcT2
HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016Li
HaQS66Li0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li
0V<H00AW>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW
>F<HHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW
>@9S6004IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@9S6004
IcUS66<HIcT2HaP016LiHaQS66Li0V<H00AW>F<HHaQW>@=S6003IcU24000
005cW00000EW>GooHaQS66Li00ES6005001oof<HHaQW>@05HaP01FLiHaQW
>F<HIcT01f<H00EW>F<HHaQS66Li009S60924004001oof<HIcT3HaP00fLi
HaQW>@05HaP01FLiHaQS66<HIcT00f<H00=W>F<HIcT00f<H0T8@00@007oo
HaQW>@ES600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@07HaP01FLiHaQ2448@
000016<H00UW>F<HHaP007ooHaQW>F<HIcT01f<H00MW>F<HIcUS66LiHaQW
>@07HaP01FLiHaQ2448@00000V<H00=W>F<HIcT00V<H00<007ooIcT00f<H
00=W>F<HHaP01F<H00=W>F<HHaP00f<H00EW>F<HIcUS66Li00AS60924004
001oof<HIcT4HaP00fLiHaQS6007HaP01fLiHaQW>F<HIcUS66Li00AS6092
4005001oof<HHaQW>@02HaP00fLiHaQS6009HaP00fLiHaQW>@03HaP016Li
HaQS66<H0T8@00L007ooHaQS66LiHaQW>@02HaP00fLiHaQS6003HaP02fLi
HaQS66<HIcUS66LiHaQW>F<HIcT00f<H0T8@00<006<HHaP00V<H00EW>F<H
HaP007oo00=S6005IcUS66LiHaQW>@03HaP00fLiHaQS6003HaP01FLiHaQW
>F<HIcT01F<H0T8@00@007ooHaQW>@AS6003IcUS66<H00iS6004IcUS66Li
HaP2@Q001@00OomS66<HIcT00V<H00=W>F<HHaP02f<H00QW>F<HHaQS66Li
HaQW>F<H0T8@00D007ooHaQS66Li01QS60924006001oof<HIcUS66Li16<H
00=W>F<HIcT01F<H00=W>F<HHaP026<H0T8@00D006<HHaQS66Li08IS6052
4040005cW00000=S67ooHaP00V<H00=W>F<HIcT00V<H00<007ooOol06goo
00=24000Ool077oo00=24000Ool077oo00E24000HaQS66Li00AS6003001o
ogoo01]oo`03@Q0006<H00AS6003IcUS600001eoo`03@Q0007oo01aoo`03
@Q0007oo01aoo`03@Q0007oo01aoo`05@Q0006<HHaQW>@04HaP00`00Oomo
o`0KOol00d8@001oo`0LOol00d8@001oo`0LOol00d8@001oo`0LOol00d8@
001oo`0LOol02d8@001S66<HIcUS66LiHaQW>F<HIcT0M6<H00AW>F<HHaQW
>@9S6009IcUS66<HIcUS66LiHaQ24000005cW00000EW>GooHaQS66Li00IS
61h00003HaP0000001`00003HaP0000001`000IS6003IcUS66<H01h0009S
6003IcUS66Li00AS61h00003HaP0000001`00003HaP0000001`00003HaP0
000001`0009S6005IcUS66<HHaQW>@02HaPN00000f<H0000000L00000f<H
0000000L00000f<H0000000L00000f<H0000000L000<HaP0LFLiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00V<H00AW
>F<HHaQW>@=S6003IcUS66<H009S60524040005cW00000=S67ooHaP00V<H
00=W>F<HIcT08F<H00=W>F<HHaP076<H00=W>F<HHaP07V<H00=W>F<HIcT0
9f<H00=W>F<HHaP07V<H00=W>F<HHaP07F<H00=W>F<HHaP076<H00=W>F<H
HaP086<H00=W>F<HHaP086<H00=W>F<HHaP076<H00=W>F<HHaP076<H00=W
>F<HHaP076<H00=W>F<HHaP07F<H00]W>F<HIcUS66LiHaQW>F<HIcUS66Li
07QS6009IcUS66<HHaQW>F<HIcU24000005cW00000EW>GooHaQS66Li00AS
6003IcUS66<H009S600GIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@08HaP05fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcT026<H01MW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00ES6003IcUS66<H00=S
6003IcUS66<H009S600GIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@07HaP01FLiHaQS66<HIcT01F<H01EW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT02F<H01MW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00QS
600GIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>@08HaP04fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66Li00=S6003IcUS66<H00ES6005IcUS66<HHaQW>@04HaP05fLiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT026<H01MW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
00QS600GIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>@08HaP05fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcT026<H01MW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66Li01=S601eIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00=S6006IcUS
66<HHaQ240000G>L00000f<HOomS6002HaP00fLiHaQW>@03HaP00fLiHaQS
601LHaP00fLiHaQW>@03HaP00fLiHaQS600JHaP00fLiHaQW>@03HaP01FLi
HaQS66<HIcT0N6<H00UW>F<HIcUS66LiHaQW>F<HIcT0Vf<H011W>F<HHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>GES6005IcUS66LiHaQW>@02HaP1
@Q010001Li`00004HaQoof<HIcT4HaP00a24@Q12400<@Q000b48HaQS600>
HaP01FLiHaQW>F<HIcT06V<H00EW>F<HIcUS66Li01US6005IcUS66LiHaQW
>@04HaP00fLiHaQS600KHaP00fLiHaQS6002HaP01FLiHaQS66<HIcT00f<H
00=W>F<HHaP05f<H00EW>F<HIcUS66Li01US6007IcUS66LiHaQW>F<HIcT0
6F<H00EW>F<HIcUS66Li01ES6003IcUS66<H00eS6003IcUS66Li01US6005
IcUS66LiHaQW>@0IHaP01fLiHaQW>F<HIcUS66Li01YS6005IcUS66LiHaQW
>@0IHaP01FLiHaQW>F<HIcT06F<H00EW>F<HHaQS66Li00eS601eIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66Li00=S6006IcUS66LiHaQ240000G>L00000fLiOomS6002HaP016LiHaQS
61cW2CgW0QcP01ANigo_G^lQ26<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66Li1V<H01UW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@06HaP05fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01V<H00=W>F<HIcT00f<H01]W>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcT00f<H00EW>F<HHaQS66Li00=S6003IcUS66<H009S600GIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@07HaP0
5FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@0;
HaP05fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcT01f<H015W>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
00ES600=IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H01MW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00MS600E
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00]S
600IIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcT01V<H01MW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66Li00MS600GIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>@03HaP03fLiHaQS66<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>@17HaPP0002HaP@0004HaP1@Q010001Li`00005HaQo
of<HHaQW>@03HaP01CgWOnmokekW?NL01Wo_00D00480OnmNkb4800IS60H0
00MS6003IcUS66Li00aS60L000US6003IcUS66Li00]S60P000ES6005IcUS
66LiHaQW>@05HaP00fLiHaQS600;HaP80008HaP016LiHaQS66Li0f<H1000
00=W>F<HIcT06F<H1`0056<H00QW>F<HIcUS66LiHaQW>F<H200000=S6000
HaP046<H00EW>F<HIcUS66Li011S60L000iS60800003IcUS66<H01ES6003
IcUS66<H00L001=S6009IcUS66LiHaQW>F<HIcUS66Li00=S60T0015S6003
IcUS66Li01ES60/001MS6005IcUS66<HHaQW>@0<HaP80000?6<HIcUS66Li
HaQW>F<HIcUS6000HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>@9S6003Oom2448@00a24003001ood8@
00e24004001S66<HOol>@Q001`00HaQS66LiHaQ24000005cW00000=W>Goo
HaP00f<H00=W>F<H?NL00Wo_0SgW00=Nkgo_Onl00Wo_00Xmkd808@1Niek_
8@QS66LiHaQW>@US6005IcUS66LiHaQW>@04HaP02FLiHaQW>F<HIcUS66Li
HaQW>@0;HaP01fLiHaQW>F<HIcUS66Li00AS6009IcUS66LiHaQW>F<HIcUS
66Li00]S6003IcUS66Li00IS600AIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>@0;HaP02FLiHaQW>F<HIcUS66LiHaQW>@03HaP00fLiHaQS
6003HaP06`00HaQS66<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@09HaP04FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT04f<H014006<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66Li00IS600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@02HaP00fLiHaQS
6008HaP02fLiHaQW>F<HIcUS66LiHaQW>F<HIcT016<H01L006<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00=S6003IcUS
66<H00IS600?IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li009S6003
IcUS66<H00MS6003IcUS66<H00YS600?IcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66Li00AS600CIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcT03V<H01EW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT00f<H00eW>F<HHaQS66LiHaQW>F<HIcUS66LiHaQW>@0C
HaP00`00HaQS600aHaP01FLiOomS66<HIcT00V<H00AW>F<HHaQW>@9S6008
IcUS648@001oofLiHaQW>@9S6004IcUS66<HIcT2HaP016LiHaQ240000V<H
00=oof<HIcT00V<H00AW>F<HHaQW>@9S6005IcUS66<H@Q000004HaP1@Q01
0001Li`00005HaQoof<HHaQW>@03HaP00cgWOnlmi`03?NL00ek_Onmok`02
?NL01Fm_8@1205k_8@P016<H00AW>F<HHaP000ES6003001S6000009S60<0
0003IcUS66<H00QS6003IcUS66<H00D000=S60@00006HaP006<HHaP006Li
36<H100016<H00@006<HHaQS60@0009S6005001S66<HHaP0000;HaP016Li
HaQS600016<H00@006<HHaQS60@000=S6005001S66LiHaP00002HaP40002
HaP40002HaP00`00HaQS6003000@HaP00`00HaQS6002HaP00`00HaQS6003
0003HaP01@00HaQS66<H00000f<H00UW>F<HIcUS66LiHaQW>F<HIcT00f<H
10000f<H10000f<H00<006<H00000V<H0`000V<H00D006<HIcUS6000009S
608000QS6003IcUS66<H009S6003001S66<H00=S6003001S600000=S6003
001S66<H00@00005HaP006<HHaP00004HaP20002HaP00`00HaQS6002000:
HaP00fLiHaQS6003HaP00`00HaQS6003HaP30003HaP30002HaP00`00HaQS
6002000036<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@9S6003001S66<H00=S
6004001S66<HHaP400001F<H001S66<H00000f<H00<006<HHaP00`000V<H
00@006<HHaQS608000aS6005IcUS66<HHaP00003HaP00`00HaQS6002HaP0
0`00HaP00003HaP00`00HaQS60040002HaP30003HaP01`00IcUS66<H001S
66Li00YS6003IcUS600000AS6004001W>F<HHaP3000016LiHaP006<H1000
02mW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66Li009S6004OomS66<HHaP60004HaP00d8@001oo`02HaP60005HaP0
1D8@001S66<HOol03F<H00Q24000HaQS66LiHaQ240000G>L00000fLiOomS
6002HaP016LiHaQS63gW0go_00<migo_Onl017o_00DmicgP8@122248009S
6006IcUS66<HHaQW>@000V<H00QW>F<HHaP006<H001S60000f<H00T006<H
IcUS66LiHaQW>F<HIcT01F<H00<006<HIcT00f<H00=W>@00HaP00V<H00D0
06<H001S600000=S6009IcUS66LiHaQW>F<HIcUS66Li009S600<001S66Li
HaP006<HIcUS6000HaQW>@000f<H00@006<HHaP0009S600<IcT006<HIcUS
66LiHaQW>F<HIcUS66Li0f<H00=W>@00HaP00V<H0P000V<H00D006<HHaQS
6000009S6003IcT006<H009S6003001S6000009S6004IcT006<H0003HaP0
0`00HaP00002HaP05@00HaQS66<H001S66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaP00002HaP01FLiHaP006<H00000f<H00@006<HHaP000=S6003
001S66Li00]S6004IcT006<HIcT2HaP02P00HaQS6000HaQW>F<H001S6000
0V<H00<006<H00000f<H00<006<H00000f<H00<006<H00000V<H00L006<H
IcUS66LiHaQW>@03HaP01VLiHaQS6000HaQW>@=S6003001S600000=S6003
001S600000=S6003001S6000009S6080009S6008001S66<H001S6000HaP0
009S6007001S66LiHaQW>F<HIcT01F<H00EW>F<HIcUS6000009S6003IcUS
600000=S6003001S600000=S6005001S6000HaP00002HaP00`00HaQS6009
HaP00fLiHaP00002HaP01`00HaQS6000HaQW>@0000=S6003001S6000009S
6004001S66<H0002HaP01`00HaQS66<H001S6000009S600>001S66<H001S
66LiHaQW>F<HIcUS66LiHaQW>@=S6003IcUS600000=S6008001S66<HIcUS
6000HaP000=S6003001S600000=S6003001S600000=S6004001S66<H0002
HaP00fLi001S6002HaP01fLiHaQW>F<HIcUS66Li00AS6003001S66Li009S
6004001S66<H0003HaP02@00HaP006<H001S66LiHaP0000`HaP017ooHaQS
66<H1P0016<H00I24000OomW>F<H0003HaP01FLi001S66<HIcT00V<H00E2
4000HaQS67oo009S6005IcT00000HaQW>@02HaP20002HaP00d8@001S6002
HaP00fLi@Q000001Li`00004HaQoof<HIcT4HaP01CgWOnmokgo_?NL01go_
00ANk`00<HPQ20AS6004IcUS66<H0005HaP01@00HaP006<H00001V<H00UW
>F<HIcUS66LiHaQW>F<HIcT00V<H00<006<HHaP016<H00/006<HHaQS6000
HaP006<H001S66Li00aS6003001S66<H009S6004001S66<H0002HaP03@00
HaQS66<H001S6000HaP006<H001S600000YS6004IcUS66<H0003HaP20002
HaP01@00HaQS66<H00000V<H00<006<H00000V<H00<006<H00000f<H00<0
06<H00000f<H00<006<H00000V<H00<006<HHaP046<H00<006<H00000f<H
00<006<H00001F<H00L006<H001S6000HaP00002HaP02FLiHaQW>F<HIcUS
66LiHaQW>@02HaP00`00HaQS6002HaP01000HaQS60000f<H00<006<H0000
0V<H00<006<H00000f<H00<006<H00000f<H00D006<HHaQS600000MS6003
IcUS66Li00AS60D0009S6007001S66LiHaP006<H00000f<H00D006<H001S
6000009S6005001S66<HHaP00002HaP01@00HaQS66<H00001f<H00EW>F<H
IcUS66Li00AS6003001S66<H009S6007001S66<HHaP006<H00000f<H00<0
06<H00000f<H00`006<HHaQW>F<HIcUS66LiHaQW>F<HIcT3HaP01000HaQS
60000V<H00@006<HHaP000=S6003001S6000009S6003001S600000=S6003
001S66<H00=S6003001S66<H009S6003001S66<H00YS600:IcUS66<H001S
6000HaP006<H0003HaP00`00HaP00003HaP00`00HaP00003HaP00`00HaP0
0003HaP05`00HaP006<H001S6000HaP006<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<H000016<H00@006<HHaP000ES6003001S600000=S6004001S66<H
IcT2HaP0:FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT0
0V<H00Eoof<HHaQS66Li00MS6005IcUS648@001oo`02HaP00`00IcUS6002
HaP00`00HaQS6003HaP01D8@001S66<HOol016<H0P000V<H0P000f<H00A2
4000HaQW>@9S60524040005cW00000=W>GooHaP00V<H00AW>F<HHaPmi`=o
k`068@@micgW<H0mh5kW0go_00=NkacW8@P00V<H00=W>F<HHaP00V<H00X0
06<HIcUS66LiHaP006<H001S60D000=S6005IcUS66LiHaQW>@03HaP00fLi
HaP00006HaP02@00HaQS66<H001S6000HaP00003HaP02FLiHaQW>F<HIcUS
66LiHaQW>@02HaP00`00HaQS6002HaP01000HaQS60000f<H100000QS6000
HaP006<H001S60000V<H00MW>F<HIcUS66LiHaQW>@04HaP01P00HaQS6000
HaP000=S60@0009S6003001S6000009S6003001S600000=S6003001S66<H
00@00004HaP006<HHaP5000036<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@9S
6003001S600000=S6003001S600000@00008HaP006<H001S6000HaP000eS
6003001S66<H009S6004001S66<H0003HaP00`00HaP00002HaP00`00HaP0
0003HaP01`00HaP006<HIcUS6000009S6008001S66<HIcUS66LiHaQW>@AS
6009IcUS66LiHaP006<HIcUS6000009S6005001S66<HHaP00002HaP40000
16<H001S60000V<H00@006<HHaP000=S6004001S66<H0002HaP01FLiHaQW
>F<HIcT01V<H00EW>F<HHaQS6000009S6003IcUS600000=S6003001S6000
00=S6003001S6000009S6003001S66<H00YS600:IcUS66<H001S6000HaP0
06<H0003HaP4000016<H001S66<H0P0016<H1@0000IS6000HaQS66Li0002
HaP02FLiHaQW>F<HIcUS66LiHaQW>@05HaP01`00HaP006<H001S600000=S
6003001S600000=S6003001S600000=S6003001S600000=S6009001S6000
HaP006<H001S600000AS6005IcUS66LiHaQW>@04HaP01P00HaQS66LiHaP0
009S60D00004HaP006<H0003HaP00`00HaQS6002HaP00fLiHaQS600XHaP0
0fLiOomS600<HaP01T8@001oofLiHaP000AS60<00005HaQW>F<H@Q000002
HaP00gooHaQS6003HaP40004HaP00d8@001S6003HaP1@Q010001Li`00004
HaQoof<HIcT4HaP01CgWOnmokgo_?NL00Wo_00MNk`00:DHaP480G^Mok`02
8@P4HaP00fLiHaQS60040002HaP01@00HaP006<H00000f<H00P006<HHaQW
>F<HIcUS66Li0V<H00AW>F<HHaQS60@00004HaQW>F<H0003HaP01`00HaP0
06<H001S66Li00aS6003001S66<H009S6004001S66<H0004HaP01FLiHaP0
06<H00000V<H00H006<HHaP006<HIcT8HaP01VLiHaQS6000HaP0009S6003
001S66<H009S6005IcUS6000HaP00003HaP01@00HaP006<H00000f<H00T0
06<HHaQS66LiHaP006Li00000V<H00D006<HHaQS600000eS6005001S66<H
HaP00002HaP02@00HaP006<HIcUS6000HaP00002HaP04P00HaQS6000HaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaP000AS6004001S66<H0003HaP00`00
HaP00002HaP00`00HaP00003HaP01000HaP000000V<H00<006<H00000V<H
00<006<HHaP00f<H00=W>F<HIcT01F<H00D006<HHaQS6000009S6080009S
600;001S66<HHaQW>F<H001W>@00HaP00002HaP00`00HaP00002HaP01@00
HaP006<H00000V<H00<006<HHaP016<H00MW>F<HIcUS66LiHaQW>@02HaP0
0`00HaQS6002HaP01`00HaQS66<H001S600000=S6005001S6000HaP00002
HaP02P00IcUS66LiHaQW>F<HIcUS66Li16<H00L006<H001S6000HaP00004
HaP01FLiHaP006Li00000V<H00@006<H001W>@9S6007001S66<HHaP006<H
00000V<H018006<HHaP006<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H0003
HaP01@00HaQS66<H00000V<H00@006<H0000009S6003001S600000=S6003
001S600000=S6003001S6000009S6004001S66<H0003HaP01FLiHaQW>F<H
IcT00V<H00=W>F<HHaP01P000V<H00T006<HIcUS6000HaP006<H00000f<H
02l006<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66Li009S6004OomS66<HIcT6HaP01fLiHaQW>F<H@Q0007oo009S60H0
0003HaP006<H009S6005@Q0006<HHaQoo`02HaP016LiHaQS66<H0P000f<H
00AW>F<H@Q00009S6004IcUS648@0001Li`00003IcUoof<H009S6004IcUS
66<H?NL2Onl00ekW?NMok`02Onl01SgWIcTicR44<H12008@Q09S6003IcUS
66<H009S6003001S66Li00=S6003001W>@00009S60<000AS6005IcUS66Li
HaQW>@03HaP01FLiHaP006<HIcT01F<H100000=W>@00HaP00P000V<H00UW
>F<HIcUS66LiHaQW>F<HIcT00V<H00<006<HIcT00V<H00<006<HHaP00P00
0V<H0`0000=S66Li00000V<H00@006<HHaP000=S6005IcUS66LiHaQW>@05
HaP00`00HaP00002HaP01000HaQS66Li0`000V<H00T006<HHaQS6000HaP0
06LiHaP010000V<H0`000V<H0P000V<H0`000V<H00eW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaP00003HaP01P00HaQS6000IcUS60<00003HaQW>@00009S
6004001S66<H000=HaP01P00HaQS66LiHaP0009S60@0009S60800004HaP0
06<HHaP3000016<HIcT006<H0P000f<H0P000V<H00=W>F<HIcT016<H00=W
>F<HIcT00f<H00<006<H00000f<H00@006<H000000=S60<0009S6003001S
6000009S6003001S66<H0080009S6003001S66<H0080009S6003IcUS66Li
00US6003IcUS6000009S6003IcUS66<H00<000=S60<00003HaQW>@00009S
608000YS6004IcUS66LiHaP20003HaP20003HaP30002HaP200001F<H001S
66<H00000f<H0`0000AS66Li0000009S608000ES6005IcUS66LiHaQW>@04
HaP01@00HaQS66<H00000f<H00L006<HHaP006<H001S60020003HaP40002
HaP300000f<HIcT00002HaP01000HaQS60000V<H00MW>F<HIcUS66LiHaQW
>@04HaP00`00HaQW>@02HaP01000HaQS66<H0`0000AS66Li001S60@0035S
6003OomS66<H009S6005IcUS66LiHaQW>@04HaP01D8@001oofLiHaP01P00
00=S6000HaP00V<H00E24000HaQS67oo00ES60@000AS6003@Q0006<H00=S
60524040005cW00000AS67ooHaQW>@AS6005?NMokek_@P0mi`03Onl01Uk_
G_M_Nd00<00aP08000AS6004IcUS66<H0007HaP00`00HaQW>@06HaP00fLi
HaQW>@04HaP01FLiHaQS66<H000016<H00MW>F<HHaQS66LiHaP00003HaP0
0`00HaQS600<HaP00`00HaQS6002HaP00`00HaQS6004HaP00fLiHaQS600;
HaP02FLiHaQW>F<HIcUS66LiHaQW>@02HaP20003HaP01@00HaQS66<HIcT0
4f<H00IW>F<HHaQW>F<H000DHaP01@00HaQS66<H00001F<H00=W>F<HHaP0
2f<H00UW>F<HIcUS66LiHaQW>F<HIcT00V<H00<006<HHaP00V<H00<006<H
HaP016<H00=W>F<H00006F<H00=W>F<HIcT01V<H00<006<H000036<H00AW
>F<HIcT001IS6007IcUS66LiHaQW>F<HIcT00f<H00<006LiHaP03V<H00<0
06<HHaP016<H00MW>F<HIcUS66LiHaQW>@05HaP20003HaP20003HaP016Li
HaQS66Li16<H00<006<HHaP04f<H00]W>F<HIcUS66LiHaQW>F<HIcUS6000
00=S6005001S66<HHaP0000<HaP00fLiHaP0000?HaP01FLiHaQW>F<HIcT0
16<H00AW>F<HHaP000AS6005001S66<HHaQW>@04HaP00`00IcUS6007HaP0
:fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li009S
6005OomS66LiHaQW>@07HaP01FLiHaQ24000Ool016<H00/006<HHaQS66Li
001S66LiHaQ24000009S6005OomS66<HIcUS60020002HaP200001F<HIcUS
648@00000V<H00AW>F<H@Q00005cW00000=W>GooHaP00V<H00AW>F<HHaPm
i`9ok`03G^LmicgW00=ok`05?NM/ib`0@00`00020002HaP00fLiHaQS6002
HaP01000HaQS66Li16<H00<006<HHaP016<H00=W>F<HHaP00V<H00=W>F<H
IcT01F<H00<006<HHaP016<H00IW>F<HHaQS6000IcT2HaP04000HaQS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS60000V<H00EW>@00HaQS66Li01ES6003
IcUS66Li00=S6004IcUS60000003HaP00`00HaQS6007HaP00fLiHaQS600@
HaP00`00HaQS6004HaP02fLiHaQW>F<HIcUS66LiHaQW>F<HIcT00V<H00@0
06<HHaQW>@9S6003001S66<H00iS6003IcUS66<H00QS6003IcUS6000009S
6003IcUS600000QS6003001S66<H00aS6003IcUS66Li009S6005IcUS66Li
HaQW>@04HaP00fLiHaQW>@04HaP01@00HaQS66<HIcT00f<H00=W>F<HIcT0
1V<H00<006<HHaP00V<H00AW>F<HHaQW>@AS6008IcUS66<HIcUS66LiHaQW
>@YS6003IcUS6000009S6003IcUS66<H00]S6003001S66<H00]S6003IcUS
66Li009S6003001S66<H00=S6003001S66<H00US6005001S66<HHaQW>@0=
HaP00fLiHaQW>@04HaP00fLiHaQW>@03HaP00`00HaQS6004HaP016LiHaQS
60003F<H00<006<HHaP046<H00EW>F<HIcUS66Li00AS6003001S66<H009S
6003001S66<H00IS6003001S66<H00AS6003IcUS66Li02aS6003IcUoof<H
00AS6005IcUS66LiHaQW>@03HaP00d8@001oo`04HaP60003HaP01D8@001S
66<HOol00f<H0P0000AS66LiHaQW>@80009S6003@Q0006<H00=S60524040
005cW00000AS67ooHaQW>@AS6005?NMokek_@P0mi`04Onl01ek_G>Mlib`0
@00`000000AS6003IcUS66<H00D00004HaP006<H0004HaP01fLiHaQS66<H
IcUS66Li00ES6003IcUS66<H00D00003IcUS66<H00=S6003001S6000011S
60@000ES6003IcUS66Li00AS600?IcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66Li009S6005IcUS66<HHaP00004HaP01000HaQS66Li16<H00EW>F<H
HaQS66Li009S6004001S66<HIcT3HaP00fLiHaQS6009HaP00fLiHaQS600<
HaP00`00IcUS6003HaP00`00HaP00008HaP01FLiHaQW>F<HIcT016<H00MW
>F<HIcUS66LiHaQW>@04HaP40002HaP016LiHaQS66Li1V<H00`006LiHaQW
>F<HIcUS66LiHaQW>F<HIcT4HaP00fLiHaQS6004HaP00fLiHaQW>@04HaP0
1VLiHaQS6000HaQW>@=S6003IcUS66<H00QS6004001S66<HIcT2HaP01fLi
HaQS66<HIcUS6000009S6003IcUS66<H00AS6007IcUS66LiHaQW>F<HIcT0
0V<H1@000V<H00UW>F<HIcUS66LiHaQW>F<HIcT00f<H00d006<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>@06HaP00`00HaQW>@03HaP01000HaQS66Li26<H
00<006<HIcT00V<H00=W>F<HIcT00V<H00QW>F<HHaQW>F<HIcUS66Li16<H
00EW>F<HIcUS66Li009S6003IcUS6000009S6003IcUS66Li00AS600;001S
6000HaQW>F<HIcUS66LiHaQW>@03HaP01000HaQS66Li0V<H00mW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H00=W>F<H000016<H00<006<H
IcT01V<H00<006<HHaP00f<H02mW>F<HHaQS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66Li009S6006OomS66<HIcUS66Li1V<H
00EW>F<H@Q0007oo00AS60H000=S6007@Q0006<HHaQoof<HIcT02f<H00Q2
4000HaQS66LiHaQ240000G>L00000fLiOomS6002HaP016LiHaQS63gW0Wo_
00=NicgW?NL017o_00INkecWO>L/0400<002HaP00fLiHaQS600<HaP00fLi
HaQS6002HaP00fLiHaQS6002HaP01fLiHaQW>F<HIcUS66Li00QS6003IcUS
66<H00IS600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@08HaP00fLiHaQW>@05
HaP00fLiHaQW>@0=HaP00fLiHaQW>@03HaP00fLiHaQS6002HaP01FLiHaQS
66<HIcT00V<H00=W>F<HIcT00V<H00EW>F<HHaQS66Li009S6004IcUS66<H
IcT3HaP00fLiHaQW>@03HaP00fLiHaQW>@03HaP02fLiHaQW>F<HIcUS66Li
HaQW>F<HIcT01F<H00=W>F<HHaP016<H00MW>F<HIcUS66LiHaQW>@05HaP0
0fLiHaQW>@08HaP00fLiHaQS6009HaP016LiHaQS66Li46<H00=W>F<HIcT0
0f<H00=W>F<HIcT01F<H00=W>F<HIcT026<H00UW>F<HHaQS66LiHaQW>F<H
IcT00V<H00=W>F<HHaP01f<H00=W>F<HHaP00f<H00IW>F<HHaQW>F<HIcT9
HaP00fLiHaQS600@HaP00fLiHaQS600<HaP00fLiHaQW>@07HaP00fLiHaQS
6004HaP00fLiHaQW>@0<HaP01FLiHaQS66<HIcT01F<H00=W>F<HIcT016<H
00=W>F<HIcT01F<H00=W>F<HHaP00V<H00=W>F<HHaP02f<H00=W>F<HHaP0
1F<H00=W>F<HHaP02f<H00MW>F<HIcUS66LiHaQW>@04HaP00fLiHaQS6004
HaP00fLiHaQW>@05HaP00fLiHaQW>@02HaP00fLiHaQS600/HaP00gooHaQS
6003HaP01FLiHaQW>F<HIcT00f<H00A24000OomW>@aS6005@Q0006<HHaQo
o`0=HaP00d8@001S6002HaP00fLi@Q000001Li`00004HaQoof<HIcT4HaP0
11cP?NLLib401cgW00DQ15cWO>L/030000AS6003IcUS66Li00MS6007IcUS
66<HHaQW>F<HIcT00f<H00=W>F<HIcT046<H00=W>F<HIcT00f<H00=W>F<H
HaP02V<H00=W>F<HIcT02V<H00=W>F<HIcT016<H00aW>F<HHaQW>F<HIcUS
66LiHaQW>F<HIcT4HaP00fLiHaQS6006HaP00fLiHaQS6005HaP01FLiHaQS
66<HIcT02V<H00=W>F<HHaP00f<H00=W>F<HHaP00f<H00=W>F<HHaP02V<H
00=W>F<HHaP00V<H00IW>F<HHaQW>F<HIcT9HaP00fLiHaQW>@05HaP01FLi
HaQW>F<HIcT016<H00=W>F<HHaP016<H00=W>F<HHaP01F<H00=W>F<HIcT0
0V<H00UW>F<HIcUS66LiHaQW>F<HIcT01F<H00UW>F<HHaQS66LiHaQW>F<H
IcT00f<H00AW>F<HHaQW>@9S6003IcUS66<H009S6003IcUS66<H00=S6003
IcUS66<H00=S6005IcUS66LiHaQW>@03HaP00fLiHaQW>@08HaP01fLiHaQW
>F<HIcUS66Li00QS600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@04HaP036Li
HaQS66LiHaQW>F<HIcUS66LiHaQW>@ES6004IcUS66<HIcT5HaP00fLiHaQW
>@04HaP00fLiHaQW>@02HaP01FLiHaQW>F<HIcT00f<H00=W>F<HHaP00V<H
00=W>F<HIcT016<H00=W>F<HIcT016<H00=W>F<HIcT016<H00mW>F<HHaQS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00V<H00IW>F<HHaQW>F<HIcT4HaP0
3FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li00MS6005IcUS66<HHaQW>@03
HaP00fLiHaQS6002HaP016LiHaQS66Li1f<H02]W>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@02HaP?Ool00`00Oomoo`0=Ool0
0`00HaQS600?Ool00`00HaQW>@02HaP1@Q010001Li`00003IcUoof<H009S
6003IcUS66<H00aS6003001LiecW00=S6003IcUS66<H00=S6006IcUS66<H
IcUS66Li0V<H00=W>F<HHaP00V<H00=W>F<HHaP00f<H00MW>F<HIcUS66Li
HaQW>@03HaP01FLiHaQW>F<HIcT01F<H00mW>F<HHaQS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcT016<H00MW>F<HIcUS66LiHaQW>@05HaP00fLiHaQW>@03
HaP00fLiHaQS6007HaP00fLiHaQW>@03HaP01FLiHaQW>F<HIcT016<H00EW
>F<HIcUS66Li00=S600;IcUS66<HHaQW>F<HIcUS66LiHaQW>@04HaP00fLi
HaQW>@03HaP00fLiHaQW>@03HaP02FLiHaQW>F<HIcUS66LiHaQW>@04HaP0
0fLiHaQS6002HaP00fLiHaQS6002HaP01fLiHaQW>F<HIcUS66Li00AS600=
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00f<H00AW>F<HHaQW>@9S6007
IcUS66LiHaQW>F<HIcT016<H00=W>F<HHaP01f<H00UW>F<HIcUS66LiHaQW
>F<HIcT01F<H00EW>F<HIcUS66Li00IS6003IcUS66<H009S6003IcUS66Li
00=S6003IcUS66Li00IS6003IcUS66<H00=S6007IcUS66LiHaQW>F<HIcT0
26<H00=W>F<HIcT00V<H00=W>F<HHaP02f<H00=W>F<HIcT00f<H00=W>F<H
HaP01f<H00EW>F<HIcUS66Li00ES6003IcUS66Li00AS6003IcUS66Li00]S
6007IcUS66<HHaQW>F<HIcT016<H00=W>F<HIcT016<H00=W>F<HIcT016<H
00=W>F<HIcT00f<H00=W>F<HHaP03V<H00=W>F<HHaP00V<H00=W>F<HHaP0
2f<H00MW>F<HIcUS66LiHaQW>@04HaP01FLiHaQS66<HIcT00f<H00=W>F<H
HaP00V<H00QW>F<HHaQW>F<HIcUS66Li;F<H00=W>F<HHaP04F<H00UW>F<H
IcUS66LiHaQW>F<HIcT06V<H0D8@0@000G>L000016<HOomS66Li0f<H00=W
>F<HHaP03F<H00=W>F<HHaP00V<H00=W>F<HIcT00f<H00=W>F<HHaP01F<H
00UW>F<HIcUS66LiHaQW>F<HIcT026<H00=W>F<HHaP01F<H00=W>F<HIcT0
16<H00=W>F<HHaP02F<H00=W>F<HIcT026<H00EW>F<HIcUS66Li00ES600;
IcUS66LiHaQW>F<HIcUS66LiHaQW>@05HaP00fLiHaQS6004HaP00fLiHaQW
>@07HaP01FLiHaQS66<HIcT026<H00=W>F<HIcT01F<H00=W>F<HHaP00f<H
00=W>F<HHaP026<H00MW>F<HIcUS66LiHaQW>@03HaP00fLiHaQW>@08HaP0
0fLiHaQW>@05HaP01FLiHaQW>F<HIcT016<H00AW>F<HHaQW>@=S6003IcUS
66<H00IS600=IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT01F<H00UW>F<H
HaQS66LiHaQW>F<HIcT00f<H00MW>F<HHaQS66LiHaQW>@03HaP00fLiHaQW
>@04HaP00fLiHaQS6004HaP00fLiHaQW>@04HaP00fLiHaQW>@08HaP01fLi
HaQW>F<HIcUS66Li00=S6003IcUS66<H009S600;IcUS66LiHaQW>F<HIcUS
66LiHaQW>@05HaP02fLiHaQW>F<HIcUS66LiHaQW>F<HIcT01f<H00=W>F<H
IcT016<H00=W>F<HIcT01F<H00eW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>@04HaP00fLiHaQW>@04HaP00fLiHaQW>@04HaP00fLiHaQW>@05HaP04FLi
HaQS66<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT00f<H01=W>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@06HaP00fLiHaQW>@03
HaP01FLiHaQS66<HIcT00f<H00=W>F<HHaP026<H02]W>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@0THaP00fLiHaQS600?HaP0
16LiHaQ240000G>L00000fLiOomS600;HaP00fLiHaQS6009HaP00fLiHaQS
6002HaP00fLiHaQS6002HaP01FLiHaQW>F<HIcT02V<H00MW>F<HIcUS66Li
HaQW>@03HaP00fLiHaQW>@06HaP00fLiHaQW>@03HaP02FLiHaQW>F<HIcUS
66LiHaQW>@04HaP01fLiHaQW>F<HIcUS66Li00IS6003IcUS66Li00=S6003
IcUS66<H00MS600;IcUS66LiHaQW>F<HIcUS66LiHaQW>@04HaP01FLiHaQW
>F<HIcT016<H00UW>F<HHaQS66LiHaQW>F<HIcT01F<H01EW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcT016<H00EW>F<HHaQS
66Li00ES6007IcUS66LiHaQW>F<HIcT016<H00eW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>@06HaP02FLiHaQS66<HIcUS66LiHaQW>@05HaP00fLiHaQS
6007HaP02FLiHaQW>F<HIcUS66LiHaQW>@05HaP02fLiHaQW>F<HIcUS66Li
HaQW>F<HIcT01F<H00=W>F<HIcT00f<H00]W>F<HIcUS66LiHaQW>F<HIcUS
66Li00AS6007IcUS66LiHaQW>F<HIcT026<H00=W>F<HIcT00V<H00=W>F<H
IcT02f<H00=W>F<HIcT00f<H00=W>F<HHaP01f<H00EW>F<HIcUS66Li00ES
6003IcUS66Li00AS6009IcUS66LiHaQW>F<HIcUS66Li00ES6007IcUS66<H
HaQW>F<HIcT016<H00=W>F<HIcT016<H00=W>F<HIcT016<H00eW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>@09HaP00fLiHaQS6003HaP00fLiHaQS600;
HaP01fLiHaQW>F<HIcUS66Li00AS600EIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66Li02aS6004IcUS66<HIcT2HaP016LiHaQS
66Li0V<H00AW>F<HHaQW>@9S6003IcUS66<H00US6005IcUS66LiHaQW>@03
HaP03fLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>@03HaP1@Q010001
Li`00004HaQoof<HHaSo013o010l010016LiHaQ240000G>L000016LiOomS
66<H0P0@00<@Q48@@Q00348@00<Q200@0100o`0@o`0@:00@0V<H0D8@0@00
0G>L000016<HOomS66Li0P0@00<LicgW?NL01cgW00HLh240G^Mokek_8@So
013e010P0002010@00020102HaP1@Q010001Li`00004IcUoof<HHaP20100
1CgWOnmokekW?NL01Wo_00D00480OnmNkb48050040=ooe00409ooaD0409o
obT0409oo`H040=oool040D04003Oom2448@00a24003001ood8@00e24004
0000400@Ool>@Q001`00010046<HIcU24000005cW00000AS67ooHaQS6080
4003?NMokgo_008mi`03G^mokgo_009ok`06?Nm20240G^MNkacWD00@0Woo
D@0@0Woo500@0Woo:`0@0Woo1P0@0Wooo`0@1@0@00=oof<HHaP02f<H00=2
4000Ool03F<H00I24000010047ooIcT2HaP016LiHaQS66Li0V<H00IW>F<H
IcUS648@00020102HaP1@Q010001Li`00004IcUoof<HHaP201000cgWOnlm
i`03?NL00ek_Onmok`02?NL01Fm_8@1205k_8@P0100@17oo100@17oo0P0@
0Woo0P0@0Woo0P0@17oo0P0@0Woo00@047ooOol0409oo`8040Eoo`80409o
o`03011oogoo008040Aoo`<040=oo`h0409oo`L040Eoo`80409oo`@0409o
o`80409oo`L0409oo`@0409oo`<0409oo`<040Aoo`@040Eoo`80409oo`<0
409oo`X040Eoo`80409oo`@0409oo`L0409oo`<040Aoo`<040Eoo`03011o
ogoo0080409oo`<040Aoo`80409oo`80409oo`80409oo`80409oo`H0409o
ool040D04004OomW>F<HHaP60004HaP01D8@001oofLiHaP02@000V<H00E2
4000010047oo00eS6004@Q00000@0102HaP1@Q010001Li`00004HaQoof<H
HaP201001CgWOnmokgo_?NL01Wo_00DmicgP8@12224800<0409oo`80409o
o`80409oo`80409oo`03011oogoo0080409oo`03011oogoo0080409oo`04
011oogoo0102Ool0100@Oomoo`0@0Woo0P0@0Woo00<047ooOol00P0@0Woo
00<047ooOol00P0@0Woo00@047ooOol0409oo`d0409oo`H0409oo`<0409o
o`03011oogoo00@0409oo`80409oo`L0409oo`@0409oo`L0409oo`80409o
o`80409oo`<0409oo`03011oogoo00<0409oo`X0409oo`80409oo`L0409o
o`L0409oo`80409oo`80409oo`04011oogoo0103Ool00`0@Oomoo`020102
Ool20102Ool20102Ool00`0@Oomoo`020102Ool00`0@Oomoo`030102Ool6
0102Oooo0105010017ooHaQS66<H1P000V<H00EW>F<H@Q0007oo009S6003
001S66<H00ES6005001S66<H@Q000002010017ooHaQS66<H0P000V<H00AW
>F<H0000009S6008@Q00000@011W>F<H@Q00005cW00000AW>GooHaQS6080
4005?NMokgo_Onlmi`07Onl015k_000aR2481`0@0Woo0P0@0Woo1@0@0Woo
0P0@0Woo00<047ooOol01@0@0Woo00@047ooOol0409oo`03011oogoo0080
409oo`03011oogoo0080409oo`03011oogoo00L0409oo`h0409oo`H0409o
o`<0409oo`8040Ioo`<0409oo`@040Ioo`<0409oo`/0409oo`80409oo`H0
409oo`<0409oo`X0409oo`80409oo`L0409oo`L0409oo`80409oo`D0409o
o`80409oo`03011oogoo0080409oo`80409oo`D0409oo`80409oo`03011o
ogoo00<0409oo`H0409oool040D04003OomS66<H00]S6003@Q0007oo009S
6003001S66<H00ES6005001S66<H@Q00000201001GooHaQS66LiHaP00P00
0V<H0P000f<H00A240000100409S60524040005cW00000AS67ooHaQS6080
4005?NMokgo_OnlQ1002?NL00beP@P1Ni`03Onl00ek_8@PLi`070102Ool2
0102Ool50102Ool20102Ool00`0@Oomoo`04Ool0100@Oomoo`0@0Woo00<0
47ooOol00P0@1Goo00<047ooOol00P0@0Woo00<047ooOol01P0@0Woo1`0@
0goo1@0@0Woo1P0@0Woo0`0@0Woo0P0@0Woo0P0@0Woo100@0Woo0`0@0Woo
00<047ooOol0100@0Woo2`0@0Woo0P0@0Woo1P0@0Woo0`0@0Woo2P0@0Woo
0P0@0Woo1`0@0Woo1`0@0Woo0P0@0Woo1@0@0Woo0P0@0Woo00<047ooOol0
0P0@0Woo0P0@1Woo00<047ooOol00P0@0Woo00<047ooOol00`0@0Woo1P0@
0Wooo`0@1@0@00=oof<HHaP01f<H00MW>F<HIcUS648@001oo`02HaP00`00
HaQS6005HaP01@00HaQS648@00000P0@00=oofLiHaP00f<H10000V<H00AW
>F<H@Q000080409S60524040005cW00000AW>GooHaQS60804005?NMokgo_
Onlmi`02Onl02Ek_000YAS60@P1Nigo_7>LQ20040104Ool30102Ool20102
Ool01@0@Oomoogoo01000Woo00<047ooOol00P0@0Woo00@047ooOol0409o
o`03011oogoo00D0409oo`03011oogoo0080409oo`03011oogoo0080409o
o`04011oogoo0102Ool=0102Ool60102Ool30102Ool20102Ool20102Ool4
0102Ool40104Ool40102Ool80104Ool30102Ool60107Ool:0102Ool20102
Ool70102Ool70102Ool20102Ool20102Ool00`0@Oomoo`020102Ool00`0@
Oomoo`020102Ool20102Ool20102Ool01@0@Oomoogoo01000Woo00<047oo
Ool00`0@0Woo1P0@0Wooo`0@1@0@00Eoof<HIcUS66Li00US6006@Q0007oo
IcUS60000V<H00=W>F<HIcT00V<H00D006<HHaQ2400000804003OomS66<H
00AS608000ES6004@Q00000@0102HaP1@Q010001Li`00004HaQoof<HHaP2
01001CgWOnmokekW?NL00go_00HmifLi>LhQ1360@P0248@30102Ool70104
Ool20105Ool30104Ool20107Ool30104Ool20103Ool00`0@Oomoo`020104
Ool30103Ool>0102Ool60102Ool30102Ool30104Ool60102Ool30104Ool4
0102Ool70102Ool60102Ool60102Ool30102Ool:0105Ool80102Ool70102
Ool30104Ool20102Ool20102Ool01@0@Oomoogoo01000goo0P0@17oo0P0@
1Goo0P0@0goo0P0@0Woo1P0@0Wooo`0@1@0@00=oof<HHaP01F<H00=W>F<H
HaP00f<H00=24000Ool00V<H00<006LiHaP01F<H00D006<HHaQ240000080
4004OomS66<HIcT2HaP40002HaP016LiHaQ240000P0@0V<H0D8@0@000G>L
000016LiOomS66<H0P0@00Dmigo_G^m203gW00=ok`06G^mNmfmk@00`0360
0P000`0@0Woo3@0@0Woo700@0Woo7P0@0Woo1P0@0Woo0`0@0Woo0`0@17oo
1P0@0Woo100@0goo100@0Woo1`0@0Woo1P0@0Woo1P0@0Woo0`0@0Woo5`0@
0Woo1`0@0Woo9P0@0Woo0`0@0Woo1P0@0Wooo`0@1@0@00Moof<HHaQS66Li
HaQW>@03HaP01fLiHaQW>F<H@Q0007oo009S6003001S66<H00AS6006IcT0
06<HHaQ240000P0@00=oof<HHaP00V<H0P000V<H0P000f<H00Q240000100
46<HIcU240000G>L000016<HOomS66<H0P0@00@migo_OnmNi`8mi`=ok`05
?NM/ib`0@00`000200030102Ool20102Ool90102OolL0102OolN0102Ool6
0102Ool30102Ool40102Ool80102Ool30103Ool20104Ool70102Ool20102
Ool20102Ool30102Ool00`0@Oomoo`030102OolE0104Ool70102OolV0102
Ool30102Ool60102Oooo0105010017ooHaQS66Li1F<H00=W>F<HHaP00V<H
00=24000Ool00V<H2@000V<H00I24000010047ooIcT2HaP2000016<HIcUS
66<H0P000V<H00A240000100409S60524040005cW00000AW>GooHaQS6080
4005?NMokek_@P0mi`04Onl01ek_G>Mlib`0@00/000000@040Aoo`X0409o
ob00409ooaX040=oo`D0409oo`<0409oo`@0409oo`@040Ioo`@0409oo`@0
409oo`P040Aoo`@040Eoo`80409oo`<0409ooaL0409oo`P0409oobT0409o
o`H040=oool040D04003OomS66<H009S6003IcUS66Li00=S6008IcUS66<H
@Q0007ooIcUS60T0009S6005@Q00000@011oo`0<HaP00fLi@Q0000020102
HaP1@Q010001Li`00004HaQoof<HHaP2010013gWOnmokekW0SgW17o_00IN
kecWO>L/0400;03o013e01001GooHaQW>F<HIcT01F<H00MW>F<HHaQS648@
001oo`0=HaP01D8@0000400@Ool03F<H00A240000100409S60524040005c
W00000AW>GooHaQS608040047>0mib447>07?NL01B44G>Mlib`0<000o`0@
m@0@3goo00<007ooOol03Goo00<0000@01003goo00L0000@011S66Li@Q00
0001Li`00004HaQoof<HHaP>01000`00G>MLi`3o013o010[0102HaP1@Q01
0001Li`00004IcUoof<HHaSo013o010l010016<HIcU240000G>L00000f<H
OomS603oHaSoHaPmHaP016LiHaQ240000G>L00000fLiOomS6007HaP01fLi
HaQS66<HIcUS66Li009S6003IcUS66<H0?mS6?mS62aS60524040005cW000
00=S67ooOol0ogooogoo?goo0D8@0@000G>L0000ofLiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>@00ofLiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66Li
HaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>@00?FLiHaQW>F<HIcUS66LiHaQW>F<HIcUS
66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<H
IcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQW
>F<HIcUS66Li00IS6040005cW000\
\>"], "Picture",
  ImageSize->{579, 495},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization Cells", "ExampleSection",
  InitializationCell->True],

Cell[TextData[{
  "Read ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package Analog Insydes:"
}], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(Off[General::spell, \ General::spell1]; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \($NotebookDirectory = 
      ToFileName@
        First["\<FileName\>" /. NotebookInformation[EvaluationNotebook[]]]; \n
    PrependTo[$Path, $NotebookDirectory]; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(<< AnalogInsydes`; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SetDirectory[ToFileName[{$NotebookDirectory, "\<PSpice\>"}]]; \)\)], 
  "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(SetOptions[{DXFGraphics, BodePlot}, 
      Background \[Rule] RGBColor[1, 1, 1]]; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["", "ExampleSection",
  Editable->False,
  ShowGroupOpenCloseIcon->False],

Cell[TextData[StyleBox["Copyright \[Copyright] 1998-2000 by ITWM e.V.",
  FontWeight->"Bold"]], "Text",
  Editable->False,
  CellFrame->{{0, 0}, {0, 1}},
  CellMargins->{{0, 0}, {0, 7}},
  FontFamily->"Helvetica",
  FontSize->16,
  FontWeight->"Bold",
  Background->RGBColor[0.8, 0.8, 0.900008],
  CellTags->"$Id: Op741.nb,v 1.2 2000/06/08 12:29:41 halfmann Exp $"],

Cell[TextData[{
  ButtonBox["Analog Insydes",
    ButtonData:>{
      URL[ "http://www.itwm.uni-kl.de/as/products/ai"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["ITWM",
    ButtonData:>{
      URL[ "http://www.itwm.uni-kl.de/"], None},
    ButtonStyle->"Hyperlink"],
  " - Institut f\[UDoubleDot]r Techno- und Wirtschaftsmathematik e.V.\n\
Gottlieb-Daimler-Str.\nD-67663 Kaiserslautern, Germany\n\nAnalog Insydes is a \
trademark of ITWM.\n",
  StyleBox["Mathematica", "TI"],
  " is a registered trademark of Wolfram Research, Inc.\nAll other product \
names are trademarks of their respective owners."
}], "Text",
  Editable->False,
  CellMargins->{{0, 12}, {0, 0}},
  Background->RGBColor[0.8, 0.8, 0.900008]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 836}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
InitializationCellWarning->False,
CellGrouping->Manual,
WindowSize->{650, 699},
WindowMargins->{{97, Automatic}, {Automatic, 5}},
ButtonBoxOptions->{Active->True,
ButtonStyle->None},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
$Id: DemoStyleSheet.nb,v 1.5 1999/02/10 08:00:23 wichmann Exp $\
\>", "Text"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->18],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->11,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "Book"],
    PageWidth->PaperWidth,
    ShowCellTags->False,
    ScriptMinSize->5,
    FontSize->13.75,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "Header"]}, {Cell[ 
            TextData[ {"Printed from the ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              " Help Browser"}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            TextData[ {"\[Copyright]1999 ITWM e.V. All rights reserved."}], 
            "Footer"], None}, {None, Cell[ 
            TextData[ {"\[Copyright]1999 ITWM e.V. All rights reserved."}], 
            "Footer"], None}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"PrintingMargins"->{{54, 54}, {108, 72}},
    "PaperSize"->{597.563, 842.375},
    "PaperOrientation"->"Portrait",
    "PrintCellBrackets"->False,
    "PrintRegistrationMarks"->False,
    "PrintMultipleHorizontalPages"->False,
    "FirstPageHeader"->False,
    "FirstPageFooter"->False,
    "FacingPages"->True,
    "FirstPageFace"->Right},
    ShowCellBracket->False,
    CellLabelAutoDelete->True,
    DefaultNewCellStyle->"Input",
    DefaultDuplicateCellStyle->"Text",
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.900008, 0.940002]],
  
  Cell[StyleData["Notebook", "Book"],
    PrintingCopies->1,
    PrintingPageRange->{Automatic, Automatic},
    PageFooters->{{None, None, None}, {None, None, None}},
    PageFooterLines->{False, False}],
  
  Cell[StyleData["Notebook", "Printout"],
    PrintingCopies->1,
    PrintingPageRange->{Automatic, Automatic},
    PageFooters->{{None, None, None}, {None, None, None}},
    PageFooterLines->{False, False},
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->28,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->42],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->26],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->28],
  
  Cell[StyleData["Title", "Book"],
    CellMargins->{{2.5, 12.5}, {15, 37.5}},
    FontSize->35]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellFrame->2,
    CellMargins->{{12, 12}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    Background->RGBColor[0.8, 0.8, 0.900008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Book"],
    CellMargins->{{2.5, 12.5}, {15, 10}},
    FontSize->30]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->20,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->30],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->18],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->20],
  
  Cell[StyleData["Subsubtitle", "Book"],
    CellMargins->{{2.5, 12.5}, {15, 10}},
    FontSize->25]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->16],
  
  Cell[StyleData["Section", "Book"],
    CellMargins->{{16.25, 0}, {8.75, 27.5}},
    FontSize->20]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExampleSection"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExampleSection", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["ExampleSection", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->14],
  
  Cell[StyleData["ExampleSection", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->16],
  
  Cell[StyleData["ExampleSection", "Book"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16.25, 0}, {8.75, 27.5}},
    FontSize->20]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->21],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Book"],
    CellMargins->{{11.25, 0}, {8.75, 27.5}},
    FontSize->17.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->8},
    CellGroupingRules->{"SectionGrouping", 50},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionIcon", "Printout"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{16, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->14],
  
  Cell[StyleData["SubsectionIcon", "Book"],
    CellDingbat->"\[FilledSquare]",
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{20, 0}, {0, 22.5}},
    PageBreakBelow->False,
    FontSize->17.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionIcon"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{24, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellGroupingRules->{"SectionGrouping", 60},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubection", 0}},
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionIcon", "Printout"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2, 0}, {0, 18}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["SubsubsectionIcon", "Book"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{2.5, 0}, {0, 22.5}},
    PageBreakBelow->False,
    FontSize->13.75]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{24, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{8, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 0}, {7, 22}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Book"],
    CellMargins->{{2.5, 0}, {8.75, 27.5}},
    FontSize->15]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1],
  
  Cell[StyleData["Text", "Book"],
    CellMargins->{{2.5, 2.5}, {7.5, 7.5}},
    TextJustification->1]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CommentInput"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"CommentInput",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["CommentInput", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["CommentInput", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2}],
  
  Cell[StyleData["CommentInput", "Printout"],
    CellMargins->{{2, 2}, {5, 5}}],
  
  Cell[StyleData["CommentInput", "Book"],
    CellMargins->{{2.5, 2.5}, {6.25, 6.25}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Comment"],
    CellMargins->{{12, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Comment",
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Comment", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Comment", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2}],
  
  Cell[StyleData["Comment", "Printout"],
    CellMargins->{{2, 2}, {5, 5}}],
  
  Cell[StyleData["Comment", "Book"],
    CellMargins->{{2.5, 2.5}, {6.25, 6.25}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names. \
Some attributes for these styles are actually set in FormatType Styles (in \
the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    ShowCellBracket->True,
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Left,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.829999, 0.829999, 0.900008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    TextAlignment->Left,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    TextAlignment->Left],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    TextAlignment->Left],
  
  Cell[StyleData["Input", "Book"],
    CellMargins->{{48.75, 0}, {5, 7.5}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[StyleData["InputOnly"],
    ShowCellBracket->True,
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Left,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    ShowCellBracket->True,
    CellMargins->{{45, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    TextJustification->0.25,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    Background->RGBColor[0.949996, 0.949996, 0.979995],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}}],
  
  Cell[StyleData["Output", "Book"],
    CellMargins->{{48.75, 0}, {7.5, 5}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{47, 10}, {7, 5}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    TextJustification->0.25,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Program",
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{39, 0}, {6, 4}}],
  
  Cell[StyleData["Program", "Book"],
    CellMargins->{{48.75, 0}, {7.5, 5}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    ShowCellBracket->True,
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Book"],
    CellMargins->{{48.75, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Book"],
    CellMargins->{{48.75, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    ShowCellBracket->False,
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Left,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8],
  
  Cell[StyleData["Graphics", "Book"],
    ImageMargins->{{37.5, Inherited}, {Inherited, 0}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Book"],
    FontFamily->"Courier",
    FontSize->10,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}],
  
  Cell[StyleData["InlineFormula", "Book"],
    CellMargins->{{2.5, 0}, {7.5, 7.5}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->7],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Book"],
    CellMargins->{{2.5, 2.5}, {6.25, 6.25}},
    FontSize->11.25]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Book"],
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->14,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SubsectionHyperlink", "Presentation"],
    FontSize->21],
  
  Cell[StyleData["SubsectionHyperlink", "Condensed"],
    FontSize->12],
  
  Cell[StyleData["SubsectionHyperlink", "Printout"],
    FontSize->14,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["SubsectionHyperlink", "Book"],
    FontSize->14,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Book"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Book"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Book"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Book"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AITopicLink"],
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AITopicLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AITopicLink", "Book"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Book"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["M4"],
    ShowCellBracket->True,
    StyleMenuListing->None,
    FontFamily->"Math4",
    CharacterEncoding->"Math4"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Book"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8.75,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1", "Book"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["C1MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->RGBColor[0.4, 0, 1]],
  
  Cell[StyleData["C1MR", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["C1MR", "Book"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Emphasis Boxes and Pictures", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Box"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["Box", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Box", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DoubleBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->2,
    RowAlignments->Top}],
  
  Cell[StyleData["DoubleBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DoubleBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["1ColumnBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.31, 0.62}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.46}],
  
  Cell[StyleData["2ColumnEvenBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnEvenBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["2ColumnSmallBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{RowSpacings->2,
    ColumnWidths->{0.2, 0.15, 0.58}}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.24,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["3ColumnSmallBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.33, 0.13, 0.33}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["4ColumnBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.194}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["5ColumnBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.12, 0.22, 0.12, 0.12, 0.22, 0.12}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 0}, {0, 8}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["6ColumnBox", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedNoteBox"],
    CellFrame->0.5,
    CellMargins->{{37, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["ItemizedNoteBox", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["ItemizedNoteBox", "Book"],
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineSpacing->{1.2, 1},
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{RowSpacings->2,
    ColumnSpacings->1,
    ColumnWidths->{0.3, 0.7},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox3Col"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineSpacing->{1.2, 1},
    LineIndent->0,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.6, 0.6],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{RowSpacings->2,
    ColumnSpacings->1,
    ColumnWidths->{0.2, 0.15, 0.65},
    ColumnAlignments->{Left},
    RowLines->{True, False}}],
  
  Cell[StyleData["DefinitionBox3Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox3Col", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox4Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.15, 0.35, 0.15, 0.35},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox4Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox4Col", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox5Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox5Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox5Col", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DefinitionBox6Col"],
    CellFrame->0.5,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["DefinitionBox6Col", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["DefinitionBox6Col", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    LineSpacing->{1.2, 1},
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->2,
    ColumnSpacings->1,
    ColumnWidths->{0.3, 0.7},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["TopBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 0}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.31, 0.62},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleBox", "Printout"],
    CellMargins->{{2, 4}, {0, 0}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["MiddleBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 0}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BottomBox"],
    CellFrame->{{0.5, 0.5}, {0.5, 0}},
    CellMargins->{{11, 4}, {0, -7}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    LineSpacing->{1.2, 1},
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->2,
    ColumnSpacings->1,
    ColumnWidths->{0.3, 0.7},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["BottomBox", "Printout"],
    CellMargins->{{2, 4}, {0, -5}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["BottomBox", "Book"],
    CellMargins->{{2.5, 5}, {0, -6.25}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TopSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0.5}},
    CellMargins->{{11, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["TopSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 10}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["TopSpanBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MiddleSpanBox"],
    CellFrame->{{0.5, 0.5}, {0, 0}},
    CellMargins->{{11, 4}, {0, 0}},
    CellHorizontalScrolling->True,
    PageBreakBelow->False,
    AutoIndent->False,
    AutoSpacing->False,
    LineIndent->0,
    StyleMenuListing->None,
    FontWeight->"Plain",
    Background->RGBColor[1, 0.6, 0.6],
    GridBoxOptions->{RowSpacings->1.5,
    ColumnSpacings->1,
    ColumnWidths->{0.9, 0.03},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["MiddleSpanBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["MiddleSpanBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{60, Inherited}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowCellLabel->False,
    CounterIncrements->"Figure",
    StyleMenuListing->None],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{30, 0}, {0, 8}}],
  
  Cell[StyleData["Picture", "Book"],
    CellMargins->{{30, 0}, {0, 10}}]
  }, Open  ]],
  
  Cell[StyleData["PictureHeading"],
    ShowGroupOpenCloseIcon->True,
    CellMargins->{{60, 10}, {5, 7}},
    Evaluatable->False,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    TextAlignment->Left,
    AutoItalicWords->{},
    ShowStringCharacters->True,
    NumberMarks->True,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["PictureOutput"],
    CellMargins->{{60, Inherited}, {0, 8}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    ShowCellLabel->False,
    CounterIncrements->"Figure",
    StyleMenuListing->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedPicture"],
    CellMargins->{{35, 4}, {0, 4}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["ItemizedPicture", "Printout"],
    CellMargins->{{27, 0}, {0, 4}}],
  
  Cell[StyleData["ItemizedPicture", "Book"],
    CellMargins->{{33.75, 0}, {0, 5}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["PictureGroup", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Sound"],
    CellMargins->{{10, Inherited}, {0, 8}},
    StyleMenuListing->None],
  
  Cell[StyleData["Sound", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["Sound", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{60, 4}, {10, 3}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{30, 0}, {10, 3}},
    FontSize->7],
  
  Cell[StyleData["Caption", "Book"],
    CellMargins->{{30, 0}, {12.5, 3.75}},
    FontSize->8.75]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BoxCaption"],
    CellMargins->{{10, 4}, {0, 8}},
    PageBreakAbove->False,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["BoxCaption", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->7],
  
  Cell[StyleData["BoxCaption", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->8.75]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.34, 0.64},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["2ColumnTable", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnEvenTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.49,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnEvenTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["2ColumnEvenTable", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->{0.28, 0.28, 0.43},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 0}, {0, 8}}],
  
  Cell[StyleData["3ColumnTable", "Book"],
    CellMargins->{{2.5, 0}, {0, 10}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Misc AI Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ModelBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    LineSpacing->{1.2, 1},
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LineIndent->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->GrayLevel[0.8],
    FontVariations->{"Underline"->False},
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}}],
  
  Cell[StyleData["ModelBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.949996]],
  
  Cell[StyleData["ModelBox", "Book"],
    CellMargins->{{2.5, 5}, {0, 10}},
    FontSize->12.5,
    Background->GrayLevel[0.949996]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AICopyright"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["AICopyright", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    TextAlignment->Left,
    LineSpacing->{1, 0}],
  
  Cell[StyleData["AICopyright", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}}],
  
  Cell[StyleData["AICopyright", "Printout"],
    CellMargins->{{2, 10}, {12, 30}}],
  
  Cell[StyleData["AICopyright", "Book"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakAbove->True,
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AIAddress"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["AIAddress", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["AIAddress", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["AIAddress", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1],
  
  Cell[StyleData["AIAddress", "Book"],
    CellMargins->{{0, 0}, {0, 0}},
    TextJustification->1,
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AIHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["AIHyperlink", "Presentation"]],
  
  Cell[StyleData["AIHyperlink", "Condensed"]],
  
  Cell[StyleData["AIHyperlink", "Printout"],
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AIHyperlink", "Book"],
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PermissionText"],
    CellMargins->{{12, 10}, {7, 7}},
    Evaluatable->False,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.501961]],
  
  Cell[StyleData["PermissionText", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 0},
    FontSize->15],
  
  Cell[StyleData["PermissionText", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    FontSize->8],
  
  Cell[StyleData["PermissionText", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->8],
  
  Cell[StyleData["PermissionText", "Book"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->1,
    FontColor->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Task"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Task", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->21],
  
  Cell[StyleData["Task", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->12],
  
  Cell[StyleData["Task", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->12],
  
  Cell[StyleData["Task", "Book"],
    CellMargins->{{2.5, 2.5}, {7.5, 7.5}},
    FontSize->15]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text",
    FontSize->12],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text",
    FontSize->12],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

